/**
 * @file
 * @brief    @ref ModbusFunction65 "ModbusFunction65".
 *
 *          
 *  65 Modbus    "".     
 *  ,     ,      ,
 *   65 Modbus.
 */

#include <stdlib.h>
#include <stdio.h>
#include <stdbool.h>
#include <stdint.h>
#include <string.h>
#include <windows.h>
#include "modbus.h"
#include "modbus-private.h"
#include "modbus-rtu-private.h"
#include "ByteOrderingConverter.h"
#include "ModbusFunction65.h"

/**
 * @addtogroup ModbusFunction65
 * @{
 */

/*=======================================  ======================================*/

#define MBF65_FUNCTION_CODE  65

#define MBF65_DELAY_AFTER_EXCEPTION_MS  300

/*========================================   ==========================================*/

/** @brief    ,    65. */
typedef enum mbf65_FileOpenMode_TAG
{
	/** @brief &mdash;           ; */
	MBF65_FOM_CREATE_OR_REWRITE = 0,

	/** @brief &mdash;   ; */
	MBF65_FOM_CREATE_ONLY = 1,

	/** @brief &mdash;     ; */
	MBF65_FOM_OPEN_FOR_READING = 2,

	/** @brief &mdash;  . */
	MBF65_FOM_CLOSED = 3
} mbf65_FileOpenMode;
/*-----------------------------------------------------------------------------------------------*/
/** @brief       65  MODBUS. */
typedef enum mbf65_ResponseType_TAG
{
	MBF65_RT_SHORT = 0,
	MBF65_RT_LONG = 1
} mbf65_ResponseType;
/*-----------------------------------------------------------------------------------------------*/
/** @brief     -. */
typedef enum mbf65_FlashInfoType_TAG
{
	MBF65_FIT_ALL_INFO = 0,
	MBF65_FIT_EVENT_LOG = 1,
	MBF65_FIT_MESSAGE_LOG = 2,
	MBF65_FIT_SETTINGS_LOG = 3,
	MBF65_FIT_OSCILLOGRAPH = 4,
	MBF65_FIT_FLASH_SPACE = 5,
	MBF65_FIT_ALARM_ACK_LOG = 6,
	MBF65_FIT_FAULT_LOCATION_LOG = 7,

	MBUF65_NUMBER_OF_TYPES = 7
} mbf65_FlashInfoType;
/*-----------------------------------------------------------------------------------------------*/
#pragma pack(push, 1)
/** @brief   MODBUS PDU   65. */
typedef struct mbf65_PDUHeading_TAG
{
	uint8_t function;		/**< @brief   MODBUS (65). */
	uint8_t subfunction;	/**< @brief    MODBUS 65. */
	uint8_t requestNo;		/**< @brief   . */
	uint8_t dataSize;		/**< @brief     . */
} mbf65_PDUHeading;
#pragma pack(pop)
/*-----------------------------------------------------------------------------------------------*/
#pragma pack(push, 1)
/** @brief  MODBUS PDU   65. */
typedef struct mbf65_PDU_TAG
{
	mbf65_PDUHeading heading;	/**< @brief . */
	uint8_t pData[];			/**< @brief  . */
} mbf65_PDU;
#pragma pack(pop)
/*-----------------------------------------------------------------------------------------------*/
#pragma pack(push, 1)
/** @brief    . */
typedef union mbf65_ResponseStatus_TAG
{
	/** @brief      . */
	uint8_t value;

	/** @brief    . */
	struct
	{
		/** @brief   (. #mbf65_ResponseCode). */
		uint8_t code : 7;

		/** @brief   (0 - , 1 - ). */
		uint8_t type : 1;
	} fields;
} mbf65_ResponseStatus;
#pragma pack(pop)
/*-----------------------------------------------------------------------------------------------*/
#pragma pack(push, 1)
/** @brief    PDU  . */
typedef struct mbf65_ShortResponsePDU_TAG
{
	mbf65_PDUHeading pduHeading;         /**< @brief  MODBUS PDU. */
	mbf65_ResponseStatus responseStatus; /**< @brief  . */
	uint8_t pResponseData[];             /**< @brief  . */
} mbf65_ShortResponsePDU;
#pragma pack(pop)
/*-----------------------------------------------------------------------------------------------*/
#pragma pack(push, 1)
/** @brief    PDU  . */
typedef struct mbf65_LongResponseHeading_TAG
{
	uint8_t pDataSize[4];			/**< @brief    . */
} mbf65_LongResponseHeading;
#pragma pack(pop)
/*-----------------------------------------------------------------------------------------------*/
#pragma pack(push, 1)
/** @brief    PDU  . */
typedef struct mbf65_LongResponsePDU_TAG
{
	mbf65_PDUHeading pduHeading;                   /**< @brief  MODBUS PDU. */
	mbf65_ResponseStatus responseStatus;           /**< @brief  . */
	mbf65_LongResponseHeading longResponseHeading; /**< @brief   . */
} mbf65_LongResponsePDU;
#pragma pack(pop)
/*-----------------------------------------------------------------------------------------------*/
#pragma pack(push, 1)
/** @brief      #MBF65_SC_OPEN_FILE. */
typedef struct mbf65_OpenFileRequestData_TAG
{
	uint8_t openMode;	/**< @brief    (#mbf65_FileOpenMode). */
	char pathName[];	/**< @brief      . */
} mbf65_OpenFileRequestData;
#pragma pack(pop)
/*-----------------------------------------------------------------------------------------------*/
#pragma pack(push, 1)
/** @brief        #MBF65_SC_OPEN_FILE 
 *         #MBF65_SC_OPEN_FILE_COMPRESSED. */
typedef struct mbf65_OpenFileResponseData_TAG
{
	uint8_t fileID;					/**< @brief  . */
	uint8_t fileSize[4];			/**< @brief  . */
	uint8_t modificationTime[8];	/**< @brief    . */
} mbf65_OpenFileResponseData;
#pragma pack(pop)
/*-----------------------------------------------------------------------------------------------*/
#pragma pack(push, 1)
/** @brief      #MBF65_SC_WRITE_FILE. */
typedef struct mbf65_WriteFileRequestData_TAG
{
	uint8_t fileID;		/**< @brief  . */
	uint8_t offset[4];	/**< @brief    . */
	uint8_t pData[];	/**< @brief   . */
} mbf65_WriteFileRequestData;
#pragma pack(pop)
/*-----------------------------------------------------------------------------------------------*/
#pragma pack(push, 1)
/** @brief        #MBF65_SC_WRITE_FILE. */
typedef struct mbf65_WriteFileResponseData_TAG
{
	uint8_t fileID;		/**< @brief  . */
	uint8_t offset[4];	/**< @brief    . */
	uint8_t length;		/**< @brief  . */
} mbf65_WriteFileResponseData;
#pragma pack(pop)
/*-----------------------------------------------------------------------------------------------*/
#pragma pack(push, 1)
/** @brief      #MBF65_SC_READ_FILE. */
typedef struct mbf65_ReadFileRequestData_TAG
{
	uint8_t fileID;		/**< @brief  . */
	uint8_t offset[4];	/**< @brief    . */
	uint8_t length;		/**< @brief  . */
} mbf65_ReadFileRequestData;
#pragma pack(pop)
/*-----------------------------------------------------------------------------------------------*/
#pragma pack(push, 1)
/** @brief        #MBF65_SC_READ_FILE. */
typedef struct mbf65_ReadFileResponseData_TAG
{
	uint8_t fileID;		/**< @brief  . */
	uint8_t offset[4];	/**< @brief    . */
	uint8_t pData[];	/**< @brief  . */
} mbf65_ReadFileResponseData;
#pragma pack(pop)
/*-----------------------------------------------------------------------------------------------*/
#pragma pack(push, 1)
/** @brief      #MBF65_SC_CLOSE_FILE 
 *         #MBF65_SC_CLOSE_FILE_COMPRESSED. */
typedef struct mbf65_CloseFileRequestData_TAG
{
	uint8_t fileID;	/**< @brief  . */
} mbf65_CloseFileRequestData;
#pragma pack(pop)
/*-----------------------------------------------------------------------------------------------*/
#pragma pack(push, 1)
/** @brief      #MBF65_SC_OPEN_FILE_COMPRESSED. */
typedef struct mbf65_OpenFileCompressedRequestData_TAG
{
	uint8_t openMode;			/**< @brief    (#mbf65_FileOpenMode). */
	uint8_t compressionType;	/**< @brief    (#mbf65_CompressionType). */
	char pathName[];			/**< @brief      . */
} mbf65_OpenFileCompressedRequestData;
#pragma pack(pop)
/*-----------------------------------------------------------------------------------------------*/
#pragma pack(push, 1)
/** @brief      #MBF65_SC_WRITE_FILE_COMPRESSED. */
typedef struct mbf65_WriteFileCompressedRequestData_TAG
{
	uint8_t fileID;		/**< @brief  . */
	uint8_t offset[4];	/**< @brief    . */
	uint8_t pData[];	/**< @brief   . */
} mbf65_WriteFileCompressedRequestData;
#pragma pack(pop)
/*-----------------------------------------------------------------------------------------------*/
#pragma pack(push, 1)
/** @brief        #MBF65_SC_WRITE_FILE_COMPRESSED. */
typedef struct mbf65_WriteFileCompressedResponseData_TAG
{
	uint8_t fileID;		/**< @brief  . */
} mbf65_WriteFileCompressedResponseData;
#pragma pack(pop)
/*-----------------------------------------------------------------------------------------------*/
#pragma pack(push, 1)
/** @brief      #MBF65_SC_READ_FILE_COMPRESSED. */
typedef struct mbf65_ReadFileCompressedRequestData_TAG
{
	/** @brief  . */
	uint8_t fileID;

	/** @brief  ,     ,    
	 *         . */
	uint8_t nexCompressedOffset[4];
} mbf65_ReadFileCompressedRequestData;
#pragma pack(pop)
/*-----------------------------------------------------------------------------------------------*/
#pragma pack(push, 1)
/** @brief        #MBF65_SC_READ_FILE_COMPRESSED. */
typedef struct mbf65_ReadFileCompressedResponseData_TAG
{
	/** @brief  . */
	uint8_t fileID;

	/** @brief      () . */
	uint8_t originalOffset[4];

	/** @brief       . */
	uint8_t compressedOffset[4];

	/** @brief    . */
	uint8_t pData[];
} mbf65_ReadFileCompressedResponseData;
#pragma pack(pop)
/*-----------------------------------------------------------------------------------------------*/
#pragma pack(push, 1)
/** @brief      #MBUF65_SC_APPLY_PROJECT. */
typedef struct mbf65_ApplyProjectRequestData_TAG
{
	/** @brief     (. #mbf65_ProjectApplicationMethod). */
	uint8_t method;
} mbf65_ApplyProjectRequestData;
#pragma pack(pop)
/*-----------------------------------------------------------------------------------------------*/
#pragma pack(push, 1)
/** @brief        #MBUF65_SC_GET_BUFFER_INFO. */
typedef struct mbf65_BufferInfoResponseData_TAG
{
	uint8_t size[4];	/**< @brief     . */
} mbf65_BufferInfoResponseData;
#pragma pack(pop)
/*-----------------------------------------------------------------------------------------------*/
#pragma pack(push, 1)
/** @brief      #MBUF65_SC_READ_BUFFER. */
typedef struct mbf65_ReadBufferRequestData_TAG
{
	uint8_t offset[4];	/**< @brief     . */
	uint8_t size;		/**< @brief  . */
} mbf65_ReadBufferRequestData;
#pragma pack(pop)
/*-----------------------------------------------------------------------------------------------*/
#pragma pack(push, 1)
/** @brief        #MBUF65_SC_READ_BUFFER. */
typedef struct mbf65_ReadBufferResponseData_TAG
{
	uint8_t offset[4];	/**< @brief     . */
	uint8_t pData[];	/**< @brief . */
} mbf65_ReadBufferResponseData;
#pragma pack(pop)
/*-----------------------------------------------------------------------------------------------*/
#pragma pack(push, 1)
/**
 * @brief        #MBUF65_SC_GET_NUMBER_OF_OSCILLOGRAMS.
 */
typedef struct mbf65_GetNumberOfOscillogramsResponseData_TAG
{
	uint8_t numberOfOscillograms[2];	/**< @brief  . */
} mbf65_GetNumberOfOscillogramsResponseData;
#pragma pack(pop)
/*-----------------------------------------------------------------------------------------------*/
#pragma pack(push, 1)
/** @brief      #MBUF65_SC_GET_OSCILLOGRAM_INFO. */
typedef struct mbf65_GetOscillogramInfoRequestData_TAG
{
	/**
	 * @brief   (   0; 0   
	 *        ).
	 */
	uint8_t oscillogramNo[2];

	/** @brief  . */
	uint8_t numberOfOscillograms[2];
} mbf65_GetOscillogramInfoRequestData;
#pragma pack(pop)
/*-----------------------------------------------------------------------------------------------*/
#pragma pack(push, 1)
/**
 * @brief         
 *        #MBUF65_SC_GET_OSCILLOGRAM_INFO.
 */
typedef struct mbf65_OscillogramInfo_TAG
{
	/** @brief        . */
	uint8_t timestamp[8];

	/** @brief    . */
	uint8_t duration[4];

	/** @brief     . */
	uint8_t fileSize[4];

	/**
	 * @brief  ,     
	 *        (. #osc_SignalTypeForOscillogramInfo).
	 */
	uint8_t signalType[1];

	/** @brief  ,     . */
	uint8_t signalID[2];
} mbf65_OscillogramInfo;
#pragma pack(pop)
/*-----------------------------------------------------------------------------------------------*/
#pragma pack(push, 1)
/** @brief      #MBUF65_SC_GET_FLASH_INFO. */
typedef struct mbf65_GetFlashInfoRequestData_TAG
{
	uint8_t infoType;	/**< @brief    (. #mbf65_FlashInfoType). */
} mbf65_GetFlashInfoRequestData;
#pragma pack(pop)
/*-----------------------------------------------------------------------------------------------*/
#pragma pack(push, 1)
/**
 * @brief          #MBUF65_SC_GET_FLASH_INFO.
 */
typedef struct mbf65_LogInfo_TAG
{
	uint8_t logVersion[4];				/**< @brief   . */
	uint8_t softwareVersion[4];			/**< @brief  ,  . */
	uint8_t recordSize[4];				/**< @brief   . */
	uint8_t maxNumberOfRecords[4];		/**< @brief     . */
	uint8_t currentNumberOfRecords[4];	/**< @brief     . */
	uint8_t lastRecordID[8];			/**< @brief    . */
	uint8_t lastRecordTimestamp[8];		/**< @brief     . */
} mbf65_LogInfo;
#pragma pack(pop)
/*-----------------------------------------------------------------------------------------------*/
#pragma pack(push, 1)
/**
 * @brief         
 *        #MBUF65_SC_GET_FLASH_INFO.
 */
typedef struct mbf65_OscillographInfo_TAG
{
	/** @brief  . */
	uint8_t numberOfOscillograms[4];

	/** @brief    ( ) . */
	mbf65_OscillogramInfo latestOscillogram;
} mbf65_OscillographInfo;
#pragma pack(pop)
/*-----------------------------------------------------------------------------------------------*/
#pragma pack(push, 1)
/**
 * @brief    -     
 *        #MBUF65_SC_GET_FLASH_INFO.
 */
typedef struct mbf65_FlashInfo_TAG
{
	uint8_t totalSize[4]; 		/**< @brief   -  . */
	uint8_t sizeOfFreeSpace[4];	/**< @brief     . */
} mbf65_FlashInfo;
#pragma pack(pop)
/*-----------------------------------------------------------------------------------------------*/
#pragma pack(push, 1)
/**
 * @brief      #MBUF65_SC_GET_FULL_LOG_RECORDS 
 *        #MBUF65_SC_GET_BRIEF_LOG_RECORDS.
 */
typedef struct mbf65_GetLogRecordsRequestData_TAG
{
	uint8_t logType;			/**< @brief    (. #mbf65_LogType). */
	uint8_t recordNo[4];		/**< @brief    . */
	uint8_t numberOfRecords[4];	/**< @brief  . */
} mbf65_GetLogRecordsRequestData;
#pragma pack(pop)
/*-----------------------------------------------------------------------------------------------*/
#pragma pack(push, 1)
/**
 * @brief        #MBUF65_SC_GET_FULL_LOG_RECORDS 
 *        #MBUF65_SC_GET_BRIEF_LOG_RECORDS.
 */
typedef struct mbf65_GetLogRecordsResponseData_TAG
{
	uint8_t recordNo[4];		/**< @brief    . */
	uint8_t numberOfRecords[4];	/**< @brief  . */
	uint8_t records[];			/**< @brief  . */
} mbf65_GetLogRecordsResponseData;
#pragma pack(pop)
/*-----------------------------------------------------------------------------------------------*/
#pragma pack(push, 1)
/** @brief      #MBUF65_SC_FETCH_LOG_RECORDS. */
typedef struct mbf65_FetchLogRecordsRequestData_TAG
{
	uint8_t logType;			/**< @brief    (. #mbf65_LogType). */
	uint8_t startOfPeriod[8];	/**< @brief  . */
	uint8_t endOfPeriod[8];		/**< @brief  . */
} mbf65_FetchLogRecordsRequestData;
#pragma pack(pop)
/*-----------------------------------------------------------------------------------------------*/
#pragma pack(push, 1)
/**
 * @brief    (     
 *        #MBUF65_SC_GET_DESCRIPTOR_OF_EVENT_LOG_RECORD).
 */
typedef struct mbf65_EventLogEventDescriptor_TAG
{
	uint8_t id[2];								/**< @brief  . */
	uint8_t name[MBUF65_MAX_EVENT_NAME_LENGTH];	/**< @brief  . */
} mbf65_EventLogEventDescriptor;
#pragma pack(pop)
/*-----------------------------------------------------------------------------------------------*/
#pragma pack(push, 1)
/**
 * @brief      (    
 *         #MBUF65_SC_GET_DESCRIPTOR_OF_EVENT_LOG_RECORD).
 */
typedef struct mbf65_EventLogAOSDescriptor_TAG
{
	uint8_t id[2];	/**< @brief    . */
	uint8_t units;	/**< @brief   (. #mbf65_UnitOfMeasureID). */
} mbf65_EventLogAOSDescriptor;
#pragma pack(pop)

/*==========================================  =========================================*/

static uint8_t s_requestNo = 0;

/*===========================================  =========================================*/

static const char* s_pOSCILLOGRAM_NAME_FORMAT = "/OSC/%04u.cff";

/*======================================   ======================================*/

static void dump_bytes(FILE* pFile, const void* pData, uint32_t dataSize);

static int receiveUF65Response(HANDLE comPort, void* pBuffer, int bufferSize);

static bool readResponse(modbus_t* pModbus, uint8_t address, const void* pResponseBuffer,
	uint16_t responseDataSize, bool isLongResponse, void* pBuffer, uint32_t bufferSize, 
	uint32_t skipBytes, uint32_t* pNumberOfBytesRead);


static int readLogRecords(modbus_t* pModbus, uint8_t address, mbf65_FlashInfoType logType,
	uint32_t recordSize, bool full, uint32_t firstRecordNumber, uint32_t numberOfRecordsToRead,
	void* pBuffer, uint32_t bufferSize, uint32_t* pNumberOfRecordsRead);

static void convertEventLogDescriptorToHostEndianness(void* pDescriptor);

static void* convertIDArrayToHostEndianness(uint16_t* pIDArray);

extern int _modbus_rtu_check_integrity(modbus_t *ctx, uint8_t *msg, const int msg_length);

/*==========================================  ============================================*/

bool mbf65_sendRequest(modbus_t* pModbus, uint8_t address, uint8_t subfunction,
                       const void* pRequestData, uint16_t requestDataSize, void* pResponseBuffer, 
                       uint16_t responseBufferSize, uint16_t* pResponseDataSize, 
                       mbf65_ResponseCode* pResponseCode, bool* pIsLongResponse)
{
	bool success = false;

	*pResponseCode = MBF65_RC_SUCCESS;
	*pIsLongResponse = false;

	if (requestDataSize <= MODBUS_RTU_MAX_ADU_LENGTH - sizeof(mbf65_PDUHeading) - sizeof(uint16_t))
	{
		uint8_t exceptionCode = MODBUS_EXCEPTION_MAX;

		do
		{
			uint8_t pADU[MODBUS_RTU_MAX_ADU_LENGTH];
			mbf65_PDU* pPDU = (mbf65_PDU*)&pADU[1];
			int bytesSent;
			int requestSize;

			exceptionCode = MODBUS_EXCEPTION_MAX;

			pADU[0] = address;
			pPDU->heading.function = MBF65_FUNCTION_CODE;
			pPDU->heading.subfunction = subfunction;
			pPDU->heading.requestNo = s_requestNo;
			pPDU->heading.dataSize = (uint8_t)requestDataSize;

			memcpy(pPDU->pData, pRequestData, requestDataSize);

			requestSize = sizeof(uint8_t) + sizeof(mbf65_PDUHeading) + requestDataSize;
			bytesSent = modbus_send_raw_request(pModbus, pADU, requestSize);
			if (bytesSent == requestSize + sizeof(uint16_t))
			{
				int bytesReceived;

//				fprintf(stdout, "%s(): Sent %u bytes:\n", __func__, bytesSent);
//				dump_bytes(stdout, pADU, bytesSent);

				bytesReceived = receiveUF65Response(
									((modbus_rtu_t*)pModbus->backend_data)->w_ser.fd, pADU,
									MODBUS_RTU_MAX_ADU_LENGTH);

				if (_modbus_rtu_check_integrity(pModbus, pADU, bytesReceived) != -1)
				{
//					fprintf(stdout, "%s(): Received %u bytes:\n", __func__, bytesReceived);
//					if (bytesReceived > 0)
//					{
//						dump_bytes(stdout, pADU, bytesReceived);
//					}

					if (bytesReceived == (int)(3 * sizeof(uint8_t) + sizeof(uint16_t)))
					{
						exceptionCode = pADU[2];

						if (pADU[0] == address)
						{
							if (pADU[1] == (MBF65_FUNCTION_CODE | 0x80))
							{
								/*   MODBUS. */
								if (exceptionCode == MODBUS_EXCEPTION_SLAVE_OR_SERVER_BUSY)
								{
									Sleep(MBF65_DELAY_AFTER_EXCEPTION_MS);
									fprintf(stdout, "%s(): server busy\n", __func__);
								}
								else
								{
									fprintf(stdout, "%s(): exception %u\n", __func__,
											exceptionCode);
								}
							}
							else
							{
								fprintf(stdout, "%s(): invalid function %u in exception %u\n",
										__func__, pADU[1], exceptionCode);
							}
						}
						else
						{
							fprintf(stdout, "%s(): invalid address %u in exception %u\n",
									__func__, pADU[0], exceptionCode);
						}
					} /* if (bytesReceived == (int)(3 * sizeof(uint8_t))) */

					if (exceptionCode == MODBUS_EXCEPTION_MAX)
					{
						if (bytesReceived >= (int)sizeof(mbf65_PDUHeading))
						{
							const mbf65_ShortResponsePDU* pPDU =
											(const mbf65_ShortResponsePDU*)&pADU[1];

							if (pADU[0] == address
								&& pPDU->pduHeading.function == MBF65_FUNCTION_CODE
								&& pPDU->pduHeading.subfunction == (uint8_t)subfunction
								&& pPDU->pduHeading.requestNo == s_requestNo)
							{
								*pResponseDataSize = (uint16_t)(bytesReceived - sizeof(mbf65_PDUHeading));
								if (responseBufferSize >= *pResponseDataSize)
								{
									*pResponseCode = pPDU->responseStatus.fields.code;
									*pIsLongResponse = 
										pPDU->responseStatus.fields.type == (uint8_t)MBF65_RT_LONG;
									if (*pResponseCode == MBF65_RC_SUCCESS)
									{
										success = true;
										*pResponseDataSize = pPDU->pduHeading.dataSize
														- sizeof(pPDU->responseStatus);
										memcpy(pResponseBuffer, pPDU->pResponseData,
														*pResponseDataSize);
//										fprintf(stdout,
//												"%s(): Received response to request %u subfunction %u.\n",
//												__func__, pPDU->pduHeading.requestNo,
//												pPDU->pduHeading.subfunction);
									}
									else
									{
										fprintf(stdout,
												"%s(): error %u in response to subfunction %u\n",
												__func__, *pResponseCode,
												pPDU->pduHeading.subfunction);
									}
								}
								else
								{
									fprintf(stdout,
											"%s(): data size (%u bytes) exceeds buffer size (%u bytes)\n",
											__func__, *pResponseDataSize, responseBufferSize);
								}
							}
							else
							{
								fprintf(stdout,
										"%s(): error: function=%u(%u), subfunction=%u(%u), requestNo=%u(%u)\n",
										__func__, pPDU->pduHeading.function,
										MBF65_FUNCTION_CODE, pPDU->pduHeading.subfunction,
										subfunction, pPDU->pduHeading.requestNo, s_requestNo);
							}
						} /* if (bytesReceived >= (int)sizeof(mbf65_PDUHeading)) */
						else if (bytesReceived < 0)
						{
							fprintf(stdout, "%s(): modbus_receive_confirmation() failed: %s\n",
											__func__, modbus_strerror(errno));
						}
						else
						{
							fprintf(stdout, "%s(): response is too short (%u bytes):\n", __func__,
											bytesReceived);
							dump_bytes(stdout, pADU, bytesReceived);
						}
					} /* if (exceptionCode == MODBUS_EXCEPTION_MAX) */
				} /* if (_modbus_rtu_check_integrity(pModbus, pADU, bytesReceived) != -1) */
				else
				{
					fprintf(stdout, "%s(): _modbus_rtu_check_integrity() failed: %s\n", __func__,
							modbus_strerror(errno));
				}
			} /* if (bytesSent == requestSize + sizeof(uint16_t)) */
			else if (bytesSent < 0)
			{
				fprintf(stdout, "%s(): modbus_send_raw_request() failed: %s\n", __func__,
						modbus_strerror(errno));
			}
			else
			{
				fprintf(stdout, "%s(): only %u bytes sent by modbus_send_raw_request()\n", __func__,
						bytesSent);
			}
		}
		while (exceptionCode == MODBUS_EXCEPTION_SLAVE_OR_SERVER_BUSY);
	}
	else
	{
		fprintf(stdout, "%s(): data size (%u bytes) exceeds ADU size\n", __func__, requestDataSize);
	}

	s_requestNo++;

	return success;
} /* mbf65_sendRequest() */
/*-----------------------------------------------------------------------------------------------*/
uint16_t mbf65_readUint16FromBuf(const void* pBuf)
{
	return (((uint8_t*)pBuf)[0] << 8) | ((uint8_t*)pBuf)[1];
}
/*-----------------------------------------------------------------------------------------------*/
uint32_t mbf65_readUint32FromBuf(const void* pBuf)
{
	return (((uint8_t*)pBuf)[0] << 24) | (((uint8_t*)pBuf)[1] << 16) | 
		(((uint8_t*)pBuf)[2] << 8) | ((uint8_t*)pBuf)[3];
}
/*-----------------------------------------------------------------------------------------------*/
float mbf65_readFloatFromBuf(const void* pBuf)
{
	float value;
	((uint8_t*)&value)[3] = *(uint8_t*)pBuf;
	((uint8_t*)pBuf)++;
	((uint8_t*)&value)[2] = *(uint8_t*)pBuf;
	((uint8_t*)pBuf)++;
	((uint8_t*)&value)[1] = *(uint8_t*)pBuf;
	((uint8_t*)pBuf)++;
	((uint8_t*)&value)[0] = *(uint8_t*)pBuf;
	((uint8_t*)pBuf)++;

	return value;
}
/*-----------------------------------------------------------------------------------------------*/
uint64_t mbf65_readUint64FromBuf(const void* pBuf)
{
	uint64_t value;
	int byteCount = sizeof(value);
	uint8_t* pValueAsByteArray = (uint8_t*)&value + byteCount;
	while (byteCount-- != 0)
	{
		--pValueAsByteArray;
		*pValueAsByteArray = *(uint8_t*)pBuf;
		((uint8_t*)pBuf)++;
	}
	return value;
}
/*-----------------------------------------------------------------------------------------------*/
void* mbf65_writeUint16ToBuf(void* pBuf, uint16_t value)
{
	*(uint8_t*)pBuf = (uint8_t)(value >> 8);
	((uint8_t*)pBuf)++;
	*(uint8_t*)pBuf = (uint8_t)(value & 0xFF);
	((uint8_t*)pBuf)++;

	return pBuf;
}
/*-----------------------------------------------------------------------------------------------*/
void* mbf65_writeUint32ToBuf(void* pBuf, uint32_t value)
{
	*(uint8_t*)pBuf = (uint8_t)(value >> 24);
	((uint8_t*)pBuf)++;
	*(uint8_t*)pBuf = (uint8_t)(value >> 16);
	((uint8_t*)pBuf)++;
	*(uint8_t*)pBuf = (uint8_t)(value >> 8);
	((uint8_t*)pBuf)++;
	*(uint8_t*)pBuf = (uint8_t)(value);
	((uint8_t*)pBuf)++;
	return pBuf;
}
/*-----------------------------------------------------------------------------------------------*/
void* mbf65_writeUint64ToBuf(void* pBuf, uint64_t value)
{
	int byteCount = sizeof(value);
	const uint8_t* pValueAsArray = (const uint8_t*)&value + byteCount;
	while (byteCount-- != 0)
	{
		--pValueAsArray;
		*(uint8_t*)pBuf = *pValueAsArray;
		((uint8_t*)pBuf)++;
	}
	return pBuf;
}
/*-----------------------------------------------------------------------------------------------*/
void* mbf65_writeFloatToBuf(void* pBuf, float value)
{
	const uint8_t* pValue = (const uint8_t*)&value;
	*(uint8_t*)pBuf = pValue[3];
	((uint8_t*)pBuf)++;
	*(uint8_t*)pBuf = pValue[2];
	((uint8_t*)pBuf)++;
	*(uint8_t*)pBuf = pValue[1];
	((uint8_t*)pBuf)++;
	*(uint8_t*)pBuf = pValue[0];
	((uint8_t*)pBuf)++;
	return pBuf;
}
/*-----------------------------------------------------------------------------------------------*/
int mbf65_getBinaryValueFromBitArray(const void* pBitArray, uint32_t bitIndex)
{
	uint32_t unitIndex = bitIndex / 8;
	uint32_t bitInUnit = bitIndex % 8;

	return (*((uint8_t*)pBitArray + unitIndex) & (uint8_t)(1 << (bitIndex))) ? 1 : 0;
} /* npr_getBinaryValueFromBitArray() */
/*-----------------------------------------------------------------------------------------------*/
int mbf65_downloadFileCompressed(modbus_t* pModbus, uint8_t address, const char* pRemoteFilename,
	const char* pLocalFilename, mbf65_CompressionType compressionType,
	uint32_t* pOriginalFileSize, uint32_t* pCompressedFileSize)
{
	int rc = 0;
	uint8_t fileID = 0;
	bool success = true;
	FILE* pLocalFile;
	uint8_t pRequestData[MODBUS_RTU_MAX_ADU_LENGTH];
	uint16_t responseDataSize;
	uint8_t pResponseBuffer[MODBUS_RTU_MAX_ADU_LENGTH];
	uint32_t readRequestCount = 0;
	mbf65_ResponseCode responseCode;
	bool isLongResponse;

	*pOriginalFileSize = 0;
	*pCompressedFileSize = 0;

	pLocalFile = fopen(pLocalFilename, "wb");
	if (pLocalFile != NULL)
	{
		mbf65_OpenFileCompressedRequestData* pOpenRequest =
			(mbf65_OpenFileCompressedRequestData*)pRequestData;
		size_t filenameLength = strlen(pRemoteFilename) + 1;

		pOpenRequest->openMode = (uint8_t)MBF65_FOM_OPEN_FOR_READING;
		pOpenRequest->compressionType = (uint8_t)compressionType;
		strncpy(pOpenRequest->pathName, pRemoteFilename, MODBUS_RTU_MAX_ADU_LENGTH -
			sizeof(mbf65_OpenFileCompressedRequestData));

		success = mbf65_sendRequest(pModbus, address, MBF65_SC_OPEN_FILE_COMPRESSED, pRequestData,
			(uint16_t)(filenameLength + sizeof(mbf65_OpenFileCompressedRequestData)), pResponseBuffer, 
			MODBUS_RTU_MAX_ADU_LENGTH, &responseDataSize, &responseCode, &isLongResponse);
	}
	else
	{
		success = false;
		fprintf(stderr, "%s(): failed to open local file \"%s\"\n", __func__, pLocalFilename);
	}

	if (success)
	{
		if (responseDataSize == sizeof(mbf65_OpenFileResponseData))
		{
			const mbf65_OpenFileResponseData* pOpenResponse =
				(const mbf65_OpenFileResponseData*)pResponseBuffer;
			fileID = pOpenResponse->fileID;
			*pOriginalFileSize = mbf65_readUint32FromBuf(pOpenResponse->fileSize);

			fprintf(stderr, "%s(): file open: fileID=%u, file size=%u\n", __func__, fileID,
				*pOriginalFileSize);
		}
		else
		{
			success = false;
			fprintf(stderr, "%s(): unexpected response data size (%u) to subfunction %u, expected %u\n",
				__func__, responseDataSize, MBF65_SC_OPEN_FILE_COMPRESSED, 
				sizeof(mbf65_OpenFileResponseData));
		}
	}

	if (success)
	{
		mbf65_CloseFileRequestData* pCloseFileRequest = (mbf65_CloseFileRequestData*)pRequestData;
		mbf65_ReadFileCompressedRequestData* pReadRequest =
			(mbf65_ReadFileCompressedRequestData*)pRequestData;

		pReadRequest->fileID = fileID;

		*pCompressedFileSize = 0;
		do
		{
			mbf65_writeUint32ToBuf(pReadRequest->nexCompressedOffset, *pCompressedFileSize);

			readRequestCount++;
			success = mbf65_sendRequest(pModbus, address, MBF65_SC_READ_FILE_COMPRESSED, 
				pRequestData, sizeof(mbf65_ReadFileCompressedRequestData), pResponseBuffer, 
				MODBUS_RTU_MAX_ADU_LENGTH, &responseDataSize, &responseCode, &isLongResponse);

			if (success)
			{
				uint32_t fragmentSize =
					responseDataSize - sizeof(mbf65_ReadFileCompressedResponseData);

				if (responseDataSize > sizeof(mbf65_ReadFileCompressedResponseData))
				{
					const mbf65_ReadFileCompressedResponseData* pReadResponse =
						(const mbf65_ReadFileCompressedResponseData*)pResponseBuffer;

					fwrite(pReadResponse->pData, 1, fragmentSize, pLocalFile);
					*pCompressedFileSize += fragmentSize;

					//					fprintf(stdout,
					//							"%s(): readRequestCount=%u, originalOffset=%u, compressedOffset=%u, "
					//							"responseDataSize=%u, bytesRead=%u, totalSize=%u\n\n",
					//							__func__, readRequestCount,
					//							mbf65_readUint32FromBuf(pReadResponse->originalOffset),
					//							mbf65_readUint32FromBuf(pReadResponse->compressedOffset),
					//							responseDataSize, bytesRead, *pCompressedFileSize);
				}
				else if (responseDataSize < sizeof(mbf65_ReadFileCompressedResponseData))
				{
					success = false;
					fprintf(stderr, "%s(): error reading file: dataSize=%u\n",
						__func__, responseDataSize);
				}
				else
				{
					fprintf(stdout,
						"%s(): responseDataSize=%u, fragmentSize=%u, totalSize=%u\n",
						__func__, responseDataSize, fragmentSize, *pCompressedFileSize);
				}
			}
		} while (success && responseDataSize > sizeof(mbf65_ReadFileCompressedResponseData));

		fprintf(stdout, "%s(): totalSize=%u\n", __func__, *pCompressedFileSize);

		pCloseFileRequest->fileID = fileID;
		mbf65_sendRequest(pModbus, address, MBF65_SC_CLOSE_FILE_COMPRESSED, pRequestData, 
			sizeof(mbf65_CloseFileRequestData), pResponseBuffer, MODBUS_RTU_MAX_ADU_LENGTH, 
			&responseDataSize, &responseCode, &isLongResponse);
	}

	if (pLocalFile != NULL)
	{
		fclose(pLocalFile);
	}

	if (!success)
	{
		rc = -1;
	}

	return rc;
} /* mbf65_downloadFileCompressed() */
/*-----------------------------------------------------------------------------------------------*/
int mbf65_downloadFile(modbus_t* pModbus, uint8_t address, const char* pRemoteFilename,
	const char* pLocalFilename, uint32_t* pFileSize)
{
	int rc = 0;
	uint8_t fileID = 0;
	bool success = true;
	FILE* pLocalFile;
	uint8_t pRequestData[MODBUS_RTU_MAX_ADU_LENGTH];
	uint16_t responseDataSize;
	uint8_t pResponseBuffer[MODBUS_RTU_MAX_ADU_LENGTH];
	mbf65_ResponseCode responseCode;
	bool isLongResponse;

	fprintf(stdout, "%s(): address=%u, remote=\"%s\", local=\"%s\"\n", __func__,
		address, pRemoteFilename, pLocalFilename);

	*pFileSize = 0;

	pLocalFile = fopen(pLocalFilename, "wb");
	if (pLocalFile != NULL)
	{
		mbf65_OpenFileRequestData* pOpenRequest = (mbf65_OpenFileRequestData*)pRequestData;
		size_t filenameLength = strlen(pRemoteFilename) + 1;

		pOpenRequest->openMode = (uint8_t)MBF65_FOM_OPEN_FOR_READING;
		strncpy(pOpenRequest->pathName, pRemoteFilename, MODBUS_RTU_MAX_ADU_LENGTH -
			sizeof(mbf65_OpenFileRequestData));

		success = mbf65_sendRequest(pModbus, address, MBF65_SC_OPEN_FILE, pRequestData, 
			(uint16_t)(filenameLength + sizeof(mbf65_OpenFileRequestData)), pResponseBuffer, 
			MODBUS_RTU_MAX_ADU_LENGTH, &responseDataSize, &responseCode, &isLongResponse);
	}
	else
	{
		success = false;
		fprintf(stderr, "%s(): failed to open local file \"%s\"\n", __func__, pLocalFilename);
	}

	if (success)
	{
		if (responseDataSize == sizeof(mbf65_OpenFileResponseData))
		{
			const mbf65_OpenFileResponseData* pOpenResponse =
				(const mbf65_OpenFileResponseData*)pResponseBuffer;
			fileID = pOpenResponse->fileID;
			*pFileSize = mbf65_readUint32FromBuf(pOpenResponse->fileSize);

			fprintf(stderr, "%s(): file open: fileID=%u, file size=%u\n", __func__, fileID,
				*pFileSize);
		}
		else
		{
			success = false;
			fprintf(stderr, "%s(): unexpected response data size (%u) to subfunction %u, expected %u\n",
				__func__, responseDataSize, MBF65_SC_OPEN_FILE, sizeof(mbf65_OpenFileResponseData));
		}
	}

	if (success)
	{
		mbf65_CloseFileRequestData* pCloseFileRequest = (mbf65_CloseFileRequestData*)pRequestData;
		uint32_t offset = 0;

		do
		{
			mbf65_ReadFileRequestData* pReadRequest = (mbf65_ReadFileRequestData*)pRequestData;

			pReadRequest->fileID = fileID;
			pReadRequest->length = (uint8_t)(MODBUS_RTU_MAX_ADU_LENGTH -
				(1 + sizeof(mbf65_ShortResponsePDU) +
					sizeof(mbf65_ReadFileResponseData) + 2));
			mbf65_writeUint32ToBuf(pReadRequest->offset, offset);

			success = mbf65_sendRequest(pModbus, address, MBF65_SC_READ_FILE, pRequestData, 
				sizeof(mbf65_ReadFileRequestData), pResponseBuffer, MODBUS_RTU_MAX_ADU_LENGTH,
				&responseDataSize, &responseCode, &isLongResponse);

			if (success)
			{
				uint32_t fragmentSize = responseDataSize - sizeof(mbf65_ReadFileResponseData);

				offset += fragmentSize;

				if (responseDataSize > sizeof(mbf65_ReadFileResponseData))
				{
					const mbf65_ReadFileResponseData* pReadResponse =
						(const mbf65_ReadFileResponseData*)pResponseBuffer;

					fwrite(pReadResponse->pData, 1, fragmentSize, pLocalFile);

					fprintf(stdout, "%s(): offset=%u, fragmentSize=%u, totalSize=%u\n", __func__,
						mbf65_readUint32FromBuf(pReadResponse->offset), fragmentSize,
						offset);
				}
				else if (responseDataSize < sizeof(mbf65_ReadFileResponseData))
				{
					success = false;
					fprintf(stderr, "%s(): error reading file: dataSize=%u\n",
						__func__, responseDataSize);
				}
				else
				{
					fprintf(stdout,
						"%s(): responseDataSize=%u, fragmentSize=%u, totalSize=%u\n",
						__func__, responseDataSize, fragmentSize, offset);
				}
			}
		} while (success && responseDataSize > sizeof(mbf65_ReadFileResponseData));

		fprintf(stdout, "%s(): totalSize=%u\n", __func__, offset);

		pCloseFileRequest->fileID = fileID;
		mbf65_sendRequest(pModbus, address, MBF65_SC_CLOSE_FILE, pRequestData, 
			sizeof(mbf65_CloseFileRequestData), pResponseBuffer, MODBUS_RTU_MAX_ADU_LENGTH, 
			&responseDataSize, &responseCode, &isLongResponse);
	}

	if (pLocalFile != NULL)
	{
		fclose(pLocalFile);
	}

	if (!success)
	{
		rc = -1;
	}

	return rc;
} /* mbf65_downloadFile() */
/*-----------------------------------------------------------------------------------------------*/
int mbf65_uploadFile(modbus_t* pModbus, uint8_t address, const char* pRemoteFilename,
	const char* pLocalFilename, uint32_t* pFileSize)
{
	int rc = 0;
	uint8_t fileID = 0;
	bool success = true;
	FILE* pLocalFile;
	uint8_t pRequestData[MODBUS_RTU_MAX_ADU_LENGTH];
	uint16_t responseDataSize;
	uint8_t pResponseBuffer[MODBUS_RTU_MAX_ADU_LENGTH];
	mbf65_ResponseCode responseCode;
	bool isLongResponse;

	*pFileSize = 0;

	pLocalFile = fopen(pLocalFilename, "rb");
	if (pLocalFile != NULL)
	{
		mbf65_OpenFileRequestData* pOpenRequest = (mbf65_OpenFileRequestData*)pRequestData;
		size_t filenameLength = strlen(pRemoteFilename) + 1;

		pOpenRequest->openMode = (uint8_t)MBF65_FOM_CREATE_OR_REWRITE;
		strncpy(pOpenRequest->pathName, pRemoteFilename, MODBUS_RTU_MAX_ADU_LENGTH -
			sizeof(mbf65_OpenFileRequestData));

		success = mbf65_sendRequest(pModbus, address, MBF65_SC_OPEN_FILE, pRequestData, 
			(uint16_t)(filenameLength + sizeof(mbf65_OpenFileRequestData)), pResponseBuffer, 
			MODBUS_RTU_MAX_ADU_LENGTH, &responseDataSize, &responseCode, &isLongResponse);
	}
	else
	{
		success = false;
		fprintf(stderr, "%s(): failed to open local file \"%s\"\n", __func__, pLocalFilename);
	}

	if (success)
	{
		if (responseDataSize == sizeof(mbf65_OpenFileResponseData))
		{
			const mbf65_OpenFileResponseData* pOpenResponse =
				(const mbf65_OpenFileResponseData*)pResponseBuffer;
			fileID = pOpenResponse->fileID;
			*pFileSize = mbf65_readUint32FromBuf(pOpenResponse->fileSize);

			fprintf(stderr, "%s(): file open: fileID=%u, file size=%u\n", __func__, fileID,
				*pFileSize);
		}
		else
		{
			success = false;
			fprintf(stderr, "%s(): unexpected response data size (%u) to subfunction %u, expected %u\n",
				__func__, responseDataSize, MBF65_SC_OPEN_FILE, sizeof(mbf65_OpenFileResponseData));
		}
	}

	if (success)
	{
		mbf65_CloseFileRequestData* pCloseFileRequest = (mbf65_CloseFileRequestData*)pRequestData;
		uint32_t totalBytesRead = 0;
		size_t bytesToRead = MODBUS_RTU_MAX_ADU_LENGTH - (1 + sizeof(mbf65_ShortResponsePDU) +
			sizeof(mbf65_WriteFileRequestData) + 2);
		size_t bytesRead = 0;

		do
		{
			mbf65_WriteFileRequestData* pWriteRequest = (mbf65_WriteFileRequestData*)pRequestData;

			bytesRead = fread(pWriteRequest->pData, 1, bytesToRead, pLocalFile);

			if (bytesRead > 0)
			{
				pWriteRequest->fileID = fileID;
				mbf65_writeUint32ToBuf(pWriteRequest->offset, totalBytesRead);

				success = mbf65_sendRequest(pModbus, address, MBF65_SC_WRITE_FILE, pRequestData, 
					(uint16_t)(sizeof(mbf65_WriteFileRequestData) + bytesRead), pResponseBuffer, 
					MODBUS_RTU_MAX_ADU_LENGTH, &responseDataSize, &responseCode, &isLongResponse);

				if (success)
				{
					if (responseDataSize == sizeof(mbf65_WriteFileResponseData))
					{
						const mbf65_WriteFileResponseData* pWriteResponse =
							(const mbf65_WriteFileResponseData*)pResponseBuffer;

						fprintf(stdout, "%s(): offset=%u, fragmentSize=%u, totalSize=%u\n", __func__,
							mbf65_readUint32FromBuf(pWriteResponse->offset), bytesRead,
							totalBytesRead);
					}
					else
					{
						success = false;
						fprintf(stderr, "%s(): unexpected response data size (%u) to subfunction %u, expected %u\n",
							__func__, responseDataSize, MBF65_SC_WRITE_FILE, sizeof(mbf65_WriteFileResponseData));
					}
				}

				totalBytesRead += (uint32_t)bytesRead;
			} /* if (bytesRead > 0) */
		} while (success && bytesRead > 0);

		fprintf(stdout, "%s(): totalSize=%u\n", __func__, totalBytesRead);
		*pFileSize = totalBytesRead;

		pCloseFileRequest->fileID = fileID;
		mbf65_sendRequest(pModbus, address, MBF65_SC_CLOSE_FILE, pRequestData, 
			sizeof(mbf65_CloseFileRequestData), pResponseBuffer, MODBUS_RTU_MAX_ADU_LENGTH, 
			&responseDataSize, &responseCode, &isLongResponse);
	}

	if (pLocalFile != NULL)
	{
		fclose(pLocalFile);
	}

	if (!success)
	{
		rc = -1;
	}

	return rc;
} /* mbf65_uploadFile() */
/*-----------------------------------------------------------------------------------------------*/
int mbf65_applyProject(modbus_t* pModbus, uint8_t address)
{
	int rc = 0;
	bool success = true;
	uint8_t pRequestData[MODBUS_RTU_MAX_ADU_LENGTH];
	uint16_t responseDataSize;
	uint8_t pResponseBuffer[MODBUS_RTU_MAX_ADU_LENGTH];
	mbf65_ResponseCode responseCode;
	bool isLongResponse;

	mbf65_ApplyProjectRequestData* pRequest = (mbf65_ApplyProjectRequestData*)pRequestData;
	pRequest->method = 0;

	success = mbf65_sendRequest(pModbus, address, MBF65_SC_APPLY_PROJECT, pRequestData,
		sizeof(mbf65_ApplyProjectRequestData), pResponseBuffer, MODBUS_RTU_MAX_ADU_LENGTH, 
		&responseDataSize, &responseCode, &isLongResponse);

	if (!success)
	{
		fprintf(stderr, "%s(): failed to apply project\n", __func__);
		rc = -1;
	}

	return rc;
} /* mbf65_applyProject() */
/*-----------------------------------------------------------------------------------------------*/
int mbf65_readNumberOfOscillograms(modbus_t* pModbus, uint8_t address, 
	uint16_t* pNumberOfOscillograms)
{
	int rc = 0;
	bool success;
	uint16_t responseDataSize;
	uint8_t pResponseBuffer[MODBUS_RTU_MAX_ADU_LENGTH];
	mbf65_ResponseCode responseCode;
	bool isLongResponse;

	success = mbf65_sendRequest(pModbus, address, MBF65_SC_GET_NUMBER_OF_OSCILLOGRAMS, NULL, 0,
		pResponseBuffer, MODBUS_RTU_MAX_ADU_LENGTH, &responseDataSize, &responseCode, 
		&isLongResponse);

	if (success)
	{
		if (responseDataSize == sizeof(mbf65_GetNumberOfOscillogramsResponseData))
		{
			const mbf65_GetNumberOfOscillogramsResponseData* pResponse =
				(const mbf65_GetNumberOfOscillogramsResponseData*)pResponseBuffer;

			*pNumberOfOscillograms = mbf65_readUint16FromBuf(pResponse->numberOfOscillograms);

			fprintf(stderr, "%s(): number of oscillograms=%u\n", __func__, *pNumberOfOscillograms);
		}
		else
		{
			success = false;
			fprintf(stderr, "%s(): unexpected response data size (%u) to subfunction %u, expected %u\n",
				__func__, responseDataSize, MBF65_SC_GET_NUMBER_OF_OSCILLOGRAMS,
				sizeof(mbf65_GetNumberOfOscillogramsResponseData));
		}
	}

	if (!success)
	{
		fprintf(stderr, "%s(): failed to read buffer info\n", __func__);
		rc = -1;
	}

	return rc;
} /* mbf65_readNumberOfOscillograms() */
/*-----------------------------------------------------------------------------------------------*/
int mbf65_readOscillogramDescriptors(modbus_t* pModbus, uint8_t address, 
	uint16_t firstOscillogramNumber, uint16_t numberOfDescriptorsToRead, 
	mbf65_OscillogramInfoExp* pBuffer, uint16_t* pNumberOfDescriptorsRead)
{
	int rc = 0;
	bool success = false;
	uint8_t pRequestData[MODBUS_RTU_MAX_ADU_LENGTH];
	uint16_t responseDataSize;
	uint8_t pResponseBuffer[MODBUS_RTU_MAX_ADU_LENGTH];
	mbf65_GetOscillogramInfoRequestData* pRequest = 
		(mbf65_GetOscillogramInfoRequestData*)pRequestData;

	*pNumberOfDescriptorsRead = 0;

	do
	{
		uint16_t numberOfDescriptors = 1;
		mbf65_ResponseCode responseCode;
		bool isLongResponse;

		mbf65_writeUint16ToBuf(pRequest->numberOfOscillograms, numberOfDescriptors);
		mbf65_writeUint16ToBuf(pRequest->oscillogramNo,
			firstOscillogramNumber + *pNumberOfDescriptorsRead);
		success = mbf65_sendRequest(pModbus, address, MBF65_SC_GET_OSCILLOGRAM_INFO,
			pRequestData, sizeof(mbf65_GetOscillogramInfoRequestData), pResponseBuffer, 
			MODBUS_RTU_MAX_ADU_LENGTH, &responseDataSize, &responseCode, &isLongResponse);

		if (success)
		{
			const mbf65_OscillogramInfo* pInfo = (const mbf65_OscillogramInfo*)pResponseBuffer;

			numberOfDescriptors = (uint16_t)(responseDataSize / sizeof(mbf65_OscillogramInfo));

			while (numberOfDescriptors != 0 && *pNumberOfDescriptorsRead < numberOfDescriptorsToRead)
			{
				pBuffer[*pNumberOfDescriptorsRead].timestamp = 
					mbf65_readUint64FromBuf(pInfo->timestamp);
				pBuffer[*pNumberOfDescriptorsRead].duration = 
					mbf65_readUint32FromBuf(pInfo->duration);
				pBuffer[*pNumberOfDescriptorsRead].fileSize =
					mbf65_readUint32FromBuf(pInfo->fileSize);
				pBuffer[*pNumberOfDescriptorsRead].signalType = pInfo->signalType[0];
				pBuffer[*pNumberOfDescriptorsRead].signalID = 
					mbf65_readUint16FromBuf(pInfo->signalID);

				numberOfDescriptors--;
				(*pNumberOfDescriptorsRead)++;
			}
		}
	} while (success && responseDataSize > sizeof(mbf65_ReadBufferResponseData) &&
		*pNumberOfDescriptorsRead < numberOfDescriptorsToRead);

	if (!success)
	{
		fprintf(stderr, "%s(): failure\n", __func__);
		rc = -1;
	}

	return rc;
} /* mbf65_readOscillogramDescriptors() */
/*-----------------------------------------------------------------------------------------------*/
int mbf65_downloadOscillogram(modbus_t* pModbus, uint8_t address, int oscillogramNumber,
	const char* pLocalFilename, uint32_t* pFileSize)
{
	char pRemoteFilename[40];

	snprintf(pRemoteFilename, sizeof(pRemoteFilename), s_pOSCILLOGRAM_NAME_FORMAT, 
		oscillogramNumber);

	return mbf65_downloadFile(pModbus, address, pRemoteFilename, pLocalFilename, pFileSize);
} /* mbf65_downloadOscillogram() */
/*-----------------------------------------------------------------------------------------------*/
int mbf65_downloadOscillogramCompressed(modbus_t* pModbus, uint8_t address, int oscillogramNumber,
	const char* pLocalFilename, mbf65_CompressionType compressionType,
	uint32_t* pOriginalFileSize, uint32_t* pCompressedFileSize)
{
	char pRemoteFilename[40];

	snprintf(pRemoteFilename, sizeof(pRemoteFilename), s_pOSCILLOGRAM_NAME_FORMAT, 
		oscillogramNumber);

	return mbf65_downloadFileCompressed(pModbus, address, pRemoteFilename,
		pLocalFilename, compressionType, pOriginalFileSize, pCompressedFileSize);
} /* mbf65_downloadOscillogramCompressed() */
/*-----------------------------------------------------------------------------------------------*/
int mbf65_readBufferInfo(modbus_t* pModbus, uint8_t address, mbf65_BufferInfoExp* pBufferInfo)
{
	int rc = 0;
	bool success;
	uint16_t responseDataSize;
	uint8_t pResponseBuffer[MODBUS_RTU_MAX_ADU_LENGTH];
	mbf65_ResponseCode responseCode;
	bool isLongResponse;

	success = mbf65_sendRequest(pModbus, address, MBF65_SC_GET_BUFFER_INFO, NULL, 0, 
		pResponseBuffer, MODBUS_RTU_MAX_ADU_LENGTH, &responseDataSize, &responseCode, 
		&isLongResponse);

	if (success)
	{
		if (responseDataSize == sizeof(mbf65_BufferInfoResponseData))
		{
			const mbf65_BufferInfoResponseData* pResponse = 
				(const mbf65_BufferInfoResponseData*)pResponseBuffer;

			memset(pBufferInfo, 0, sizeof(mbf65_BufferInfoExp));
			pBufferInfo->dataSize = mbf65_readUint32FromBuf(pResponse->size);

			fprintf(stderr, "%s(): data size=%u\n", __func__, pBufferInfo->dataSize);
		}
		else
		{
			success = false;
			fprintf(stderr, "%s(): unexpected response data size (%u) to subfunction %u, expected %u\n",
				__func__, responseDataSize, MBF65_SC_GET_BUFFER_INFO,
				sizeof(mbf65_BufferInfoResponseData));
		}
	}

	if (!success)
	{
		fprintf(stderr, "%s(): failed to read buffer info\n", __func__);
		rc = -1;
	}

	return rc;
} /* mbf65_readBufferInfo() */
/*-----------------------------------------------------------------------------------------------*/
int mbf65_readDataFromBuffer(modbus_t* pModbus, uint8_t address, void* pData, uint32_t offset,
	uint32_t size, uint32_t* pNumberOfBytesRead)
{
	int rc = 0;
	bool success;
	uint8_t pRequestData[MODBUS_RTU_MAX_ADU_LENGTH];
	uint16_t responseDataSize;
	uint8_t pResponseBuffer[MODBUS_RTU_MAX_ADU_LENGTH];
	mbf65_ReadBufferRequestData* pRequest = (mbf65_ReadBufferRequestData*)pRequestData;
	uint32_t deviceBufferOffset = offset;
	const uint8_t MAX_FRAGMENT_SIZE = (uint8_t)(MODBUS_RTU_MAX_ADU_LENGTH -
		(1 + sizeof(mbf65_ShortResponsePDU) + sizeof(mbf65_ReadBufferResponseData) + 2));

	*pNumberOfBytesRead = 0;

	do
	{
		mbf65_ResponseCode responseCode;
		bool isLongResponse;

		mbf65_writeUint32ToBuf(pRequest->offset, deviceBufferOffset);
		if ((uint32_t)MAX_FRAGMENT_SIZE > size - *pNumberOfBytesRead)
		{
			pRequest->size = (uint8_t)(size - *pNumberOfBytesRead);
		}
		else
		{
			pRequest->size = MAX_FRAGMENT_SIZE;
		}

		success = mbf65_sendRequest(pModbus, address, MBF65_SC_READ_BUFFER, pRequestData, 
			sizeof(mbf65_ReadBufferRequestData), pResponseBuffer, MODBUS_RTU_MAX_ADU_LENGTH, 
			&responseDataSize, &responseCode, &isLongResponse);

		if (success)
		{
			uint32_t fragmentSize = responseDataSize - sizeof(mbf65_ReadBufferResponseData);

			if (responseDataSize >= sizeof(mbf65_ReadBufferResponseData))
			{
				const mbf65_ReadBufferResponseData* pResponse = 
					(const mbf65_ReadBufferResponseData*)pResponseBuffer;

				//fprintf(stdout, "%s(): buffer offset=%u, fragmentSize=%u, bytesRead=%u, size=%u\n", 
				//	__func__, mbf65_readUint32FromBuf(pResponse->offset), fragmentSize, 
				//	*pNumberOfBytesRead, size);

				if (fragmentSize <= size - *pNumberOfBytesRead)
				{
					memcpy((uint8_t*)pData + *pNumberOfBytesRead, pResponse->pData, fragmentSize);
					deviceBufferOffset += fragmentSize;
				}
				else
				{
					success = false;
					fprintf(stdout, "%s(): fragment size exceeds local buffer size\n", __func__);
				}
			}
			else if (responseDataSize < sizeof(mbf65_ReadBufferResponseData))
			{
				success = false;
				fprintf(stderr, "%s(): error reading from buffer file: dataSize=%u\n",
					__func__, responseDataSize);
			}

			*pNumberOfBytesRead += fragmentSize;
		}
	} while (success && responseDataSize > sizeof(mbf65_ReadBufferResponseData) && 
		*pNumberOfBytesRead < size);

	//fprintf(stdout, "%s(): bytesRead=%u\n", __func__, *pNumberOfBytesRead);

	if (!success)
	{
		fprintf(stderr, "%s(): failed to read buffer info\n", __func__);
		rc = -1;
	}

	return rc;
} /* mbf65_readDataFromBuffer() */
/*-----------------------------------------------------------------------------------------------*/
int mbf65_readLogInfo(modbus_t* pModbus, uint8_t address, mbf65_LogType logType, 
	mbf65_LogInfoExp* pInfo)
{
	int rc = 0;
	bool success = false;
	uint8_t pRequestData[MODBUS_RTU_MAX_ADU_LENGTH];
	uint16_t responseDataSize;
	uint8_t pResponseBuffer[MODBUS_RTU_MAX_ADU_LENGTH];
	mbf65_GetFlashInfoRequestData* pRequest = (mbf65_GetFlashInfoRequestData*)pRequestData;
	mbf65_ResponseCode responseCode;
	bool isLongResponse;

	pRequest->infoType = (uint8_t)logType;
	success = mbf65_sendRequest(pModbus, address, MBF65_SC_GET_FLASH_INFO, pRequestData, 
		sizeof(mbf65_GetFlashInfoRequestData), pResponseBuffer, MODBUS_RTU_MAX_ADU_LENGTH, 
		&responseDataSize, &responseCode, &isLongResponse);

	if (success)
	{
		const mbf65_LogInfo* pLogInfo = (const mbf65_LogInfo*)pResponseBuffer;

		pInfo->currentNumberOfRecords = mbf65_readUint32FromBuf(pLogInfo->currentNumberOfRecords);
		pInfo->lastRecordID = mbf65_readUint64FromBuf(pLogInfo->lastRecordID);
		pInfo->lastRecordTimestamp = mbf65_readUint64FromBuf(pLogInfo->lastRecordTimestamp);
		pInfo->logVersion = mbf65_readUint32FromBuf(pLogInfo->logVersion);
		pInfo->maxNumberOfRecords = mbf65_readUint32FromBuf(pLogInfo->maxNumberOfRecords);
		pInfo->recordSize = mbf65_readUint32FromBuf(pLogInfo->recordSize);
		pInfo->softwareVersion = mbf65_readUint32FromBuf(pLogInfo->softwareVersion);
	}
	else
	{
		fprintf(stderr, "%s(): failure\n", __func__);
		rc = -1;
	}

	return rc;
} /* mbf65_readLogInfo() */
/*-----------------------------------------------------------------------------------------------*/
int mbf65_readDescriptorOfEventLogRecord(modbus_t* pModbus, uint8_t address, void* pBuffer,
	uint32_t bufferSize, uint32_t* pNumberOfBytesRead)
{
	int rc = 0;
	bool success;
	uint16_t responseDataSize;
	uint8_t pResponseBuffer[MODBUS_RTU_MAX_ADU_LENGTH];
	mbf65_ResponseCode responseCode;
	bool isLongResponse;

	success = mbf65_sendRequest(pModbus, address, MBF65_SC_GET_DESCRIPTOR_OF_EVENT_LOG_RECORD, 
		NULL, 0, pResponseBuffer, MODBUS_RTU_MAX_ADU_LENGTH, &responseDataSize, &responseCode, 
		&isLongResponse);

	if (success)
	{
		success = readResponse(pModbus, address, pResponseBuffer, responseDataSize, isLongResponse, 
			pBuffer, bufferSize, 0, pNumberOfBytesRead);
		if (success)
		{
			convertEventLogDescriptorToHostEndianness(pBuffer);
		}
	}

	if (!success)
	{
		fprintf(stderr, "%s(): failure\n", __func__);
		rc = -1;
	}

	return rc;
} /* mbf65_readDescriptorOfEventLogRecord() */
/*-----------------------------------------------------------------------------------------------*/
int mbf65_readFullLogRecords(modbus_t* pModbus, uint8_t address, mbf65_LogType logType,
	uint32_t recordSize, uint32_t firstRecordNumber, uint32_t numberOfRecordsToRead, 
	void* pBuffer, uint32_t bufferSize, uint32_t* pNumberOfRecordsRead)
{
	return readLogRecords(pModbus, address, logType, recordSize, true, firstRecordNumber,
		numberOfRecordsToRead, pBuffer, bufferSize, pNumberOfRecordsRead);
} /* mbf65_readFullLogRecords() */
/*-----------------------------------------------------------------------------------------------*/
int mbf65_readBriefLogRecords(modbus_t* pModbus, uint8_t address, mbf65_LogType logType,
	uint32_t recordSize, uint32_t firstRecordNumber, uint32_t numberOfRecordsToRead,
	void* pBuffer, uint32_t bufferSize, uint32_t* pNumberOfRecordsRead)
{
	return readLogRecords(pModbus, address, logType, recordSize, false, firstRecordNumber,
		numberOfRecordsToRead, pBuffer, bufferSize, pNumberOfRecordsRead);
} /* mbf65_readBriefLogRecords() */
/*-----------------------------------------------------------------------------------------------*/
void dump_bytes(FILE* pFile, const void* pData, uint32_t dataSize)
{
	unsigned int bytesPerLine = 16;

	for (unsigned int i = 0; i < dataSize; i++)
	{
		/*   */
		if ((i & (bytesPerLine - 1)) == 0)
		{
			fprintf(pFile, "\t%04X : ", i);
		}

		fprintf(pFile, "%02X ", ((const uint8_t*)pData)[i]);

		/*   */
		if (((i + 1) & (bytesPerLine - 1)) == 0)
		{
			fprintf(pFile, "\n");
		}
	}

	fprintf(pFile, "\n");
} /* dump_bytes() */
/*-----------------------------------------------------------------------------------------------*/
int receiveUF65Response(HANDLE comPort, void* pBuffer, int bufferSize)
{
	int totalBytesReceived = 0;
	int minResponseSize = sizeof(uint8_t) + sizeof(mbf65_ShortResponsePDU) + sizeof(uint16_t);

	if (bufferSize >= minResponseSize)
	{
		DWORD bytesToReceive;
		DWORD bytesReceived = 0;
		DWORD eventMask;
		BOOL success;
		COMMTIMEOUTS timeouts;
		uint8_t* pData = (uint8_t*)pBuffer;

		SetCommMask(comPort, EV_TXEMPTY | EV_RXCHAR);

		eventMask = EV_TXEMPTY;
		success = WaitCommEvent(comPort, &eventMask, NULL);
		if (!success)
		{
			fprintf(stdout, "%s(): Error %u in WaitCommEvent()-1\n", __func__, GetLastError());
		}

		timeouts.ReadIntervalTimeout = 0;
		timeouts.ReadTotalTimeoutMultiplier = 1;
		timeouts.ReadTotalTimeoutConstant = 2000;
		timeouts.WriteTotalTimeoutMultiplier = 0;
		timeouts.WriteTotalTimeoutConstant = 0;
		SetCommTimeouts(comPort, &timeouts);

		bytesToReceive = 2;
		success = ReadFile(comPort, pData, bytesToReceive, &bytesReceived, NULL);
		if (success)
		{
			totalBytesReceived += (int)bytesReceived;
			//			dump_bytes(stdout, pData, totalBytesReceived);
			if (bytesReceived == bytesToReceive)
			{
				/*   MODBUS. */
				if ((pData[1] & 0x80) != 0)
				{
					/*    . */
					success = ReadFile(comPort, pData + totalBytesReceived, 3, &bytesReceived,
						NULL);
					if (success)
					{
						totalBytesReceived += (int)bytesReceived;
						//						dump_bytes(stdout, pData, totalBytesReceived);
					}
					else
					{
						fprintf(stdout, "%s(): Error %u in ReadFile()-3\n", __func__,
							GetLastError());
					}
				}
				else
				{
					mbf65_ShortResponsePDU* pResponse = (mbf65_ShortResponsePDU*)(pData + 1);

					/*    . */
					success = ReadFile(comPort, pData + totalBytesReceived,
						sizeof(mbf65_ShortResponsePDU) - (totalBytesReceived - 1),
						&bytesReceived, NULL);
					if (success)
					{
						totalBytesReceived += (int)bytesReceived;
						//						dump_bytes(stdout, pData, totalBytesReceived);
						if (pResponse->pduHeading.dataSize <= bufferSize - minResponseSize + 1)
						{
							success = ReadFile(comPort, pResponse->pResponseData,
								pResponse->pduHeading.dataSize - sizeof(uint8_t) +
								sizeof(uint16_t), &bytesReceived, NULL);
							if (success)
							{
								totalBytesReceived += (int)bytesReceived;
								//								dump_bytes(stdout, pData, totalBytesReceived);
							}
							else
							{
								fprintf(stdout, "%s(): Error %u in ReadFile()-2\n", __func__,
									GetLastError());
							}
						}
						else
						{
							fprintf(stdout, "%s(): Incorrect data size (%u), buffer size=%u\n",
								__func__, pResponse->pduHeading.dataSize, bufferSize);
						}
					}
					else
					{
						fprintf(stdout, "%s(): Error %u in ReadFile()-3\n", __func__,
							GetLastError());
					}
				}
			} /* if (bytesReceived == 2) */
			else
			{
				fprintf(stdout, "%s(): Not enough data (%u < %u)\n", __func__, bytesReceived,
					bytesToReceive);
			}
		}
		else
		{
			fprintf(stdout, "%s(): Error %u in ReadFile()-1\n", __func__, GetLastError());
		}
	} /* if (bufferSize >= minResponseSize) */
	else
	{
		fprintf(stdout, "%s(): Not enough memory in buffer (%u < %u)\n", __func__,
			bufferSize, minResponseSize);
	}

	return totalBytesReceived;
} /* receiveUF65Response() */
/*-----------------------------------------------------------------------------------------------*/
bool readResponse(modbus_t* pModbus, uint8_t address, const void* pResponseBuffer, 
	uint16_t responseDataSize, bool isLongResponse, void* pBuffer, uint32_t bufferSize, 
	uint32_t skipBytes, uint32_t* pNumberOfBytesRead)
{
	bool success = false;

	*pNumberOfBytesRead = 0;

	if (isLongResponse)
	{
		const mbf65_LongResponseHeading* pLongResponseHeading =
			(const mbf65_LongResponseHeading*)pResponseBuffer;
		uint32_t totalDataSize = mbf65_readUint32FromBuf(pLongResponseHeading->pDataSize);
		uint32_t firstFragmentSize = responseDataSize - sizeof(mbf65_LongResponseHeading);
		if (totalDataSize - skipBytes <= bufferSize)
		{
			int rc;

			if (skipBytes > firstFragmentSize)
			{
				rc = mbf65_readDataFromBuffer(pModbus, address, (uint8_t*)pBuffer,
					skipBytes, totalDataSize - skipBytes, pNumberOfBytesRead);
			}
			else
			{
				memcpy(pBuffer, (const uint8_t*)pResponseBuffer + sizeof(mbf65_LongResponseHeading) 
					+ skipBytes, firstFragmentSize - skipBytes);

				rc = mbf65_readDataFromBuffer(pModbus, address, 
					(uint8_t*)pBuffer + firstFragmentSize - skipBytes, firstFragmentSize, 
					totalDataSize - firstFragmentSize, pNumberOfBytesRead);
				*pNumberOfBytesRead += firstFragmentSize - skipBytes;
			}

			success = rc == 0;
		}
		else
		{
			success = false;
			fprintf(stderr, "%s(): response data size (%u) exceeds buffer size (%u)\n",
				__func__, totalDataSize - skipBytes, bufferSize);
		}
	}
	else
	{
		if (skipBytes <= responseDataSize)
		{
			responseDataSize -= skipBytes;
			if (responseDataSize <= bufferSize)
			{
				memcpy(pBuffer, (const uint8_t*)pResponseBuffer + skipBytes,
					responseDataSize);
				*pNumberOfBytesRead = responseDataSize;

				success = true;
			}
			else
			{
				success = false;
				fprintf(stderr, "%s(): response data size (%u) exceeds buffer size (%u)\n",
					__func__, responseDataSize, bufferSize);
			}
		}
	}

	return success;
} /* readResponse() */
/*-----------------------------------------------------------------------------------------------*/
int readLogRecords(modbus_t* pModbus, uint8_t address, mbf65_FlashInfoType logType,
	uint32_t recordSize, bool full, uint32_t firstRecordNumber, uint32_t numberOfRecordsToRead,
	void* pBuffer, uint32_t bufferSize, uint32_t* pNumberOfRecordsRead)
{
	int rc = 0;
	bool success = false;
	uint8_t pRequestData[MODBUS_RTU_MAX_ADU_LENGTH];
	uint16_t responseDataSize;
	uint8_t pResponseBuffer[MODBUS_RTU_MAX_ADU_LENGTH];
	mbf65_GetLogRecordsRequestData* pRequest = (mbf65_GetLogRecordsRequestData*)pRequestData;
	uint8_t* pBufferPtr = (uint8_t*)pBuffer;
	mbf65_SubfunctionCode subfunction = 
		full ? MBF65_SC_GET_FULL_LOG_RECORDS : MBF65_SC_GET_BRIEF_LOG_RECORDS;

	*pNumberOfRecordsRead = 0;

	pRequest->logType = (uint8_t)logType;
	mbf65_writeUint32ToBuf(pRequest->numberOfRecords, 1);

	do
	{
		mbf65_ResponseCode responseCode; 
		bool isLongResponse;

		mbf65_writeUint32ToBuf(pRequest->recordNo, firstRecordNumber + *pNumberOfRecordsRead);
		success = mbf65_sendRequest(pModbus, address, subfunction, pRequestData, 
			sizeof(mbf65_GetLogRecordsRequestData), pResponseBuffer, MODBUS_RTU_MAX_ADU_LENGTH, 
			&responseDataSize, &responseCode, &isLongResponse);

		if (success)
		{
			uint32_t numberOfBytesRead = 0;
			success = readResponse(pModbus, address, pResponseBuffer, responseDataSize, 
				isLongResponse, pBufferPtr, bufferSize, sizeof(mbf65_GetLogRecordsResponseData), 
				&numberOfBytesRead);
			if (success)
			{
				pBufferPtr += numberOfBytesRead;
				bufferSize -= numberOfBytesRead;
				*pNumberOfRecordsRead += numberOfBytesRead / recordSize;
			}
		}
	} while (success && responseDataSize > sizeof(mbf65_GetLogRecordsResponseData) &&
		*pNumberOfRecordsRead < numberOfRecordsToRead && bufferSize >= recordSize);

	if (!success)
	{
		fprintf(stderr, "%s(): failure\n", __func__);
		rc = -1;
	}

	return rc;
} /* readLogRecords() */
/*-----------------------------------------------------------------------------------------------*/
void convertEventLogDescriptorToHostEndianness(void* pDescriptor)
{
	/* . */
	uint16_t numberOfEventTypes = *boc_convert16BitValueInSitu(pDescriptor);
	((uint8_t*)pDescriptor) += sizeof(numberOfEventTypes);
	for (uint16_t i = 0; i < numberOfEventTypes; i++)
	{
		boc_convert16BitValueInSitu(((mbf65_EventLogEventDescriptor*)pDescriptor)->id);
		((uint8_t*)pDescriptor) += sizeof(mbf65_EventLogEventDescriptor);
	}

	/*  . */
	pDescriptor = convertIDArrayToHostEndianness(pDescriptor);

	/*  . */
	pDescriptor = convertIDArrayToHostEndianness(pDescriptor);

	/*   . */
	pDescriptor = convertIDArrayToHostEndianness(pDescriptor);

	/*   . */
	pDescriptor = convertIDArrayToHostEndianness(pDescriptor);

	/*   . */
	uint16_t numberOfAOS = *boc_convert16BitValueInSitu(pDescriptor);
	((uint8_t*)pDescriptor) += sizeof(numberOfAOS);
	for (uint16_t i = 0; i < numberOfAOS; i++)
	{
		boc_convert16BitValueInSitu(((mbf65_EventLogAOSDescriptor*)pDescriptor)->id);
		((uint8_t*)pDescriptor) += sizeof(mbf65_EventLogAOSDescriptor);
	}

	/* . */
	pDescriptor = convertIDArrayToHostEndianness(pDescriptor);
} /* convertEventLogDescriptorToHostEndianness() */
/*-----------------------------------------------------------------------------------------------*/
void* convertIDArrayToHostEndianness(uint16_t* pIDArray)
{
	uint16_t numberOfIDs = *boc_convert16BitValueInSitu(pIDArray++);
	for (uint16_t i = 0; i < numberOfIDs; i++)
	{
		boc_convert16BitValueInSitu(pIDArray++);
	}

	return pIDArray;
} /* convertIDArrayToHostEndianness() */
/*-----------------------------------------------------------------------------------------------*/

/*@}*/
