/**
 * @file
 * @brief   ,     @ref ModbusFunction65 "ModbusFunction65".
 */
#ifndef SOURCE_MODBUSFUNCTION65_H_
#define SOURCE_MODBUSFUNCTION65_H_

#include <stdbool.h>
#include <stdint.h>
#include <stdio.h>
#include "modbus.h"

#ifdef __cplusplus
extern "C"
{
#endif

#pragma warning(disable : 4200)

/**
 * @defgroup ModbusFunction65  ModbusFunction65
 *
 *          
 *  65 Modbus    "".     
 *  ,     ,      ,
 *   65 Modbus.
 */
 /*@{*/

/*=======================================  ======================================*/

/** @brief      ,   . */
#define MBUF65_MAX_EVENT_NAME_LENGTH  100

/*========================================   ==========================================*/

/**
 * @brief     65  MODBUS.
 *        . ,    65 Modbus    "".
 */
typedef enum mbf65_SubfunctionCode_TAG
{
	MBF65_SC_OPEN_SESSION = 1,
	MBF65_SC_CLOSE_SESSION = 2,
	MBF65_SC_UPDATE_FIRMWARE = 3,
	MBF65_SC_GET_TIME = 4,
	MBF65_SC_SET_TIME = 5,
	MBF65_SC_GET_SUMMER_TIME = 6,
	MBF65_SC_SET_SUMMER_TIME = 7,
	MBF65_SC_SET_OPERATION_MODE = 8,
	MBF65_SC_GET_OPERATION_MODE = 9,
	MBF65_SC_GET_PARAMETERS = 10,
	MBF65_SC_SET_SETTINGS = 11,
	MBF65_SC_SET_PROGRAMME_OF_SETTINGS = 12,
	MBF65_SC_GET_PROGRAMME_OF_SETTINGS = 13,
	MBF65_SC_SET_LEVEL_OF_ZERO = 14,
	MBF65_SC_SET_LEVEL_OF_ONE = 15,
	MBF65_SC_GET_BINARY_INPUTS = 16,
	MBF65_SC_GET_BINARY_OUTPUTS = 17,
	MBF65_SC_GET_BINARY_INPUT_SIGNALS = 18,
	MBF65_SC_GET_BINARY_OUTPUT_SIGNALS = 19,
	MBF65_SC_GET_LIST_OF_BINARIES = 20,
	MBF65_SC_GET_NUMBER_OF_OSCILLOGRAMS = 21,
	MBF65_SC_GET_OSCILLOGRAM_INFO = 22,
	MBF65_SC_GET_FLASH_INFO = 23,
	MBF65_SC_GET_DESCRIPTOR_OF_EVENT_LOG_RECORD = 24,
	MBF65_SC_GET_FULL_LOG_RECORDS = 25,
	MBF65_SC_GET_BRIEF_LOG_RECORDS = 26,
	MBF65_SC_FETCH_LOG_RECORDS = 27,
	MBF65_SC_OPEN_DIRECTORY = 28,
	MBF65_SC_READ_NEXT_DIRECTORY_ITEM = 29,
	MBF65_SC_GET_FILE_INFO = 30,
	MBF65_SC_OPEN_FILE = 31,
	MBF65_SC_WRITE_FILE = 32,
	MBF65_SC_READ_FILE = 33,
	MBF65_SC_CLOSE_FILE = 34,
	MBF65_SC_DELETE_FILE = 35,
	MBF65_SC_APPLY_PROJECT = 36,
	MBF65_SC_SEND_CLIENT_STATUS = 37,
	MBF65_SC_SEND_CLIENT_ID_DATA = 38,
	MBF65_SC_EXECUTE_COMMAND = 39,
	MBF65_SC_SEND_MESSAGE = 40,
	MBF65_SC_GET_DESCRIPTOR_OF_ALARM_ACK_LOG_RECORD = 41,
	MBF65_SC_OPEN_FILE_COMPRESSED = 42,
	MBF65_SC_WRITE_FILE_COMPRESSED = 43,
	MBF65_SC_READ_FILE_COMPRESSED = 44,
	MBF65_SC_CLOSE_FILE_COMPRESSED = 45,
	MBF65_SC_SEND_LONG_COMMAND = 239,
	MBF65_SC_GET_BUFFER_INFO = 240,
	MBF65_SC_READ_BUFFER = 241,
	MBF65_SC_NOTIFY_BUFFER_READING_FINISHED = 242,
	MBF65_SC_READ_RS485_PARAMETERS = 250,
	MBF65_SC_WRITE_RS485_PARAMETERS = 251,
	MBF65_SC_CLEAR_DIAGNOSTICS = 252,
	MBF65_SC_GET_DIAGNOSTICS = 253,
	MBF65_SC_GET_DEVICE_INFO = 254
} mbf65_SubfunctionCode;
/*-----------------------------------------------------------------------------------------------*/
/** @brief       65  MODBUS. */
typedef enum mbf65_ResponseCode_TAG
{
	/** @brief &mdash;  ; */
	MBF65_RC_SUCCESS = 0,

	/** @brief &mdash; :      ; */
	MBF65_RC_ERROR_INVALID_LENGTH = 1,

	/** @brief &mdash; :   ; */
	MBF65_RC_ERROR_INVALID_ARGUMENTS = 2,

	/** @brief &mdash;      ; */
	MBF65_RC_ERROR_SERVING_REQUEST = 3,

	/** @brief &mdash; :     ; */
	MBF65_RC_ERROR_ACCESS_NOT_GRANTED = 4,

	/** @brief &mdash; :  ; */
	MBF65_RC_ERROR_INVALID_PASSWORD = 5,

	/** @brief &mdash; :   ; */
	MBF65_RC_ERROR_SESSION_CLOSED = 6,

	/** @brief &mdash; :        ; */
	MBF65_RC_ERROR_RESPONSE_BUFFER_TIMEOUT = 7,

	/** @brief &mdash; :       ; */
	MBF65_RC_ERROR_RESPONSE_BUFFER_TOO_SMALL = 8,

	/** @brief &mdash;    ; */
	MBF65_RC_ERROR_OPENING_FILE = 9,

	/** @brief &mdash;    ; */
	MBF65_RC_ERROR_READING_FILE = 10,

	/** @brief &mdash;    ; */
	MBF65_RC_ERROR_WRITING_FILE = 11,

	/** @brief &mdash;    ; */
	MBF65_RC_ERROR_WRITING_SETTINGS = 12,

	/** @brief &mdash; :       ; */
	MBF65_RC_ERROR_REQUEST_BUFFER_TOO_SMALL = 13,

	/** @brief &mdash; :   ; */
	MBF65_RC_ERROR_INVALID_FILE_ID = 14,

	/** @brief &mdash; :    ; */
	MBF65_RC_ERROR_INVALID_FILE_OPEN_MODE = 15,

	/** @brief &mdash; :        ; */
	MBF65_RC_ERROR_UNSUPPORTED_FILE_OPERATION = 16,

	/** @brief &mdash; :   ; */
	MBF65_RC_UNKNOWN_SUBFUNCTION_CODE = 17,

	/** @brief &mdash; :       ,  
	 *  . */
	MBF65_RC_REQUEST_DATA_SIZE_MISMATCH = 18
} mbf65_ResponseCode;
/*-----------------------------------------------------------------------------------------------*/
/** @brief    ,    65. */
typedef enum mbf65_CompressionType_TAG
{
	/** @brief &mdash;  ; */
	MBF65_CT_UNCOMPRESSED = 0,

	/** @brief &mdash; ZLIB DEFLATE     (RFC 1950  RFC 1951). */
	MBF65_CT_ZLIB_DEFLATE_BEST_SPEED = 1,

	/** @brief &mdash; ZLIB DEFLATE     (RFC 1950  RFC 1951). */
	MBF65_CT_ZLIB_DEFLATE_BEST_COMPRESSION = 2,

	/** @brief &mdash; ZLIB DEFLATE       (RFC 1950  RFC 1951). */
	MBF65_CT_ZLIB_DEFLATE_DEFAULT_COMPRESSION = 3
} mbf65_CompressionType;
/*-----------------------------------------------------------------------------------------------*/
/** @brief     -. */
typedef enum mbf65_LogType_TAG
{
	MBF65_LT_EVENT_LOG = 1,
	MBF65_LT_MESSAGE_LOG = 2,
	MBF65_LT_SETTINGS_LOG = 3,
	MBF65_LT_ALARM_ACK_LOG = 6,
	MBF65_LT_FAULT_LOCATION_LOG = 7,
} mbf65_LogType;
/*-----------------------------------------------------------------------------------------------*/
#pragma pack(push, 1)
/** @brief    . */
typedef struct mbf65_LogRecordHeading_TAG
{
	/** @brief   . */
	uint64_t recordNo;

	/** @brief    (  UNIX    ). */
	uint64_t timestamp;
} mbf65_LogRecordHeading;
#pragma pack(pop)
/*-----------------------------------------------------------------------------------------------*/
#pragma pack(push, 1)
/** @brief     . */
typedef struct mbf65_EventLogRecordBuffer_TAG
{
	/** @brief  . */
	mbf65_LogRecordHeading heading;

	/** @brief  . */
	uint8_t pData[];
} mbf65_EventLogRecordBuffer;
#pragma pack(pop)
/*-----------------------------------------------------------------------------------------------*/
#pragma pack(push, 1)
/** @brief    . */
typedef struct mbf65_EventLogEventDescriptorExp_TAG
{
	uint16_t id;								/**< @brief  . */
	uint8_t name[MBUF65_MAX_EVENT_NAME_LENGTH];	/**< @brief  . */
} mbf65_EventLogEventDescriptorExp;
#pragma pack(pop)
/*-----------------------------------------------------------------------------------------------*/
#pragma pack(push, 1)
/** @brief      . */
typedef struct mbf65_EventLogAOSDescriptorExp_TAG
{
	uint16_t id;	/**< @brief    . */
	uint8_t units;	/**< @brief   (. #mbf65_UnitOfMeasureID). */
} mbf65_EventLogAOSDescriptorExp;
#pragma pack(pop)
/*-----------------------------------------------------------------------------------------------*/
#pragma pack(push, 1)
/** @brief    . */
typedef struct msglog_MessageLogRecordBuffer_TAG
{
	/** @brief  . */
	mbf65_LogRecordHeading heading;

	/** @brief      . */
	uint8_t scadaAccessLevelID;

	/** @brief      . */
	uint8_t kiwiAccessLevelID;

	/** @brief      . */
	uint8_t cpAccessLevelID;

	/** @brief  . */
	char pMessage[];
} msglog_MessageLogRecordBuffer;
#pragma pack(pop)
/*-----------------------------------------------------------------------------------------------*/
#pragma pack(push, 1)
/** @brief     ,    3. */
typedef struct setlog_Record_ver_3_TAG
{
	/** @brief  . */
	mbf65_LogRecordHeading heading;

	/** @brief   . */
	uint16_t settingID;

	/** @brief    ,  . */
	uint8_t accessLevelID;

	/** @brief    . */
	uint8_t sourceID;

	/** @brief   . */
	int32_t oldValue;

	/** @brief   . */
	int32_t newValue;

	/**
	 * @brief    (  0,       
	 *        ).
	 */
	uint8_t programNo;
} setlog_Record_ver_3;
#pragma pack(pop)
/*-----------------------------------------------------------------------------------------------*/
#pragma pack(push, 1)
/** @brief         1  2. */
typedef struct setlog_Record_ver_1_and_2_TAG
{
	/** @brief  . */
	mbf65_LogRecordHeading heading;

	/** @brief   . */
	uint16_t settingID;

	/** @brief    ,  . */
	uint8_t accessLevelID;

	/** @brief    . */
	uint8_t sourceID;

	/** @brief   . */
	int32_t oldValue;

	/** @brief   . */
	int32_t newValue;
} setlog_Record_ver_1_and_2;
#pragma pack(pop)
/*-----------------------------------------------------------------------------------------------*/
/** @brief     . */
typedef struct mbf65_LogInfoExp_TAG
{
	uint32_t logVersion;             /**< @brief   . */
	uint32_t softwareVersion;        /**< @brief  ,  . */
	uint32_t recordSize;             /**< @brief   . */
	uint32_t maxNumberOfRecords;     /**< @brief     . */
	uint32_t currentNumberOfRecords; /**< @brief     . */
	uint64_t lastRecordID;           /**< @brief    . */
	uint64_t lastRecordTimestamp;    /**< @brief     . */
} mbf65_LogInfoExp;
/*-----------------------------------------------------------------------------------------------*/
/** @brief     . */
typedef struct mbf65_OscillogramInfoExp_TAG
{
	/** @brief        . */
	uint64_t timestamp;

	/** @brief    . */
	uint32_t duration;

	/** @brief     . */
	uint32_t fileSize;

	/**
	 * @brief  ,     
	 *        (. #osc_SignalTypeForOscillogramInfo).
	 */
	uint8_t signalType;

	/** @brief  ,     . */
	uint16_t signalID;
} mbf65_OscillogramInfoExp;
/*-----------------------------------------------------------------------------------------------*/
/** @brief     . */
typedef struct mbf65_OscillographInfoExp_TAG
{
	/** @brief  . */
	uint32_t numberOfOscillograms;

	/** @brief    ( ) . */
	mbf65_OscillogramInfoExp latestOscillogram;
} mbf65_OscillographInfoExp;
/*-----------------------------------------------------------------------------------------------*/
/** @brief     -. */
typedef struct mbf65_FlashInfoExp_TAG
{
	uint32_t totalSize;       /**< @brief   -  . */
	uint32_t sizeOfFreeSpace; /**< @brief     . */
} mbf65_FlashInfoExp;
/*-----------------------------------------------------------------------------------------------*/
/** @brief    . */
typedef struct mbf65_BufferInfo_TAG
{
	uint32_t dataSize;	/**< @brief     . */
} mbf65_BufferInfoExp;

/*=====================================   =======================================*/

bool mbf65_sendRequest(modbus_t* pModbus, uint8_t address, uint8_t subfunction,
                       const void* pRequestData, uint16_t requestDataSize, void* pResponseBuffer, 
                       uint16_t responseBufferSize, uint16_t* pResponseDataSize, 
                       mbf65_ResponseCode* pResponseCode, bool* pIsLongResponse);
/*-----------------------------------------------------------------------------------------------*/
uint16_t mbf65_readUint16FromBuf(const void* pBuf);
/*-----------------------------------------------------------------------------------------------*/
uint32_t mbf65_readUint32FromBuf(const void* pBuf);
/*-----------------------------------------------------------------------------------------------*/
float mbf65_readFloatFromBuf(const void* pBuf);
/*-----------------------------------------------------------------------------------------------*/
uint64_t mbf65_readUint64FromBuf(const void* pBuf);
/*-----------------------------------------------------------------------------------------------*/
void* mbf65_writeUint16ToBuf(void* pBuf, uint16_t value);
/*-----------------------------------------------------------------------------------------------*/
void* mbf65_writeUint32ToBuf(void* pBuf, uint32_t value);
/*-----------------------------------------------------------------------------------------------*/
void* mbf65_writeUint64ToBuf(void* pBuf, uint64_t value);
/*-----------------------------------------------------------------------------------------------*/
void* mbf65_writeFloatToBuf(void* pBuf, float value);
/*-----------------------------------------------------------------------------------------------*/
int mbf65_getBinaryValueFromBitArray(const void* pBitArray, uint32_t bitIndex);
/*-----------------------------------------------------------------------------------------------*/
int mbf65_downloadFile(modbus_t* pModbus, uint8_t address, const char* pRemoteFilename,
	const char* pLocalFilename, uint32_t* pFileSize);
/*-----------------------------------------------------------------------------------------------*/
int mbf65_uploadFile(modbus_t* pModbus, uint8_t address, const char* pRemoteFilename,
	const char* pLocalFilename, uint32_t* pFileSize);
/*-----------------------------------------------------------------------------------------------*/
int mbf65_downloadFileCompressed(modbus_t* pModbus, uint8_t address, const char* pRemoteFilename,
	const char* pLocalFilename, mbf65_CompressionType compressionType,
	uint32_t* pOriginalFileSize, uint32_t* pCompressedFileSize);
/*-----------------------------------------------------------------------------------------------*/
int mbf65_applyProject(modbus_t* pModbus, uint8_t address);
/*-----------------------------------------------------------------------------------------------*/
int mbf65_readNumberOfOscillograms(modbus_t* pModbus, uint8_t address, 
	uint16_t* pNumberOfOscillograms);
/*-----------------------------------------------------------------------------------------------*/
int mbf65_readOscillogramDescriptors(modbus_t* pModbus, uint8_t address,
	uint16_t firstOscillogramNumber, uint16_t numberOfDescriptorsToRead,
	mbf65_OscillogramInfoExp* pBuffer, uint16_t* pNumberOfDescriptorsRead);
/*-----------------------------------------------------------------------------------------------*/
int mbf65_downloadOscillogram(modbus_t* pModbus, uint8_t address, int oscillogramNumber,
	const char* pLocalFilename, uint32_t* pFileSize);
/*-----------------------------------------------------------------------------------------------*/
int mbf65_downloadOscillogramCompressed(modbus_t* pModbus, uint8_t address, int oscillogramNumber,
	const char* pLocalFilename, mbf65_CompressionType compressionType,
	uint32_t* pOriginalFileSize, uint32_t* pCompressedFileSize);
/*-----------------------------------------------------------------------------------------------*/
int mbf65_readBufferInfo(modbus_t* pModbus, uint8_t address, mbf65_BufferInfoExp* pBufferInfo);
/*-----------------------------------------------------------------------------------------------*/
int mbf65_readDataFromBuffer(modbus_t* pModbus, uint8_t address, void* pData, uint32_t offset, 
	uint32_t size, uint32_t* pNumberOfBytesRead);
/*-----------------------------------------------------------------------------------------------*/
int mbf65_readLogInfo(modbus_t* pModbus, uint8_t address, mbf65_LogType logType, 
	mbf65_LogInfoExp* pInfo);
/*-----------------------------------------------------------------------------------------------*/
int mbf65_readDescriptorOfEventLogRecord(modbus_t* pModbus, uint8_t address, void* pBuffer,
	uint32_t bufferSize, uint32_t* pNumberOfBytesRead);
/*-----------------------------------------------------------------------------------------------*/
int mbf65_readFullLogRecords(modbus_t* pModbus, uint8_t address, mbf65_LogType logType,
	uint32_t recordSize, uint32_t firstRecordNumber, uint32_t numberOfRecordsToRead, 
	void* pBuffer, uint32_t bufferSize, uint32_t* pNumberOfRecordsRead);
/*-----------------------------------------------------------------------------------------------*/
int mbf65_readBriefLogRecords(modbus_t* pModbus, uint8_t address, mbf65_LogType logType,
	uint32_t recordSize, uint32_t firstRecordNumber, uint32_t numberOfRecordsToRead,
	void* pBuffer, uint32_t bufferSize, uint32_t* pNumberOfRecordsRead);
/*-----------------------------------------------------------------------------------------------*/

/*@}*/

#ifdef __cplusplus
}
#endif

#endif /* SOURCE_MODBUSFUNCTION65_H_ */
