﻿/**
 * @file
 * @brief Содержит объявления констант, типов и функций модуля @ref KIWIDatabaseIDs "KIWIDatabaseIDs".
 */

#ifndef APPLICATION_USER_BFSOFTWARE_KIWIDATABASEIDS_H_
#define APPLICATION_USER_BFSOFTWARE_KIWIDATABASEIDS_H_

#include <stdint.h>

#ifdef __cplusplus
extern "C"
{
#endif

/**
 * @defgroup KIWIDatabaseIDs Модуль KIWIDatabaseIDs
 *
 * Этот модуль определяет идентификаторы уставок, сигналов и событий, используемые в базе данных
 * KIWI.
 *
 * @version 1.0.0
 * @date 15.07.2016
 * @copyright ООО НПП "Микропроцессорные технологии"
 * @author А.Молдованов
 */
/*@{*/

/*======================================= МАКРООПРЕДЕЛЕНИЯ ======================================*/

/** @brief Недействительное значение идентификатора. */
#define KIWI_INVALID_ID  (UINT16_MAX)

/*======================================== ТИПЫ ДАННЫХ ==========================================*/

/** @brief Тип идентификатора группы уставок, используемый в базе данных KIWI. */
typedef enum kiwi_SettingGroupID_TAG
{
	KIWI_SGID_DISKRETNYJE_VKHODY = 0,
	KIWI_SGID_DTO_I_DZT = 1,
	KIWI_SGID_NB = 2,
	KIWI_SGID_TO_I_MTZ_VN = 3,
	KIWI_SGID_MTZ_SNT = 4,
	KIWI_SGID_MTZ_NN = 5,
	KIWI_SGID_DZP = 6,
	KIWI_SGID_GZ = 7,
	KIWI_SGID_PO_ZPO = 8,
	KIWI_SGID_VZ_VS = 9,
	KIWI_SGID_UROV = 10,
	KIWI_SGID_OTKL = 11,
	KIWI_SGID_USTAVKI = 12,
	KIWI_SGID_AVARIJNAJA_SIGN = 13,
	KIWI_SGID_PREDUPR_SIGN = 14,
	KIWI_SGID_SJOM_SIGN = 15,
	KIWI_SGID_GIBKAJA_LOGIKA = 50,
	KIWI_SGID_KOEFFICIJENTY_TRANSFORMACII = 51,
	KIWI_SGID_PARAMETRY_OBJEKTA = 52,
	KIWI_SGID_OSCILLOGRAF = 53,
	KIWI_SGID_KONFIGURACIJA_BLOKA = 54,
	KIWI_SGID_PUSK_ORGANY = 37,
	KIWI_SGID_VKHODY_ALGORITMOV = 38,
	KIWI_SGID_OTLADKA = 40,

	KIWI_SGID_INVALID_SETTING_GROUP = KIWI_INVALID_ID
} kiwi_SettingGroupID;
/*-----------------------------------------------------------------------------------------------*/
/** @brief Тип идентификатора уставки. */
typedef enum kiwi_SettingID_TAG
{
	KIWI_SETID_V001_N1 = 0,
	KIWI_SETID_IDTO_N1 = 1,
	KIWI_SETID_V002_N1 = 2,
	KIWI_SETID_IDZT_N1 = 3,
	KIWI_SETID_ITORM1_N1 = 4,
	KIWI_SETID_KTORM1_N1 = 5,
	KIWI_SETID_ITORM2_N1 = 6,
	KIWI_SETID_KTORM2_N1 = 7,
	KIWI_SETID_IPB_2G_N1 = 8,
	KIWI_SETID_TDZT_N1 = 9,
	KIWI_SETID_V003_N1 = 10,
	KIWI_SETID_TPB_2G_N1 = 11,
	KIWI_SETID_V004_N1 = 12,
	KIWI_SETID_IPB_5G_N1 = 13,
	KIWI_SETID_V005_N1 = 14,
	KIWI_SETID_TPB_5G_N1 = 15,
	KIWI_SETID_V010_N2 = 16,
	KIWI_SETID_INB_N2 = 17,
	KIWI_SETID_TNB_N2 = 18,
	KIWI_SETID_V101_N3 = 19,
	KIWI_SETID_ITO_VN_N3 = 20,
	KIWI_SETID_TTO_VN_N3 = 21,
	KIWI_SETID_V102_N3 = 22,
	KIWI_SETID_V104_N3 = 23,
	KIWI_SETID_V106_N3 = 24,
	KIWI_SETID_V107_N3 = 25,
	KIWI_SETID_IMTZ_VN_N3 = 26,
	KIWI_SETID_TMTZ_VN_NN_N3 = 27,
	KIWI_SETID_TMTZ_VN_SN_N3 = 28,
	KIWI_SETID_TMTZ_VN_N3 = 29,
	KIWI_SETID_TUMTZ_VN_N3 = 30,
	KIWI_SETID_V121_N4 = 31,
	KIWI_SETID_V124_N4 = 32,
	KIWI_SETID_IMTZ_SN_N4 = 33,
	KIWI_SETID_TMTZ_SN_N4 = 34,
	KIWI_SETID_V126_N4 = 35,
	KIWI_SETID_TUMTZ_SN_N4 = 36,
	KIWI_SETID_V128_N4 = 37,
	KIWI_SETID_DTMTZ_SN_N4 = 38,
	KIWI_SETID_V111_N5 = 39,
	KIWI_SETID_V114_N5 = 40,
	KIWI_SETID_IMTZ_NN_N5 = 41,
	KIWI_SETID_TMTZ_NN_N5 = 42,
	KIWI_SETID_V116_N5 = 43,
	KIWI_SETID_TUMTZ_NN_N5 = 44,
	KIWI_SETID_V118_N5 = 45,
	KIWI_SETID_DTMTZ_NN_N5 = 46,
	KIWI_SETID_V131_VN_N6 = 47,
	KIWI_SETID_IZP_VN_N6 = 48,
	KIWI_SETID_TZP_VN_N6 = 49,
	KIWI_SETID_V132_VN_N6 = 50,
	KIWI_SETID_TZP_VN_OTKL_N6 = 51,
	KIWI_SETID_V133_VN_N6 = 52,
	KIWI_SETID_TRAZGR_VN_1_N6 = 53,
	KIWI_SETID_V134_VN_N6 = 54,
	KIWI_SETID_TRAZGR_VN_2_N6 = 55,
	KIWI_SETID_V131_SN_N6 = 56,
	KIWI_SETID_IZP_SN_N6 = 57,
	KIWI_SETID_TZP_SN_N6 = 58,
	KIWI_SETID_V132_SN_N6 = 59,
	KIWI_SETID_TZP_SN_OTKL_N6 = 60,
	KIWI_SETID_V133_SN_N6 = 61,
	KIWI_SETID_TRAZGR_SN_1_N6 = 62,
	KIWI_SETID_V134_SN_N6 = 63,
	KIWI_SETID_TRAZGR_SN_2_N6 = 64,
	KIWI_SETID_V131_NN_N6 = 65,
	KIWI_SETID_IZP_NN_N6 = 66,
	KIWI_SETID_TZP_NN_N6 = 67,
	KIWI_SETID_V132_NN_N6 = 68,
	KIWI_SETID_TZP_NN_OTKL_N6 = 69,
	KIWI_SETID_V133_NN_N6 = 70,
	KIWI_SETID_TRAZGR_NN_1_N6 = 71,
	KIWI_SETID_V134_NN_N6 = 72,
	KIWI_SETID_TRAZGR_NN_2_N6 = 73,
	KIWI_SETID_V131_OO_N6 = 74,
	KIWI_SETID_IZP_OO_N6 = 75,
	KIWI_SETID_TZP_OO_N6 = 76,
	KIWI_SETID_V132_OO_N6 = 77,
	KIWI_SETID_TZP_OO_OTKL_N6 = 78,
	KIWI_SETID_V133_OO_N6 = 79,
	KIWI_SETID_TRAZGR_OO_1_N6 = 80,
	KIWI_SETID_V134_OO_N6 = 81,
	KIWI_SETID_TRAZGR_OO_2_N6 = 82,
	KIWI_SETID_TGZ1_N7 = 83,
	KIWI_SETID_TGZ2_N7 = 84,
	KIWI_SETID_TGZ_RPN_N7 = 85,
	KIWI_SETID_V201_N7 = 86,
	KIWI_SETID_V202_N7 = 87,
	KIWI_SETID_V203_N7 = 88,
	KIWI_SETID_TKI_GZ_N7 = 89,
	KIWI_SETID_TGZ_SIGN_N7 = 90,
	KIWI_SETID_V211_N8 = 91,
	KIWI_SETID_V214_N8 = 92,
	KIWI_SETID_V219_N8 = 93,
	KIWI_SETID_IPO1_N8 = 94,
	KIWI_SETID_TPO1_N8 = 95,
	KIWI_SETID_V212_N8 = 96,
	KIWI_SETID_IPO2_N8 = 97,
	KIWI_SETID_TPO2_N8 = 98,
	KIWI_SETID_V213_N8 = 99,
	KIWI_SETID_IPO3_N8 = 100,
	KIWI_SETID_TPO3_N8 = 101,
	KIWI_SETID_V215_N8 = 102,
	KIWI_SETID_TZPO1_N8 = 103,
	KIWI_SETID_V216_N8 = 104,
	KIWI_SETID_TZPO2_N8 = 105,
	KIWI_SETID_V217_N8 = 106,
	KIWI_SETID_TZPO3_N8 = 107,
	KIWI_SETID_V218_N8 = 108,
	KIWI_SETID_TZPO4_N8 = 109,
	KIWI_SETID_TZPO_PUSK_N8 = 110,
	KIWI_SETID_TVS_TM_N9 = 111,
	KIWI_SETID_TVZ_TM_N9 = 112,
	KIWI_SETID_TVS_TO_N9 = 113,
	KIWI_SETID_TVZ_TO_N9 = 114,
	KIWI_SETID_TVS_UM_N9 = 115,
	KIWI_SETID_TVZ_N9 = 116,
	KIWI_SETID_TVZ_AVR_N9 = 117,
	KIWI_SETID_TVS_PK_N9 = 118,
	KIWI_SETID_TVZ_PK_N9 = 119,
	KIWI_SETID_TVS_OK_N9 = 120,
	KIWI_SETID_V301_N10 = 121,
	KIWI_SETID_IUROV_VN_N10 = 122,
	KIWI_SETID_TUROV_VN_N10 = 123,
	KIWI_SETID_V302_N10 = 124,
	KIWI_SETID_V305_N10 = 125,
	KIWI_SETID_IUROV_SN_N10 = 126,
	KIWI_SETID_TUROV_SN_N10 = 127,
	KIWI_SETID_V306_N10 = 128,
	KIWI_SETID_V307_N10 = 187,
	KIWI_SETID_V308_N10 = 188,
	KIWI_SETID_TOK_N11 = 129,
	KIWI_SETID_V881_N12 = 130,
	KIWI_SETID_TPR_1_N12 = 131,
	KIWI_SETID_TAS_DOP_N13 = 132,
	KIWI_SETID_V900_N14 = 133,
	KIWI_SETID_TPS_DOP_N14 = 134,
	KIWI_SETID_VGL1_N50 = 135,
	KIWI_SETID_VGL2_N50 = 136,
	KIWI_SETID_VGL3_N50 = 137,
	KIWI_SETID_VGL4_N50 = 138,
	KIWI_SETID_VGL5_N50 = 139,
	KIWI_SETID_VGL6_N50 = 140,
	KIWI_SETID_VGL7_N50 = 141,
	KIWI_SETID_VGL8_N50 = 142,
	KIWI_SETID_VGL9_N50 = 143,
	KIWI_SETID_VGL10_N50 = 144,
	KIWI_SETID_TGL1_N50 = 145,
	KIWI_SETID_TGL2_N50 = 146,
	KIWI_SETID_TGL3_N50 = 147,
	KIWI_SETID_TGL4_N50 = 148,
	KIWI_SETID_TGL5_N50 = 149,
	KIWI_SETID_TGL6_N50 = 150,
	KIWI_SETID_TGL7_N50 = 151,
	KIWI_SETID_TGL8_N50 = 152,
	KIWI_SETID_TGL9_N50 = 153,
	KIWI_SETID_TGL10_N50 = 154,
	KIWI_SETID_IVN_MAKS_1_N50 = 155,
	KIWI_SETID_IVN_MAKS_2_N50 = 156,
	KIWI_SETID_IVN_MAKS_3_N50 = 157,
	KIWI_SETID_IVN_MIN_1_N50 = 158,
	KIWI_SETID_ISN_MAKS_1_N50 = 159,
	KIWI_SETID_ISN_MAKS_2_N50 = 160,
	KIWI_SETID_ISN_MAKS_3_N50 = 161,
	KIWI_SETID_ISN_MIN_1_N50 = 162,
	KIWI_SETID_INN_MAKS_1_N50 = 163,
	KIWI_SETID_INN_MAKS_2_N50 = 164,
	KIWI_SETID_INN_MAKS_3_N50 = 165,
	KIWI_SETID_INN_MIN_1_N50 = 166,
	KIWI_SETID_IN_TT_VN_P_N51 = 167,
	KIWI_SETID_IN_TT_SN_P_N51 = 168,
	KIWI_SETID_IN_TT_NN_P_N51 = 169,
	KIWI_SETID_IN_TT_VN_V_N51 = 170,
	KIWI_SETID_IN_TT_SN_V_N51 = 171,
	KIWI_SETID_IN_TT_NN_V_N51 = 172,
	KIWI_SETID_VYBOR_DIAPAZONA_N51 = 173,
	KIWI_SETID_I_VN_D_N51 = 174,
	KIWI_SETID_I_SN_D_N51 = 175,
	KIWI_SETID_I_NN_D_N51 = 176,
	KIWI_SETID_TIP_N52 = 177,
	KIWI_SETID_SN_N52 = 178,
	KIWI_SETID_UN_VN_N52 = 179,
	KIWI_SETID_UN_SN_N52 = 180,
	KIWI_SETID_UN_NN_N52 = 181,
	KIWI_SETID_IN_N52 = 182,
	KIWI_SETID_TOSC_DOAV_N53 = 183,
	KIWI_SETID_TOSC_N53 = 184,
	KIWI_SETID_MVV_N54 = 185,
	KIWI_SETID_OBJEKT_N54 = 186,

	/* Идентификаторы фиктивных уставок, которые используются только в пульте. */
	KIWI_SETID_PAROL_PULTA = 9999,

	KIWI_SETID_INVALID_SETTING = KIWI_INVALID_ID
} kiwi_SettingID;
/*-----------------------------------------------------------------------------------------------*/
/** @brief Тип идентификатора аналогового входа. */
typedef enum kiwi_AnalogInputID_TAG
{
	KIWI_AIID_INPUT_1 = 0,
	KIWI_AIID_INPUT_2 = 1,
	KIWI_AIID_INPUT_3 = 2,
	KIWI_AIID_INPUT_4 = 3,
	KIWI_AIID_INPUT_5 = 4,
	KIWI_AIID_INPUT_6 = 5,
	KIWI_AIID_INPUT_7 = 6,
	KIWI_AIID_INPUT_8 = 7,
	KIWI_AIID_INPUT_9 = 8,

	KIWI_AIID_INVALID_INPUT = KIWI_INVALID_ID
} kiwi_AnalogInputID;
/*-----------------------------------------------------------------------------------------------*/
/** @brief Тип идентификатора двоичного входа. */
typedef enum kiwi_BinaryInputID_TAG
{
	KIWI_BIID_INPUT_1 = 0,
	KIWI_BIID_INPUT_2 = 1,
	KIWI_BIID_INPUT_3 = 2,
	KIWI_BIID_INPUT_4 = 3,
	KIWI_BIID_INPUT_5 = 4,
	KIWI_BIID_INPUT_6 = 5,
	KIWI_BIID_INPUT_7 = 6,
	KIWI_BIID_INPUT_8 = 7,
	KIWI_BIID_INPUT_9 = 8,
	KIWI_BIID_INPUT_10 = 9,
	KIWI_BIID_INPUT_11 = 10,
	KIWI_BIID_INPUT_12 = 11,
	KIWI_BIID_INPUT_13 = 12,
	KIWI_BIID_INPUT_14 = 13,
	KIWI_BIID_INPUT_15 = 14,
	KIWI_BIID_INPUT_16 = 15,
	KIWI_BIID_INPUT_17 = 16,
	KIWI_BIID_INPUT_18 = 17,
	KIWI_BIID_INPUT_19 = 18,
	KIWI_BIID_INPUT_20 = 19,
	KIWI_BIID_INPUT_21 = 20,
	KIWI_BIID_INPUT_22 = 21,
	KIWI_BIID_INPUT_23 = 22,
	KIWI_BIID_INPUT_24 = 23,
	KIWI_BIID_INPUT_25 = 24,
	KIWI_BIID_INPUT_26 = 25,
	KIWI_BIID_INPUT_27 = 26,
	KIWI_BIID_INPUT_28 = 27,
	KIWI_BIID_INPUT_29 = 28,
	KIWI_BIID_INPUT_30 = 29,
	KIWI_BIID_INPUT_31 = 30,
	KIWI_BIID_INPUT_32 = 31,
	KIWI_BIID_INPUT_33 = 32,
	KIWI_BIID_INPUT_34 = 33,
	KIWI_BIID_INPUT_35 = 34,
	KIWI_BIID_INPUT_36 = 35,
	KIWI_BIID_INPUT_37 = 36,
	KIWI_BIID_INPUT_38 = 37,
	KIWI_BIID_INPUT_39 = 38,
	KIWI_BIID_INPUT_40 = 39,
	KIWI_BIID_INPUT_41 = 40,
	KIWI_BIID_INPUT_42 = 41,

	KIWI_BIID_INVALID_INPUT = KIWI_INVALID_ID
} kiwi_BinaryInputID;
/*-----------------------------------------------------------------------------------------------*/
/** @brief Тип идентификатора двоичного выхода. */
typedef enum kiwi_BinaryOutputID_TAG
{
	KIWI_BOID_OUTPUT_1 = 0,
	KIWI_BOID_OUTPUT_2 = 1,
	KIWI_BOID_OUTPUT_3 = 2,
	KIWI_BOID_OUTPUT_4 = 3,
	KIWI_BOID_OUTPUT_5 = 4,
	KIWI_BOID_OUTPUT_6 = 5,
	KIWI_BOID_OUTPUT_7 = 6,
	KIWI_BOID_OUTPUT_8 = 7,
	KIWI_BOID_OUTPUT_9 = 8,
	KIWI_BOID_OUTPUT_10 = 9,
	KIWI_BOID_OUTPUT_11 = 10,
	KIWI_BOID_OUTPUT_12 = 11,
	KIWI_BOID_OUTPUT_13 = 12,
	KIWI_BOID_OUTPUT_14 = 13,
	KIWI_BOID_OUTPUT_15 = 14,
	KIWI_BOID_OUTPUT_16 = 15,
	KIWI_BOID_OUTPUT_17 = 16,
	KIWI_BOID_OUTPUT_18 = 17,
	KIWI_BOID_OUTPUT_19 = 18,
	KIWI_BOID_OUTPUT_20 = 19,
	KIWI_BOID_OUTPUT_21 = 20,
	KIWI_BOID_OUTPUT_22 = 21,
	KIWI_BOID_OUTPUT_23 = 22,
	KIWI_BOID_OUTPUT_24 = 23,
	KIWI_BOID_OUTPUT_25 = 24,
	KIWI_BOID_OUTPUT_26 = 25,
	KIWI_BOID_OUTPUT_27 = 26,
	KIWI_BOID_OUTPUT_28 = 27,

	KIWI_BOID_INVALID_OUTPUT = KIWI_INVALID_ID
} kiwi_BinaryOutputID;
/*-----------------------------------------------------------------------------------------------*/
/** @brief Тип идентификатора двоичного входного сигнала. */
typedef enum kiwi_BinaryInputSignalID_TAG
{
	KIWI_BISID_VYVOD_DTO_N1_1 = 0,
	KIWI_BISID_VYVOD_DZT_N1_2 = 1,
	KIWI_BISID_VYVOD_TO_VN_N1_3 = 2,
	KIWI_BISID_VYVOD_MTZ_VN_N1_4 = 3,
	KIWI_BISID_RPO_VN_N1_5 = 4,
	KIWI_BISID_RPO_SN_N1_6 = 5,
	KIWI_BISID_RPO_NN_N1_7 = 6,
	KIWI_BISID_PON_MTZ_SN_N1_8 = 7,
	KIWI_BISID_PON_MTZ_NN_N1_9 = 8,
	KIWI_BISID_USK_MTZ_VN_N1_10 = 9,
	KIWI_BISID_VYVOD_MTZ_SN_N1_11 = 10,
	KIWI_BISID_USK_MTZ_SN_N1_12 = 11,
	KIWI_BISID_VYVOD_MTZ_NN_N1_13 = 12,
	KIWI_BISID_USK_MTZ_NN_N1_14 = 13,
	KIWI_BISID_VYVOD_PEREGRUZKA_VN_N1_15 = 14,
	KIWI_BISID_VYVOD_PEREGRUZKA_SN_N1_16 = 15,
	KIWI_BISID_VYVOD_PEREGRUZKA_NN_N1_17 = 16,
	KIWI_BISID_VYVOD_PEREGRUZKA_OO_N1_18 = 17,
	KIWI_BISID_GZ_T_1_N1_19 = 18,
	KIWI_BISID_GZ_T_2_N1_20 = 19,
	KIWI_BISID_GZ_RPN_N1_21 = 20,
	KIWI_BISID_KI_GZ_T_1_N1_22 = 21,
	KIWI_BISID_KI_GZ_T_2_N1_23 = 22,
	KIWI_BISID_KI_GZ_RPN_N1_24 = 23,
	KIWI_BISID_GZ_T_1_NA_OTKL_N1_25 = 24,
	KIWI_BISID_GZ_T_2_NA_SIGNAL_N1_26 = 25,
	KIWI_BISID_GZ_RPN_NA_SIGNAL_N1_27 = 26,
	KIWI_BISID_PITANIE_GZ_N1_28 = 27,
	KIWI_BISID_T_MASLA_SRAB_N1_29 = 28,
	KIWI_BISID_T_MASLA_VOZVR_N1_30 = 29,
	KIWI_BISID_OHL_OTKLJUCHENO_N1_31 = 30,
	KIWI_BISID_OTKL_OT_SHAOT_N1_32 = 31,
	KIWI_BISID_T_MASLA_1_ST_N1_33 = 32,
	KIWI_BISID_T_MASLA_2_ST_N1_34 = 33,
	KIWI_BISID_T_OBMOTKI_1_ST_N1_35 = 34,
	KIWI_BISID_T_OBMOTKI_2_ST_N1_36 = 35,
	KIWI_BISID_UROVEN_MASLA_SIGN_N1_37 = 36,
	KIWI_BISID_VNESH_ZASHH_BEZ_AVR_N1_38 = 37,
	KIWI_BISID_VNESH_ZASHH_S_AVR_N1_39 = 38,
	KIWI_BISID_PRED_KLAPAN_SIGN_N1_40 = 39,
	KIWI_BISID_PRED_KLAPAN_OTKL_N1_41 = 40,
	KIWI_BISID_OTSECH_KLAPAN_SIGN_N1_42 = 41,
	KIWI_BISID_VYVOD_UROV_VN_N1_43 = 42,
	KIWI_BISID_VYVOD_UROV_SN_N1_44 = 43,
	KIWI_BISID_RPV_VN_N1_45 = 44,
	KIWI_BISID_RPV_SN_N1_46 = 45,
	KIWI_BISID_OTKL_OT_UROV_SN_N1_47 = 46,
	KIWI_BISID_OTKL_OT_UROV_NN_N1_48 = 47,
	KIWI_BISID_DU_N1_49 = 48,
	KIWI_BISID_REZHIM_NALADKI_N1_50 = 49,
	KIWI_BISID_PROGRAMMA_2_N1_51 = 50,
	KIWI_BISID_PROGRAMMA_2_ASU_N1_52 = 51,
	KIWI_BISID_PROGRAMMA_2_PU_N1_53 = 52,
	KIWI_BISID_PROGRAMMA_2_KIWI_N1_54 = 53,
	KIWI_BISID_PROGRAMMA_1_N1_55 = 54,
	KIWI_BISID_PROGRAMMA_1_ASU_N1_56 = 55,
	KIWI_BISID_PROGRAMMA_1_PU_N1_57 = 56,
	KIWI_BISID_PROGRAMMA_1_KIWI_N1_58 = 57,
	KIWI_BISID_NA_AVAR_SIGN_N1_59 = 58,
	KIWI_BISID_NA_PRED_SIGN_N1_60 = 59,
	KIWI_BISID_SJEM_SIGNALIZACII_DV_N1_61 = 60,
	KIWI_BISID_SJEM_SIGNALIZACII_ASU_N1_62 = 61,
	KIWI_BISID_SJEM_SIGNALIZACII_PU_N1_63 = 62,
	KIWI_BISID_SJEM_SIGNALIZACII_KIWI_N1_64 = 63,
	KIWI_BISID_PUSK_OSC_S_N1_65 = 64,
	KIWI_BISID_PUSK_OSC_I_N1_66 = 65,
	KIWI_BISID_PUSK_OSC_ASU_N1_67 = 66,
	KIWI_BISID_PUSK_OSC_PU_N1_68 = 67,
	KIWI_BISID_PUSK_OSC_KIWI_N1_69 = 68,
	KIWI_BISID_NEISPRAVNOST_ALTEI_N1_70 = 69,
	KIWI_BISID_OTKAZ_ALTEI_N1_71 = 70,

	KIWI_BISID_INVALID_SIGNAL = KIWI_INVALID_ID
} kiwi_BinaryInputSignalID;
/*-----------------------------------------------------------------------------------------------*/
/** @brief Тип идентификатора двоичного выходного сигнала. */
typedef enum kiwi_BinaryOutputSignalID_TAG
{
	KIWI_BOSID_DTO_A_SRAB_N1_1 = 0,
	KIWI_BOSID_DTO_B_SRAB_N1_2 = 1,
	KIWI_BOSID_DTO_C_SRAB_N1_3 = 2,
	KIWI_BOSID_DTO_NA_OTKL_N1_4 = 3,
	KIWI_BOSID_DZT_A_PUSK_N1_5 = 4,
	KIWI_BOSID_DZT_B_PUSK_N1_6 = 5,
	KIWI_BOSID_DZT_C_PUSK_N1_7 = 6,
	KIWI_BOSID_DZT_PUSK_N1_8 = 7,
	KIWI_BOSID_DZT_A_SRAB_N1_9 = 8,
	KIWI_BOSID_DZT_B_SRAB_N1_10 = 9,
	KIWI_BOSID_DZT_C_SRAB_N1_11 = 10,
	KIWI_BOSID_DZT_NA_OTKL_N1_12 = 11,
	KIWI_BOSID_IPB_2G_A_N1_13 = 12,
	KIWI_BOSID_IPB_2G_B_N1_14 = 13,
	KIWI_BOSID_IPB_2G_C_N1_15 = 14,
	KIWI_BOSID_PB_2G_N1_16 = 15,
	KIWI_BOSID_IPB_5G_A_N1_17 = 16,
	KIWI_BOSID_IPB_5G_B_N1_18 = 17,
	KIWI_BOSID_IPB_5G_C_N1_19 = 18,
	KIWI_BOSID_PB_5G_N1_20 = 19,
	KIWI_BOSID_NB_A_SRAB_N2_1 = 20,
	KIWI_BOSID_NB_B_SRAB_N2_2 = 21,
	KIWI_BOSID_NB_C_SRAB_N2_3 = 22,
	KIWI_BOSID_NB_SRAB_N2_4 = 23,
	KIWI_BOSID_NB_PUSK_N2_5 = 24,
	KIWI_BOSID_TO_VN_PUSK_N3_1 = 25,
	KIWI_BOSID_TO_VN_NA_OTKL_N3_2 = 26,
	KIWI_BOSID_MTZ_VN_PUSK_N3_3 = 27,
	KIWI_BOSID_MTZ_VN_NA_OTKL_NN_N3_4 = 28,
	KIWI_BOSID_MTZ_VN_NA_OTKL_SN_N3_5 = 29,
	KIWI_BOSID_MTZ_VN_NA_OTKL_T_N3_6 = 30,
	KIWI_BOSID_UMTZ_VN_NA_OTKL_T_N3_7 = 31,
	KIWI_BOSID_MTZ_SN_PUSK_N4_1 = 32,
	KIWI_BOSID_MTZ_SN_NA_OTKL_SN_N4_2 = 33,
	KIWI_BOSID_UMTZ_SN_NA_OTKL_SN_N4_3 = 34,
	KIWI_BOSID_MTZ_SN_NA_OTKL_T_N4_4 = 35,
	KIWI_BOSID_MTZ_NN_PUSK_N5_1 = 36,
	KIWI_BOSID_MTZ_NN_NA_OTKL_NN_N5_2 = 37,
	KIWI_BOSID_UMTZ_NN_NA_OTKL_NN_N5_3 = 38,
	KIWI_BOSID_MTZ_NN_NA_OTKL_T_N5_4 = 39,
	KIWI_BOSID_PEREGRUZKA_VN_PUSK_N6_1 = 40,
	KIWI_BOSID_PEREGRUZKA_VN_N6_2 = 41,
	KIWI_BOSID_PEREGRUZKA_VN_NA_OTKL_N6_3 = 42,
	KIWI_BOSID_RAZGRUZKA_VN_1_N6_4 = 43,
	KIWI_BOSID_RAZGRUZKA_VN_2_N6_5 = 44,
	KIWI_BOSID_PEREGRUZKA_SN_PUSK_N6_6 = 45,
	KIWI_BOSID_PEREGRUZKA_SN_N6_7 = 46,
	KIWI_BOSID_PEREGRUZKA_SN_NA_OTKL_N6_8 = 47,
	KIWI_BOSID_RAZGRUZKA_SN_1_N6_9 = 48,
	KIWI_BOSID_RAZGRUZKA_SN_2_N6_10 = 49,
	KIWI_BOSID_PEREGRUZKA_NN_PUSK_N6_11 = 50,
	KIWI_BOSID_PEREGRUZKA_NN_N6_12 = 51,
	KIWI_BOSID_PEREGRUZKA_NN_NA_OTKL_N6_13 = 52,
	KIWI_BOSID_RAZGRUZKA_NN_1_N6_14 = 53,
	KIWI_BOSID_RAZGRUZKA_NN_2_N6_15 = 54,
	KIWI_BOSID_PEREGRUZKA_OO_PUSK_N6_16 = 55,
	KIWI_BOSID_PEREGRUZKA_OO_N6_17 = 56,
	KIWI_BOSID_PEREGRUZKA_OO_NA_OTKL_N6_18 = 57,
	KIWI_BOSID_RAZGRUZKA_OO_1_N6_19 = 58,
	KIWI_BOSID_RAZGRUZKA_OO_2_N6_20 = 59,
	KIWI_BOSID_GZ_T_1_SRAB_N7_1 = 60,
	KIWI_BOSID_GZ_T_1_NEISPR_N7_2 = 61,
	KIWI_BOSID_GZ_T_2_SRAB_N7_3 = 62,
	KIWI_BOSID_GZ_T_2_NEISPR_N7_4 = 63,
	KIWI_BOSID_GZ_RPN_SRAB_N7_5 = 64,
	KIWI_BOSID_GZ_RPN_NEISPR_N7_6 = 65,
	KIWI_BOSID_GZ_NA_OTKL_N7_7 = 66,
	KIWI_BOSID_GZ_NEISPRAVNOST_N7_8 = 67,
	KIWI_BOSID_VYSOKAJA_T_MASLA_N8_1 = 68,
	KIWI_BOSID_PUSK_OHL_1_N8_2 = 69,
	KIWI_BOSID_PUSK_OHL_2_N8_3 = 70,
	KIWI_BOSID_PUSK_OHL_3_N8_4 = 71,
	KIWI_BOSID_ZPO_PUSK_N8_5 = 72,
	KIWI_BOSID_ZPO_1_SRAB_N8_6 = 73,
	KIWI_BOSID_ZPO_2_SRAB_N8_7 = 74,
	KIWI_BOSID_ZPO_3_SRAB_N8_8 = 75,
	KIWI_BOSID_ZPO_4_SRAB_N8_9 = 76,
	KIWI_BOSID_ZPO_NA_OTKL_N8_10 = 77,
	KIWI_BOSID_T_MASLA_NA_SIGN_N9_1 = 78,
	KIWI_BOSID_T_MASLA_NA_OTKL_N9_2 = 79,
	KIWI_BOSID_T_OBMOTKI_NA_SIGN_N9_3 = 80,
	KIWI_BOSID_T_OBMOTKI_NA_OTKL_N9_4 = 81,
	KIWI_BOSID_UM_NA_SIGN_N9_5 = 82,
	KIWI_BOSID_VZ_BEZ_AVR_NA_OTKL_N9_6 = 83,
	KIWI_BOSID_VZ_S_AVR_NA_OTKL_N9_7 = 84,
	KIWI_BOSID_PK_NA_SIGN_N9_8 = 85,
	KIWI_BOSID_PK_NA_OTKL_N9_9 = 86,
	KIWI_BOSID_OK_NA_SIGN_N9_10 = 87,
	KIWI_BOSID_UROV_VN_SRAB_N10_1 = 88,
	KIWI_BOSID_RT_UROV_VN_N10_2 = 89,
	KIWI_BOSID_UROV_SN_SRAB_N10_3 = 90,
	KIWI_BOSID_RT_UROV_SN_N10_4 = 91,
	KIWI_BOSID_OTKLUCHIT_VN_N11_1 = 92,
	KIWI_BOSID_OTKLUCHIT_SN_N11_2 = 93,
	KIWI_BOSID_OTKLUCHIT_SN_S_AVR_N11_3 = 94,
	KIWI_BOSID_OTKLUCHIT_SN_S_APV_N11_4 = 95,
	KIWI_BOSID_OTKLUCHIT_NN_N11_5 = 96,
	KIWI_BOSID_OTKLUCHIT_NN_S_AVR_N11_6 = 97,
	KIWI_BOSID_OTKLUCHIT_NN_S_APV_N11_7 = 98,
	KIWI_BOSID_ZAKRYTIE_OK_N11_8 = 99,
	KIWI_BOSID_ZAPRET_AVR_SN_N11_9 = 100,
	KIWI_BOSID_ZAPRET_AVR_NN_N11_10 = 101,
	KIWI_BOSID_PUSK_AVR_NN_SN_N11_11 = 102,
	KIWI_BOSID_ZAPRET_AVR_NN_SN_N11_12 = 103,
	KIWI_BOSID_PUSK_UROV_VN_N11_13 = 104,
	KIWI_BOSID_PUSK_UROV_SN_N11_14 = 105,
	KIWI_BOSID_PR_USTAVOK_2_N12_1 = 106,
	KIWI_BOSID_PR_USTAVOK_1_N12_2 = 107,
	KIWI_BOSID_PR_UST_PO_DV_N12_3 = 108,
	KIWI_BOSID_PR_UST_IZ_ASU_N12_4 = 109,
	KIWI_BOSID_PR_UST_S_PU_N12_5 = 110,
	KIWI_BOSID_PUSK_ZASHHIT_N12_6 = 111,
	KIWI_BOSID_BLOK_SMENY_PR_UST_N12_7 = 112,
	KIWI_BOSID_AVARIJNAJA_SIGN_N13_1 = 113,
	KIWI_BOSID_DTO_OTKLJUCHENIE_N13_2 = 114,
	KIWI_BOSID_DZT_OTKLJUCHENIE_N13_3 = 115,
	KIWI_BOSID_TO_VN_OTKLJUCHENIE_N13_4 = 116,
	KIWI_BOSID_MTZ_VN_OTKL_NN_N13_5 = 117,
	KIWI_BOSID_MTZ_VN_OTKL_SN_N13_6 = 118,
	KIWI_BOSID_MTZ_VN_OTKL_T_N13_7 = 119,
	KIWI_BOSID_UMTZ_VN_OTKL_T_N13_8 = 120,
	KIWI_BOSID_MTZ_SN_OTKL_SN_N13_9 = 121,
	KIWI_BOSID_UMTZ_SN_OTKL_SN_N13_10 = 122,
	KIWI_BOSID_MTZ_SN_OTKL_T_N13_11 = 123,
	KIWI_BOSID_MTZ_NN_OTKL_NN_N13_12 = 124,
	KIWI_BOSID_UMTZ_NN_OTKL_NN_N13_13 = 125,
	KIWI_BOSID_MTZ_NN_OTKL_T_N13_14 = 126,
	KIWI_BOSID_PEREGRUZKA_OTKL_VN_N13_15 = 127,
	KIWI_BOSID_PEREGRUZKA_OTKL_SN_N13_16 = 128,
	KIWI_BOSID_PEREGRUZKA_OTKL_NN_N13_17 = 129,
	KIWI_BOSID_PEREGRUZKA_OTKL_OO_N13_18 = 130,
	KIWI_BOSID_GZ_T1_OTKLJUCHENIE_N13_19 = 131,
	KIWI_BOSID_GZ_T2_OTKLJUCHENIE_N13_20 = 132,
	KIWI_BOSID_GZ_RPN_OTKLJUCHENIE_N13_21 = 133,
	KIWI_BOSID_ZPO_OTKLJUCHENIE_N13_22 = 134,
	KIWI_BOSID_VZ_TEMPER_MASLA_N13_23 = 135,
	KIWI_BOSID_VZ_TEMPER_OBMOTKI_N13_24 = 136,
	KIWI_BOSID_VZ_OTKL_T_N13_25 = 137,
	KIWI_BOSID_VZ_OTKL_T_S_AVR_N13_26 = 138,
	KIWI_BOSID_VZ_PRED_KLAPAN_N13_27 = 139,
	KIWI_BOSID_VZ_UROV_SN_N13_28 = 140,
	KIWI_BOSID_VZ_UROV_NN_N13_29 = 141,
	KIWI_BOSID_AVAR_SIGN_DOP_N13_30 = 142,
	KIWI_BOSID_PREDUPR_SIGN_N14_1 = 143,
	KIWI_BOSID_NEBALANS_TOKOV_N14_2 = 144,
	KIWI_BOSID_PEREGRUZKA_VN_SIGN_N14_3 = 145,
	KIWI_BOSID_RAZGRUZKA_VN_1_SIGN_N14_4 = 146,
	KIWI_BOSID_RAZGRUZKA_VN_2_SIGN_N14_5 = 147,
	KIWI_BOSID_PEREGRUZKA_SN_SIGN_N14_6 = 148,
	KIWI_BOSID_RAZGRUZKA_SN_1_SIGN_N14_7 = 149,
	KIWI_BOSID_RAZGRUZKA_SN_2_SIGN_N14_8 = 150,
	KIWI_BOSID_PEREGRUZKA_NN_SIGN_N14_9 = 151,
	KIWI_BOSID_RAZGRUZKA_NN_1_SIGN_N14_10 = 152,
	KIWI_BOSID_RAZGRUZKA_NN_2_SIGN_N14_11 = 153,
	KIWI_BOSID_PEREGRUZKA_OO_SIGN_N14_12 = 154,
	KIWI_BOSID_RAZGRUZKA_OO_1_SIGN_N14_13 = 155,
	KIWI_BOSID_RAZGRUZKA_OO_2_SIGN_N14_14 = 156,
	KIWI_BOSID_GZ_T1_SIGNAL_N14_15 = 157,
	KIWI_BOSID_GZ_T2_SIGNAL_N14_16 = 158,
	KIWI_BOSID_GZ_RPN_SIGNAL_N14_17 = 159,
	KIWI_BOSID_GZ_T1_NEISPRAV_N14_18 = 160,
	KIWI_BOSID_GZ_T2_NEISPRAV_N14_19 = 161,
	KIWI_BOSID_GZ_RPN_NEISPRAV_N14_20 = 162,
	KIWI_BOSID_GZ_NEISPRAV_PIT_N14_21 = 163,
	KIWI_BOSID_VS_TEMPER_MASLA_N14_22 = 164,
	KIWI_BOSID_VS_TEMPER_OBMOTKI_N14_23 = 165,
	KIWI_BOSID_VS_PRED_KLAPAN_N14_24 = 166,
	KIWI_BOSID_VS_OTSECH_KLAPAN_N14_25 = 167,
	KIWI_BOSID_VS_UROVEN_MASLA_N14_26 = 168,
	KIWI_BOSID_UROV_VN_N14_27 = 169,
	KIWI_BOSID_UROV_SN_N14_28 = 170,
	KIWI_BOSID_PREDUPR_SIGN_DOP_N14_29 = 171,
	KIWI_BOSID_ALTEI_NEISPRAVEN_N14_30 = 172,
	KIWI_BOSID_SJEM_SIGNALIZACII_N15_1 = 173,
	KIWI_BOSID_PITANIE_OT_SETI_N70_1 = 174,
	KIWI_BOSID_FNED_N40_1 = 175,
	KIWI_BOSID_FRATENED_N40_2 = 176,
	KIWI_BOSID_START_N40_3 = 177,
	KIWI_BOSID_TRANSIENT_N40_4 = 178,

	KIWI_BOSID_INVALID_SIGNAL = KIWI_INVALID_ID
} kiwi_BinaryOutputSignalID;
/*-----------------------------------------------------------------------------------------------*/
/** @brief Тип идентификатора (двоичного) выходного сигнала пускового органа. */
typedef enum kiwi_FaultDetectorBinaryOutputSignalID_TAG
{
	KIWI_BOSID_PO_IDTO_A_N1_1 = 0,
	KIWI_BOSID_PO_IDTO_B_N1_2 = 1,
	KIWI_BOSID_PO_IDTO_C_N1_3 = 2,
	KIWI_BOSID_PO_DZT_A_N1_4 = 3,
	KIWI_BOSID_PO_DZT_B_N1_5 = 4,
	KIWI_BOSID_PO_DZT_C_N1_6 = 5,
	KIWI_BOSID_PO_IPB_2G_A_N1_7 = 6,
	KIWI_BOSID_PO_IPB_2G_B_N1_8 = 7,
	KIWI_BOSID_PO_IPB_2G_C_N1_9 = 8,
	KIWI_BOSID_PO_IPB_5G_A_N1_10 = 9,
	KIWI_BOSID_PO_IPB_5G_B_N1_11 = 10,
	KIWI_BOSID_PO_IPB_5G_C_N1_12 = 11,
	KIWI_BOSID_PO_INB_A_N2_1 = 12,
	KIWI_BOSID_PO_INB_B_N2_2 = 13,
	KIWI_BOSID_PO_INB_C_N2_3 = 14,
	KIWI_BOSID_PO_ITO_VN_N3_1 = 15,
	KIWI_BOSID_PO_IMTZ_VN_N3_2 = 16,
	KIWI_BOSID_PO_IMTZ_SN_N4_1 = 17,
	KIWI_BOSID_PO_IMTZ_NN_N5_1 = 18,
	KIWI_BOSID_PO_IZP_VN_N6_1 = 19,
	KIWI_BOSID_PO_IZP_SN_N6_2 = 20,
	KIWI_BOSID_PO_IZP_NN_N6_3 = 21,
	KIWI_BOSID_PO_IZP_OO_N6_4 = 22,
	KIWI_BOSID_PO_IPO_1_N8_1 = 23,
	KIWI_BOSID_PO_IPO_2_N8_2 = 24,
	KIWI_BOSID_PO_IPO_3_N8_3 = 25,
	KIWI_BOSID_PO_IUROV_VN_N10_1 = 26,
	KIWI_BOSID_PO_IUROV_SN_N10_2 = 27,
	KIWI_BOSID_PO_I_VN_MAX_1_N50_1 = 28,
	KIWI_BOSID_PO_I_VN_MAX_2_N50_2 = 29,
	KIWI_BOSID_PO_I_VN_MAX_3_N50_3 = 30,
	KIWI_BOSID_PO_I_VN_MIN_N50_4 = 31,
	KIWI_BOSID_PO_I_SN_MAX_1_N50_5 = 32,
	KIWI_BOSID_PO_I_SN_MAX_2_N50_6 = 33,
	KIWI_BOSID_PO_I_SN_MAX_3_N50_7 = 34,
	KIWI_BOSID_PO_I_SN_MIN_N50_8 = 35,
	KIWI_BOSID_PO_I_NN_MAX_1_N50_9 = 36,
	KIWI_BOSID_PO_I_NN_MAX_2_N50_10 = 37,
	KIWI_BOSID_PO_I_NN_MAX_3_N50_11 = 38,
	KIWI_BOSID_PO_I_NN_MIN_N50_12 = 39,
	KIWI_BOSID_PO_IA_VN_NED_N60_1 = 40,
	KIWI_BOSID_PO_IB_VN_NED_N60_2 = 41,
	KIWI_BOSID_PO_IC_VN_NED_N60_3 = 42,
	KIWI_BOSID_PO_IA_SN_NED_N60_4 = 43,
	KIWI_BOSID_PO_IB_SN_NED_N60_5 = 44,
	KIWI_BOSID_PO_IC_SN_NED_N60_6 = 45,
	KIWI_BOSID_PO_IA_NN_NED_N60_7 = 46,
	KIWI_BOSID_PO_IB_NN_NED_N60_8 = 47,
	KIWI_BOSID_PO_IC_NN_NED_N60_9 = 48,
	KIWI_BOSID_PO_U_PIT_NORM_N70_1 = 49,
	KIWI_BOSID_PO_U_PIT_PONIJ_N70_2 = 50,
	KIWI_BOSID_PO_U_PIT_ISCHEZ_N70_3 = 51,

	KIWI_BOSID_PO_INVALID_SIGNAL = KIWI_INVALID_ID
} kiwi_FaultDetectorBinaryOutputSignalID;
/*-----------------------------------------------------------------------------------------------*/
/** @brief Тип идентификатора (двоичного) выходного сигнала ДФПО. */
typedef enum kiwi_AFSWBinaryOutputSignalID_TAG
{
	KIWI_AFSW_BOSID_OUTPUT_1 = 0,
	KIWI_AFSW_BOSID_OUTPUT_2 = 1,
	KIWI_AFSW_BOSID_OUTPUT_3 = 2,
	KIWI_AFSW_BOSID_OUTPUT_4 = 3,
	KIWI_AFSW_BOSID_OUTPUT_5 = 4,
	KIWI_AFSW_BOSID_OUTPUT_6 = 5,
	KIWI_AFSW_BOSID_OUTPUT_7 = 6,
	KIWI_AFSW_BOSID_OUTPUT_8 = 7,
	KIWI_AFSW_BOSID_OUTPUT_9 = 8,
	KIWI_AFSW_BOSID_OUTPUT_10 = 9,
	KIWI_AFSW_BOSID_OUTPUT_11 = 10,
	KIWI_AFSW_BOSID_OUTPUT_12 = 11,
	KIWI_AFSW_BOSID_OUTPUT_13 = 12,
	KIWI_AFSW_BOSID_OUTPUT_14 = 13,
	KIWI_AFSW_BOSID_OUTPUT_15 = 14,
	KIWI_AFSW_BOSID_OUTPUT_16 = 15,
	KIWI_AFSW_BOSID_OUTPUT_17 = 16,
	KIWI_AFSW_BOSID_OUTPUT_18 = 17,
	KIWI_AFSW_BOSID_OUTPUT_19 = 18,
	KIWI_AFSW_BOSID_OUTPUT_20 = 19,
	KIWI_AFSW_BOSID_OUTPUT_21 = 20,
	KIWI_AFSW_BOSID_OUTPUT_22 = 21,
	KIWI_AFSW_BOSID_OUTPUT_23 = 22,
	KIWI_AFSW_BOSID_OUTPUT_24 = 23,
	KIWI_AFSW_BOSID_OUTPUT_25 = 24,
	KIWI_AFSW_BOSID_OUTPUT_26 = 25,
	KIWI_AFSW_BOSID_OUTPUT_27 = 26,
	KIWI_AFSW_BOSID_OUTPUT_28 = 27,
	KIWI_AFSW_BOSID_OUTPUT_29 = 28,
	KIWI_AFSW_BOSID_OUTPUT_30 = 29,
	KIWI_AFSW_BOSID_OUTPUT_31 = 30,
	KIWI_AFSW_BOSID_OUTPUT_32 = 31,
	KIWI_AFSW_BOSID_OUTPUT_33 = 32,
	KIWI_AFSW_BOSID_OUTPUT_34 = 33,
	KIWI_AFSW_BOSID_OUTPUT_35 = 34,
	KIWI_AFSW_BOSID_OUTPUT_36 = 35,
	KIWI_AFSW_BOSID_OUTPUT_37 = 36,
	KIWI_AFSW_BOSID_OUTPUT_38 = 37,
	KIWI_AFSW_BOSID_OUTPUT_39 = 38,
	KIWI_AFSW_BOSID_OUTPUT_40 = 39,
	KIWI_AFSW_BOSID_OUTPUT_41 = 40,
	KIWI_AFSW_BOSID_OUTPUT_42 = 41,
	KIWI_AFSW_BOSID_OUTPUT_43 = 42,
	KIWI_AFSW_BOSID_OUTPUT_44 = 43,
	KIWI_AFSW_BOSID_OUTPUT_45 = 44,
	KIWI_AFSW_BOSID_OUTPUT_46 = 45,
	KIWI_AFSW_BOSID_OUTPUT_47 = 46,
	KIWI_AFSW_BOSID_OUTPUT_48 = 47,
	KIWI_AFSW_BOSID_OUTPUT_49 = 48,
	KIWI_AFSW_BOSID_OUTPUT_50 = 49,
	KIWI_AFSW_BOSID_OUTPUT_51 = 50,
	KIWI_AFSW_BOSID_OUTPUT_52 = 51,
	KIWI_AFSW_BOSID_OUTPUT_53 = 52,
	KIWI_AFSW_BOSID_OUTPUT_54 = 53,
	KIWI_AFSW_BOSID_OUTPUT_55 = 54,
	KIWI_AFSW_BOSID_OUTPUT_56 = 55,
	KIWI_AFSW_BOSID_OUTPUT_57 = 56,
	KIWI_AFSW_BOSID_OUTPUT_58 = 57,
	KIWI_AFSW_BOSID_OUTPUT_59 = 58,
	KIWI_AFSW_BOSID_OUTPUT_60 = 59,
	KIWI_AFSW_BOSID_OUTPUT_61 = 60,
	KIWI_AFSW_BOSID_OUTPUT_62 = 61,
	KIWI_AFSW_BOSID_OUTPUT_63 = 62,
	KIWI_AFSW_BOSID_OUTPUT_64 = 63,

	KIWI_AFSW_BOSID_INVALID_SIGNAL = KIWI_INVALID_ID
} kiwi_AFSWBinaryOutputSignalID;
/*-----------------------------------------------------------------------------------------------*/
/** @brief Тип идентификатора светодиода. */
typedef enum kiwi_LEDID_TAG
{
	KIWI_LED_1 = 0,
	KIWI_LED_2 = 1,
	KIWI_LED_3 = 2,
	KIWI_LED_4 = 3,
	KIWI_LED_5 = 4,
	KIWI_LED_6 = 5,
	KIWI_LED_7 = 6,
	KIWI_LED_8 = 7,
	KIWI_LED_9 = 8,
	KIWI_LED_10 = 9,
	KIWI_LED_11 = 10,
	KIWI_LED_12 = 11,
	KIWI_LED_13 = 12,
	KIWI_LED_14 = 13,

	KIWI_INVALID_LED_ID = KIWI_INVALID_ID
} kiwi_LEDID;

/*-----------------------------------------------------------------------------------------------*/
/** @brief Тип идентификатора аналогового входного сигнала. */
typedef enum kiwi_AnalogInputSignalID_TAG
{
	KIWI_AISID_IA_VN = 0,
	KIWI_AISID_IB_VN = 1,
	KIWI_AISID_IC_VN = 2,
	KIWI_AISID_IA_SN = 3,
	KIWI_AISID_IB_SN = 4,
	KIWI_AISID_IC_SN = 5,
	KIWI_AISID_IA_NN = 6,
	KIWI_AISID_IB_NN = 7,
	KIWI_AISID_IC_NN = 8,
	KIWI_AISID_U_PWR = 9,
	KIWI_AISID_U_CAP = 10,

	KIWI_AISID_INVALID_SIGNAL = KIWI_INVALID_ID
} kiwi_AnalogInputSignalID;
/*-----------------------------------------------------------------------------------------------*/
/** @brief Тип идентификатора аналогового выходного сигнала. */
typedef enum kiwi_AnalogOutputSignalID_TAG
{
	KIWI_AOSID_IA_VN = 0,
	KIWI_AOSID_IB_VN = 1,
	KIWI_AOSID_IC_VN = 2,
	KIWI_AOSID_IA_SN = 3,
	KIWI_AOSID_IB_SN = 4,
	KIWI_AOSID_IC_SN = 5,
	KIWI_AOSID_IA_NN = 6,
	KIWI_AOSID_IB_NN = 7,
	KIWI_AOSID_IC_NN = 8,
	KIWI_AOSID_F = 9,
	KIWI_AOSID_DF = 10,
	KIWI_AOSID_IDIF_A = 11,
	KIWI_AOSID_IDIF_B = 12,
	KIWI_AOSID_IDIF_C = 13,
	KIWI_AOSID_ITORM_A = 14,
	KIWI_AOSID_ITORM_B = 15,
	KIWI_AOSID_ITORM_C = 16,
	KIWI_AOSID_IDIF2G_A = 17,
	KIWI_AOSID_IDIF2G_B = 18,
	KIWI_AOSID_IDIF2G_C = 19,
	KIWI_AOSID_KI2G_A = 20,
	KIWI_AOSID_KI2G_B = 21,
	KIWI_AOSID_KI2G_C = 22,
	KIWI_AOSID_IDIF5G_A = 23,
	KIWI_AOSID_IDIF5G_B = 24,
	KIWI_AOSID_IDIF5G_C = 25,
	KIWI_AOSID_KI5G_A = 26,
	KIWI_AOSID_KI5G_B = 27,
	KIWI_AOSID_KI5G_C = 28,
	KIWI_AOSID_IA_SHTRIKH_VN = 29,
	KIWI_AOSID_IB_SHTRIKH_VN = 30,
	KIWI_AOSID_IC_SHTRIKH_VN = 31,
	KIWI_AOSID_IA_OO = 32,
	KIWI_AOSID_IB_OO = 33,
	KIWI_AOSID_IC_OO = 34,
	KIWI_AOSID_INOM_VN = 35,
	KIWI_AOSID_INOM_SN = 36,
	KIWI_AOSID_INOM_NN = 37,
	KIWI_AOSID_I_SHTRIKH_VN_MAKS = 38,
	KIWI_AOSID_I_VN_MAKS = 39,
	KIWI_AOSID_I_SN_MAKS = 40,
	KIWI_AOSID_I_NN_MAKS = 41,
	KIWI_AOSID_I_OO_MAKS = 42,
	KIWI_AOSID_U_PWR = 43,
	KIWI_AOSID_U_PWR_CAP = 44,
	KIWI_AOSID_DT = 60,
	KIWI_AOSID_NS = 61,
	KIWI_AOSID_T_OLD = 62,
	KIWI_AOSID_CH = 63,
	KIWI_AOSID_CTR_START = 64,
	KIWI_AOSID_CTR_T_CYCLE = 65,
	KIWI_AOSID_CTR_FRATE = 66,
	KIWI_AOSID_DELTA_A = 67,
	KIWI_AOSID_DELTA_T = 68,
	KIWI_AOSID_DFAZA = 69,
	KIWI_AOSID_FIND = 70,
	KIWI_AOSID_FCALC = 71,
	KIWI_AOSID_FRATE = 72,
	KIWI_AOSID_FRATECALC = 73,
	KIWI_AOSID_FAZA = 74,
	KIWI_AOSID_NT = 75,
	KIWI_AOSID_T = 76,
	KIWI_AOSID_T_CALC = 77,

	KIWI_AOSID_INVALID_SIGNAL = KIWI_INVALID_ID
} kiwi_AnalogOutputSignalID;
/*-----------------------------------------------------------------------------------------------*/
/** @brief Тип идентификатора события, используемый в базе данных KIWI. */
typedef enum kiwi_EventID_TAG
{
	KIWI_EID_SRABATYVANIE_DTO = 1,
	KIWI_EID_PUSK_DZT = 2,
	KIWI_EID_SRABATYVANIE_DZT = 3,
	KIWI_EID_NEBALANS_FAZA_A = 4,
	KIWI_EID_NEBALANS_FAZA_B = 5,
	KIWI_EID_NEBALANS_FAZA_C = 6,
	KIWI_EID_PUSK_TO_VN = 7,
	KIWI_EID_SRABATYVANIE_TO_VN = 8,
	KIWI_EID_PUSK_MTZ_VN = 9,
	KIWI_EID_SRABATYVANIE_MTZ_VN_NA_NN = 10,
	KIWI_EID_SRABATYVANIE_MTZ_VN_NA_SN = 11,
	KIWI_EID_SRABATYVANIE_MTZ_VN_NA_T = 12,
	KIWI_EID_SRABATYVANIE_UMTZ_VN_NA_T = 13,
	KIWI_EID_PUSK_MTZ_SN = 14,
	KIWI_EID_SRABATYVANIE_MTZ_SN_NA_SN = 15,
	KIWI_EID_SRABATYVANIE_UMTZ_SN_NA_SN = 16,
	KIWI_EID_SRABATYVANIE_MTZ_SN_NA_T = 17,
	KIWI_EID_PUSK_MTZ_NN = 18,
	KIWI_EID_SRABATYVANIE_MTZ_NN_NA_NN = 19,
	KIWI_EID_SRABATYVANIE_UMTZ_NN_NA_NN = 20,
	KIWI_EID_SRABATYVANIE_MTZ_NN_NA_T = 21,
	KIWI_EID_PEREGRUZKA_VN_SIGNAL = 22,
	KIWI_EID_PEREGRUZKA_VN_OTKLUCHENIE = 23,
	KIWI_EID_SRABATYVANIE_RAZGRUZKI_VN_1_OCHEREDI = 24,
	KIWI_EID_SRABATYVANIE_RAZGRUZKI_VN_2_OCHEREDI = 25,
	KIWI_EID_PEREGRUZKA_SN_SIGNAL = 26,
	KIWI_EID_PEREGRUZKA_SN_OTKLUCHENIE = 27,
	KIWI_EID_SRABATYVANIE_RAZGRUZKI_SN_1_OCHEREDI = 28,
	KIWI_EID_SRABATYVANIE_RAZGRUZKI_SN_2_OCHEREDI = 29,
	KIWI_EID_PEREGRUZKA_NN_SIGNAL = 30,
	KIWI_EID_PEREGRUZKA_NN_OTKLUCHENIE = 31,
	KIWI_EID_SRABATYVANIE_RAZGRUZKI_NN_1_OCHEREDI = 32,
	KIWI_EID_SRABATYVANIE_RAZGRUZKI_NN_2_OCHEREDI = 33,
	KIWI_EID_PEREGRUZKA_OO_SIGNAL = 34,
	KIWI_EID_PEREGRUZKA_OO_OTKLUCHENIE = 35,
	KIWI_EID_SRABATYVANIE_RAZGRUZKI_OO_1_OCHEREDI = 36,
	KIWI_EID_SRABATYVANIE_RAZGRUZKI_OO_2_OCHEREDI = 37,
	KIWI_EID_SRABATYVANIE_GZ_T1 = 38,
	KIWI_EID_NEISPRAVNOST_GZ_T1 = 39,
	KIWI_EID_SRABATYVANIE_GZ_T2 = 40,
	KIWI_EID_NEISPRAVNOST_GZ_T2 = 41,
	KIWI_EID_SRABATYVANIE_GZ_RPN = 42,
	KIWI_EID_NEISPRAVNOST_GZ_RPN = 43,
	KIWI_EID_NEISPRAVNOST_PITANIJA_GZ = 44,
	KIWI_EID_PUSK_OHLAZHDENIJA_1 = 45,
	KIWI_EID_PUSK_OHLAZHDENIJA_2 = 46,
	KIWI_EID_PUSK_OHLAZHDENIJA_3 = 47,
	KIWI_EID_PUSK_ZPO = 48,
	KIWI_EID_SRABATYVANIE_ZPO_1 = 49,
	KIWI_EID_SRABATYVANIE_ZPO_2 = 50,
	KIWI_EID_SRABATYVANIE_ZPO_3 = 51,
	KIWI_EID_SRABATYVANIE_ZPO_4 = 52,
	KIWI_EID_SIGNALIZACIJA_T_MASLA = 53,
	KIWI_EID_T_MASLA_OTKLUCHENIE = 54,
	KIWI_EID_SIGNALIZACIJA_T_OBMOTKI = 55,
	KIWI_EID_T_OBMOTKI_OTKLUCHENIE = 56,
	KIWI_EID_SIGNALIZACIJA_UROVNIA_MASLA = 57,
	KIWI_EID_VNESHNEE_OTKLUCHENIE = 58,
	KIWI_EID_VNESHNEE_OTKLUCHENIE_S_AVR = 59,
	KIWI_EID_SIGNALIZACIJA_PREDOHR_KLAPANA = 60,
	KIWI_EID_OTKLUCHENIE_OT_PREDOHR_KLAPANA = 61,
	KIWI_EID_SIGNALIZACIJA_OTSECHNOGO_KLAPANA = 62,
	KIWI_EID_SRABATYVANIE_UROV_VN = 63,
	KIWI_EID_SRABATYVANIE_UROV_SN = 64,
	KIWI_EID_OTKLUCHENIE_VYKLUCHATELIA_VN = 65,
	KIWI_EID_OTKLUCHENIE_VYKLUCHATELIA_SN = 66,
	KIWI_EID_OTKLUCHENIE_VYKLUCHATELIA_NN = 67,
	KIWI_EID_ZAKRYTIE_OTSECHNOGO_KLAPANA = 68,
	KIWI_EID_AVARIJNAJA_SIGNALIZACIJA = 69,
	KIWI_EID_PREDUPREDITELNAJA_SIGNALIZACIJA = 70,
	KIWI_EID_USER_EVENT_1,
	KIWI_EID_USER_EVENT_2,
	KIWI_EID_USER_EVENT_3,
	KIWI_EID_USER_EVENT_4,
	KIWI_EID_USER_EVENT_5,
	KIWI_EID_USER_EVENT_6,
	KIWI_EID_USER_EVENT_7,
	KIWI_EID_USER_EVENT_8,
	KIWI_EID_USER_EVENT_9,
	KIWI_EID_USER_EVENT_10,
	KIWI_EID_USER_EVENT_11,
	KIWI_EID_USER_EVENT_12,
	KIWI_EID_USER_EVENT_13,
	KIWI_EID_USER_EVENT_14,
	KIWI_EID_USER_EVENT_15,
	KIWI_EID_USER_EVENT_16,
	KIWI_EID_USER_EVENT_17,
	KIWI_EID_USER_EVENT_18,
	KIWI_EID_USER_EVENT_19,
	KIWI_EID_USER_EVENT_20,
	KIWI_EID_USER_EVENT_21,
	KIWI_EID_USER_EVENT_22,
	KIWI_EID_USER_EVENT_23,
	KIWI_EID_USER_EVENT_24,
	KIWI_EID_USER_EVENT_25,
	KIWI_EID_USER_EVENT_26,
	KIWI_EID_USER_EVENT_27,
	KIWI_EID_USER_EVENT_28,
	KIWI_EID_USER_EVENT_29,
	KIWI_EID_USER_EVENT_30,
	KIWI_EID_USER_EVENT_31,
	KIWI_EID_USER_EVENT_32,
	KIWI_EID_USER_EVENT_33,
	KIWI_EID_USER_EVENT_34,
	KIWI_EID_USER_EVENT_35,
	KIWI_EID_USER_EVENT_36,
	KIWI_EID_USER_EVENT_37,
	KIWI_EID_USER_EVENT_38,
	KIWI_EID_USER_EVENT_39,
	KIWI_EID_USER_EVENT_40,
	KIWI_EID_USER_EVENT_41,
	KIWI_EID_USER_EVENT_42,
	KIWI_EID_USER_EVENT_43,
	KIWI_EID_USER_EVENT_44,
	KIWI_EID_USER_EVENT_45,
	KIWI_EID_USER_EVENT_46,
	KIWI_EID_USER_EVENT_47,
	KIWI_EID_USER_EVENT_48,
	KIWI_EID_USER_EVENT_49,
	KIWI_EID_USER_EVENT_50,
	KIWI_EID_USER_EVENT_51,
	KIWI_EID_USER_EVENT_52,
	KIWI_EID_USER_EVENT_53,
	KIWI_EID_USER_EVENT_54,
	KIWI_EID_USER_EVENT_55,
	KIWI_EID_USER_EVENT_56,
	KIWI_EID_USER_EVENT_57,
	KIWI_EID_USER_EVENT_58,
	KIWI_EID_USER_EVENT_59,
	KIWI_EID_USER_EVENT_60,
	KIWI_EID_USER_EVENT_61,
	KIWI_EID_USER_EVENT_62,
	KIWI_EID_USER_EVENT_63,
	KIWI_EID_USER_EVENT_64,
	KIWI_EID_USER_EVENT_65,
	KIWI_EID_USER_EVENT_66,
	KIWI_EID_USER_EVENT_67,
	KIWI_EID_USER_EVENT_68,
	KIWI_EID_USER_EVENT_69,
	KIWI_EID_USER_EVENT_70,
	KIWI_EID_USER_EVENT_71,
	KIWI_EID_USER_EVENT_72,
	KIWI_EID_USER_EVENT_73,
	KIWI_EID_USER_EVENT_74,
	KIWI_EID_USER_EVENT_75,
	KIWI_EID_USER_EVENT_76,
	KIWI_EID_USER_EVENT_77,
	KIWI_EID_USER_EVENT_78,
	KIWI_EID_USER_EVENT_79,
	KIWI_EID_USER_EVENT_80,
	KIWI_EID_USER_EVENT_81,
	KIWI_EID_USER_EVENT_82,
	KIWI_EID_USER_EVENT_83,
	KIWI_EID_USER_EVENT_84,
	KIWI_EID_USER_EVENT_85,
	KIWI_EID_USER_EVENT_86,
	KIWI_EID_USER_EVENT_87,
	KIWI_EID_USER_EVENT_88,
	KIWI_EID_USER_EVENT_89,
	KIWI_EID_USER_EVENT_90,
	KIWI_EID_USER_EVENT_91,
	KIWI_EID_USER_EVENT_92,
	KIWI_EID_USER_EVENT_93,
	KIWI_EID_USER_EVENT_94,
	KIWI_EID_USER_EVENT_95,
	KIWI_EID_USER_EVENT_96,
	KIWI_EID_USER_EVENT_97,
	KIWI_EID_USER_EVENT_98,
	KIWI_EID_USER_EVENT_99,
	KIWI_EID_USER_EVENT_100,

	KIWI_EID_INVALID_EVENT = KIWI_INVALID_ID
} kiwi_EventID;
/*-----------------------------------------------------------------------------------------------*/
/** @brief Тип идентификатора накопителя. */
typedef enum kiwi_AccumulatorID_TAG
{
	KIWI_CID_DTO_NA_OTKL = 0,
	KIWI_CID_DZT_NA_OTKL = 1,
	KIWI_CID_NB_A_SRAB = 2,
	KIWI_CID_NB_B_SRAB = 3,
	KIWI_CID_NB_C_SRAB = 4,
	KIWI_CID_NB_SRAB = 5,
	KIWI_CID_MTZ_VN_NA_OTKL_NN = 6,
	KIWI_CID_MTZ_VN_NA_OTKL_SN = 7,
	KIWI_CID_MTZ_VN_NA_OTKL_T = 8,
	KIWI_CID_UMTZ_VN_NA_OTKL_T = 9,
	KIWI_CID_MTZ_SN_NA_OTKL_SN = 10,
	KIWI_CID_UMTZ_SN_NA_OTKL_SN = 11,
	KIWI_CID_MTZ_SN_NA_OTKL_T = 12,
	KIWI_CID_MTZ_NN_NA_OTKL_NN = 13,
	KIWI_CID_UMTZ_NN_NA_OTKL_NN = 14,
	KIWI_CID_MTZ_NN_NA_OTKL_T = 15,
	KIWI_CID_PEREGRUZKA_VN = 16,
	KIWI_CID_PEREGRUZKA_VN_NA_OTKL = 17,
	KIWI_CID_RAZGRUZKA_VN_1 = 18,
	KIWI_CID_RAZGRUZKA_VN_2 = 19,
	KIWI_CID_PEREGRUZKA_SN = 20,
	KIWI_CID_PEREGRUZKA_SN_NA_OTKL = 21,
	KIWI_CID_RAZGRUZKA_SN_1 = 22,
	KIWI_CID_RAZGRUZKA_SN_2 = 23,
	KIWI_CID_PEREGRUZKA_NN = 24,
	KIWI_CID_PEREGRUZKA_NN_NA_OTKL = 25,
	KIWI_CID_RAZGRUZKA_NN_1 = 26,
	KIWI_CID_RAZGRUZKA_NN_2 = 27,
	KIWI_CID_PEREGRUZKA_OO = 28,
	KIWI_CID_PEREGRUZKA_OO_NA_OTKL = 29,
	KIWI_CID_RAZGRUZKA_OO_1 = 30,
	KIWI_CID_RAZGRUZKA_OO_2 = 31,
	KIWI_CID_GZ_T1_SRAB = 32,
	KIWI_CID_GZ_T2_SRAB = 33,
	KIWI_CID_GZ_RPN_SRAB = 34,
	KIWI_CID_ZPO_1_SRAB = 35,
	KIWI_CID_ZPO_2_SRAB = 36,
	KIWI_CID_ZPO_3_SRAB = 37,
	KIWI_CID_ZPO_4_SRAB = 38,
	KIWI_CID_UROV_VN_SRAB = 39,
	KIWI_CID_UROV_SN_SRAB = 40,
	KIWI_CID_OTKLUCHIT_VN = 41,
	KIWI_CID_OTKLUCHIT_SN = 42,
	KIWI_CID_OTKLUCHIT_NN = 43,
	KIWI_CID_AVARIYNAYA_SIGN = 44,

	KIWI_CID_PREDUPR_SIGN = 45,

	KIWI_CID_TO_VN_NA_OTKL = 48,

	KIWI_CID_MOTOCHASY = 52,
	KIWI_CID_KOLICHESTVO_VKLUCHENIJ = 53,

	/**
	 * @brief &mdash; количество ошибок при приёме ЦП данных от ПВВ базового блока по синхронному
	 *                интерфейсу;
	 */
	KIWI_CID_CPU_FROM_BASE_IOP_SYNC = 60,

	/**
	 * @brief &mdash; количество ошибок при приёме ПВВ базового блока данных от ЦП по синхронному
	 *                интерфейсу;
	 */
	KIWI_CID_BASE_IOP_FROM_CPU_SYNC = 61,

	/**
	 * @brief &mdash; количество ошибок при приёме ЦП данных от ПВВ базового блока по асинхронному
	 *                интерфейсу;
	 */
	KIWI_CID_CPU_FROM_BASE_IOP_ASYNC = 62,

	/**
	 * @brief &mdash; количество ошибок при приёме ПВВ базового блока данных от ЦП по асинхронному
	 *                интерфейсу;
	 */
	KIWI_CID_BASE_IOP_FROM_CPU_ASYNC = 63,

	/** @brief &mdash; количество ошибок при приёме ПВВ базового блока данных от ПВВ доп. модуля; */
	KIWI_CID_BASE_IOP_FROM_AUX_IOP = 64,

	/** @brief &mdash; количество ошибок при приёме ПВВ доп. модуля данных от ПВВ базового блока; */
	KIWI_CID_AUX_IOP_FROM_BASE_IOP = 65,

	/** @brief &mdash; количество ошибок при приёме ЦП данных от КП; */
	KIWI_CID_CPU_FROM_COM_P = 66,

	/** @brief &mdash; количество ошибок при приёме КП данных от ЦП; */
	KIWI_CID_COM_P_FROM_CPU = 67,

	/** @brief &mdash; количество ошибок при приёме ЦП данных от пульта; */
	KIWI_CID_CPU_FROM_CONTROL_PANEL = 68,

	/** @brief &mdash; количество ошибок при приёме пультом данных от ЦП; */
	KIWI_CID_CONTROL_PANEL_FROM_CPU = 69,

	/**
	 * @brief &mdash; количество ошибок при приёме данных КП базового блока по 1-му каналу MODBUS;
	 */
	KIWI_CID_MODBUS_1 = 70,

	/**
	 * @brief &mdash; количество ошибок при приёме данных КП базового блока по 2-му каналу MODBUS;
	 */
	KIWI_CID_MODBUS_2 = 71,

	/** @brief &mdash; Nотп; */
	KIWI_CID_N_OTP = 72,

	/** @brief &mdash; Ресурс РПН; */
	KIWI_CID_RESURS_RPN = 73,

	/** @brief &mdash; Ресурс РПН нагр. */
	KIWI_CID_RESURS_RPN_NAGR = 74,

	KIWI_CID_INVALID_ACCUMULATOR = KIWI_INVALID_ID
} kiwi_AccumulatorID;
/*-----------------------------------------------------------------------------------------------*/

/*@}*/

#ifdef __cplusplus
}
#endif

#endif /* APPLICATION_USER_BFSOFTWARE_KIWIDATABASEIDS_H_ */
