﻿/**
 * @file
 * @brief Содержит объявления констант, типов и функций модуля @ref KIWIDatabaseIDs "KIWIDatabaseIDs".
 */

#ifndef APPLICATION_USER_BFSOFTWARE_KIWIDATABASEIDS_H_
#define APPLICATION_USER_BFSOFTWARE_KIWIDATABASEIDS_H_

#include <stdint.h>

#ifdef __cplusplus
extern "C"
{
#endif

/**
 * @defgroup KIWIDatabaseIDs Модуль KIWIDatabaseIDs
 *
 * Этот модуль определяет идентификаторы уставок, сигналов и событий, используемые в базе данных
 * KIWI.
 *
 * @version 1.0.0
 * @date 15.07.2016
 * @copyright ООО НПП "Микропроцессорные технологии"
 * @author А.Молдованов
 */
/*@{*/

/*======================================= МАКРООПРЕДЕЛЕНИЯ ======================================*/

/** @brief Недействительное значение идентификатора. */
#define KIWI_INVALID_ID  (UINT16_MAX)

/*======================================== ТИПЫ ДАННЫХ ==========================================*/

/** @brief Тип идентификатора группы уставок, используемый в базе данных KIWI. */
typedef enum kiwi_SettingGroupID_TAG
{
	KIWI_SGID_DISKRIETNYJE_VKHODY = 0,
	KIWI_SGID_DTO_I_DZT_N1 = 1,
	KIWI_SGID_KCT_N2 = 2,
	KIWI_SGID_TO_I_MTZ_VN_N3 = 3,
	KIWI_SGID_MTZ_NN_N4 = 4,
	KIWI_SGID_ZP_N5 = 5,
	KIWI_SGID_LZSH_LZT_N6 = 6,
	KIWI_SGID_ZDZ_N7 = 7,
	KIWI_SGID_TZOP_N8 = 8,
	KIWI_SGID_TZNP_N9 = 9,
	KIWI_SGID_OZZ_N10 = 10,
	KIWI_SGID_GZ_N11 = 11,
	KIWI_SGID_PO_ZPO_N12 = 12,
	KIWI_SGID_SF6_N13 = 13,
	KIWI_SGID_UROV_N14 = 14,
	KIWI_SGID_OU_N15 = 15,
	KIWI_SGID_VKLJUCHENIE_N16 = 16,
	KIWI_SGID_OTKLJUCHENIE_N17 = 17,
	KIWI_SGID_AVARIJNOE_OTKLJUCHENIE_N18 = 18,
	KIWI_SGID_APV_N19 = 19,
	KIWI_SGID_DIAGNOSTIKA_CU_N20 = 20,
	KIWI_SGID_KONTROL_PARAMIETROV_RPN_N21 = 21,
	KIWI_SGID_BLOKIROVKA_RPN_N22 = 22,
	KIWI_SGID_OU_RPN_N23 = 23,
	KIWI_SGID_UPRAVLIENIJE_RPN_N24 = 24,
	KIWI_SGID_POLOZHENIJE_RPN_N25 = 25,
	KIWI_SGID_RESURS_RPN_N26 = 26,
	KIWI_SGID_DIAGNOSTIKA_RPN_N27 = 27,
	KIWI_SGID_SMIENA_PROGRAMM_USTAVOK_N28 = 28,
	KIWI_SGID_AVARIJNAJA_SIGN_N29 = 29,
	KIWI_SGID_PREDUPR_SIGN_N30 = 30,
	KIWI_SGID_PREDUPR_SIGN_RPN_N31 = 31,
	KIWI_SGID_KOEFFICIJENTY_TRANSFORMACII_N32 = 32,
	KIWI_SGID_PARAMIETRY_OBJEKTA_N33 = 33,
	KIWI_SGID_OSCILLOGRAF_N34 = 34,
	KIWI_SGID_KONFIGURACIJA_BLOKA_N35 = 35,
	KIWI_SGID_NIEDOSTOVIERNOSTI = 36,
	KIWI_SGID_PUSK_ORGANY = 37,
	KIWI_SGID_VKHODY_ALGORITMOV = 38,
	KIWI_SGID_GIBKAJA_LOGIKA_N60 = 39,
	KIWI_SGID_OTLADKA = 40,

	KIWI_SGID_INVALID_SETTING_GROUP = KIWI_INVALID_ID
} kiwi_SettingGroupID;
/*-----------------------------------------------------------------------------------------------*/
/** @brief Тип идентификатора уставки. */
typedef enum kiwi_SettingID_TAG
{
	KIWI_SETID_V001_N1_1 = 29,
	KIWI_SETID_IDTO_N1_2 = 30,
	KIWI_SETID_V002_N1_3 = 31,
	KIWI_SETID_IDZT_N1_4 = 32,
	KIWI_SETID_IDZT_G_N1_5 = 33,
	KIWI_SETID_ITORM1_N1_6 = 34,
	KIWI_SETID_KTORM1_N1_7 = 35,
	KIWI_SETID_ITORM2_N1_8 = 36,
	KIWI_SETID_KTORM2_N1_9 = 37,
	KIWI_SETID_IPB_2G_N1_10 = 38,
	KIWI_SETID_TDZT_N1_11 = 39,
	KIWI_SETID_V003_N1_12 = 40,
	KIWI_SETID_TPB_2G_N1_13 = 41,
	KIWI_SETID_V004_N1_14 = 269,
	KIWI_SETID_IPB_5G_N1_15 = 270,
	KIWI_SETID_V005_N1_16 = 271,
	KIWI_SETID_TPB_5G_N1_17 = 272,
	KIWI_SETID_V006_N1_18 = 42,
	KIWI_SETID_V007_N1_19 = 43,
	KIWI_SETID_INB_N2_1 = 44,
	KIWI_SETID_TNB_N2_2 = 45,
	KIWI_SETID_V010_N2_3 = 46,
	KIWI_SETID_V011_N2_4 = 47,
	KIWI_SETID_V1000_N3_1 = 312,
	KIWI_SETID_V101_N3_2 = 48,
	KIWI_SETID_ITO_VN_N3_3 = 49,
	KIWI_SETID_TTO_VN_N3_4 = 50,
	KIWI_SETID_V102_N3_5 = 51,
	KIWI_SETID_IMTZ_VN_N3_6 = 52,
	KIWI_SETID_TMTZ_VN_N3_7 = 53,
	KIWI_SETID_V103_N3_8 = 54,
	KIWI_SETID_IMTZ_VN_CH_N3_9 = 55,
	KIWI_SETID_TMTZ_VN_CH_N3_10 = 56,
	KIWI_SETID_V104_N3_11 = 57,
	KIWI_SETID_V105_N3_12 = 58,
	KIWI_SETID_UMIN_MTZ_N3_13 = 59,
	KIWI_SETID_U2_MTZ_N3_14 = 60,
	KIWI_SETID_V106_N3_15 = 61,
	KIWI_SETID_TUMTZ_VN_N3_16 = 62,
	KIWI_SETID_V107_N3_17 = 63,
	KIWI_SETID_V112_N4_1 = 64,
	KIWI_SETID_IMTZ_NN_N4_2 = 65,
	KIWI_SETID_TMTZ_NN_SV_N4_3 = 66,
	KIWI_SETID_TMTZ_NN_N4_4 = 67,
	KIWI_SETID_V113_N4_5 = 68,
	KIWI_SETID_IMTZ_NN_CH_N4_6 = 69,
	KIWI_SETID_TMTZ_NN_CH_N4_7 = 70,
	KIWI_SETID_V114_N4_8 = 71,
	KIWI_SETID_V116_N4_9 = 72,
	KIWI_SETID_TUMTZ_NN_N4_10 = 73,
	KIWI_SETID_V118_N4_11 = 74,
	KIWI_SETID_TMTZ_NN_T_N4_12 = 75,
	KIWI_SETID_V121_N5_1 = 76,
	KIWI_SETID_V122_N5_2 = 77,
	KIWI_SETID_IZP_N5_3 = 78,
	KIWI_SETID_TZP_N5_4 = 79,
	KIWI_SETID_TZP_OTKL_N5_5 = 80,
	KIWI_SETID_V123_N5_6 = 81,
	KIWI_SETID_TRAZGR1_N5_7 = 82,
	KIWI_SETID_V124_N5_8 = 83,
	KIWI_SETID_TRAZGR2_N5_9 = 84,
	KIWI_SETID_V141_N6_1 = 85,
	KIWI_SETID_V142_N6_2 = 86,
	KIWI_SETID_TLZSH_N6_3 = 87,
	KIWI_SETID_V144_N6_4 = 88,
	KIWI_SETID_V145_N6_5 = 89,
	KIWI_SETID_TLZT_N6_6 = 90,
	KIWI_SETID_V151_N7_1 = 91,
	KIWI_SETID_IZDZ_N7_2 = 92,
	KIWI_SETID_V152_N7_3 = 93,
	KIWI_SETID_V161_N8_1 = 94,
	KIWI_SETID_I2TZOP_VN_N8_2 = 95,
	KIWI_SETID_TTZOP_VN_N8_3 = 96,
	KIWI_SETID_V162_N8_4 = 97,
	KIWI_SETID_I2TZOP_NN_N8_5 = 98,
	KIWI_SETID_TTZOP_NN_N8_6 = 99,
	KIWI_SETID_V163_N8_7 = 100,
	KIWI_SETID_TTZOP_NN_T_N8_8 = 101,
	KIWI_SETID_V171_N9_1 = 102,
	KIWI_SETID_V172_N9_2 = 103,
	KIWI_SETID_ITZNP_N9_3 = 104,
	KIWI_SETID_IPB_K3I0_N9_4 = 105,
	KIWI_SETID_TTZNP_T2_N9_5 = 106,
	KIWI_SETID_TTZNP_SV_N9_6 = 107,
	KIWI_SETID_TTZNP_VN_N9_7 = 108,
	KIWI_SETID_TTZNP_T_N9_8 = 109,
	KIWI_SETID_V175_N10_1 = 273,
	KIWI_SETID_IOZZ_N10_2 = 274,
	KIWI_SETID_TOZZ_N10_3 = 275,
	KIWI_SETID_V176_N10_4 = 276,
	KIWI_SETID_TOZZ_OTKL_N10_5 = 277,
	KIWI_SETID_TGZ1_N11_1 = 110,
	KIWI_SETID_TGZ2_N11_2 = 111,
	KIWI_SETID_TGZ_RPN_N11_3 = 112,
	KIWI_SETID_V201_N11_4 = 113,
	KIWI_SETID_V202_N11_5 = 114,
	KIWI_SETID_V203_N11_6 = 115,
	KIWI_SETID_TKI_GZ_N11_7 = 116,
	KIWI_SETID_TGZ_SIGN_N11_8 = 117,
	KIWI_SETID_V211_N12_1 = 118,
	KIWI_SETID_V214_N12_2 = 119,
	KIWI_SETID_V219_N12_3 = 120,
	KIWI_SETID_IPO1_N12_4 = 121,
	KIWI_SETID_TPO1_N12_5 = 122,
	KIWI_SETID_V212_N12_6 = 123,
	KIWI_SETID_IPO2_N12_7 = 124,
	KIWI_SETID_TPO2_N12_8 = 125,
	KIWI_SETID_V213_N12_9 = 126,
	KIWI_SETID_IPO3_N12_10 = 127,
	KIWI_SETID_TPO3_N12_11 = 128,
	KIWI_SETID_V215_N12_12 = 129,
	KIWI_SETID_TZPO1_N12_13 = 130,
	KIWI_SETID_V216_N12_14 = 131,
	KIWI_SETID_TZPO2_N12_15 = 132,
	KIWI_SETID_V217_N12_16 = 133,
	KIWI_SETID_TZPO3_N12_17 = 134,
	KIWI_SETID_V218_N12_18 = 135,
	KIWI_SETID_TZPO4_N12_19 = 136,
	KIWI_SETID_TZPO_PUSK_N12_20 = 137,
	KIWI_SETID_V311_N13_1 = 138,
	KIWI_SETID_V312_N13_2 = 139,
	KIWI_SETID_V313_N13_3 = 140,
	KIWI_SETID_I_SF6_BLOK_N13_4 = 141,
	KIWI_SETID_T_SF6_OTKL_N13_5 = 142,
	KIWI_SETID_V314_N13_6 = 143,
	KIWI_SETID_V315_N13_7 = 144,
	KIWI_SETID_T_SF6_TT_N13_8 = 145,
	KIWI_SETID_V301_N14_1 = 146,
	KIWI_SETID_IUROV_N14_2 = 147,
	KIWI_SETID_TUROV_N14_3 = 148,
	KIWI_SETID_V302_N14_4 = 149,
	KIWI_SETID_V303_N14_5 = 150,
	KIWI_SETID_TUROV_NS_N14_6 = 151,
	KIWI_SETID_V304_N14_7 = 152,
	KIWI_SETID_V307_N14_8 = 286,
	KIWI_SETID_V406_N14_9 = 153,
	KIWI_SETID_IQK_N14_10 = 154,
	KIWI_SETID_V401_N15_1 = 155,
	KIWI_SETID_TVKL_IMP_N16_1 = 156,
	KIWI_SETID_TRPV_N16_2 = 157,
	KIWI_SETID_V402_N16_3 = 158,
	KIWI_SETID_TEM_N16_4 = 159,
	KIWI_SETID_V403_N17_1 = 160,
	KIWI_SETID_TOTKL_IMP_N17_2 = 161,
	KIWI_SETID_TRPO_N17_3 = 162,
	KIWI_SETID_V404_N17_4 = 163,
	KIWI_SETID_V405_N17_5 = 164,
	KIWI_SETID_TOD_N17_6 = 165,
	KIWI_SETID_TPAUZY_N17_7 = 278,
	KIWI_SETID_TUROK_N17_8 = 166,
	KIWI_SETID_V441_N18_1 = 284,
	KIWI_SETID_V501_N19_1 = 167,
	KIWI_SETID_V502_N19_2 = 279,
	KIWI_SETID_TAPV_N19_3 = 168,
	KIWI_SETID_TAPV_GOT_N19_4 = 169,
	KIWI_SETID_TAV_SHP_N20_1 = 170,
	KIWI_SETID_TPRUZH_N20_2 = 171,
	KIWI_SETID_TTEMP_N20_3 = 172,
	KIWI_SETID_V409_N20_4 = 173,
	KIWI_SETID_TNCU_N20_5 = 285,
	KIWI_SETID_SHAG_RPN_N21_1 = 174,
	KIWI_SETID_DU_ARKT_N21_2 = 175,
	KIWI_SETID_UPOD1_N21_3 = 176,
	KIWI_SETID_UPOD2_N21_4 = 177,
	KIWI_SETID_UPOD3_N21_5 = 178,
	KIWI_SETID_UPOD4_N21_6 = 179,
	KIWI_SETID_V801_N21_7 = 180,
	KIWI_SETID_INOM_ARKT_N21_8 = 181,
	KIWI_SETID_UKOMP_N21_9 = 182,
	KIWI_SETID_UKOMP_MAX_N21_10 = 183,
	KIWI_SETID_IRPN_BLOK_N21_11 = 184,
	KIWI_SETID_IRPN_NAGR_N21_12 = 185,
	KIWI_SETID_URPN_MIN_N21_13 = 186,
	KIWI_SETID_U2RPN_N21_14 = 187,
	KIWI_SETID_3U0RPN_N21_15 = 188,
	KIWI_SETID_URPN_MAX_N21_16 = 189,
	KIWI_SETID_V811_N22_1 = 190,
	KIWI_SETID_V812_N22_2 = 191,
	KIWI_SETID_V813_N22_3 = 192,
	KIWI_SETID_V821_N23_1 = 193,
	KIWI_SETID_V822_N23_2 = 194,
	KIWI_SETID_TRPN1_N24_1 = 195,
	KIWI_SETID_TRPN2_N24_2 = 196,
	KIWI_SETID_TRPN3_N24_3 = 197,
	KIWI_SETID_TRPN4_N24_4 = 198,
	KIWI_SETID_V841_N25_1 = 199,
	KIWI_SETID_V842_N25_2 = 200,
	KIWI_SETID_V843_N25_3 = 201,
	KIWI_SETID_N_N25_4 = 202,
	KIWI_SETID_NOTP_NACH_N25_5 = 203,
	KIWI_SETID_N2_BLOK_N25_6 = 204,
	KIWI_SETID_N3_BLOK_N25_7 = 205,
	KIWI_SETID_N4_BLOK_N25_8 = 206,
	KIWI_SETID_N5_BLOK_N25_9 = 207,
	KIWI_SETID_N6_BLOK_N25_10 = 208,
	KIWI_SETID_N7_BLOK_N25_11 = 209,
	KIWI_SETID_N8_BLOK_N25_12 = 210,
	KIWI_SETID_N9_BLOK_N25_13 = 211,
	KIWI_SETID_N10_BLOK_N25_14 = 212,
	KIWI_SETID_N11_BLOK_N25_15 = 213,
	KIWI_SETID_N12_BLOK_N25_16 = 214,
	KIWI_SETID_N13_BLOK_N25_17 = 215,
	KIWI_SETID_N14_BLOK_N25_18 = 216,
	KIWI_SETID_N15_BLOK_N25_19 = 217,
	KIWI_SETID_N16_BLOK_N25_20 = 218,
	KIWI_SETID_N17_BLOK_N25_21 = 219,
	KIWI_SETID_N18_BLOK_N25_22 = 220,
	KIWI_SETID_N19_BLOK_N25_23 = 221,
	KIWI_SETID_N20_BLOK_N25_24 = 222,
	KIWI_SETID_N21_BLOK_N25_25 = 223,
	KIWI_SETID_N22_BLOK_N25_26 = 224,
	KIWI_SETID_N23_BLOK_N25_27 = 225,
	KIWI_SETID_N24_BLOK_N25_28 = 226,
	KIWI_SETID_N25_BLOK_N25_29 = 227,
	KIWI_SETID_N26_BLOK_N25_30 = 228,
	KIWI_SETID_N27_BLOK_N25_31 = 229,
	KIWI_SETID_N28_BLOK_N25_32 = 230,
	KIWI_SETID_N29_BLOK_N25_33 = 231,
	KIWI_SETID_N30_BLOK_N25_34 = 232,
	KIWI_SETID_N31_BLOK_N25_35 = 233,
	KIWI_SETID_N32_BLOK_N25_36 = 234,
	KIWI_SETID_N33_BLOK_N25_37 = 235,
	KIWI_SETID_N34_BLOK_N25_38 = 236,
	KIWI_SETID_N35_BLOK_N25_39 = 237,
	KIWI_SETID_N36_BLOK_N25_40 = 238,
	KIWI_SETID_N37_BLOK_N25_41 = 239,
	KIWI_SETID_N38_BLOK_N25_42 = 240,
	KIWI_SETID_N39_BLOK_N25_43 = 241,
	KIWI_SETID_N40_BLOK_N25_44 = 242,
	KIWI_SETID_N41_BLOK_N25_45 = 243,
	KIWI_SETID_N42_BLOK_N25_46 = 244,
	KIWI_SETID_N43_BLOK_N25_47 = 245,
	KIWI_SETID_N44_BLOK_N25_48 = 246,
	KIWI_SETID_N45_BLOK_N25_49 = 247,
	KIWI_SETID_N46_BLOK_N25_50 = 248,
	KIWI_SETID_N47_BLOK_N25_51 = 249,
	KIWI_SETID_RESURS_N26_1 = 250,
	KIWI_SETID_RESURS_PN_N26_2 = 251,
	KIWI_SETID_RESURS_SIGN_N26_3 = 252,
	KIWI_SETID_V855_N27_1 = 253,
	KIWI_SETID_V856_N27_2 = 254,
	KIWI_SETID_TRPN5_N27_3 = 255,
	KIWI_SETID_TRPN6_N27_4 = 256,
	KIWI_SETID_TPM_N27_5 = 257,
	KIWI_SETID_V881_N28_1 = 280,
	KIWI_SETID_TPR_1_N28_2 = 258,
	KIWI_SETID_TPS_1_N30_1 = 259,
	KIWI_SETID_TPS_2_N30_2 = 260,
	KIWI_SETID_TPS_3_N30_3 = 261,
	KIWI_SETID_TPS_4_N30_4 = 262,
	KIWI_SETID_TPS_5_N30_5 = 263,
	KIWI_SETID_TPS_6_N30_6 = 264,
	KIWI_SETID_TPS_DOP_N30_7 = 265,
	KIWI_SETID_V970_N30_8 = 287,
	KIWI_SETID_3U0_SIGN_N30_9 = 288,
	KIWI_SETID_TOZZ_SIGN_N30_10 = 289,
	KIWI_SETID_V891_N31_1 = 281,
	KIWI_SETID_TPS_RPN_1_N31_2 = 266,
	KIWI_SETID_TPS_RPN_2_N31_3 = 267,
	KIWI_SETID_TPS_RPN_3_N31_4 = 282,
	KIWI_SETID_TPS_RPN_4_N31_5 = 283,
	KIWI_SETID_TPS_RPN_DOP_N31_6 = 268,
	KIWI_SETID_IN_TT_VN_P_N32_1 = 0,
	KIWI_SETID_IN_TT_NN_P_N32_2 = 1,
	KIWI_SETID_IN_TT_3I0_P_N32_3 = 2,
	KIWI_SETID_IN_TT_VN_V_N32_4 = 3,
	KIWI_SETID_IN_TT_NN_V_N32_5 = 4,
	KIWI_SETID_IN_TT_3I0_V_N32_6 = 5,
	KIWI_SETID_UN_TN_NN_P_N32_7 = 6,
	KIWI_SETID_UN_TN_NN_V_N32_8 = 14,
	KIWI_SETID_UN_TN_NN_DOP_N32_9 = 15,
	KIWI_SETID_VYBOR_DIAPAZONA_N32_10 = 25,
	KIWI_SETID_I_VN_D_N32_11 = 26,
	KIWI_SETID_3I0_D_N32_12 = 27,
	KIWI_SETID_I_NN_D_N32_13 = 28,
	KIWI_SETID_SKHEMA_VN_N33_1 = 17,
	KIWI_SETID_SKHEMA_NN_N33_2 = 18,
	KIWI_SETID_GRUPPA_N33_3 = 13,
	KIWI_SETID_SN_N33_4 = 7,
	KIWI_SETID_UN_VN_N33_5 = 8,
	KIWI_SETID_UN_NN_N33_6 = 9,
	KIWI_SETID_IN_N33_7 = 10,
	KIWI_SETID_TOSC_DOAV_N34_1 = 11,
	KIWI_SETID_TOSC_N34_2 = 12,
	KIWI_SETID_UPIT_N35_1 = 16,
	KIWI_SETID_MVV_N35_2 = 19,
	KIWI_SETID_MK_N35_3 = 20,
	KIWI_SETID_I4_N35_4 = 21,
	KIWI_SETID_AUV_N35_5 = 22,
	KIWI_SETID_ARKT_N35_6 = 23,
	KIWI_SETID_OBJEKT_N35_7 = 24,
	KIWI_SETID_PU_N35_8 = 777, /* Эта уставка сейчас не испольузется ни в Киви, ни в пульте. */
	KIWI_SETID_I_MAKS_1_VN_N60_1 = 290,
	KIWI_SETID_I_MAKS_2_VN_N60_2 = 291,
	KIWI_SETID_I_MAKS_3_VN_N60_3 = 292,
	KIWI_SETID_I_MIN_1_VN_N60_4 = 293,
	KIWI_SETID_I_MIN_2_VN_N60_5 = 294,
	KIWI_SETID_I2_MAKS_VN_N60_6 = 295,
	KIWI_SETID_3I0_MAKS_1_VN_N60_7 = 296,
	KIWI_SETID_3I0_MAKS_2_VN_N60_8 = 297,
	KIWI_SETID_3I0_MAKS_3_VN_N60_9 = 298,
	KIWI_SETID_I_MAKS_1_NN_N60_10 = 299,
	KIWI_SETID_I_MAKS_2_NN_N60_11 = 300,
	KIWI_SETID_I_MAKS_3_NN_N60_12 = 301,
	KIWI_SETID_I_MIN_1_NN_N60_13 = 302,
	KIWI_SETID_I_MIN_2_NN_N60_14 = 303,
	KIWI_SETID_I4_MAKS_N60_15 = 304,
	KIWI_SETID_I4_MIN_N60_16 = 305,
	KIWI_SETID_U_MAKS_1_N60_17 = 306,
	KIWI_SETID_U_MAKS_2_N60_18 = 307,
	KIWI_SETID_U_MIN_1_N60_19 = 308,
	KIWI_SETID_U_MIN_2_N60_20 = 309,
	KIWI_SETID_U2_MAKS_1_N60_21 = 310,
	KIWI_SETID_3U0_MAKS_1_N60_22 = 311,

	/* Идентификаторы фиктивных уставок, которые используются только в пульте. */
	KIWI_SETID_PAROL_PULTA = 9999,

	KIWI_SETID_INVALID_SETTING = KIWI_INVALID_ID
} kiwi_SettingID;
/*-----------------------------------------------------------------------------------------------*/
/** @brief Тип идентификатора аналогового входа. */
typedef enum kiwi_AnalogInputID_TAG
{
	KIWI_AIID_INPUT_1 = 0,
	KIWI_AIID_INPUT_2 = 1,
	KIWI_AIID_INPUT_3 = 2,
	KIWI_AIID_INPUT_4 = 3,
	KIWI_AIID_INPUT_5 = 4,
	KIWI_AIID_INPUT_6 = 5,
	KIWI_AIID_INPUT_7 = 6,
	KIWI_AIID_INPUT_8 = 7,
	KIWI_AIID_INPUT_9 = 8,
	KIWI_AIID_INPUT_10 = 9,

	KIWI_AIID_INVALID_INPUT = KIWI_INVALID_ID
} kiwi_AnalogInputID;
/*-----------------------------------------------------------------------------------------------*/
/** @brief Тип идентификатора двоичного входа. */
typedef enum kiwi_BinaryInputID_TAG
{
	KIWI_BIID_INPUT_1 = 0,
	KIWI_BIID_INPUT_2 = 1,
	KIWI_BIID_INPUT_3 = 2,
	KIWI_BIID_INPUT_4 = 3,
	KIWI_BIID_INPUT_5 = 4,
	KIWI_BIID_INPUT_6 = 5,
	KIWI_BIID_INPUT_7 = 6,
	KIWI_BIID_INPUT_8 = 7,
	KIWI_BIID_INPUT_9 = 8,
	KIWI_BIID_INPUT_10 = 9,
	KIWI_BIID_INPUT_11 = 10,
	KIWI_BIID_INPUT_12 = 11,
	KIWI_BIID_INPUT_13 = 12,
	KIWI_BIID_INPUT_14 = 13,
	KIWI_BIID_INPUT_15 = 14,
	KIWI_BIID_INPUT_16 = 15,
	KIWI_BIID_INPUT_17 = 16,
	KIWI_BIID_INPUT_18 = 17,
	KIWI_BIID_INPUT_19 = 18,
	KIWI_BIID_INPUT_20 = 19,
	KIWI_BIID_INPUT_21 = 20,
	KIWI_BIID_INPUT_22 = 21,
	KIWI_BIID_INPUT_23 = 22,
	KIWI_BIID_INPUT_24 = 23,
	KIWI_BIID_INPUT_25 = 24,
	KIWI_BIID_INPUT_26 = 25,
	KIWI_BIID_INPUT_27 = 26,
	KIWI_BIID_INPUT_28 = 27,
	KIWI_BIID_INPUT_29 = 28,
	KIWI_BIID_INPUT_30 = 29,
	KIWI_BIID_INPUT_31 = 30,
	KIWI_BIID_INPUT_32 = 31,
	KIWI_BIID_INPUT_33 = 32,
	KIWI_BIID_INPUT_34 = 33,
	KIWI_BIID_INPUT_35 = 34,
	KIWI_BIID_INPUT_36 = 35,
	KIWI_BIID_INPUT_37 = 36,
	KIWI_BIID_INPUT_38 = 37,
	KIWI_BIID_INPUT_39 = 38,
	KIWI_BIID_INPUT_40 = 39,
	KIWI_BIID_INPUT_41 = 40,
	KIWI_BIID_INPUT_42 = 41,

	KIWI_BIID_INVALID_INPUT = KIWI_INVALID_ID
} kiwi_BinaryInputID;
/*-----------------------------------------------------------------------------------------------*/
/** @brief Тип идентификатора двоичного выхода. */
typedef enum kiwi_BinaryOutputID_TAG
{
	KIWI_BOID_OUTPUT_1 = 0,
	KIWI_BOID_OUTPUT_2 = 1,
	KIWI_BOID_OUTPUT_3 = 2,
	KIWI_BOID_OUTPUT_4 = 3,
	KIWI_BOID_OUTPUT_5 = 4,
	KIWI_BOID_OUTPUT_6 = 5,
	KIWI_BOID_OUTPUT_7 = 6,
	KIWI_BOID_OUTPUT_8 = 7,
	KIWI_BOID_OUTPUT_9 = 8,
	KIWI_BOID_OUTPUT_10 = 9,
	KIWI_BOID_OUTPUT_11 = 10,
	KIWI_BOID_OUTPUT_12 = 11,
	KIWI_BOID_OUTPUT_13 = 12,
	KIWI_BOID_OUTPUT_14 = 13,
	KIWI_BOID_OUTPUT_15 = 14,
	KIWI_BOID_OUTPUT_16 = 15,
	KIWI_BOID_OUTPUT_17 = 16,
	KIWI_BOID_OUTPUT_18 = 17,
	KIWI_BOID_OUTPUT_19 = 18,
	KIWI_BOID_OUTPUT_20 = 19,
	KIWI_BOID_OUTPUT_21 = 20,
	KIWI_BOID_OUTPUT_22 = 21,
	KIWI_BOID_OUTPUT_23 = 22,
	KIWI_BOID_OUTPUT_24 = 23,
	KIWI_BOID_OUTPUT_25 = 24,
	KIWI_BOID_OUTPUT_26 = 25,
	KIWI_BOID_OUTPUT_27 = 26,
	KIWI_BOID_OUTPUT_28 = 27,

	KIWI_BOID_INVALID_OUTPUT = KIWI_INVALID_ID
} kiwi_BinaryOutputID;
/*-----------------------------------------------------------------------------------------------*/
/** @brief Тип идентификатора двоичного входного сигнала. */
typedef enum kiwi_BinaryInputSignalID_TAG
{
	KIWI_BISID_VYVOD_DTO_N1_1 = 0,
	KIWI_BISID_VYVOD_DZT_N1_2 = 1,
	KIWI_BISID_VYVOD_TO_VN_N1_3 = 2,
	KIWI_BISID_VYVOD_MTZ_VN_N1_4 = 3,
	KIWI_BISID_RPV_NN_VV_N1_5 = 4,
	KIWI_BISID_PON_NN_N1_6 = 5,
	KIWI_BISID_RPO_NN_SV_N1_7 = 6,
	KIWI_BISID_USK_MTZ_VN_N1_8 = 7,
	KIWI_BISID_RPO_VN_N1_9 = 8,
	KIWI_BISID_VYVOD_MTZ_NN_N1_10 = 9,
	KIWI_BISID_USK_MTZ_NN_N1_11 = 10,
	KIWI_BISID_RPO_NN_VV_N1_12 = 11,
	KIWI_BISID_LZSHP_N1_13 = 12,
	KIWI_BISID_LZSH_PITANIE_N1_14 = 13,
	KIWI_BISID_LZTP_N1_15 = 14,
	KIWI_BISID_ZDZ_REGISTRATOR_N1_16 = 15,
	KIWI_BISID_ZDZ_VNESHNIJ_N1_17 = 16,
	KIWI_BISID_VYVOD_TZOP_VN_N1_18 = 17,
	KIWI_BISID_VYVOD_TZOP_NN_N1_19 = 18,
	KIWI_BISID_VYVOD_TZNP_N1_20 = 19,
	KIWI_BISID_VYVOD_OZZ_N1_21 = 106,
	KIWI_BISID_GZ_T_1_N1_22 = 20,
	KIWI_BISID_GZ_T_2_N1_23 = 21,
	KIWI_BISID_GZ_RPN_N1_24 = 22,
	KIWI_BISID_KI_GZ_T_1_N1_25 = 23,
	KIWI_BISID_KI_GZ_T_2_N1_26 = 24,
	KIWI_BISID_KI_GZ_RPN_N1_27 = 25,
	KIWI_BISID_GZ_T_1_NA_OTKL_N1_28 = 26,
	KIWI_BISID_GZ_T_2_NA_SIGNAL_N1_29 = 27,
	KIWI_BISID_GZ_RPN_NA_SIGNAL_N1_30 = 28,
	KIWI_BISID_PITANIE_GZ_N1_31 = 29,
	KIWI_BISID_T_MASLA_SRAB_N1_32 = 30,
	KIWI_BISID_T_MASLA_VOZVR_N1_33 = 31,
	KIWI_BISID_OHL_OTKLJUCHENO_N1_34 = 32,
	KIWI_BISID_OTKL_OT_SHAOT_N1_35 = 33,
	KIWI_BISID_SF6_Q_2_ST_N1_36 = 34,
	KIWI_BISID_SF6_Q_1_ST_N1_37 = 35,
	KIWI_BISID_SF6_TT_2_ST_N1_38 = 36,
	KIWI_BISID_SF6_TT_1_ST_N1_39 = 37,
	KIWI_BISID_PUSK_UROV_VNESH_N1_40 = 38,
	KIWI_BISID_RPV_VN_N1_41 = 39,
	KIWI_BISID_VYVOD_UROV_N1_42 = 40,
	KIWI_BISID_OU_VKLJUCHIT_N1_43 = 41,
	KIWI_BISID_OU_VKLJUCHIT_ASU_N1_44 = 42,
	KIWI_BISID_OU_VKLJUCHIT_PU_N1_45 = 43,
	KIWI_BISID_OU_VKLJUCHIT_KIWI_N1_46 = 44,
	KIWI_BISID_OU_OTKLJUCHIT_N1_47 = 45,
	KIWI_BISID_OU_OTKLJUCHIT_ASU_N1_48 = 46,
	KIWI_BISID_OU_OTKLJUCHIT_PU_N1_49 = 47,
	KIWI_BISID_OU_OTKLJUCHIT_KIWI_N1_50 = 48,
	KIWI_BISID_DU_N1_51 = 49,
	KIWI_BISID_REZHIM_NALADKI_N1_52 = 50,
	KIWI_BISID_VYVOD_AUV_N1_53 = 51,
	KIWI_BISID_BLOK_VKLJUCHENIJA_N1_54 = 52,
	KIWI_BISID_DT_EV_N1_55 = 53,
	KIWI_BISID_DT_EO_1_N1_56 = 54,
	KIWI_BISID_DT_EO_2_N1_57 = 55,
	KIWI_BISID_OTKL_OT_OSN_ZASHH_N1_58 = 56,
	KIWI_BISID_OTKL_OT_UROV_N1_59 = 57,
	KIWI_BISID_VNESH_ZASHH_BEZ_APV_N1_60 = 58,
	KIWI_BISID_PREDOHR_KLAPAN_N1_61 = 59,
	KIWI_BISID_VNESH_ZASHH_S_APV_N1_62 = 60,
	KIWI_BISID_OTKL_OT_TZNP_T2_N1_63 = 61,
	KIWI_BISID_QK_VKLJUCHEN_N1_64 = 62,
	KIWI_BISID_QK_OTKLJUCHEN_N1_65 = 63,
	KIWI_BISID_VYVOD_APV_N1_66 = 64,
	KIWI_BISID_AV_SHP_N1_67 = 65,
	KIWI_BISID_PRUZHINA_N1_68 = 66,
	KIWI_BISID_T_POLJUSOV_N1_69 = 67,
	KIWI_BISID_RPV_2_VN_N1_70 = 68,
	KIWI_BISID_VYBOR_UPOD_1_N1_71 = 69,
	KIWI_BISID_VYBOR_UPOD_2_N1_72 = 70,
	KIWI_BISID_T_MASLA_RPN_N1_73 = 71,
	KIWI_BISID_UROVEN_MASLA_RPN_N1_74 = 72,
	KIWI_BISID_ZAPRET_PRIBAVIT_N1_75 = 73,
	KIWI_BISID_ZAPRET_UBAVIT_N1_76 = 74,
	KIWI_BISID_BLOK_RPN_N1_77 = 75,
	KIWI_BISID_PRIBAVIT_N1_78 = 76,
	KIWI_BISID_PRIBAVIT_ASU_N1_79 = 77,
	KIWI_BISID_PRIBAVIT_PU_N1_80 = 78,
	KIWI_BISID_PRIBAVIT_KIWI_N1_81 = 79,
	KIWI_BISID_UBAVIT_N1_82 = 80,
	KIWI_BISID_UBAVIT_ASU_N1_83 = 81,
	KIWI_BISID_UBAVIT_PU_N1_84 = 82,
	KIWI_BISID_UBAVIT_KIWI_N1_85 = 83,
	KIWI_BISID_VYVOD_AU_RPN_N1_86 = 84,
	KIWI_BISID_PEREKL_N1_87 = 85,
	KIWI_BISID_USTANOVIT_NOTP_PU_N1_88 = 107,
	KIWI_BISID_USTANOVIT_NOTP_KIWI_N1_89 = 108,
	KIWI_BISID_USTANOVIT_RESURS_PU_N1_90 = 109,
	KIWI_BISID_USTANOVIT_RESURS_KIWI_N1_91 = 110,
	KIWI_BISID_PROGRAMMA_2_N1_92 = 86,
	KIWI_BISID_PROGRAMMA_2_ASU_N1_93 = 87,
	KIWI_BISID_PROGRAMMA_2_PU_N1_94 = 88,
	KIWI_BISID_PROGRAMMA_2_KIWI_N1_95 = 89,
	KIWI_BISID_PROGRAMMA_1_N1_96 = 90,
	KIWI_BISID_PROGRAMMA_1_ASU_N1_97 = 91,
	KIWI_BISID_PROGRAMMA_1_PU_N1_98 = 92,
	KIWI_BISID_PROGRAMMA_1_KIWI_N1_99 = 93,
	KIWI_BISID_SJEM_SIGNALIZACII_DV_N1_100 = 94,
	KIWI_BISID_SJEM_SIGNALIZACII_ASU_N1_101 = 95,
	KIWI_BISID_SJEM_SIGNALIZACII_PU_N1_102 = 96,
	KIWI_BISID_SJEM_SIGNALIZACII_KIWI_N1_103 = 97,
	KIWI_BISID_NA_AVAR_SIGN_N1_104 = 98,
	KIWI_BISID_UROVEN_MASLA_N1_105 = 99,
	KIWI_BISID_T_MASLA_SIGNAL_N1_106 = 100,
	KIWI_BISID_NA_PRED_SIGN_N1_107 = 101,
	KIWI_BISID_PUSK_OSC_S_N1_108 = 102,
	KIWI_BISID_PUSK_OSC_I_N1_109 = 103,
	KIWI_BISID_PUSK_OSC_ASU_N1_110 = 111,
	KIWI_BISID_PUSK_OSC_PU_N1_111 = 112,
	KIWI_BISID_PUSK_OSC_KIWI_N1_112 = 113,
	KIWI_BISID_NEISPRAVNOST_ALTEI_N1_113 = 104,
	KIWI_BISID_OTKAZ_ALTEI_N1_114 = 114,
	KIWI_BISID_NA_PRED_SIGN_RPN_N1_115 = 105,

	KIWI_BISID_INVALID_SIGNAL = KIWI_INVALID_ID
} kiwi_BinaryInputSignalID;
/*-----------------------------------------------------------------------------------------------*/
/** @brief Тип идентификатора двоичного выходного сигнала. */
typedef enum kiwi_BinaryOutputSignalID_TAG
{
	KIWI_BOSID_DTO_A_SRAB_N1_1 = 0,
	KIWI_BOSID_DTO_B_SRAB_N1_2 = 1,
	KIWI_BOSID_DTO_C_SRAB_N1_3 = 2,
	KIWI_BOSID_DTO_SRAB_N1_4 = 3,
	KIWI_BOSID_DZT_A_PUSK_N1_5 = 4,
	KIWI_BOSID_DZT_B_PUSK_N1_6 = 5,
	KIWI_BOSID_DZT_C_PUSK_N1_7 = 6,
	KIWI_BOSID_DZT_PUSK_N1_8 = 7,
	KIWI_BOSID_DZT_A_SRAB_N1_9 = 8,
	KIWI_BOSID_DZT_B_SRAB_N1_10 = 9,
	KIWI_BOSID_DZT_C_SRAB_N1_11 = 10,
	KIWI_BOSID_DZT_SRAB_N1_12 = 11,
	KIWI_BOSID_IPB_2G_A_N1_13 = 12,
	KIWI_BOSID_IPB_2G_B_N1_14 = 13,
	KIWI_BOSID_IPB_2G_C_N1_15 = 14,
	KIWI_BOSID_PB_2G_N1_16 = 15,
	KIWI_BOSID_IPB_5G_A_N1_17 = 249,
	KIWI_BOSID_IPB_5G_B_N1_18 = 250,
	KIWI_BOSID_IPB_5G_C_N1_19 = 251,
	KIWI_BOSID_PB_5G_N1_20 = 252,
	KIWI_BOSID_NB_A_SRAB_N2_1 = 16,
	KIWI_BOSID_NB_B_SRAB_N2_2 = 17,
	KIWI_BOSID_NB_C_SRAB_N2_3 = 18,
	KIWI_BOSID_NB_SRAB_N2_4 = 19,
	KIWI_BOSID_NB_PUSK_N2_5 = 20,
	KIWI_BOSID_KCT_A_SRAB_N2_6 = 21,
	KIWI_BOSID_KCT_B_SRAB_N2_7 = 22,
	KIWI_BOSID_KCT_C_SRAB_N2_8 = 23,
	KIWI_BOSID_KCT_SRAB_N2_9 = 24,
	KIWI_BOSID_TO_VN_PUSK_N3_1 = 25,
	KIWI_BOSID_TO_VN_SRAB_N3_2 = 26,
	KIWI_BOSID_MTZ_VN_SRAB_N3_3 = 27,
	KIWI_BOSID_MTZ_VN_PUSK_N3_4 = 28,
	KIWI_BOSID_PON_NN_SRAB_N3_5 = 29,
	KIWI_BOSID_NEISPR_CN_N3_6 = 30,
	KIWI_BOSID_NEISPR_CN_PUSK_N3_7 = 31,
	KIWI_BOSID_MTZ_NN_SV_SRAB_N4_1 = 32,
	KIWI_BOSID_MTZ_NN_T_SRAB_N4_2 = 33,
	KIWI_BOSID_MTZ_NN_VV_SRAB_N4_3 = 34,
	KIWI_BOSID_MTZ_NN_PUSK_N4_4 = 35,
	KIWI_BOSID_PEREGRUZKA_N5_1 = 36,
	KIWI_BOSID_PEREGRUZKA_PUSK_N5_2 = 37,
	KIWI_BOSID_PEREGRUZKA_NA_OTKL_N5_3 = 38,
	KIWI_BOSID_RAZGRUZKA_1_N5_4 = 39,
	KIWI_BOSID_RAZGRUZKA_2_N5_5 = 40,
	KIWI_BOSID_LZSH_SRAB_N6_1 = 41,
	KIWI_BOSID_LZSH_NEISPR_N6_2 = 42,
	KIWI_BOSID_LZT_SRAB_N6_3 = 43,
	KIWI_BOSID_ZDZ_PUSK_PO_I_N7_1 = 44,
	KIWI_BOSID_ZDZ_SRAB_N7_2 = 45,
	KIWI_BOSID_ZDZ_NEISPR_N7_3 = 46,
	KIWI_BOSID_TZOP_VN_SRAB_N8_1 = 47,
	KIWI_BOSID_TZOP_VN_PUSK_N8_2 = 48,
	KIWI_BOSID_TZOP_NN_T_SRAB_N8_3 = 49,
	KIWI_BOSID_TZOP_NN_VV_SRAB_N8_4 = 50,
	KIWI_BOSID_TZOP_NN_PUSK_N8_5 = 51,
	KIWI_BOSID_TZNP_NA_T2_N9_1 = 52,
	KIWI_BOSID_TZNP_NA_SV_N9_2 = 53,
	KIWI_BOSID_TZNP_NA_VN_N9_3 = 54,
	KIWI_BOSID_TZNP_NA_T_N9_4 = 55,
	KIWI_BOSID_TZNP_PUSK_N9_5 = 56,
	KIWI_BOSID_OZZ_PUSK_N10_1 = 253,
	KIWI_BOSID_OZZ_SRAB_N10_2 = 254,
	KIWI_BOSID_OZZ_NA_OTKL_N10_3 = 255,
	KIWI_BOSID_GZ_T_1_SRAB_N11_1 = 57,
	KIWI_BOSID_GZ_T_1_NEISPR_N11_2 = 58,
	KIWI_BOSID_GZ_T_2_SRAB_N11_3 = 59,
	KIWI_BOSID_GZ_T_2_NEISPR_N11_4 = 60,
	KIWI_BOSID_GZ_RPN_SRAB_N11_5 = 61,
	KIWI_BOSID_GZ_RPN_NEISPR_N11_6 = 62,
	KIWI_BOSID_GZ_NA_OTKL_N11_7 = 63,
	KIWI_BOSID_GZ_NEISPRAVNOST_N11_8 = 64,
	KIWI_BOSID_VYSOKAJA_T_MASLA_N12_1 = 65,
	KIWI_BOSID_PUSK_OHL_1_N12_2 = 66,
	KIWI_BOSID_PUSK_OHL_2_N12_3 = 67,
	KIWI_BOSID_PUSK_OHL_3_N12_4 = 68,
	KIWI_BOSID_ZPO_PUSK_N12_5 = 69,
	KIWI_BOSID_ZPO_1_SRAB_N12_6 = 70,
	KIWI_BOSID_ZPO_2_SRAB_N12_7 = 71,
	KIWI_BOSID_ZPO_3_SRAB_N12_8 = 72,
	KIWI_BOSID_ZPO_4_SRAB_N12_9 = 73,
	KIWI_BOSID_ZPO_NA_OTKL_N12_10 = 74,
	KIWI_BOSID_RT_SF6_BLOK_N13_1 = 75,
	KIWI_BOSID_SF6_Q_NA_OTKL_N13_2 = 76,
	KIWI_BOSID_BLOK_OTKL_PO_SF6_N13_3 = 77,
	KIWI_BOSID_POTERJA_SF6_Q_N13_4 = 78,
	KIWI_BOSID_POTERJA_SF6_TT_N13_5 = 79,
	KIWI_BOSID_SF6_TT_NA_OTKL_N13_6 = 80,
	KIWI_BOSID_UROV_NA_SEBJA_N14_1 = 81,
	KIWI_BOSID_UROV_SRAB_N14_2 = 82,
	KIWI_BOSID_RT_UROV_N14_3 = 83,
	KIWI_BOSID_NET_TOKOV_N14_4 = 84,
	KIWI_BOSID_RT_QK_N14_5 = 85,
	KIWI_BOSID_OPERATIVNOE_VKL_N15_1 = 86,
	KIWI_BOSID_OPERATIVNOE_OTKL_N15_2 = 87,
	KIWI_BOSID_UPR_PO_DV_N15_3 = 88,
	KIWI_BOSID_UPR_PO_ASU_N15_4 = 89,
	KIWI_BOSID_UPR_S_PU_N15_5 = 90,
	KIWI_BOSID_AUV_VYVEDENA_N15_6 = 91,
	KIWI_BOSID_VKL_NA_VN_N16_1 = 92,
	KIWI_BOSID_VKLJUCHIT_N16_2 = 93,
	KIWI_BOSID_VKL_BLOKIROVANO_N16_3 = 94,
	KIWI_BOSID_OTKL_NA_T2_N17_1 = 95,
	KIWI_BOSID_OTKL_NA_SV_VN_N17_2 = 96,
	KIWI_BOSID_OTKL_NA_SV_NN_N17_3 = 97,
	KIWI_BOSID_OTKL_NA_VV_NN_N17_4 = 98,
	KIWI_BOSID_OTKL_NN_BEZ_AVR_N17_5 = 99,
	KIWI_BOSID_OTKL_NN_S_AVR_N17_6 = 100,
	KIWI_BOSID_ZAPRET_APV_OT_ZASHHIT_N17_7 = 101,
	KIWI_BOSID_SRAB_ZASHH_T_N17_8 = 102,
	KIWI_BOSID_OTKL_NA_VN_N17_9 = 103,
	KIWI_BOSID_OTKLJUCHIT_N17_10 = 104,
	KIWI_BOSID_UROK_SRAB_N17_11 = 105,
	KIWI_BOSID_OTKL_OTDELITEL_N17_12 = 106,
	KIWI_BOSID_ZASHH_EV_EO_1_N17_13 = 107,
	KIWI_BOSID_ZASHH_EO_2_N17_14 = 108,
	KIWI_BOSID_DT_EO_N17_15 = 109,
	KIWI_BOSID_AVARIJNOJE_OTKL_N18_1 = 110,
	KIWI_BOSID_NS_N18_2 = 259,
	KIWI_BOSID_RABOTA_APV_N19_1 = 111,
	KIWI_BOSID_APV_SRAB_N19_2 = 112,
	KIWI_BOSID_APV_PUSK_N19_3 = 113,
	KIWI_BOSID_RAZRESHENIE_APV_N19_4 = 114,
	KIWI_BOSID_APV_NEUSPESHNOE_N19_5 = 115,
	KIWI_BOSID_APV_USPESHNOE_N19_6 = 116,
	KIWI_BOSID_NEISPR_VYKL_N20_1 = 117,
	KIWI_BOSID_AVARIJA_SHP_N20_2 = 118,
	KIWI_BOSID_PRUZH_NE_ZAVEDENA_N20_3 = 119,
	KIWI_BOSID_NIZKAJA_T_POLJUSOV_N20_4 = 120,
	KIWI_BOSID_VYKL_NE_GOTOV_N20_5 = 121,
	KIWI_BOSID_NEISPR_CU_N20_6 = 122,
	KIWI_BOSID_NEUSPESHN_VKL_N20_7 = 123,
	KIWI_BOSID_NEUSPESHN_OTKL_N20_8 = 124,
	KIWI_BOSID_RPN_PEREGRUZKA_N21_1 = 125,
	KIWI_BOSID_RPN_POD_NAGR_N21_2 = 126,
	KIWI_BOSID_RPN_BLOK_PO_U_N21_3 = 127,
	KIWI_BOSID_RPN_BLOK_PO_U2_N21_4 = 128,
	KIWI_BOSID_RPN_BLOK_PO_3U0_N21_5 = 129,
	KIWI_BOSID_RPN_PERENAPR_N21_6 = 130,
	KIWI_BOSID_U_VYSOKOE_N21_7 = 131,
	KIWI_BOSID_U_NIZKOE_N21_8 = 132,
	KIWI_BOSID_U_PODDERZHANIJA_1_N21_9 = 133,
	KIWI_BOSID_U_PODDERZHANIJA_2_N21_10 = 134,
	KIWI_BOSID_U_PODDERZHANIJA_3_N21_11 = 135,
	KIWI_BOSID_U_PODDERZHANIJA_4_N21_12 = 136,
	KIWI_BOSID_BLOK_PRIBAVIT_N22_1 = 137,
	KIWI_BOSID_RPN_BLOKIROVAN_N22_2 = 138,
	KIWI_BOSID_BLOK_UBAVIT_N22_3 = 139,
	KIWI_BOSID_OU_PRIBAVIT_N23_1 = 140,
	KIWI_BOSID_OU_UBAVIT_N23_2 = 141,
	KIWI_BOSID_OU_RPN_PO_DV_N23_3 = 142,
	KIWI_BOSID_OU_RPN_PO_ASU_N23_4 = 143,
	KIWI_BOSID_OU_RPN_S_PU_N23_5 = 144,
	KIWI_BOSID_AU_RPN_N23_6 = 145,
	KIWI_BOSID_AU_PRIBAVIT_N23_7 = 146,
	KIWI_BOSID_AU_UBAVIT_N23_8 = 147,
	KIWI_BOSID_RPN_PRIBAVIT_N24_1 = 148,
	KIWI_BOSID_RPN_UBAVIT_N24_2 = 149,
	KIWI_BOSID_NOTP_NEVERNYJ_N25_1 = 150,
	KIWI_BOSID_STUPEN_BLOK_N25_2 = 151,
	KIWI_BOSID_RPN_RESURS_N26_1 = 152,
	KIWI_BOSID_RPN_NE_POSHEL_N27_1 = 153,
	KIWI_BOSID_RPN_POBEZHAL_N27_2 = 154,
	KIWI_BOSID_PITANIE_PM_N27_3 = 155,
	KIWI_BOSID_RPN_ZASTRJAL_N27_4 = 156,
	KIWI_BOSID_NEISPR_RPN_N27_5 = 157,
	KIWI_BOSID_PR_USTAVOK_2_N28_1 = 158,
	KIWI_BOSID_PR_USTAVOK_1_N28_2 = 159,
	KIWI_BOSID_PR_UST_PO_DV_N28_3 = 160,
	KIWI_BOSID_PR_UST_IZ_ASU_N28_4 = 161,
	KIWI_BOSID_PR_UST_S_PU_N28_5 = 162,
	KIWI_BOSID_PUSK_ZASHHIT_N28_6 = 163,
	KIWI_BOSID_BLOK_SMENY_PR_UST_N28_7 = 164,
	KIWI_BOSID_AVARIJNAJA_SIGN_N29_1 = 165,
	KIWI_BOSID_SJEM_SIGNALIZACII_N29_2 = 166,
	KIWI_BOSID_AVARIJA_N29_3 = 167,
	KIWI_BOSID_DTO_OTKLJUCHENIE_N29_4 = 168,
	KIWI_BOSID_DZT_OTKLJUCHENIE_N29_5 = 169,
	KIWI_BOSID_TO_VN_OTKLJUCHENIE_N29_6 = 170,
	KIWI_BOSID_MTZ_VN_OTKLJUCHENIE_N29_7 = 171,
	KIWI_BOSID_MTZ_NN_OTKL_NA_T_N29_8 = 172,
	KIWI_BOSID_PEREGRUZKA_OTKL_N29_9 = 173,
	KIWI_BOSID_LZT_OTKLJUCHENIE_N29_10 = 174,
	KIWI_BOSID_ZDZ_OTKLJUCHENIE_N29_11 = 175,
	KIWI_BOSID_TZOP_VN_OTKLJUCHENIE_N29_12 = 176,
	KIWI_BOSID_TZOP_NN_OTKLJUCHENIE_N29_13 = 177,
	KIWI_BOSID_TZNP_OTKL_NA_VN_N29_14 = 178,
	KIWI_BOSID_TZNP_OTKL_NA_T_N29_15 = 179,
	KIWI_BOSID_OZZ_OTKLJUCHENIE_N29_16 = 256,
	KIWI_BOSID_GZ_T1_OTKLJUCHENIE_N29_17 = 180,
	KIWI_BOSID_GZ_T2_OTKLJUCHENIE_N29_18 = 181,
	KIWI_BOSID_GZ_RPN_OTKLJUCHENIE_N29_19 = 182,
	KIWI_BOSID_ZPO_OTKLJUCHENIE_N29_20 = 183,
	KIWI_BOSID_UROV_NA_SEBJA_SRAB_N29_21 = 184,
	KIWI_BOSID_SF6_TT_OTKLJUCHENIE_N29_22 = 185,
	KIWI_BOSID_SF6_Q_OTKLJUCHENIE_N29_23 = 186,
	KIWI_BOSID_VNESH_OSN_ZASHHITY_N29_24 = 187,
	KIWI_BOSID_VNESH_UROV_N29_25 = 188,
	KIWI_BOSID_VNESH_OTKL_BEZ_APV_N29_26 = 189,
	KIWI_BOSID_VNESH_OTKL_S_APV_N29_27 = 190,
	KIWI_BOSID_VNESH_PRED_KLAPAN_N29_28 = 191,
	KIWI_BOSID_VNESH_TZNP_N29_29 = 192,
	KIWI_BOSID_AVAR_SIGN_DOP_N29_30 = 193,
	KIWI_BOSID_PREDUPR_SIGN_N30_1 = 194,
	KIWI_BOSID_NEBALANS_TOKOV_N30_2 = 195,
	KIWI_BOSID_NEISPR_CEPEJ_TOKA_N30_3 = 196,
	KIWI_BOSID_NEISPR_CEPEJ_NAPR_N30_4 = 197,
	KIWI_BOSID_MTZ_NN_OTKL_NA_SV_N30_5 = 198,
	KIWI_BOSID_MTZ_NN_OTKL_NA_VV_N30_6 = 199,
	KIWI_BOSID_PEREGRUZKA_SIGNAL_N30_7 = 200,
	KIWI_BOSID_LZSH_OTKL_NA_VV_N30_8 = 201,
	KIWI_BOSID_LZSH_NEISPRAVNOST_N30_9 = 202,
	KIWI_BOSID_ZDZ_NEISPRAVNOST_N30_10 = 203,
	KIWI_BOSID_TZOP_NN_OTKL_NA_VV_N30_11 = 204,
	KIWI_BOSID_TZNP_OTKL_NA_T2_N30_12 = 205,
	KIWI_BOSID_TZNP_OTKL_NA_SV_N30_13 = 206,
	KIWI_BOSID_OZZ_SIGNAL_N30_14 = 257,
	KIWI_BOSID_GZ_T1_SIGNAL_N30_15 = 207,
	KIWI_BOSID_GZ_T2_SIGNAL_N30_16 = 208,
	KIWI_BOSID_GZ_RPN_SIGNAL_N30_17 = 209,
	KIWI_BOSID_GZ_T1_NEISPRAV_N30_18 = 210,
	KIWI_BOSID_GZ_T2_NEISPRAV_N30_19 = 211,
	KIWI_BOSID_GZ_RPN_NEISPRAV_N30_20 = 212,
	KIWI_BOSID_GZ_NEISPRAV_PIT_N30_21 = 213,
	KIWI_BOSID_UROV_N30_22 = 214,
	KIWI_BOSID_OTKL_NA_AV_EV_EO1_N30_23 = 215,
	KIWI_BOSID_OTKL_NA_AV_EO2_N30_24 = 216,
	KIWI_BOSID_UROK_N30_25 = 217,
	KIWI_BOSID_VYKLJUCHATEL_NEISPR_N30_26 = 218,
	KIWI_BOSID_SHP_NEISPR_N30_27 = 219,
	KIWI_BOSID_PRUZHINA_NE_ZAVEDENA_N30_28 = 220,
	KIWI_BOSID_T_POLJUSOV_NIZKAJA_N30_29 = 221,
	KIWI_BOSID_CEPI_UPRAVL_NEISPR_N30_30 = 222,
	KIWI_BOSID_VKL_NEUSPESHNOE_N30_31 = 223,
	KIWI_BOSID_OTKL_NEUSPESHNOE_N30_32 = 224,
	KIWI_BOSID_SF6_Q_SIGNAL_N30_33 = 225,
	KIWI_BOSID_SF6_Q_AVARIA_N30_34 = 226,
	KIWI_BOSID_SF6_TT_1_SIGNAL_N30_35 = 227,
	KIWI_BOSID_SF6_TT_2_AVARIA_N30_36 = 228,
	KIWI_BOSID_MASLO_UROVEN_N30_37 = 229,
	KIWI_BOSID_MASLO_TEMPERATURA_N30_38 = 230,
	KIWI_BOSID_3U0_SIGNAL_N30_39 = 260,
	KIWI_BOSID_PREDUPR_SIGN_DOP_N30_40 = 231,
	KIWI_BOSID_ALTEI_NEISPRAVEN_N30_41 = 232,
	KIWI_BOSID_PREDUPR_SIGN_RPN_N31_1 = 233,
	KIWI_BOSID_RPN_BLOKIROVAN_N31_2 = 234,
	KIWI_BOSID_RPN_TEMPER_MASLA_N31_3 = 235,
	KIWI_BOSID_RPN_UROVEN_MASLA_N31_4 = 236,
	KIWI_BOSID_RPN_PERENAPRIAZHENIE_N31_5 = 237,
	KIWI_BOSID_RPN_NOTP_NEVERNYJ_N31_6 = 238,
	KIWI_BOSID_RPN_RESURS_N31_7 = 239,
	KIWI_BOSID_RPN_NE_POSHEL_N31_8 = 240,
	KIWI_BOSID_RPN_POBEZHAL_N31_9 = 241,
	KIWI_BOSID_RPN_ZASTRJAL_N31_10 = 242,
	KIWI_BOSID_PREDUPR_SIGN_RPN_DOP_N31_11 = 244,
	KIWI_BOSID_RPN_NEISPRAVNOST_N31_12 = 243,
	KIWI_BOSID_PITANIE_OT_SETI_N32_2 = 258,
	KIWI_BOSID_OTKAZ_MVV_DOP_N39_1 = 261,

#ifdef DSP_ENABLE_DEBUG_VARS
	KIWI_BOSID_FNED_N40_1 = 245,
	KIWI_BOSID_FRATENED_N40_2 = 246,
	KIWI_BOSID_START_N40_3 = 247,
	KIWI_BOSID_TRANSIENT_N40_4 = 248,
#endif

	KIWI_BOSID_INVALID_SIGNAL = KIWI_INVALID_ID
} kiwi_BinaryOutputSignalID;
/*-----------------------------------------------------------------------------------------------*/
/** @brief Тип идентификатора (двоичного) выходного сигнала пускового органа. */
typedef enum kiwi_FaultDetectorBinaryOutputSignalID_TAG
{
	KIWI_BOSID_PO_IDTO_A_N1_1 = 0,
	KIWI_BOSID_PO_IDTO_B_N1_2 = 1,
	KIWI_BOSID_PO_IDTO_C_N1_3 = 2,
	KIWI_BOSID_PO_DZT_A_N1_4 = 3,
	KIWI_BOSID_PO_DZT_B_N1_5 = 4,
	KIWI_BOSID_PO_DZT_C_N1_6 = 5,
	KIWI_BOSID_PO_DZT_G_A_N1_7 = 6,
	KIWI_BOSID_PO_DZT_G_B_N1_8 = 7,
	KIWI_BOSID_PO_DZT_G_C_N1_9 = 8,
	KIWI_BOSID_PO_IPB_2G_A_N1_10 = 9,
	KIWI_BOSID_PO_IPB_2G_B_N1_11 = 10,
	KIWI_BOSID_PO_IPB_2G_C_N1_12 = 11,
	KIWI_BOSID_PO_IPB_5G_A_N1_13 = 63,
	KIWI_BOSID_PO_IPB_5G_B_N1_14 = 64,
	KIWI_BOSID_PO_IPB_5G_C_N1_15 = 65,
	KIWI_BOSID_PO_INB_A_N2_1 = 12,
	KIWI_BOSID_PO_INB_B_N2_2 = 13,
	KIWI_BOSID_PO_INB_C_N2_3 = 14,
	KIWI_BOSID_PO_IDIF_KCT_A_N2_4 = 15,
	KIWI_BOSID_PO_IDIF_KCT_B_N2_5 = 16,
	KIWI_BOSID_PO_IDIF_KCT_C_N2_6 = 17,
	KIWI_BOSID_PO_ITORM_KCT_A_N2_7 = 18,
	KIWI_BOSID_PO_ITORM_KCT_B_N2_8 = 19,
	KIWI_BOSID_PO_ITORM_KCT_C_N2_9 = 20,
	KIWI_BOSID_PO_DI_KCT_A_N2_10 = 21,
	KIWI_BOSID_PO_DI_KCT_B_N2_11 = 22,
	KIWI_BOSID_PO_DI_KCT_C_N2_12 = 23,
	KIWI_BOSID_PO_ITO_VN_N3_1 = 24,
	KIWI_BOSID_PO_IMTZ_VN_N3_2 = 25,
	KIWI_BOSID_PO_IMTZ_VN_CH_N3_3 = 26,
	KIWI_BOSID_PO_UMIN_MTZ_N3_4 = 27,
	KIWI_BOSID_PO_U2_MTZ_N3_5 = 28,
	KIWI_BOSID_PO_IMTZ_NN_N4_1 = 29,
	KIWI_BOSID_PO_IMTZ_NN_CH_N4_2 = 30,
	KIWI_BOSID_PO_IZP_N5_1 = 31,
	KIWI_BOSID_PO_IZDZ_N7_1 = 32,
	KIWI_BOSID_PO_I2_TZOP_VN_N8_1 = 33,
	KIWI_BOSID_PO_I2_TZOP_NN_N8_2 = 34,
	KIWI_BOSID_PO_ITZNP_N9_1 = 35,
	KIWI_BOSID_PO_IPB_K3I0_N9_2 = 36,
	KIWI_BOSID_PO_IOZZ_N10_1 = 66,
	KIWI_BOSID_PO_IPO_1_N12_1 = 37,
	KIWI_BOSID_PO_IPO_2_N12_2 = 38,
	KIWI_BOSID_PO_IPO_3_N12_3 = 39,
	KIWI_BOSID_PO_ISF6_BLOK_N13_1 = 40,
	KIWI_BOSID_PO_IUROV_N14_1 = 41,
	KIWI_BOSID_PO_IQK_N14_2 = 42,
	KIWI_BOSID_PO_IRPN_BLOK_N21_1 = 43,
	KIWI_BOSID_PO_INAGR_N21_2 = 44,
	KIWI_BOSID_PO_URPN_MIN_N21_3 = 45,
	KIWI_BOSID_PO_U2RPN_MAKS_N21_4 = 46,
	KIWI_BOSID_PO_3U0RPN_MAKS_N21_5 = 47,
	KIWI_BOSID_PO_URPN_MAKS_N21_6 = 48,
	KIWI_BOSID_PO_PLUS_DU_ARKT_N21_7 = 49,
	KIWI_BOSID_PO_MINUS_DU_ARKT_N21_8 = 50,
KIWI_BOSID_PO_3U0_SIGN_N30_1 = 67,
	KIWI_BOSID_PO_IA_VN_NED_N31_1 = 51,
	KIWI_BOSID_PO_IB_VN_NED_N31_2 = 52,
	KIWI_BOSID_PO_IC_VN_NED_N31_3 = 53,
	KIWI_BOSID_PO_IA_NN_NED_N31_4 = 54,
	KIWI_BOSID_PO_IB_NN_NED_N31_5 = 55,
	KIWI_BOSID_PO_IC_NN_NED_N31_6 = 56,
	KIWI_BOSID_PO_3I0_NED_N31_7 = 57,
	KIWI_BOSID_PO_IQK_NED_N31_8 = 58,
	KIWI_BOSID_PO_ISV_NN_NED_N31_9 = 59,
	KIWI_BOSID_PO_UAB_NN_NED_N31_10 = 60,
	KIWI_BOSID_PO_UBC_NN_NED_N31_11 = 61,
	KIWI_BOSID_PO_3U0_NN_NED_N31_12 = 62,
	KIWI_BOSID_PO_U_PIT_NORM_N32_1 = 200,
	KIWI_BOSID_PO_U_PIT_PONIJ_N32_2 = 201,
	KIWI_BOSID_PO_U_PIT_ISCHEZ_N32_3 = 202,
KIWI_BOSID_PO_I_MAKS_1_VN_N60_1 = 68,
KIWI_BOSID_PO_I_MAKS_2_VN_N60_2 = 69,
KIWI_BOSID_PO_I_MAKS_3_VN_N60_3 = 70,
KIWI_BOSID_PO_I_MIN_1_VN_N60_4 = 71,
KIWI_BOSID_PO_I_MIN_2_VN_N60_5 = 72,
KIWI_BOSID_PO_I2_MAKS_VN_N60_6 = 73,
KIWI_BOSID_PO_3I0_MAKS_1_VN_N60_7 = 74,
KIWI_BOSID_PO_3I0_MAKS_2_VN_N60_8 = 75,
KIWI_BOSID_PO_3I0_MAKS_3_VN_N60_9 = 76,
KIWI_BOSID_PO_I_MAKS_1_NN_N60_10 = 77,
KIWI_BOSID_PO_I_MAKS_2_NN_N60_11 = 78,
KIWI_BOSID_PO_I_MAKS_3_NN_N60_12 = 79,
KIWI_BOSID_PO_I_MIN_1_NN_N60_13 = 80,
KIWI_BOSID_PO_I_MIN_2_NN_N60_14 = 81,
KIWI_BOSID_PO_I4_MAKS_N60_15 = 82,
KIWI_BOSID_PO_I4_MIN_N60_16 = 83,
KIWI_BOSID_PO_U_MAKS_1_N60_17 = 84,
KIWI_BOSID_PO_U_MAKS_2_N60_18 = 85,
KIWI_BOSID_PO_U_MIN_1_N60_19 = 86,
KIWI_BOSID_PO_U_MIN_2_N60_20 = 87,
KIWI_BOSID_PO_U2_MAKS_N60_21 = 88,
KIWI_BOSID_PO_3U0_MAKS_N60_22 = 89,

	KIWI_BOSID_PO_INVALID_SIGNAL = KIWI_INVALID_ID
} kiwi_FaultDetectorBinaryOutputSignalID;
/*-----------------------------------------------------------------------------------------------*/
/** @brief Тип идентификатора (двоичного) выходного сигнала ДФПО. */
typedef enum kiwi_AFSWBinaryOutputSignalID_TAG
{
	KIWI_AFSW_BOSID_OUTPUT_1 = 0,
	KIWI_AFSW_BOSID_OUTPUT_2 = 1,
	KIWI_AFSW_BOSID_OUTPUT_3 = 2,
	KIWI_AFSW_BOSID_OUTPUT_4 = 3,
	KIWI_AFSW_BOSID_OUTPUT_5 = 4,
	KIWI_AFSW_BOSID_OUTPUT_6 = 5,
	KIWI_AFSW_BOSID_OUTPUT_7 = 6,
	KIWI_AFSW_BOSID_OUTPUT_8 = 7,
	KIWI_AFSW_BOSID_OUTPUT_9 = 8,
	KIWI_AFSW_BOSID_OUTPUT_10 = 9,
	KIWI_AFSW_BOSID_OUTPUT_11 = 10,
	KIWI_AFSW_BOSID_OUTPUT_12 = 11,
	KIWI_AFSW_BOSID_OUTPUT_13 = 12,
	KIWI_AFSW_BOSID_OUTPUT_14 = 13,
	KIWI_AFSW_BOSID_OUTPUT_15 = 14,
	KIWI_AFSW_BOSID_OUTPUT_16 = 15,
	KIWI_AFSW_BOSID_OUTPUT_17 = 16,
	KIWI_AFSW_BOSID_OUTPUT_18 = 17,
	KIWI_AFSW_BOSID_OUTPUT_19 = 18,
	KIWI_AFSW_BOSID_OUTPUT_20 = 19,
	KIWI_AFSW_BOSID_OUTPUT_21 = 20,
	KIWI_AFSW_BOSID_OUTPUT_22 = 21,
	KIWI_AFSW_BOSID_OUTPUT_23 = 22,
	KIWI_AFSW_BOSID_OUTPUT_24 = 23,
	KIWI_AFSW_BOSID_OUTPUT_25 = 24,
	KIWI_AFSW_BOSID_OUTPUT_26 = 25,
	KIWI_AFSW_BOSID_OUTPUT_27 = 26,
	KIWI_AFSW_BOSID_OUTPUT_28 = 27,
	KIWI_AFSW_BOSID_OUTPUT_29 = 28,
	KIWI_AFSW_BOSID_OUTPUT_30 = 29,
	KIWI_AFSW_BOSID_OUTPUT_31 = 30,
	KIWI_AFSW_BOSID_OUTPUT_32 = 31,
	KIWI_AFSW_BOSID_OUTPUT_33 = 32,
	KIWI_AFSW_BOSID_OUTPUT_34 = 33,
	KIWI_AFSW_BOSID_OUTPUT_35 = 34,
	KIWI_AFSW_BOSID_OUTPUT_36 = 35,
	KIWI_AFSW_BOSID_OUTPUT_37 = 36,
	KIWI_AFSW_BOSID_OUTPUT_38 = 37,
	KIWI_AFSW_BOSID_OUTPUT_39 = 38,
	KIWI_AFSW_BOSID_OUTPUT_40 = 39,
	KIWI_AFSW_BOSID_OUTPUT_41 = 40,
	KIWI_AFSW_BOSID_OUTPUT_42 = 41,
	KIWI_AFSW_BOSID_OUTPUT_43 = 42,
	KIWI_AFSW_BOSID_OUTPUT_44 = 43,
	KIWI_AFSW_BOSID_OUTPUT_45 = 44,
	KIWI_AFSW_BOSID_OUTPUT_46 = 45,
	KIWI_AFSW_BOSID_OUTPUT_47 = 46,
	KIWI_AFSW_BOSID_OUTPUT_48 = 47,
	KIWI_AFSW_BOSID_OUTPUT_49 = 48,
	KIWI_AFSW_BOSID_OUTPUT_50 = 49,
	KIWI_AFSW_BOSID_OUTPUT_51 = 50,
	KIWI_AFSW_BOSID_OUTPUT_52 = 51,
	KIWI_AFSW_BOSID_OUTPUT_53 = 52,
	KIWI_AFSW_BOSID_OUTPUT_54 = 53,
	KIWI_AFSW_BOSID_OUTPUT_55 = 54,
	KIWI_AFSW_BOSID_OUTPUT_56 = 55,
	KIWI_AFSW_BOSID_OUTPUT_57 = 56,
	KIWI_AFSW_BOSID_OUTPUT_58 = 57,
	KIWI_AFSW_BOSID_OUTPUT_59 = 58,
	KIWI_AFSW_BOSID_OUTPUT_60 = 59,
	KIWI_AFSW_BOSID_OUTPUT_61 = 60,
	KIWI_AFSW_BOSID_OUTPUT_62 = 61,
	KIWI_AFSW_BOSID_OUTPUT_63 = 62,
	KIWI_AFSW_BOSID_OUTPUT_64 = 63,

	KIWI_AFSW_BOSID_INVALID_SIGNAL = KIWI_INVALID_ID
} kiwi_AFSWBinaryOutputSignalID;
/*-----------------------------------------------------------------------------------------------*/
/** @brief Тип идентификатора светодиода. */
typedef enum kiwi_LEDID_TAG
{
	KIWI_LED_1 = 0,
	KIWI_LED_2 = 1,
	KIWI_LED_3 = 2,
	KIWI_LED_4 = 3,
	KIWI_LED_5 = 4,
	KIWI_LED_6 = 5,
	KIWI_LED_7 = 6,
	KIWI_LED_8 = 7,
	KIWI_LED_9 = 8,
	KIWI_LED_10 = 9,
	KIWI_LED_11 = 10,
	KIWI_LED_12 = 11,
	KIWI_LED_13 = 12,
	KIWI_LED_14 = 13,

	KIWI_INVALID_LED_ID = KIWI_INVALID_ID
} kiwi_LEDID;

/*-----------------------------------------------------------------------------------------------*/
/** @brief Тип идентификатора аналогового входного сигнала. */
typedef enum kiwi_AnalogInputSignalID_TAG
{
	KIWI_AISID_IA_VN = 0,
	KIWI_AISID_IB_VN = 1,
	KIWI_AISID_IC_VN = 2,
	KIWI_AISID_3I0 = 3,
	KIWI_AISID_I_QK = 12,
	KIWI_AISID_ISV_NN = 13,
	KIWI_AISID_IA_NN = 4,
	KIWI_AISID_IB_NN = 5,
	KIWI_AISID_IC_NN = 6,
	KIWI_AISID_UAB_NN = 7,
	KIWI_AISID_UBC_NN = 8,
	KIWI_AISID_3U0_NN = 9,
	KIWI_AISID_U_PWR = 10,
	KIWI_AISID_U_CAP = 11,

	KIWI_AISID_INVALID_SIGNAL = KIWI_INVALID_ID
} kiwi_AnalogInputSignalID;
/*-----------------------------------------------------------------------------------------------*/
/** @brief Тип идентификатора аналогового выходного сигнала. */
typedef enum kiwi_AnalogOutputSignalID_TAG
{
	KIWI_AOSID_IA_VN = 0,
	KIWI_AOSID_IB_VN = 1,
	KIWI_AOSID_IC_VN = 2,
	KIWI_AOSID_IA_NN = 3,
	KIWI_AOSID_IB_NN = 4,
	KIWI_AOSID_IC_NN = 5,
	KIWI_AOSID_3I0 = 6,
	KIWI_AOSID_I_QK = 7,
	KIWI_AOSID_ISV_NN = 8,
	KIWI_AOSID_UAB_NN = 9,
	KIWI_AOSID_UBC_NN = 10,
	KIWI_AOSID_3U0_NN = 11,
	KIWI_AOSID_F = 12,
	KIWI_AOSID_DF = 13,
	KIWI_AOSID_FIND = 70,
	KIWI_AOSID_IDIF_A = 14,
	KIWI_AOSID_IDIF_B = 15,
	KIWI_AOSID_IDIF_C = 16,
	KIWI_AOSID_ITORM_A = 20,
	KIWI_AOSID_ITORM_B = 21,
	KIWI_AOSID_ITORM_C = 22,
	KIWI_AOSID_IDIF2G_A = 17,
	KIWI_AOSID_IDIF2G_B = 18,
	KIWI_AOSID_IDIF2G_C = 19,
	KIWI_AOSID_KI2G_A = 23,
	KIWI_AOSID_KI2G_B = 24,
	KIWI_AOSID_KI2G_C = 25,
	KIWI_AOSID_IDIF5G_A = 53,
	KIWI_AOSID_IDIF5G_B = 54,
	KIWI_AOSID_IDIF5G_C = 55,
	KIWI_AOSID_KI5G_A = 56,
	KIWI_AOSID_KI5G_B = 57,
	KIWI_AOSID_KI5G_C = 58,
	KIWI_AOSID_DITORM_A = 26,
	KIWI_AOSID_DITORM_B = 27,
	KIWI_AOSID_DITORM_C = 28,
	KIWI_AOSID_IA_SHTRIKH_VN = 29,
	KIWI_AOSID_IB_SHTRIKH_VN = 30,
	KIWI_AOSID_IC_SHTRIKH_VN = 31,
	KIWI_AOSID_I1_VN = 32,
	KIWI_AOSID_I2_VN = 33,
	KIWI_AOSID_3I0_VN = 34,
	KIWI_AOSID_K3I0 = 35,
	KIWI_AOSID_I1_NN = 36,
	KIWI_AOSID_I2_NN = 37,
	KIWI_AOSID_U2_NN = 38,
	KIWI_AOSID_UPOD = 39,
	KIWI_AOSID_UKOMP = 40,
	KIWI_AOSID_DU = 41,
	KIWI_AOSID_INOM_VN = 42,
	KIWI_AOSID_INOM_NN = 43,
	KIWI_AOSID_I_SHTRIKH_VN_MAKS = 79,
	KIWI_AOSID_I_VN_MAKS = 80,
	KIWI_AOSID_I_NN_MAKS = 81,
	KIWI_AOSID_U_NN_MAKS = 82,
	KIWI_AOSID_U_NN_MIN = 83,
	KIWI_AOSID_U_PWR = 100,
	KIWI_AOSID_U_PWR_CAP = 101,

#ifdef DSP_ENABLE_DEBUG_VARS
	KIWI_AOSID_DT = 60,
	KIWI_AOSID_NS = 61,
	KIWI_AOSID_T_OLD = 62,
	KIWI_AOSID_CH = 63,
	KIWI_AOSID_CTR_START = 64,
	KIWI_AOSID_CTR_T_CYCLE = 65,
	KIWI_AOSID_CTR_FRATE = 66,
	KIWI_AOSID_DELTA_A = 67,
	KIWI_AOSID_DELTA_T = 68,
	KIWI_AOSID_DFAZA = 69,
	KIWI_AOSID_FCALC = 71,
	KIWI_AOSID_FRATE = 72,
	KIWI_AOSID_FRATECALC = 73,
	KIWI_AOSID_FAZA = 74,
	KIWI_AOSID_NT = 75,
	KIWI_AOSID_T = 76,
	KIWI_AOSID_T_CALC = 77,
#endif

	KIWI_AOSID_INVALID_SIGNAL = KIWI_INVALID_ID
} kiwi_AnalogOutputSignalID;
/*-----------------------------------------------------------------------------------------------*/
/** @brief Тип идентификатора события, используемый в базе данных KIWI. */
typedef enum kiwi_EventID_TAG
{
	KIWI_EID_SRABATYVANIE_DTO_N1_1 = 1,
	KIWI_EID_PUSK_DZT_N1_2 = 2,
	KIWI_EID_SRABATYVANIE_DZT_N1_3 = 3,
	KIWI_EID_NEBALANS_FAZA_A_N2_1 = 4,
	KIWI_EID_NEBALANS_FAZA_B_N2_2 = 5,
	KIWI_EID_NEBALANS_FAZA_C_N2_3 = 6,
	KIWI_EID_SRABATYVANIE_KCT_FAZA_A_N2_4 = 7,
	KIWI_EID_SRABATYVANIE_KCT_FAZA_B_N2_5 = 8,
	KIWI_EID_SRABATYVANIE_KCT_FAZA_C_N2_6 = 9,
	KIWI_EID_PUSK_TO_VN_N3_1 = 10,
	KIWI_EID_SRABATYVANIE_TO_VN_N3_2 = 11,
	KIWI_EID_SRABATYVANIE_MTZ_VN_N3_3 = 12,
	KIWI_EID_PUSK_MTZ_VN_N3_4 = 13,
	KIWI_EID_NEISPRAVNOST_CEPIEJ_NAPRIAZHENIJA_N3_5 = 14,
	KIWI_EID_SRABATYVANIE_MTZ_NN_NA_SV_NN_N4_1 = 15,
	KIWI_EID_SRABATYVANIE_MTZ_NN_NA_T_N4_2 = 16,
	KIWI_EID_SRABATYVANIE_MTZ_NN_N4_3 = 17,
	KIWI_EID_PUSK_MTZ_NN_N4_4 = 18,
	KIWI_EID_PEREGRUZKA_N5_1 = 19,
	KIWI_EID_SRABATYVANIE_RAZGRUZKI_1_OCHIERIEDI_N5_2 = 20,
	KIWI_EID_SRABATYVANIE_RAZGRUZKI_2_OCHIERIEDI_N5_3 = 21,
	KIWI_EID_SRABATYVANIE_LZH_N6_1 = 22,
	KIWI_EID_NEISPRAVNOST_LZH_N6_2 = 23,
	KIWI_EID_SRABATYVANIE_LZT_N6_3 = 24,
	KIWI_EID_SRABATYVANIE_ZDZ_N7_1 = 25,
	KIWI_EID_NEISPRAVNOST_ZDZ_N7_2 = 26,
	KIWI_EID_SRABATYVANIE_TZOP_VN_N8_1 = 27,
	KIWI_EID_PUSK_TZOP_VN_N8_2 = 28,
	KIWI_EID_SRABATYVANIE_TZOP_NN_NA_T_N8_3 = 29,
	KIWI_EID_SRABATYVANIE_TZOP_NN_N8_4 = 30,
	KIWI_EID_PUSK_TZOP_NN_N8_5 = 31,
	KIWI_EID_SRABATYVANIE_TZNP_NA_T2_N9_1 = 32,
	KIWI_EID_SRABATYVANIE_TZNP_NA_SV_N9_2 = 33,
	KIWI_EID_SRABATYVANIE_TZNP_NA_VN_N9_3 = 34,
	KIWI_EID_SRABATYVANIE_TZNP_NA_T_N9_4 = 35,
	KIWI_EID_PUSK_TZNP_N9_5 = 36,
	KIWI_EID_PUSK_OZZ_N10_1 = 98,
	KIWI_EID_SRABATYVANIE_OZZ_N10_2 = 99,
	KIWI_EID_SRABATYVANIE_GZ_T1_N11_1 = 37,
	KIWI_EID_NEISPRAVNOST_GZ_T1_N11_2 = 44,
	KIWI_EID_SRABATYVANIE_GZ_T2_N11_3 = 38,
	KIWI_EID_NEISPRAVNOST_GZ_T2_N11_4 = 39,
	KIWI_EID_SRABATYVANIE_GZ_RPN_N11_5 = 40,
	KIWI_EID_NEISPRAVNOST_GZ_RPN_N11_6 = 41,
	KIWI_EID_NEISPRAVNOST_PITANIJA_GZ_N11_7 = 42,
	KIWI_EID_PUSK_OKHLAZHDIENIJA_1_N12_1 = 43,
	KIWI_EID_PUSK_OKHLAZHDIENIJA_2_N12_2 = 45,
	KIWI_EID_PUSK_OKHLAZHDIENIJA_3_N12_3 = 46,
	KIWI_EID_PUSK_ZPO_N12_4 = 47,
	KIWI_EID_SRABATYVANIE_ZPO_1_N12_5 = 48,
	KIWI_EID_SRABATYVANIE_ZPO_2_N12_6 = 49,
	KIWI_EID_SRABATYVANIE_ZPO_3_N12_7 = 50,
	KIWI_EID_SRABATYVANIE_ZPO_4_N12_8 = 51,
	KIWI_EID_OTKLJUCHENIE_PRI_POTERE_SF_Q_N13_1 = 52,
	KIWI_EID_POTERJA_SF_Q_N13_2 = 53,
	KIWI_EID_POTERJA_SF_TT_N13_3 = 54,
	KIWI_EID_OTKLJUCHENIE_PRI_POTIERIE_SF_TT_N13_4 = 55,
	KIWI_EID_UROV_NA_SEBJA_N14_1 = 56,
	KIWI_EID_SRABATYVANIE_UROV_N14_2 = 57,
	KIWI_EID_KOMANDA_OPERATIVNOGO_VKLJUCHENIJA_N15_1 = 58,
	KIWI_EID_KOMANDA_OPERATIVNOGO_OTKLJUCHENIJA_N15_2 = 59,
	KIWI_EID_VKLJUCHENIE_VYKLJUCHATELJA_N16_1 = 60,
	KIWI_EID_OTKLJUCHENIE_T2_N17_1 = 63,
	KIWI_EID_OTKLJUCHENIE_SV_VN_N17_2 = 64,
	KIWI_EID_OTKLJUCHENIE_SV_NN_N17_3 = 65,
	KIWI_EID_OTKLJUCHENIE_VV_NN_N17_4 = 66,
	KIWI_EID_OTKLJUCHENIE_VYKLJUCHATELJA_N17_5 = 67,
	KIWI_EID_SRABATYVANIE_UROK_N17_6 = 68,
	KIWI_EID_OTKLJUCHENIE_OTDELITELJA_N17_7 = 69,
	KIWI_EID_SRABATYVANIE_ZASHCHITY_EV_EO_1_N17_8 = 61,
	KIWI_EID_SRABATYVANIE_ZASHCHITY_EO_2_N17_9 = 62,
	KIWI_EID_AVARIJNOJE_OTKLJUCHENIE_N18_1 = 70,
	KIWI_EID_SRABATYVANIE_APV_N19_1 = 71,
	KIWI_EID_PUSK_APV_N19_2 = 72,
	KIWI_EID_APV_NEUSPESHNOE_N19_3 = 73,
	KIWI_EID_APV_USPESHNOE_N19_4 = 74,
	KIWI_EID_NEISPRAVNOST_VYKLJUCHATELJA_N20_1 = 75,
	KIWI_EID_AV_SHP_OTKLJUCHEN_N20_2 = 76,
	KIWI_EID_PRUZHINA_NE_ZAVEDENA_N20_3 = 77,
	KIWI_EID_NIZKAJA_T_POLJUSOV_N20_4 = 78,
	KIWI_EID_NEISPRAVNOST_CU_N20_5 = 79,
	KIWI_EID_NEUSPESHNOE_VKLJUCHENIE_N20_6 = 80,
	KIWI_EID_NEUSPESHNOE_OTKLJUCHENIE_N20_7 = 81,
	KIWI_EID_RPN_BLOKIROVAN_N22_1 = 82,
	KIWI_EID_OPERATIVNAJA_KOMANDA_PRIBAVIT_N23_1 = 83,
	KIWI_EID_OPERATIVNAJA_KOMANDA_UBAVIT_N23_2 = 84,
	KIWI_EID_AVTOMATICHESKAJA_KOMANDA_PRIBAVIT_N23_3 = 85,
	KIWI_EID_AVTOMATICHESKAJA_KOMANDA_UBAVIT_N23_4 = 86,
	KIWI_EID_RPN_PRIBAVIT_N24_1 = 87,
	KIWI_EID_RPN_UBAVIT_N24_2 = 88,
	KIWI_EID_POLOZHENIE_RPN_OPREDELENO_NEKORREKTNO_N25_1 = 89,
	KIWI_EID_SNIZHENIE_RESURSA_RPN_N26_1 = 90,
	KIWI_EID_RPN_NE_POSHEL_N27_1 = 91,
	KIWI_EID_RPN_POBEZHAL_N27_2 = 92,
	KIWI_EID_RPN_ZASTRJAL_N27_3 = 93,
	KIWI_EID_NEISPRAVNOST_RPN_N27_4 = 94,
	KIWI_EID_AVARIJNAJA_SIGNALIZACIJA_N29_1 = 95,
	KIWI_EID_PREDUPREDITIELNAJA_SIGNALIZACIJA_N30_1 = 96,
	KIWI_EID_PREDUPREDITIELNAJA_SIGNALIZACIJA_RPN_N31_1 = 97,
	KIWI_EID_USER_EVENT_1 = 100,
	KIWI_EID_USER_EVENT_2 = 101,
	KIWI_EID_USER_EVENT_3 = 102,
	KIWI_EID_USER_EVENT_4 = 103,
	KIWI_EID_USER_EVENT_5 = 104,
	KIWI_EID_USER_EVENT_6 = 105,
	KIWI_EID_USER_EVENT_7 = 106,
	KIWI_EID_USER_EVENT_8 = 107,
	KIWI_EID_USER_EVENT_9 = 108,
	KIWI_EID_USER_EVENT_10 = 109,
	KIWI_EID_USER_EVENT_11 = 110,
	KIWI_EID_USER_EVENT_12 = 111,
	KIWI_EID_USER_EVENT_13 = 112,
	KIWI_EID_USER_EVENT_14 = 113,
	KIWI_EID_USER_EVENT_15 = 114,
	KIWI_EID_USER_EVENT_16 = 115,
	KIWI_EID_USER_EVENT_17 = 116,
	KIWI_EID_USER_EVENT_18 = 117,
	KIWI_EID_USER_EVENT_19 = 118,
	KIWI_EID_USER_EVENT_20 = 119,
	KIWI_EID_USER_EVENT_21 = 120,
	KIWI_EID_USER_EVENT_22 = 121,
	KIWI_EID_USER_EVENT_23 = 122,
	KIWI_EID_USER_EVENT_24 = 123,
	KIWI_EID_USER_EVENT_25 = 124,
	KIWI_EID_USER_EVENT_26 = 125,
	KIWI_EID_USER_EVENT_27 = 126,
	KIWI_EID_USER_EVENT_28 = 127,
	KIWI_EID_USER_EVENT_29 = 128,
	KIWI_EID_USER_EVENT_30 = 129,
	KIWI_EID_USER_EVENT_31 = 130,
	KIWI_EID_USER_EVENT_32 = 131,
	KIWI_EID_USER_EVENT_33 = 132,
	KIWI_EID_USER_EVENT_34 = 133,
	KIWI_EID_USER_EVENT_35 = 134,
	KIWI_EID_USER_EVENT_36 = 135,
	KIWI_EID_USER_EVENT_37 = 136,
	KIWI_EID_USER_EVENT_38 = 137,
	KIWI_EID_USER_EVENT_39 = 138,
	KIWI_EID_USER_EVENT_40 = 139,
	KIWI_EID_USER_EVENT_41 = 140,
	KIWI_EID_USER_EVENT_42 = 141,
	KIWI_EID_USER_EVENT_43 = 142,
	KIWI_EID_USER_EVENT_44 = 143,
	KIWI_EID_USER_EVENT_45 = 144,
	KIWI_EID_USER_EVENT_46 = 145,
	KIWI_EID_USER_EVENT_47 = 146,
	KIWI_EID_USER_EVENT_48 = 147,
	KIWI_EID_USER_EVENT_49 = 148,
	KIWI_EID_USER_EVENT_50 = 149,
	KIWI_EID_USER_EVENT_51 = 150,
	KIWI_EID_USER_EVENT_52 = 151,
	KIWI_EID_USER_EVENT_53 = 152,
	KIWI_EID_USER_EVENT_54 = 153,
	KIWI_EID_USER_EVENT_55 = 154,
	KIWI_EID_USER_EVENT_56 = 155,
	KIWI_EID_USER_EVENT_57 = 156,
	KIWI_EID_USER_EVENT_58 = 157,
	KIWI_EID_USER_EVENT_59 = 158,
	KIWI_EID_USER_EVENT_60 = 159,
	KIWI_EID_USER_EVENT_61 = 160,
	KIWI_EID_USER_EVENT_62 = 161,
	KIWI_EID_USER_EVENT_63 = 162,
	KIWI_EID_USER_EVENT_64 = 163,
	KIWI_EID_USER_EVENT_65 = 164,
	KIWI_EID_USER_EVENT_66 = 165,
	KIWI_EID_USER_EVENT_67 = 166,
	KIWI_EID_USER_EVENT_68 = 167,
	KIWI_EID_USER_EVENT_69 = 168,
	KIWI_EID_USER_EVENT_70 = 169,
	KIWI_EID_USER_EVENT_71 = 170,
	KIWI_EID_USER_EVENT_72 = 171,
	KIWI_EID_USER_EVENT_73 = 172,
	KIWI_EID_USER_EVENT_74 = 173,
	KIWI_EID_USER_EVENT_75 = 174,
	KIWI_EID_USER_EVENT_76 = 175,
	KIWI_EID_USER_EVENT_77 = 176,
	KIWI_EID_USER_EVENT_78 = 177,
	KIWI_EID_USER_EVENT_79 = 178,
	KIWI_EID_USER_EVENT_80 = 179,
	KIWI_EID_USER_EVENT_81 = 180,
	KIWI_EID_USER_EVENT_82 = 181,
	KIWI_EID_USER_EVENT_83 = 182,
	KIWI_EID_USER_EVENT_84 = 183,
	KIWI_EID_USER_EVENT_85 = 184,
	KIWI_EID_USER_EVENT_86 = 185,
	KIWI_EID_USER_EVENT_87 = 186,
	KIWI_EID_USER_EVENT_88 = 187,
	KIWI_EID_USER_EVENT_89 = 188,
	KIWI_EID_USER_EVENT_90 = 189,
	KIWI_EID_USER_EVENT_91 = 190,
	KIWI_EID_USER_EVENT_92 = 191,
	KIWI_EID_USER_EVENT_93 = 192,
	KIWI_EID_USER_EVENT_94 = 193,
	KIWI_EID_USER_EVENT_95 = 194,
	KIWI_EID_USER_EVENT_96 = 195,
	KIWI_EID_USER_EVENT_97 = 196,
	KIWI_EID_USER_EVENT_98 = 197,
	KIWI_EID_USER_EVENT_99 = 198,
	KIWI_EID_USER_EVENT_100 = 199,

	KIWI_EID_INVALID_EVENT = KIWI_INVALID_ID
} kiwi_EventID;
/*-----------------------------------------------------------------------------------------------*/
/** @brief Тип идентификатора накопителя. */
typedef enum kiwi_AccumulatorID_TAG
{
	KIWI_CID_DTO_A_SRAB_N1_1 = 1,
	KIWI_CID_DTO_B_SRAB_N1_2 = 2,
	KIWI_CID_DTO_C_SRAB_N1_3 = 3,
	KIWI_CID_DTO_SRAB_N1_4 = 4,
	KIWI_CID_DZT_A_SRAB_N1_5 = 5,
	KIWI_CID_DZT_B_SRAB_N1_6 = 6,
	KIWI_CID_DZT_C_SRAB_N1_7 = 7,
	KIWI_CID_DZT_SRAB_N1_8 = 8,
	KIWI_CID_NB_A_SRAB_N2_1 = 9,
	KIWI_CID_NB_B_SRAB_N2_2 = 10,
	KIWI_CID_NB_C_SRAB_N2_3 = 11,
	KIWI_CID_KCT_A_SRAB_N2_4 = 12,
	KIWI_CID_KCT_B_SRAB_N2_5 = 13,
	KIWI_CID_KCT_C_SRAB_N2_6 = 14,
	KIWI_CID_TO_VN_SRAB_N3_1 = 15,
	KIWI_CID_MTZ_VN_SRAB_N3_2 = 16,
	KIWI_CID_MTZ_NN_SRAB_N4_1 = 17,
	KIWI_CID_PEREGR_SRAB_N5_1 = 18,
	KIWI_CID_LZSH_SRAB_N6_1 = 19,
	KIWI_CID_LZT_SRAB_N6_2 = 20,
	KIWI_CID_ZDZ_SRAB_N7_1 = 21,
	KIWI_CID_TZOP_VN_SRAB_N8_1 = 22,
	KIWI_CID_TZOP_NN_SRAB_N8_2 = 23,
	KIWI_CID_TZNP_SRAB_N9_1 = 24,
	KIWI_CID_OZZ_SRAB_N10_1 = 54,
	KIWI_CID_GZ_T1_SRAB_N11_1 = 25,
	KIWI_CID_GZ_T2_SRAB_N11_2 = 26,
	KIWI_CID_GZ_RPN_SRAB_N11_3 = 27,
	KIWI_CID_ZPO_1_SRAB_N12_1 = 28,
	KIWI_CID_ZPO_2_SRAB_N12_2 = 29,
	KIWI_CID_ZPO_3_SRAB_N12_3 = 30,
	KIWI_CID_ZPO_4_SRAB_N12_4 = 31,
	KIWI_CID_UROV_SRAB_N13_1 = 32,
	KIWI_CID_OPER_VKL_N14_1 = 33,
	KIWI_CID_OPER_OTKL_N14_2 = 34,
	KIWI_CID_VKLUCHENIE_N15_1 = 35,
	KIWI_CID_OTKLUCHENIE_N16_1 = 36,
	KIWI_CID_AVAR_OTKL_N17_1 = 37,
	KIWI_CID_APV_SRAB_N19_1 = 38,
	KIWI_CID_APV_USPESHNOE_N19_2 = 39,
	KIWI_CID_APV_NEUSPESHNOE_N19_3 = 40,
	KIWI_CID_POTERIA_SF6_Q_N20_1 = 41,
	KIWI_CID_POTERIA_SF6_TT_N20_2 = 42,
	KIWI_CID_OU_PRIBAVIT_N23_1 = 43,
	KIWI_CID_OU_UBAVIT_N23_2 = 44,
	KIWI_CID_AU_PRIBAVIT_N23_3 = 45,
	KIWI_CID_AU_UBAVIT_N23_4 = 46,
	KIWI_CID_PRIBAVIT_N24_1 = 47,
	KIWI_CID_UBAVIT_N24_2 = 48,
	KIWI_CID_RPN_NE_POSHEL_N27_1 = 49,
	KIWI_CID_RPN_POBEZHAL_N27_2 = 50,
	KIWI_CID_RPN_ZASTRIAL_N27_3 = 51,
	KIWI_CID_MOTOCHASY_N28_1 = 52,
	KIWI_CID_KOLICHESTVO_VKLUCHENIJ_N28_2 = 53,

	/**
	 * @brief &mdash; количество ошибок при приёме ЦП данных от ПВВ базового блока по синхронному
	 *                интерфейсу;
	 */
	KIWI_CID_CPU_FROM_BASE_IOP_SYNC = 60,

	/**
	 * @brief &mdash; количество ошибок при приёме ПВВ базового блока данных от ЦП по синхронному
	 *                интерфейсу;
	 */
	KIWI_CID_BASE_IOP_FROM_CPU_SYNC = 61,

	/**
	 * @brief &mdash; количество ошибок при приёме ЦП данных от ПВВ базового блока по асинхронному
	 *                интерфейсу;
	 */
	KIWI_CID_CPU_FROM_BASE_IOP_ASYNC = 62,

	/**
	 * @brief &mdash; количество ошибок при приёме ПВВ базового блока данных от ЦП по асинхронному
	 *                интерфейсу;
	 */
	KIWI_CID_BASE_IOP_FROM_CPU_ASYNC = 63,

	/** @brief &mdash; количество ошибок при приёме ПВВ базового блока данных от ПВВ доп. модуля; */
	KIWI_CID_BASE_IOP_FROM_AUX_IOP = 64,

	/** @brief &mdash; количество ошибок при приёме ПВВ доп. модуля данных от ПВВ базового блока; */
	KIWI_CID_AUX_IOP_FROM_BASE_IOP = 65,

	/** @brief &mdash; количество ошибок при приёме ЦП данных от КП; */
	KIWI_CID_CPU_FROM_COM_P = 66,

	/** @brief &mdash; количество ошибок при приёме КП данных от ЦП; */
	KIWI_CID_COM_P_FROM_CPU = 67,

	/** @brief &mdash; количество ошибок при приёме ЦП данных от пульта; */
	KIWI_CID_CPU_FROM_CONTROL_PANEL = 68,

	/** @brief &mdash; количество ошибок при приёме пультом данных от ЦП; */
	KIWI_CID_CONTROL_PANEL_FROM_CPU = 69,

	/**
	 * @brief &mdash; количество ошибок при приёме данных КП базового блока по 1-му каналу MODBUS;
	 */
	KIWI_CID_MODBUS_1 = 70,

	/**
	 * @brief &mdash; количество ошибок при приёме данных КП базового блока по 2-му каналу MODBUS;
	 */
	KIWI_CID_MODBUS_2 = 71,

	/** @brief &mdash; Nотп; */
	KIWI_CID_N_OTP = 72,

	/** @brief &mdash; Ресурс РПН; */
	KIWI_CID_RESURS_RPN = 73,

	/** @brief &mdash; Ресурс РПН нагр. */
	KIWI_CID_RESURS_RPN_NAGR = 74,

	KIWI_CID_INVALID_ACCUMULATOR = KIWI_INVALID_ID
} kiwi_AccumulatorID;
/*-----------------------------------------------------------------------------------------------*/

/*@}*/

#ifdef __cplusplus
}
#endif

#endif /* APPLICATION_USER_BFSOFTWARE_KIWIDATABASEIDS_H_ */
