﻿/**
 * @file
 */

#ifndef APPLICATION_USER_BFSOFTWARE_BZP_KIWIDATABASEIDS_H_
#define APPLICATION_USER_BFSOFTWARE_BZP_KIWIDATABASEIDS_H_

#include <stdint.h>

#ifdef __cplusplus
extern "C"
{
#endif

/**
 * @defgroup KIWIDatabaseIDs Модуль KIWIDatabaseIDs
 *
 * Этот модуль определяет идентификаторы уставок, сигналов и событий устройства Алтей-БЗП,
 * используемые в базе данных KIWI.
 *
 * @version 1.0.0
 * @date 26.09.2018
 * @copyright ООО НПП "Микропроцессорные технологии"
 * @author А.Молдованов
 */
/*@{*/

/*======================================= МАКРООПРЕДЕЛЕНИЯ ======================================*/

/** @brief Недействительное значение идентификатора. */
#define KIWI_INVALID_ID  (UINT16_MAX)

/*======================================== ТИПЫ ДАННЫХ ==========================================*/

/** @brief Тип идентификатора группы уставок, используемый в базе данных KIWI. */
typedef enum kiwi_SettingGroupID_TAG
{
	KIWI_SGID_DISKRETNYJE_VKHODY = 0,
	KIWI_SGID_KEP = 1,
	KIWI_SGID_BK = 3,
	KIWI_SGID_DZ = 4,
	KIWI_SGID_DZDV = 5,
	KIWI_SGID_TO = 7,
	KIWI_SGID_MTZ_1 = 8,
	KIWI_SGID_MTZ_2 = 9,
	KIWI_SGID_ZP = 10,
	KIWI_SGID_LZSH = 11,
	KIWI_SGID_ZDZ = 12,
	KIWI_SGID_ZOF = 13,
	KIWI_SGID_OZZ = 14,
	KIWI_SGID_ZMN = 16,
	KIWI_SGID_ZPP = 17,
	KIWI_SGID_ZPN = 18,
	KIWI_SGID_DTO_I_DZT = 20,
	KIWI_SGID_ZPP_ZBR = 21,
	KIWI_SGID_TM = 22,
	KIWI_SGID_MINTZ = 23,
	KIWI_SGID_ZAR = 24,
	KIWI_SGID_VZ_VS = 25,
	KIWI_SGID_OKP = 26,
	KIWI_SGID_SF6 = 28,
	KIWI_SGID_UROV = 29,
	KIWI_SGID_ACHR = 31,
	KIWI_SGID_CHAPV = 32,
	KIWI_SGID_ACHR_N_OCH = 33,
	KIWI_SGID_CHAPV_N_OCH = 34,
	KIWI_SGID_AVR = 36,
	KIWI_SGID_VNR = 37,
	KIWI_SGID_OU = 39,
	KIWI_SGID_VKL = 40,
	KIWI_SGID_OTKL = 41,
	KIWI_SGID_NS = 42,
	KIWI_SGID_PODGOTOVKA_APV = 43,
	KIWI_SGID_APV = 44,
	KIWI_SGID_KCU = 46,
	KIWI_SGID_KCN = 47,
	KIWI_SGID_KCT = 48,
	KIWI_SGID_KOEF_TRANSFORM = 49,
	KIWI_SGID_USTAVKI = 50,
	KIWI_SGID_AVARIJNAJA = 51,
	KIWI_SGID_PREDUPREDITELNAJA = 52,
	KIWI_SGID_SJEM_SIGNALIZATSII = 53,
	KIWI_SGID_OSCILLOGRAF = 54,
	KIWI_SGID_KONFIGURACIJA = 55,
	KIWI_SGID_GIBKAJA_LOGIKA = 60,
	KIWI_SGID_RESURS = 62,
	KIWI_SGID_OMP = 63,
	KIWI_SGID_UCHET = 64,
	KIWI_SGID_PUSK_ORGANY = 65,
	KIWI_SGID_VKHODY_ALGORITMOV = 38,
	KIWI_SGID_SISTEMA = 66,

	KIWI_SGID_INVALID_SETTING_GROUP = KIWI_INVALID_ID
} kiwi_SettingGroupID;
/*-----------------------------------------------------------------------------------------------*/
/** @brief Тип идентификатора уставки. */
typedef enum kiwi_SettingID_TAG
{
	KIWI_SETID_IMIN_N1 = 0,
	KIWI_SETID_USH_MAKS_N1 = 1,
	KIWI_SETID_USH_MIN_N1 = 2,
	KIWI_SETID_UVST_MAKS_N1 = 3,
	KIWI_SETID_UVST_MIN_N1 = 4,
	KIWI_SETID_U2_MAKS_N1 = 5,
	KIWI_SETID_3U0_MAKS_1_N1 = 6,
	KIWI_SETID_V481_N1 = 7,
	KIWI_SETID_3U0_MAKS_2_N1 = 8,
	KIWI_SETID_TOZZ_N1 = 9,
	KIWI_SETID_F_MAKS_N1 = 10,
	KIWI_SETID_KS_DU_N1 = 11,
	KIWI_SETID_KS_DF_N1 = 12,
	KIWI_SETID_KS_DFI_N1 = 13,
	KIWI_SETID_KS_KUVST_N1 = 14,
	KIWI_SETID_KS_FIVST_N1 = 15,
	KIWI_SETID_V491_N1 = 16,
	KIWI_SETID_V492_N1 = 17,
	KIWI_SETID_US_DF_N1 = 18,
	KIWI_SETID_TUS_N1 = 19,
	KIWI_SETID_FIMCH_N1 = 20,
	KIWI_SETID_V482_N1 = 21,
	KIWI_SETID_V483_N1 = 22,
	KIWI_SETID_UVMB_N1 = 23,
	KIWI_SETID_U2_VMB_N1 = 24,
	KIWI_SETID_UBLOK_N1 = 336,
	KIWI_SETID_V091_N3 = 25,
	KIWI_SETID_I1_BK_N3 = 26,
	KIWI_SETID_I2_BK_N3 = 27,
	KIWI_SETID_TBK_SBROS_N3 = 28,
	KIWI_SETID_V021_N4 = 29,
	KIWI_SETID_V025_N4 = 30,
	KIWI_SETID_V051_N4 = 31,
	KIWI_SETID_TDZ_1_N4 = 32,
	KIWI_SETID_DZ_1_VID_N4 = 33,
	KIWI_SETID_DZ_1_ZSR_N4 = 34,
	KIWI_SETID_DZ_1_ZSM_N4 = 35,
	KIWI_SETID_DZ_1_RSR_N4 = 36,
	KIWI_SETID_DZ_1_RSM_N4 = 37,
	KIWI_SETID_DZ_1_FIMCH_N4 = 38,
	KIWI_SETID_DZ_1_FITR_N4 = 39,
	KIWI_SETID_V022_N4 = 40,
	KIWI_SETID_V026_N4 = 41,
	KIWI_SETID_V052_N4 = 42,
	KIWI_SETID_TDZ_2_N4 = 43,
	KIWI_SETID_DZ_2_VID_N4 = 44,
	KIWI_SETID_DZ_2_ZSR_N4 = 45,
	KIWI_SETID_DZ_2_ZSM_N4 = 46,
	KIWI_SETID_DZ_2_RSR_N4 = 47,
	KIWI_SETID_DZ_2_RSM_N4 = 48,
	KIWI_SETID_DZ_2_FIMCH_N4 = 49,
	KIWI_SETID_DZ_2_FITR_N4 = 50,
	KIWI_SETID_V023_N4 = 51,
	KIWI_SETID_V027_N4 = 52,
	KIWI_SETID_V053_N4 = 53,
	KIWI_SETID_TDZ_3_N4 = 54,
	KIWI_SETID_DZ_3_VID_N4 = 55,
	KIWI_SETID_DZ_3_ZSR_N4 = 56,
	KIWI_SETID_DZ_3_ZSM_N4 = 57,
	KIWI_SETID_DZ_3_RSR_N4 = 58,
	KIWI_SETID_DZ_3_RSM_N4 = 59,
	KIWI_SETID_DZ_3_FIMCH_N4 = 60,
	KIWI_SETID_DZ_3_FITR_N4 = 61,
	KIWI_SETID_V024_N4 = 62,
	KIWI_SETID_V054_N4 = 63,
	KIWI_SETID_TDZ_4_N4 = 64,
	KIWI_SETID_DZ_4_VID_N4 = 65,
	KIWI_SETID_DZ_4_ZSR_N4 = 66,
	KIWI_SETID_DZ_4_ZSM_N4 = 67,
	KIWI_SETID_DZ_4_RSR_N4 = 68,
	KIWI_SETID_DZ_4_RSM_N4 = 69,
	KIWI_SETID_DZ_4_FIMCH_N4 = 70,
	KIWI_SETID_DZ_4_FITR_N4 = 71,
	KIWI_SETID_V041_N4 = 72,
	KIWI_SETID_V042_N4 = 73,
	KIWI_SETID_V043_N4 = 74,
	KIWI_SETID_V044_N4 = 75,
	KIWI_SETID_V045_N4 = 76,
	KIWI_SETID_V046_N4 = 77,
	KIWI_SETID_TUDZ_N4 = 78,
	KIWI_SETID_3I0_DZZ_N5 = 79,
	KIWI_SETID_KDZDV_RE_N5 = 80,
	KIWI_SETID_KDZDV_IM_N5 = 755,
	KIWI_SETID_DTDZDV_A_N5 = 81,
	KIWI_SETID_DTDZDV_B_N5 = 82,
	KIWI_SETID_DTDZDV_C_N5 = 83,
	KIWI_SETID_V061_N5 = 84,
	KIWI_SETID_V065_N5 = 85,
	KIWI_SETID_TDZDV_1_N5 = 86,
	KIWI_SETID_DZDV_1_VID_N5 = 87,
	KIWI_SETID_DZDV_1_ZSR_N5 = 88,
	KIWI_SETID_DZDV_1_ZSM_N5 = 89,
	KIWI_SETID_DZDV_1_RSR_N5 = 90,
	KIWI_SETID_DZDV_1_RSM_N5 = 91,
	KIWI_SETID_DZDV_1_FIMCH_N5 = 92,
	KIWI_SETID_DZDV_1_FITR_N5 = 93,
	KIWI_SETID_V062_N5 = 94,
	KIWI_SETID_V066_N5 = 95,
	KIWI_SETID_TDZDV_2_N5 = 96,
	KIWI_SETID_DZDV_2_VID_N5 = 97,
	KIWI_SETID_DZDV_2_ZSR_N5 = 98,
	KIWI_SETID_DZDV_2_ZSM_N5 = 99,
	KIWI_SETID_DZDV_2_RSR_N5 = 100,
	KIWI_SETID_DZDV_2_RSM_N5 = 101,
	KIWI_SETID_DZDV_2_FIMCH_N5 = 102,
	KIWI_SETID_DZDV_2_FITR_N5 = 103,
	KIWI_SETID_V063_N5 = 104,
	KIWI_SETID_V067_N5 = 105,
	KIWI_SETID_TDZDV_3_N5 = 106,
	KIWI_SETID_DZDV_3_VID_N5 = 107,
	KIWI_SETID_DZDV_3_ZSR_N5 = 108,
	KIWI_SETID_DZDV_3_ZSM_N5 = 109,
	KIWI_SETID_DZDV_3_RSR_N5 = 110,
	KIWI_SETID_DZDV_3_RSM_N5 = 111,
	KIWI_SETID_DZDV_3_FIMCH_N5 = 112,
	KIWI_SETID_DZDV_3_FITR_N5 = 113,
	KIWI_SETID_V064_N5 = 114,
	KIWI_SETID_TDZDV_4_N5 = 115,
	KIWI_SETID_DZDV_4_VID_N5 = 116,
	KIWI_SETID_DZDV_4_ZSR_N5 = 117,
	KIWI_SETID_DZDV_4_ZSM_N5 = 118,
	KIWI_SETID_DZDV_4_RSR_N5 = 119,
	KIWI_SETID_DZDV_4_RSM_N5 = 120,
	KIWI_SETID_DZDV_4_FIMCH_N5 = 121,
	KIWI_SETID_DZDV_4_FITR_N5 = 122,
	KIWI_SETID_V081_N5 = 123,
	KIWI_SETID_V082_N5 = 124,
	KIWI_SETID_V083_N5 = 125,
	KIWI_SETID_V084_N5 = 126,
	KIWI_SETID_V085_N5 = 127,
	KIWI_SETID_V086_N5 = 128,
	KIWI_SETID_TUDZDV_N5 = 129,
	KIWI_SETID_V101_N7 = 130,
	KIWI_SETID_V107_N7 = 131,
	KIWI_SETID_V109_N7 = 132,
	KIWI_SETID_ITO_1_VN_N7 = 133,
	KIWI_SETID_TTO_1_VN_N7 = 134,
	KIWI_SETID_V102_N7 = 135,
	KIWI_SETID_V108_N7 = 136,
	KIWI_SETID_V110_N7 = 137,
	KIWI_SETID_ITO_2_VN_N7 = 138,
	KIWI_SETID_TTO_2_VN_N7 = 139,
	KIWI_SETID_V111_N8 = 140,
	KIWI_SETID_IMTZ_1_N8 = 141,
	KIWI_SETID_TMTZ_1_N8 = 142,
	KIWI_SETID_V112_N8 = 143,
	KIWI_SETID_VTH_MTZ_1_N8 = 144,
	KIWI_SETID_KVTH_1_N8 = 145,
	KIWI_SETID_TVTH_1_N8 = 146,
	KIWI_SETID_V114_N8 = 147,
	KIWI_SETID_V116_N8 = 148,
	KIWI_SETID_V1161_N8 = 149,
	KIWI_SETID_TUMTZ_1_N8 = 150,
	KIWI_SETID_V117_N8 = 151,
	KIWI_SETID_V119_N8 = 152,
	KIWI_SETID_V120_N8 = 153,
	KIWI_SETID_IMTZ_1_GR_N8 = 154,
	KIWI_SETID_TMTZ_1_GR_N8 = 155,
	KIWI_SETID_V1110_N8 = 156,
	KIWI_SETID_V1111_N8 = 157,
	KIWI_SETID_V121_N9 = 158,
	KIWI_SETID_IMTZ_2_N9 = 159,
	KIWI_SETID_TMTZ_2_N9 = 160,
	KIWI_SETID_V122_N9 = 161,
	KIWI_SETID_VTH_MTZ_2_N9 = 162,
	KIWI_SETID_KVTH_2_N9 = 163,
	KIWI_SETID_TVTH_2_N9 = 164,
	KIWI_SETID_V124_N9 = 165,
	KIWI_SETID_V126_N9 = 166,
	KIWI_SETID_V1261_N9 = 167,
	KIWI_SETID_TUMTZ_2_N9 = 168,
	KIWI_SETID_V127_N9 = 169,
	KIWI_SETID_V129_N9 = 170,
	KIWI_SETID_V130_N9 = 171,
	KIWI_SETID_IMTZ_2_GR_N9 = 172,
	KIWI_SETID_TMTZ_2_GR_N9 = 173,
	KIWI_SETID_V1210_N9 = 174,
	KIWI_SETID_V1211_N9 = 175,
	KIWI_SETID_V131_N10 = 176,
	KIWI_SETID_V132_N10 = 177,
	KIWI_SETID_IZP_N10 = 178,
	KIWI_SETID_TZP_N10 = 179,
	KIWI_SETID_TZP_OTKL_N10 = 180,
	KIWI_SETID_V133_N10 = 181,
	KIWI_SETID_TRAZGR_1_N10 = 182,
	KIWI_SETID_V134_N10 = 183,
	KIWI_SETID_TRAZGR_2_N10 = 184,
	KIWI_SETID_V135_N10 = 185,
	KIWI_SETID_VTH_ZP_N10 = 186,
	KIWI_SETID_KVTH_ZP_N10 = 187,
	KIWI_SETID_TVTH_ZP_N10 = 188,
	KIWI_SETID_V141_N11 = 189,
	KIWI_SETID_V142_N11 = 190,
	KIWI_SETID_V149_N11 = 191,
	KIWI_SETID_TLZSH_N11 = 192,
	KIWI_SETID_V151_N12 = 193,
	KIWI_SETID_IZDZ_N12 = 194,
	KIWI_SETID_V153_N12 = 195,
	KIWI_SETID_3I0ZDZ_N12 = 196,
	KIWI_SETID_V165_N13 = 197,
	KIWI_SETID_KI2_ZOF_N13 = 198,
	KIWI_SETID_TZOF_N13 = 199,
	KIWI_SETID_V166_N13 = 200,
	KIWI_SETID_I2_ZOF_N13 = 201,
	KIWI_SETID_V167_N13 = 202,
	KIWI_SETID_V168_N13 = 203,
	KIWI_SETID_FIMCH_OP_N13 = 204,
	KIWI_SETID_V171_N14 = 205,
	KIWI_SETID_V172_N14 = 206,
	KIWI_SETID_V173_N14 = 207,
	KIWI_SETID_V174_N14 = 208,
	KIWI_SETID_V175_N14 = 209,
	KIWI_SETID_IOZZ_1_VG_N14 = 210,
	KIWI_SETID_IOZZ_1_N14 = 211,
	KIWI_SETID_UOZZ_1_N14 = 212,
	KIWI_SETID_TOZZ_1_N14 = 213,
	KIWI_SETID_TOZZ_1_OTKL_N14 = 214,
	KIWI_SETID_FIMCH_NP_N14 = 215,
	KIWI_SETID_V177_N14 = 216,
	KIWI_SETID_V178_N14 = 217,
	KIWI_SETID_IOZZ_2_N14 = 218,
	KIWI_SETID_TOZZ_2_N14 = 219,
	KIWI_SETID_V231_N16 = 220,
	KIWI_SETID_V233_N16 = 221,
	KIWI_SETID_UZMN_1_N16 = 222,
	KIWI_SETID_TZMN_1_N16 = 223,
	KIWI_SETID_V232_N16 = 224,
	KIWI_SETID_V234_N16 = 225,
	KIWI_SETID_UZMN_2_N16 = 226,
	KIWI_SETID_TZMN_2_N16 = 227,
	KIWI_SETID_V235_N16 = 228,
	KIWI_SETID_V236_N16 = 229,
	KIWI_SETID_V241_N17 = 230,
	KIWI_SETID_V242_N17 = 231,
	KIWI_SETID_FZPP_N17 = 232,
	KIWI_SETID_TZPP_N17 = 233,
	KIWI_SETID_V251_N18 = 234,
	KIWI_SETID_V253_N18 = 235,
	KIWI_SETID_UZPN_1_N18 = 236,
	KIWI_SETID_TZPN_1_N18 = 237,
	KIWI_SETID_V252_N18 = 238,
	KIWI_SETID_V254_N18 = 239,
	KIWI_SETID_UZPN_2_N18 = 240,
	KIWI_SETID_TZPN_2_N18 = 241,
	KIWI_SETID_V256_N18 = 242,
	KIWI_SETID_V257_N18 = 243,
	KIWI_SETID_TZPN_BLOK_N18 = 244,
	KIWI_SETID_INOM_N20 = 245,
	KIWI_SETID_V001_N20 = 246,
	KIWI_SETID_IDTO_N20 = 247,
	KIWI_SETID_V002_N20 = 248,
	KIWI_SETID_IDZT_N20 = 249,
	KIWI_SETID_KTORM_N20 = 250,
	KIWI_SETID_TDZT_N20 = 251,
	KIWI_SETID_V003_N20 = 252,
	KIWI_SETID_IPB_2G_N20 = 253,
	KIWI_SETID_V006_N20 = 254,
	KIWI_SETID_IDZT_G_N20 = 255,
	KIWI_SETID_V007_N20 = 256,
	KIWI_SETID_V261_N21 = 257,
	KIWI_SETID_V262_N21 = 258,
	KIWI_SETID_IZZP_N21 = 259,
	KIWI_SETID_TZZP_N21 = 260,
	KIWI_SETID_V265_N21 = 261,
	KIWI_SETID_V266_N21 = 262,
	KIWI_SETID_TZBR_N21 = 263,
	KIWI_SETID_V271_N22 = 264,
	KIWI_SETID_ETM_PUSK_N22 = 265,
	KIWI_SETID_ITM_PUSK_N22 = 266,
	KIWI_SETID_V272_N22 = 267,
	KIWI_SETID_V273_N22 = 268,
	KIWI_SETID_ETM_SIGN_N22 = 269,
	KIWI_SETID_V274_N22 = 270,
	KIWI_SETID_ETM_OTKL_N22 = 271,
	KIWI_SETID_V275_N22 = 272,
	KIWI_SETID_ITM_N22 = 273,
	KIWI_SETID_K2_TM_N22 = 274,
	KIWI_SETID_TN_N22 = 275,
	KIWI_SETID_TO_N22 = 276,
	KIWI_SETID_V281_N23 = 277,
	KIWI_SETID_V282_N23 = 278,
	KIWI_SETID_IMIN_TZ_N23 = 279,
	KIWI_SETID_TMIN_TZ_N23 = 280,
	KIWI_SETID_V291_N24 = 281,
	KIWI_SETID_XZAR_1_N24 = 282,
	KIWI_SETID_XZAR_2_N24 = 283,
	KIWI_SETID_TZAR_N24 = 284,
	KIWI_SETID_TZAR_VOZVR_N24 = 285,
	KIWI_SETID_V292_N24 = 286,
	KIWI_SETID_IZAR_N24 = 287,
	KIWI_SETID_V293_N24 = 288,
	KIWI_SETID_V295_N25 = 289,
	KIWI_SETID_TSP_N25 = 290,
	KIWI_SETID_V296_N25 = 291,
	KIWI_SETID_TVOZD_N25 = 292,
	KIWI_SETID_V297_N25 = 293,
	KIWI_SETID_TVOD_1_N25 = 294,
	KIWI_SETID_V298_N25 = 295,
	KIWI_SETID_TVOD_2_N25 = 296,
	KIWI_SETID_TVOD_3_N25 = 297,
	KIWI_SETID_V451_N26 = 298,
	KIWI_SETID_NOKP_N26 = 299,
	KIWI_SETID_TOKP_N26 = 300,
	KIWI_SETID_V452_N26 = 301,
	KIWI_SETID_TOKP_MP_N26 = 302,
	KIWI_SETID_V453_N26 = 303,
	KIWI_SETID_NOKP_GOR_N26 = 304,
	KIWI_SETID_NOKP_HOL_N26 = 305,
	KIWI_SETID_TOKP_OHL_N26 = 306,
	KIWI_SETID_TOKP_SBROS_N26 = 307,
	KIWI_SETID_V311_N28 = 308,
	KIWI_SETID_V312_N28 = 309,
	KIWI_SETID_V313_N28 = 310,
	KIWI_SETID_I_SF6_BLOK_N28 = 311,
	KIWI_SETID_T_SF6_OTKL_N28 = 312,
	KIWI_SETID_V314_N28 = 313,
	KIWI_SETID_V315_N28 = 314,
	KIWI_SETID_T_SF6_TT_N28 = 315,
	KIWI_SETID_V301_N29 = 316,
	KIWI_SETID_IUROV_N29 = 317,
	KIWI_SETID_TUROV_N29 = 318,
	KIWI_SETID_V302_N29 = 319,
	KIWI_SETID_V304_N29 = 320,
	KIWI_SETID_V307_N29 = 752,
	KIWI_SETID_V350_N31 = 321,
	KIWI_SETID_TACHR_DV_N31 = 322,
	KIWI_SETID_V351_N31 = 323,
	KIWI_SETID_FACHR_1_N31 = 324,
	KIWI_SETID_TACHR_1_N31 = 325,
	KIWI_SETID_V354_N31 = 326,
	KIWI_SETID_DFACHR_1_N31 = 327,
	KIWI_SETID_V352_N31 = 328,
	KIWI_SETID_FACHR_2_N31 = 329,
	KIWI_SETID_FACHR_2_V_N31 = 330,
	KIWI_SETID_TACHR_2_N31 = 331,
	KIWI_SETID_V353_N31 = 332,
	KIWI_SETID_FDAR_N31 = 333,
	KIWI_SETID_DFDAR_N31 = 334,
	KIWI_SETID_TDAR_N31 = 335,
	KIWI_SETID_V358_N31 = 337,
	KIWI_SETID_TCHAPV_GOT_N32 = 338,
	KIWI_SETID_V360_N32 = 339,
	KIWI_SETID_TCHAPV_DV_N32 = 340,
	KIWI_SETID_V361_N32 = 341,
	KIWI_SETID_FCHAPV_N32 = 342,
	KIWI_SETID_TCHAPV_N32 = 343,
	KIWI_SETID_V362_N32 = 344,
	KIWI_SETID_UCHAPV_N32 = 345,
	KIWI_SETID_V351_1_N33 = 346,
	KIWI_SETID_FACHR_1_1_N33 = 347,
	KIWI_SETID_TACHR_1_1_N33 = 348,
	KIWI_SETID_V354_1_N33 = 349,
	KIWI_SETID_DFACHR_1_1_N33 = 350,
	KIWI_SETID_V352_1_N33 = 351,
	KIWI_SETID_FACHR_2_1_N33 = 352,
	KIWI_SETID_FACHR_2_V_1_N33 = 353,
	KIWI_SETID_TACHR_2_1_N33 = 354,
	KIWI_SETID_V353_1_N33 = 355,
	KIWI_SETID_FDAR_1_N33 = 356,
	KIWI_SETID_DFDAR_1_N33 = 357,
	KIWI_SETID_TDAR_1_N33 = 358,
	KIWI_SETID_V358_1_N33 = 359,
	KIWI_SETID_V351_2_N33 = 360,
	KIWI_SETID_FACHR_1_2_N33 = 361,
	KIWI_SETID_TACHR_1_2_N33 = 362,
	KIWI_SETID_V354_2_N33 = 363,
	KIWI_SETID_DFACHR_1_2_N33 = 364,
	KIWI_SETID_V352_2_N33 = 365,
	KIWI_SETID_FACHR_2_2_N33 = 366,
	KIWI_SETID_FACHR_2_V_2_N33 = 367,
	KIWI_SETID_TACHR_2_2_N33 = 368,
	KIWI_SETID_V353_2_N33 = 369,
	KIWI_SETID_FDAR_2_N33 = 370,
	KIWI_SETID_DFDAR_2_N33 = 371,
	KIWI_SETID_TDAR_2_N33 = 372,
	KIWI_SETID_V358_2_N33 = 373,
	KIWI_SETID_V351_3_N33 = 374,
	KIWI_SETID_FACHR_1_3_N33 = 375,
	KIWI_SETID_TACHR_1_3_N33 = 376,
	KIWI_SETID_V354_3_N33 = 377,
	KIWI_SETID_DFACHR_1_3_N33 = 378,
	KIWI_SETID_V352_3_N33 = 379,
	KIWI_SETID_FACHR_2_3_N33 = 380,
	KIWI_SETID_FACHR_2_V_3_N33 = 381,
	KIWI_SETID_TACHR_2_3_N33 = 382,
	KIWI_SETID_V353_3_N33 = 383,
	KIWI_SETID_FDAR_3_N33 = 384,
	KIWI_SETID_DFDAR_3_N33 = 385,
	KIWI_SETID_TDAR_3_N33 = 386,
	KIWI_SETID_V358_3_N33 = 387,
	KIWI_SETID_V351_4_N33 = 388,
	KIWI_SETID_FACHR_1_4_N33 = 389,
	KIWI_SETID_TACHR_1_4_N33 = 390,
	KIWI_SETID_V354_4_N33 = 391,
	KIWI_SETID_DFACHR_1_4_N33 = 392,
	KIWI_SETID_V352_4_N33 = 393,
	KIWI_SETID_FACHR_2_4_N33 = 394,
	KIWI_SETID_FACHR_2_V_4_N33 = 395,
	KIWI_SETID_TACHR_2_4_N33 = 396,
	KIWI_SETID_V353_4_N33 = 397,
	KIWI_SETID_FDAR_4_N33 = 398,
	KIWI_SETID_DFDAR_4_N33 = 399,
	KIWI_SETID_TDAR_4_N33 = 400,
	KIWI_SETID_V358_4_N33 = 401,
	KIWI_SETID_V351_5_N33 = 402,
	KIWI_SETID_FACHR_1_5_N33 = 403,
	KIWI_SETID_TACHR_1_5_N33 = 404,
	KIWI_SETID_V354_5_N33 = 405,
	KIWI_SETID_DFACHR_1_5_N33 = 406,
	KIWI_SETID_V352_5_N33 = 407,
	KIWI_SETID_FACHR_2_5_N33 = 408,
	KIWI_SETID_FACHR_2_V_5_N33 = 409,
	KIWI_SETID_TACHR_2_5_N33 = 410,
	KIWI_SETID_V353_5_N33 = 411,
	KIWI_SETID_FDAR_5_N33 = 412,
	KIWI_SETID_DFDAR_5_N33 = 413,
	KIWI_SETID_TDAR_5_N33 = 414,
	KIWI_SETID_V358_5_N33 = 415,
	KIWI_SETID_V351_6_N33 = 416,
	KIWI_SETID_FACHR_1_6_N33 = 417,
	KIWI_SETID_TACHR_1_6_N33 = 418,
	KIWI_SETID_V354_6_N33 = 419,
	KIWI_SETID_DFACHR_1_6_N33 = 420,
	KIWI_SETID_V352_6_N33 = 421,
	KIWI_SETID_FACHR_2_6_N33 = 422,
	KIWI_SETID_FACHR_2_V_6_N33 = 423,
	KIWI_SETID_TACHR_2_6_N33 = 424,
	KIWI_SETID_V353_6_N33 = 425,
	KIWI_SETID_FDAR_6_N33 = 426,
	KIWI_SETID_DFDAR_6_N33 = 427,
	KIWI_SETID_TDAR_6_N33 = 428,
	KIWI_SETID_V358_6_N33 = 429,
	KIWI_SETID_V351_7_N33 = 430,
	KIWI_SETID_FACHR_1_7_N33 = 431,
	KIWI_SETID_TACHR_1_7_N33 = 432,
	KIWI_SETID_V354_7_N33 = 433,
	KIWI_SETID_DFACHR_1_7_N33 = 434,
	KIWI_SETID_V352_7_N33 = 435,
	KIWI_SETID_FACHR_2_7_N33 = 436,
	KIWI_SETID_FACHR_2_V_7_N33 = 437,
	KIWI_SETID_TACHR_2_7_N33 = 438,
	KIWI_SETID_V353_7_N33 = 439,
	KIWI_SETID_FDAR_7_N33 = 440,
	KIWI_SETID_DFDAR_7_N33 = 441,
	KIWI_SETID_TDAR_7_N33 = 442,
	KIWI_SETID_V358_7_N33 = 443,
	KIWI_SETID_V351_8_N33 = 444,
	KIWI_SETID_FACHR_1_8_N33 = 445,
	KIWI_SETID_TACHR_1_8_N33 = 446,
	KIWI_SETID_V354_8_N33 = 447,
	KIWI_SETID_DFACHR_1_8_N33 = 448,
	KIWI_SETID_V352_8_N33 = 449,
	KIWI_SETID_FACHR_2_8_N33 = 450,
	KIWI_SETID_FACHR_2_V_8_N33 = 451,
	KIWI_SETID_TACHR_2_8_N33 = 452,
	KIWI_SETID_V353_8_N33 = 453,
	KIWI_SETID_FDAR_8_N33 = 454,
	KIWI_SETID_DFDAR_8_N33 = 455,
	KIWI_SETID_TDAR_8_N33 = 456,
	KIWI_SETID_V358_8_N33 = 457,
	KIWI_SETID_V351_9_N33 = 458,
	KIWI_SETID_FACHR_1_9_N33 = 459,
	KIWI_SETID_TACHR_1_9_N33 = 460,
	KIWI_SETID_V354_9_N33 = 461,
	KIWI_SETID_DFACHR_1_9_N33 = 462,
	KIWI_SETID_V352_9_N33 = 463,
	KIWI_SETID_FACHR_2_9_N33 = 464,
	KIWI_SETID_FACHR_2_V_9_N33 = 465,
	KIWI_SETID_TACHR_2_9_N33 = 466,
	KIWI_SETID_V353_9_N33 = 467,
	KIWI_SETID_FDAR_9_N33 = 468,
	KIWI_SETID_DFDAR_9_N33 = 469,
	KIWI_SETID_TDAR_9_N33 = 470,
	KIWI_SETID_V358_9_N33 = 471,
	KIWI_SETID_V361_1_N34 = 472,
	KIWI_SETID_FCHAPV_1_N34 = 473,
	KIWI_SETID_TCHAPV_1_N34 = 474,
	KIWI_SETID_V362_1_N34 = 475,
	KIWI_SETID_UCHAPV_1_N34 = 476,
	KIWI_SETID_V361_2_N34 = 477,
	KIWI_SETID_FCHAPV_2_N34 = 478,
	KIWI_SETID_TCHAPV_2_N34 = 479,
	KIWI_SETID_V362_2_N34 = 480,
	KIWI_SETID_UCHAPV_2_N34 = 481,
	KIWI_SETID_V361_3_N34 = 482,
	KIWI_SETID_FCHAPV_3_N34 = 483,
	KIWI_SETID_TCHAPV_3_N34 = 484,
	KIWI_SETID_V362_3_N34 = 485,
	KIWI_SETID_UCHAPV_3_N34 = 486,
	KIWI_SETID_V361_4_N34 = 487,
	KIWI_SETID_FCHAPV_4_N34 = 488,
	KIWI_SETID_TCHAPV_4_N34 = 489,
	KIWI_SETID_V362_4_N34 = 490,
	KIWI_SETID_UCHAPV_4_N34 = 491,
	KIWI_SETID_V361_5_N34 = 492,
	KIWI_SETID_FCHAPV_5_N34 = 493,
	KIWI_SETID_TCHAPV_5_N34 = 494,
	KIWI_SETID_V362_5_N34 = 495,
	KIWI_SETID_UCHAPV_5_N34 = 496,
	KIWI_SETID_V361_6_N34 = 497,
	KIWI_SETID_FCHAPV_6_N34 = 498,
	KIWI_SETID_TCHAPV_6_N34 = 499,
	KIWI_SETID_V362_6_N34 = 500,
	KIWI_SETID_UCHAPV_6_N34 = 501,
	KIWI_SETID_V361_7_N34 = 502,
	KIWI_SETID_FCHAPV_7_N34 = 503,
	KIWI_SETID_TCHAPV_7_N34 = 504,
	KIWI_SETID_V362_7_N34 = 505,
	KIWI_SETID_UCHAPV_7_N34 = 506,
	KIWI_SETID_V361_8_N34 = 507,
	KIWI_SETID_FCHAPV_8_N34 = 508,
	KIWI_SETID_TCHAPV_8_N34 = 509,
	KIWI_SETID_V362_8_N34 = 510,
	KIWI_SETID_UCHAPV_8_N34 = 511,
	KIWI_SETID_V361_9_N34 = 512,
	KIWI_SETID_FCHAPV_9_N34 = 513,
	KIWI_SETID_TCHAPV_9_N34 = 514,
	KIWI_SETID_V362_9_N34 = 515,
	KIWI_SETID_UCHAPV_9_N34 = 516,
	KIWI_SETID_V551_N36 = 517,
	KIWI_SETID_UAVR_N36 = 518,
	KIWI_SETID_TAVR_N36 = 519,
	KIWI_SETID_V552_N36 = 520,
	KIWI_SETID_FAVR_N36 = 521,
	KIWI_SETID_V553_N36 = 522,
	KIWI_SETID_V555_N36 = 523,
	KIWI_SETID_V556_N36 = 524,
	KIWI_SETID_V557_N36 = 525,
	KIWI_SETID_V571_N36 = 526,
	KIWI_SETID_V572_N36 = 527,
	KIWI_SETID_V573_N36 = 528,
	KIWI_SETID_V574_N36 = 529,
	KIWI_SETID_V575_N36 = 530,
	KIWI_SETID_V561_N37 = 531,
	KIWI_SETID_UVNR_N37 = 532,
	KIWI_SETID_TVNR_N37 = 533,
	KIWI_SETID_TVNR_GOT_N37 = 534,
	KIWI_SETID_V562_N37 = 535,
	KIWI_SETID_TVNR_BP_N37 = 536,
	KIWI_SETID_V401_N39 = 538,
	KIWI_SETID_V402_N39 = 541,
	KIWI_SETID_TVKL_IMP_N40 = 539,
	KIWI_SETID_TRPV_N40 = 540,
	KIWI_SETID_V411_N40 = 542,
	KIWI_SETID_V412_N40 = 543,
	KIWI_SETID_V413_N40 = 544,
	KIWI_SETID_V414_N40 = 545,
	KIWI_SETID_V421_N40 = 546,
	KIWI_SETID_V422_N40 = 547,
	KIWI_SETID_V423_N40 = 548,
	KIWI_SETID_V424_N40 = 549,
	KIWI_SETID_V425_N40 = 550,
	KIWI_SETID_V426_N40 = 551,
	KIWI_SETID_TKS_N40 = 552,
	KIWI_SETID_TOTKL_IMP_N41 = 553,
	KIWI_SETID_TRPO_N41 = 554,
	KIWI_SETID_TEM_N41 = 555,
	KIWI_SETID_V441_N42 = 556,
	KIWI_SETID_TAPV_GOT_N43 = 557,
	KIWI_SETID_V503_N43 = 558,
	KIWI_SETID_V504_N43 = 559,
	KIWI_SETID_V521_N43 = 560,
	KIWI_SETID_V531_N43 = 561,
	KIWI_SETID_V532_N43 = 562,
	KIWI_SETID_V533_N43 = 563,
	KIWI_SETID_V534_N43 = 564,
	KIWI_SETID_V537_N43 = 756,
	KIWI_SETID_V538_N43 = 757,
	KIWI_SETID_V539_N43 = 758,
	KIWI_SETID_V501_N44 = 565,
	KIWI_SETID_V502_N44 = 566,
	KIWI_SETID_V505_N44 = 567,
	KIWI_SETID_V507_N44 = 568,
	KIWI_SETID_V508_N44 = 569,
	KIWI_SETID_V509_N44 = 570,
	KIWI_SETID_V510_N44 = 571,
	KIWI_SETID_V511_N44 = 572,
	KIWI_SETID_V512_N44 = 753,
	KIWI_SETID_V513_N44 = 573,
	KIWI_SETID_V514_N44 = 574,
	KIWI_SETID_V515_N44 = 575,
	KIWI_SETID_V516_N44 = 576,
	KIWI_SETID_V517_N44 = 577,
	KIWI_SETID_V518_N44 = 578,
	KIWI_SETID_V519_N44 = 579,
	KIWI_SETID_V520_N44 = 580,
	KIWI_SETID_TAPV_L1_N44 = 581,
	KIWI_SETID_TAPV_L2_N44 = 582,
	KIWI_SETID_TAPV_SH_N44 = 583,
	KIWI_SETID_V522_N44 = 584,
	KIWI_SETID_TAV_SHP_N46 = 585,
	KIWI_SETID_TPRUZH_N46 = 586,
	KIWI_SETID_TTEMP_N46 = 587,
	KIWI_SETID_TNCU_N46 = 588,
	KIWI_SETID_V409_N46 = 589,
	KIWI_SETID_V471_N47 = 590,
	KIWI_SETID_V472_N47 = 591,
	KIWI_SETID_I2_KCN_N47 = 592,
	KIWI_SETID_TKCN_N47 = 593,
	KIWI_SETID_TKCN_SIGN_N47 = 594,
	KIWI_SETID_INB_N48 = 595,
	KIWI_SETID_TNB_N48 = 596,
	KIWI_SETID_V010_N48 = 597,
	KIWI_SETID_V011_N48 = 598,
	KIWI_SETID_IN_TT_P_N49 = 626,
	KIWI_SETID_IN_TT_V_N49 = 627,
	KIWI_SETID_IN_TT_3I0_P_N49 = 628,
	KIWI_SETID_IN_TT_3I0_V_N49 = 629,
	KIWI_SETID_IN_TTN_P_N49 = 630,
	KIWI_SETID_IN_TTN_V_N49 = 631,
	KIWI_SETID_UN_TN_P_N49 = 632,
	KIWI_SETID_UN_TN_V_N49 = 633,
	KIWI_SETID_UN_TN_V_DOP_N49 = 634,
	KIWI_SETID_UN_TNVST_P_N49 = 635,
	KIWI_SETID_UN_TNVST_V_N49 = 636,
	KIWI_SETID_VYBOR_DIAPAZONA_N49 = 637,
	KIWI_SETID_I_D_N49 = 638,
	KIWI_SETID_I_N_D_N49 = 639,
	KIWI_SETID_V881_N50 = 599,
	KIWI_SETID_V882_N50 = 600,
	KIWI_SETID_TPR_1_N50 = 601,
	KIWI_SETID_TPR_NAPR_N50 = 602,
	KIWI_SETID_TAS_DOP_N51 = 603,
	KIWI_SETID_V900_N52 = 604,
	KIWI_SETID_V951_N52 = 605,
	KIWI_SETID_V952_N52 = 606,
	KIWI_SETID_V953_N52 = 607,
	KIWI_SETID_V954_N52 = 608,
	KIWI_SETID_V955_N52 = 609,
	KIWI_SETID_V956_N52 = 610,
	KIWI_SETID_V957_N52 = 611,
	KIWI_SETID_V961_N52 = 612,
	KIWI_SETID_V962_N52 = 613,
	KIWI_SETID_V963_N52 = 614,
	KIWI_SETID_V964_N52 = 615,
	KIWI_SETID_V965_N52 = 616,
	KIWI_SETID_V966_N52 = 617,
	KIWI_SETID_V967_N52 = 618,
	KIWI_SETID_V968_N52 = 619,
	KIWI_SETID_V969_N52 = 620,
	KIWI_SETID_TPS_SF6_Q_1_N52 = 621,
	KIWI_SETID_TPS_SF6_Q_2_N52 = 622,
	KIWI_SETID_TPS_SF6_TT_1_N52 = 623,
	KIWI_SETID_TPS_SF6_TT_2_N52 = 624,
	KIWI_SETID_TPS_DOP_N52 = 625,
	KIWI_SETID_TOSC_DOAV_N54 = 640,
	KIWI_SETID_TOSC_N54 = 641,
	KIWI_SETID_MVV_N55 = 642,
	KIWI_SETID_SHEMA_TN_N55 = 643,
	KIWI_SETID_SHEMA_TT_N55 = 644,
	KIWI_SETID_V_DZ_N55 = 645,
	KIWI_SETID_V_TZ_N55 = 646,
	KIWI_SETID_V_ZN_N55 = 647,
	KIWI_SETID_V_ED_N55 = 648,
	KIWI_SETID_V_VZ_I_UROV_N55 = 649,
	KIWI_SETID_V_CHA_N55 = 650,
	KIWI_SETID_V_CCHA_N55 = 754,
	KIWI_SETID_V_AVR_I_VNR_N55 = 651,
	KIWI_SETID_V_AUV_N55 = 652,
	KIWI_SETID_V_D_N55 = 653,
	KIWI_SETID_V_PF_N55 = 654,
	KIWI_SETID_PU_N55 = 655,
	KIWI_SETID_OBJEKT_N55 = 656,
	KIWI_SETID_VGL_1_N60 = 657,
	KIWI_SETID_VGL_2_N60 = 658,
	KIWI_SETID_VGL_3_N60 = 659,
	KIWI_SETID_VGL_4_N60 = 660,
	KIWI_SETID_VGL_5_N60 = 661,
	KIWI_SETID_VGL_6_N60 = 662,
	KIWI_SETID_VGL_7_N60 = 663,
	KIWI_SETID_VGL_8_N60 = 664,
	KIWI_SETID_VGL_9_N60 = 665,
	KIWI_SETID_VGL_10_N60 = 666,
	KIWI_SETID_TGL_1_N60 = 667,
	KIWI_SETID_TGL_2_N60 = 668,
	KIWI_SETID_TGL_3_N60 = 669,
	KIWI_SETID_TGL_4_N60 = 670,
	KIWI_SETID_TGL_5_N60 = 671,
	KIWI_SETID_TGL_6_N60 = 672,
	KIWI_SETID_TGL_7_N60 = 673,
	KIWI_SETID_TGL_8_N60 = 674,
	KIWI_SETID_TGL_9_N60 = 675,
	KIWI_SETID_TGL_10_N60 = 676,
	KIWI_SETID_I_MAKS_1_N60 = 677,
	KIWI_SETID_I_MAKS_2_N60 = 678,
	KIWI_SETID_I_MAKS_3_N60 = 679,
	KIWI_SETID_I_MIN_1_N60 = 680,
	KIWI_SETID_I_MIN_2_N60 = 681,
	KIWI_SETID_I2_MAKS_1_N60 = 682,
	KIWI_SETID_3I0_MAKS_1_N60 = 683,
	KIWI_SETID_IN_MAKS_1_N60 = 684,
	KIWI_SETID_IN_MAKS_2_N60 = 685,
	KIWI_SETID_IN_MIN_1_N60 = 686,
	KIWI_SETID_IN_MIN_2_N60 = 687,
	KIWI_SETID_U_MAKS_1_N60 = 688,
	KIWI_SETID_U_MAKS_2_N60 = 689,
	KIWI_SETID_U_MIN_1_N60 = 690,
	KIWI_SETID_U_MIN_2_N60 = 691,
	KIWI_SETID_U2_MAKS_1_N60 = 692,
	KIWI_SETID_3U0_MAKS_3_N60 = 693,
	KIWI_SETID_UVST_MAKS_1_N60 = 694,
	KIWI_SETID_V701_N62 = 695,
	KIWI_SETID_INOM_Q_N62 = 696,
	KIWI_SETID_INOM_OTKL_Q_N62 = 697,
	KIWI_SETID_QMR_N62 = 698,
	KIWI_SETID_QKR_N62 = 699,
	KIWI_SETID_QKR_OTKL_N62 = 700,
	KIWI_SETID_QRESURS_N62 = 701,
	KIWI_SETID_QRESURS_SIGN_N62 = 702,
	KIWI_SETID_KNOM_N62 = 703,
	KIWI_SETID_KNOM_OTKL_N62 = 704,
	KIWI_SETID_KOBSHCH_N62 = 705,
	KIWI_SETID_V710_N63 = 706,
	KIWI_SETID_V711_N63 = 707,
	KIWI_SETID_V712_N63 = 708,
	KIWI_SETID_V713_N63 = 709,
	KIWI_SETID_V714_N63 = 710,
	KIWI_SETID_V715_N63 = 711,
	KIWI_SETID_V716_N63 = 712,
	KIWI_SETID_V717_N63 = 713,
	KIWI_SETID_V718_N63 = 714,
	KIWI_SETID_V719_N63 = 715,
	KIWI_SETID_NUCH_N63 = 716,
	KIWI_SETID_L1_N63 = 717,
	KIWI_SETID_X1_N63 = 718,
	KIWI_SETID_R1_N63 = 719,
	KIWI_SETID_L2_N63 = 720,
	KIWI_SETID_X2_N63 = 721,
	KIWI_SETID_R2_N63 = 722,
	KIWI_SETID_L3_N63 = 723,
	KIWI_SETID_X3_N63 = 724,
	KIWI_SETID_R3_N63 = 725,
	KIWI_SETID_L4_N63 = 726,
	KIWI_SETID_X4_N63 = 727,
	KIWI_SETID_R4_N63 = 728,
	KIWI_SETID_L5_N63 = 729,
	KIWI_SETID_X5_N63 = 730,
	KIWI_SETID_R5_N63 = 731,
	KIWI_SETID_L6_N63 = 732,
	KIWI_SETID_X6_N63 = 733,
	KIWI_SETID_R6_N63 = 734,
	KIWI_SETID_L7_N63 = 735,
	KIWI_SETID_X7_N63 = 736,
	KIWI_SETID_R7_N63 = 737,
	KIWI_SETID_L8_N63 = 738,
	KIWI_SETID_X8_N63 = 739,
	KIWI_SETID_R8_N63 = 740,
	KIWI_SETID_L9_N63 = 741,
	KIWI_SETID_X9_N63 = 742,
	KIWI_SETID_R9_N63 = 743,
	KIWI_SETID_L10_N63 = 744,
	KIWI_SETID_X10_N63 = 745,
	KIWI_SETID_R10_N63 = 746,
	KIWI_SETID_V721_N64 = 747,
	KIWI_SETID_DEN_ZAMERA_N64 = 748,
	KIWI_SETID_CHAS_ZAMERA_N64 = 749,
	KIWI_SETID_PSUM_N64 = 750,
	KIWI_SETID_QSUM_N64 = 751,

	/* Идентификаторы фиктивных уставок, которые используются только в пульте. */
	KIWI_SETID_V_DZ_AND_SHEMA_TN_2 = 1000,
	KIWI_SETID_V_TZ_OR_V_ED = 1001,
	KIWI_SETID_V_ED_AND_V_D = 1002,
	KIWI_SETID_V_CHA_OR_V_CCHA = 1003,
	KIWI_SETID_V_DZ_OR_V_TZ = 1004,
	KIWI_SETID_V_D_AND_V_AUV = 1005,
	KIWI_SETID_PAROL_PULTA = 9999,

	KIWI_SETID_INVALID_SETTING = KIWI_INVALID_ID
} kiwi_SettingID;
/*-----------------------------------------------------------------------------------------------*/
/** @brief Тип идентификатора аналогового входа. */
typedef enum kiwi_AnalogInputID_TAG
{
	KIWI_AIID_INPUT_1 = 0,
	KIWI_AIID_INPUT_2 = 1,
	KIWI_AIID_INPUT_3 = 2,
	KIWI_AIID_INPUT_4 = 3,
	KIWI_AIID_INPUT_5 = 4,
	KIWI_AIID_INPUT_6 = 5,
	KIWI_AIID_INPUT_7 = 6,
	KIWI_AIID_INPUT_8 = 7,
	KIWI_AIID_INPUT_9 = 8,
	KIWI_AIID_INPUT_10 = 9,

	KIWI_AIID_INVALID_INPUT = KIWI_INVALID_ID
} kiwi_AnalogInputID;
/*-----------------------------------------------------------------------------------------------*/
/** @brief Тип идентификатора двоичного входа. */
typedef enum kiwi_BinaryInputID_TAG
{
	KIWI_BIID_INPUT_1 = 0,
	KIWI_BIID_INPUT_2 = 1,
	KIWI_BIID_INPUT_3 = 2,
	KIWI_BIID_INPUT_4 = 3,
	KIWI_BIID_INPUT_5 = 4,
	KIWI_BIID_INPUT_6 = 5,
	KIWI_BIID_INPUT_7 = 6,
	KIWI_BIID_INPUT_8 = 7,
	KIWI_BIID_INPUT_9 = 8,
	KIWI_BIID_INPUT_10 = 9,
	KIWI_BIID_INPUT_11 = 10,
	KIWI_BIID_INPUT_12 = 11,
	KIWI_BIID_INPUT_13 = 12,
	KIWI_BIID_INPUT_14 = 13,
	KIWI_BIID_INPUT_15 = 14,
	KIWI_BIID_INPUT_16 = 15,
	KIWI_BIID_INPUT_17 = 16,
	KIWI_BIID_INPUT_18 = 17,
	KIWI_BIID_INPUT_19 = 18,
	KIWI_BIID_INPUT_20 = 19,
	KIWI_BIID_INPUT_21 = 20,
	KIWI_BIID_INPUT_22 = 21,
	KIWI_BIID_INPUT_23 = 22,
	KIWI_BIID_INPUT_24 = 23,
	KIWI_BIID_INPUT_25 = 24,
	KIWI_BIID_INPUT_26 = 25,
	KIWI_BIID_INPUT_27 = 26,
	KIWI_BIID_INPUT_28 = 27,
	KIWI_BIID_INPUT_29 = 28,
	KIWI_BIID_INPUT_30 = 29,
	KIWI_BIID_INPUT_31 = 30,
	KIWI_BIID_INPUT_32 = 31,
	KIWI_BIID_INPUT_33 = 32,
	KIWI_BIID_INPUT_34 = 33,
	KIWI_BIID_INPUT_35 = 34,
	KIWI_BIID_INPUT_36 = 35,
	KIWI_BIID_INPUT_37 = 36,
	KIWI_BIID_INPUT_38 = 37,
	KIWI_BIID_INPUT_39 = 38,
	KIWI_BIID_INPUT_40 = 39,
	KIWI_BIID_INPUT_41 = 40,
	KIWI_BIID_INPUT_42 = 41,

	KIWI_BIID_INVALID_INPUT = KIWI_INVALID_ID
} kiwi_BinaryInputID;
/*-----------------------------------------------------------------------------------------------*/
/** @brief Тип идентификатора двоичного выхода. */
typedef enum kiwi_BinaryOutputID_TAG
{
	KIWI_BOID_OUTPUT_1 = 0,
	KIWI_BOID_OUTPUT_2 = 1,
	KIWI_BOID_OUTPUT_3 = 2,
	KIWI_BOID_OUTPUT_4 = 3,
	KIWI_BOID_OUTPUT_5 = 4,
	KIWI_BOID_OUTPUT_6 = 5,
	KIWI_BOID_OUTPUT_7 = 6,
	KIWI_BOID_OUTPUT_8 = 7,
	KIWI_BOID_OUTPUT_9 = 8,
	KIWI_BOID_OUTPUT_10 = 9,
	KIWI_BOID_OUTPUT_11 = 10,
	KIWI_BOID_OUTPUT_12 = 11,
	KIWI_BOID_OUTPUT_13 = 12,
	KIWI_BOID_OUTPUT_14 = 13,
	KIWI_BOID_OUTPUT_15 = 14,
	KIWI_BOID_OUTPUT_16 = 15,
	KIWI_BOID_OUTPUT_17 = 16,
	KIWI_BOID_OUTPUT_18 = 17,
	KIWI_BOID_OUTPUT_19 = 18,
	KIWI_BOID_OUTPUT_20 = 19,
	KIWI_BOID_OUTPUT_21 = 20,
	KIWI_BOID_OUTPUT_22 = 21,
	KIWI_BOID_OUTPUT_23 = 22,
	KIWI_BOID_OUTPUT_24 = 23,
	KIWI_BOID_OUTPUT_25 = 24,
	KIWI_BOID_OUTPUT_26 = 25,
	KIWI_BOID_OUTPUT_27 = 26,
	KIWI_BOID_OUTPUT_28 = 27,

	KIWI_BOID_INVALID_OUTPUT = KIWI_INVALID_ID
} kiwi_BinaryOutputID;
/*-----------------------------------------------------------------------------------------------*/
/** @brief Тип идентификатора двоичного входного сигнала. */
typedef enum kiwi_BinaryInputSignalID_TAG
{
	KIWI_BISID_UVST_NET_VNESH_N1_1 = 0,
	KIWI_BISID_UVST_EST_VNESH_N1_2 = 1,
	KIWI_BISID_KS_VNESH_N1_3 = 2,
	KIWI_BISID_RPO_N1_4 = 3,
	KIWI_BISID_VYVOD_DZ_1_N1_5 = 4,
	KIWI_BISID_VYVOD_DZ_2_N1_6 = 5,
	KIWI_BISID_VYVOD_DZ_3_N1_7 = 6,
	KIWI_BISID_VYVOD_DZ_4_N1_8 = 7,
	KIWI_BISID_USK_DZ_N1_9 = 8,
	KIWI_BISID_VYVOD_DZDV_1_N1_10 = 9,
	KIWI_BISID_VYVOD_DZDV_2_N1_11 = 10,
	KIWI_BISID_VYVOD_DZDV_3_N1_12 = 11,
	KIWI_BISID_VYVOD_DZDV_4_N1_13 = 12,
	KIWI_BISID_USK_DZDV_N1_14 = 13,
	KIWI_BISID_VYVOD_TO_1_N1_15 = 14,
	KIWI_BISID_VYVOD_TO_2_N1_16 = 15,
	KIWI_BISID_VYVOD_MTZ_1_N1_17 = 16,
	KIWI_BISID_VMB_VNESH_N1_18 = 17,
	KIWI_BISID_USK_MTZ_1_N1_19 = 18,
	KIWI_BISID_VYVOD_MTZ_2_N1_20 = 19,
	KIWI_BISID_USK_MTZ_2_N1_21 = 20,
	KIWI_BISID_VYVOD_ZP_N1_22 = 21,
	KIWI_BISID_VYVOD_LZSH_N1_23 = 22,
	KIWI_BISID_LZSH_1_PRIEMNIK_N1_24 = 23,
	KIWI_BISID_LZSH_1_NET_PITANIA_N1_25 = 24,
	KIWI_BISID_LZSH_2_PRIEMNIK_N1_26 = 25,
	KIWI_BISID_LZSH_2_NET_PITANIA_N1_27 = 26,
	KIWI_BISID_ZDZ_PUSK_VNESH_N1_28 = 27,
	KIWI_BISID_ZDZ_REGISTRATOR_N1_29 = 28,
	KIWI_BISID_ZDZ_VNESHNIJ_N1_30 = 29,
	KIWI_BISID_VYVOD_ZOF_N1_31 = 30,
	KIWI_BISID_VYVOD_OZZ_1_N1_32 = 31,
	KIWI_BISID_VYVOD_OZZ_2_N1_33 = 32,
	KIWI_BISID_VYVOD_ZMN_N1_34 = 33,
	KIWI_BISID_RPV_N1_35 = 34,
	KIWI_BISID_VYVOD_ZPP_N1_36 = 35,
	KIWI_BISID_VYVOD_ZPN_N1_37 = 36,
	KIWI_BISID_VYVOD_DTO_N1_38 = 37,
	KIWI_BISID_VYVOD_DZT_N1_39 = 38,
	KIWI_BISID_VYVOD_ZZP_N1_40 = 39,
	KIWI_BISID_VYVOD_ZBR_N1_41 = 40,
	KIWI_BISID_SBROS_TM_N1_42 = 41,
	KIWI_BISID_VYVOD_MIN_TZ_N1_43 = 42,
	KIWI_BISID_VYVOD_ZAR_N1_44 = 43,
	KIWI_BISID_OSTANOV_SP_N1_45 = 44,
	KIWI_BISID_OSTANOV_VOZD_OHL_N1_46 = 45,
	KIWI_BISID_OSTANOV_VOD_OHL_N1_47 = 46,
	KIWI_BISID_SNIZHENIE_VOD_OHL_N1_48 = 47,
	KIWI_BISID_VODA_V_KORPUSE_N1_49 = 48,
	KIWI_BISID_SBROS_OKP_N1_50 = 49,
	KIWI_BISID_SF6_Q_2_ST_N1_51 = 50,
	KIWI_BISID_SF6_Q_1_ST_N1_52 = 51,
	KIWI_BISID_SF6_TT_2_ST_N1_53 = 52,
	KIWI_BISID_SF6_TT_1_ST_N1_54 = 53,
	KIWI_BISID_PUSK_UROV_VNESH_N1_55 = 54,
	KIWI_BISID_VYVOD_UROV_N1_56 = 55,
	KIWI_BISID_VYVOD_ACHR_N1_57 = 56,
	KIWI_BISID_ACHR_N1_58 = 57,
	KIWI_BISID_CHAPV_N1_59 = 58,
	KIWI_BISID_VYVOD_CHAPV_N1_60 = 59,
	KIWI_BISID_SBROS_ACHR_N1_61 = 60,
	KIWI_BISID_VYVOD_ACHR_1_OCH_N1_62 = 61,
	KIWI_BISID_VYVOD_ACHR_2_OCH_N1_63 = 62,
	KIWI_BISID_VYVOD_ACHR_3_OCH_N1_64 = 63,
	KIWI_BISID_VYVOD_ACHR_4_OCH_N1_65 = 64,
	KIWI_BISID_VYVOD_ACHR_5_OCH_N1_66 = 65,
	KIWI_BISID_VYVOD_ACHR_6_OCH_N1_67 = 66,
	KIWI_BISID_VYVOD_ACHR_7_OCH_N1_68 = 67,
	KIWI_BISID_VYVOD_ACHR_8_OCH_N1_69 = 68,
	KIWI_BISID_VYVOD_ACHR_9_OCH_N1_70 = 69,
	KIWI_BISID_VYVOD_CHAPV_1_OCH_N1_71 = 70,
	KIWI_BISID_VYVOD_CHAPV_2_OCH_N1_72 = 71,
	KIWI_BISID_VYVOD_CHAPV_3_OCH_N1_73 = 72,
	KIWI_BISID_VYVOD_CHAPV_4_OCH_N1_74 = 73,
	KIWI_BISID_VYVOD_CHAPV_5_OCH_N1_75 = 74,
	KIWI_BISID_VYVOD_CHAPV_6_OCH_N1_76 = 75,
	KIWI_BISID_VYVOD_CHAPV_7_OCH_N1_77 = 76,
	KIWI_BISID_VYVOD_CHAPV_8_OCH_N1_78 = 77,
	KIWI_BISID_VYVOD_CHAPV_9_OCH_N1_79 = 78,
	KIWI_BISID_PUSK_AVR_VNESH_N1_80 = 79,
	KIWI_BISID_AVR_GOTOVNOST_N1_81 = 80,
	KIWI_BISID_VYVOD_AVR_N1_82 = 81,
	KIWI_BISID_ZAPRET_AVR_VNESH_N1_83 = 82,
	KIWI_BISID_OU_VKLUCHIT_N1_84 = 83,
	KIWI_BISID_OU_OTKLUCHIT_N1_85 = 84,
	KIWI_BISID_DU_N1_86 = 85,
	KIWI_BISID_VYVOD_AUV_N1_87 = 86,
	KIWI_BISID_VKL_SV_PO_AVR_N1_88 = 87,
	KIWI_BISID_VNESHNIJ_VKL_N1_89 = 88,
	KIWI_BISID_BLOK_VKLUCHENIA_N1_90 = 89,
	KIWI_BISID_DT_EV_N1_91 = 90,
	KIWI_BISID_DZSH_NA_OTKL_N1_92 = 91,
	KIWI_BISID_OTKL_OT_UROV_N1_93 = 92,
	KIWI_BISID_OTKL_SV_PO_VNR_N1_94 = 93,
	KIWI_BISID_VNESHNIJ_OTKL_N1_95 = 94,
	KIWI_BISID_VNESH_ZASHCH_N1_96 = 95,
	KIWI_BISID_DT_EO_1_N1_97 = 96,
	KIWI_BISID_DT_EO_2_N1_98 = 97,
	KIWI_BISID_REZHIM_APVL_1_N1_99 = 98,
	KIWI_BISID_REZHIM_APVL_2_N1_100 = 99,
	KIWI_BISID_PUSK_APVSH_VNESH_N1_101 = 100,
	KIWI_BISID_REZHIM_APVSH_1_N1_102 = 101,
	KIWI_BISID_REZHIM_APVSH_2_N1_103 = 102,
	KIWI_BISID_VYVOD_APV_N1_104 = 103,
	KIWI_BISID_PUSK_APV_VNESH_N1_105 = 104,
	KIWI_BISID_AV_SHP_N1_106 = 105,
	KIWI_BISID_PRUZHINA_N1_107 = 106,
	KIWI_BISID_T_POLUSOV_N1_108 = 107,
	KIWI_BISID_RPV_2_N1_109 = 108,
	KIWI_BISID_RPV_VV_N1_110 = 109,
	KIWI_BISID_RPV_SV_N1_111 = 110,
	KIWI_BISID_AV_TNSH_OTKL_N1_112 = 111,
	KIWI_BISID_PROGRAMMA_2_N1_113 = 112,
	KIWI_BISID_PROGRAMMA_1_N1_114 = 113,
	KIWI_BISID_NA_AVAR_SIGN_N1_115 = 114,
	KIWI_BISID_NA_PRED_SIGN_N1_116 = 115,
	KIWI_BISID_SJEM_SIGNALIZACII_DV_N1_117 = 116,
	KIWI_BISID_PUSK_OSC_N1_118 = 117,

	KIWI_BISID_OMP_PUSK_N100_1 = 118,
	KIWI_BISID_PUSK_OSC_IMP_REZHIM_N100_2 = 119,

	KIWI_BISID_SBROS_TM_ASU_N101_1 = 120,
	KIWI_BISID_SBROS_OKP_ASU_N101_2 = 121,
	KIWI_BISID_SBROS_ACHR_ASU_N101_3 = 122,
	KIWI_BISID_OU_VKLUCHIT_ASU_N101_4 = 123,
	KIWI_BISID_OU_OTKLUCHIT_ASU_N101_5 = 124,
	KIWI_BISID_PROGRAMMA_2_ASU_N101_6 = 125,
	KIWI_BISID_PROGRAMMA_1_ASU_N101_7 = 126,
	KIWI_BISID_SJEM_SIGNALIZACII_ASU_N101_8 = 127,
	KIWI_BISID_PUSK_OSC_ASU_N101_9 = 128,
	KIWI_BISID_REZHIM_NALADKI_ASU_N101_10 = 129,
	KIWI_BISID_REZHIM_FKIK_ASU_N101_11 = 130,

	KIWI_BISID_SBROS_TM_PU_N102_1 = 131,
	KIWI_BISID_SBROS_OKP_PU_N102_2 = 132,
	KIWI_BISID_SBROS_ACHR_PU_N102_3 = 133,
	KIWI_BISID_OU_VKLUCHIT_PU_N102_4 = 134,
	KIWI_BISID_OU_OTKLUCHIT_PU_N102_5 = 135,
	KIWI_BISID_PROGRAMMA_2_PU_N102_6 = 136,
	KIWI_BISID_PROGRAMMA_1_PU_N102_7 = 137,
	KIWI_BISID_SJEM_SIGNALIZACII_PU_N102_8 = 138,
	KIWI_BISID_PUSK_OSC_PU_N102_9 = 139,
	KIWI_BISID_REZHIM_NALADKI_PU_N102_10 = 140,
	KIWI_BISID_REZHIM_FKIK_PU_N102_11 = 141,

	KIWI_BISID_SBROS_TM_KIWI_N103_1 = 142,
	KIWI_BISID_SBROS_OKP_KIWI_N103_2 = 143,
	KIWI_BISID_SBROS_ACHR_KIWI_N103_3 = 144,
	KIWI_BISID_OU_VKLUCHIT_KIWI_N103_4 = 145,
	KIWI_BISID_OU_OTKLUCHIT_KIWI_N103_5 = 146,
	KIWI_BISID_PROGRAMMA_2_KIWI_N103_6 = 147,
	KIWI_BISID_PROGRAMMA_1_KIWI_N103_7 = 148,
	KIWI_BISID_SJEM_SIGNALIZACII_KIWI_N103_8 = 149,
	KIWI_BISID_PUSK_OSC_KIWI_N103_9 = 150,
	KIWI_BISID_REZHIM_NALADKI_KIWI_N103_10 = 151,
	KIWI_BISID_REZHIM_FKIK_KIWI_N103_11 = 152,

	KIWI_BISID_INVALID_SIGNAL = KIWI_INVALID_ID
} kiwi_BinaryInputSignalID;
/*-----------------------------------------------------------------------------------------------*/
/** @brief Тип идентификатора двоичного выходного сигнала. */
typedef enum kiwi_BinaryOutputSignalID_TAG
{
	KIWI_BOSID_NALICHIE_TOKA_N1_1 = 0,
	KIWI_BOSID_USH_NET_N1_2 = 1,
	KIWI_BOSID_USH_NET_UVST_EST_N1_3 = 2,
	KIWI_BOSID_USH_EST_N1_4 = 3,
	KIWI_BOSID_USH_EST_UVST_NET_N1_5 = 4,
	KIWI_BOSID_UVST_NET_N1_6 = 5,
	KIWI_BOSID_USH_EST_UVST_EST_N1_7 = 6,
	KIWI_BOSID_UVST_EST_N1_8 = 7,
	KIWI_BOSID_3U0_EST_N1_9 = 8,
	KIWI_BOSID_3U0_NA_SIGN_N1_10 = 9,
	KIWI_BOSID_USH_UVST_SINHRONNY_N1_11 = 10,
	KIWI_BOSID_U2_EST_N1_12 = 11,
	KIWI_BOSID_F_EST_N1_13 = 12,
	KIWI_BOSID_RNM_A_PRIAMOE_N1_14 = 13,
	KIWI_BOSID_RNM_A_OBRATNOE_N1_15 = 14,
	KIWI_BOSID_RNM_B_PRIAMOE_N1_16 = 15,
	KIWI_BOSID_RNM_B_OBRATNOE_N1_17 = 16,
	KIWI_BOSID_RNM_C_PRIAMOE_N1_18 = 17,
	KIWI_BOSID_RNM_C_OBRATNOE_N1_19 = 18,
	KIWI_BOSID_RNM_PRIAMOE_N1_20 = 19,
	KIWI_BOSID_RNM_OBRATNOE_N1_21 = 20,
	KIWI_BOSID_VMB_SRAB_N1_22 = 21,
	KIWI_BOSID_BLOK_ACHR_CHAPV_PO_U_N1_23 = 194,
	KIWI_BOSID_BK_SRAB_N3_1 = 22,
	KIWI_BOSID_DZ_1_AB_N4_1 = 23,
	KIWI_BOSID_DZ_1_BC_N4_2 = 24,
	KIWI_BOSID_DZ_1_CA_N4_3 = 25,
	KIWI_BOSID_DZ_2_AB_N4_4 = 26,
	KIWI_BOSID_DZ_2_BC_N4_5 = 27,
	KIWI_BOSID_DZ_2_CA_N4_6 = 28,
	KIWI_BOSID_DZ_3_AB_N4_7 = 29,
	KIWI_BOSID_DZ_3_BC_N4_8 = 30,
	KIWI_BOSID_DZ_3_CA_N4_9 = 31,
	KIWI_BOSID_DZ_4_AB_N4_10 = 32,
	KIWI_BOSID_DZ_4_BC_N4_11 = 33,
	KIWI_BOSID_DZ_4_CA_N4_12 = 34,
	KIWI_BOSID_DZ_1_N4_13 = 35,
	KIWI_BOSID_DZ_2_N4_14 = 36,
	KIWI_BOSID_DZ_3_N4_15 = 37,
	KIWI_BOSID_DZ_4_N4_16 = 38,
	KIWI_BOSID_DZ_1_PUSK_N4_17 = 39,
	KIWI_BOSID_DZ_2_PUSK_N4_18 = 40,
	KIWI_BOSID_DZ_3_PUSK_N4_19 = 41,
	KIWI_BOSID_DZ_4_PUSK_N4_20 = 42,
	KIWI_BOSID_DZ_PUSK_N4_21 = 43,
	KIWI_BOSID_DZ_1_SRAB_N4_22 = 44,
	KIWI_BOSID_DZ_2_SRAB_N4_23 = 45,
	KIWI_BOSID_DZ_3_SRAB_N4_24 = 46,
	KIWI_BOSID_DZ_4_SRAB_N4_25 = 47,
	KIWI_BOSID_UDZ_SRAB_N4_26 = 48,
	KIWI_BOSID_DZ_NA_OTKL_N4_27 = 49,
	KIWI_BOSID_DZDV_1_A_N5_1 = 50,
	KIWI_BOSID_DZDV_1_B_N5_2 = 51,
	KIWI_BOSID_DZDV_1_C_N5_3 = 52,
	KIWI_BOSID_DZDV_2_A_N5_4 = 53,
	KIWI_BOSID_DZDV_2_B_N5_5 = 54,
	KIWI_BOSID_DZDV_2_C_N5_6 = 55,
	KIWI_BOSID_DZDV_3_A_N5_7 = 56,
	KIWI_BOSID_DZDV_3_B_N5_8 = 57,
	KIWI_BOSID_DZDV_3_C_N5_9 = 58,
	KIWI_BOSID_DZDV_4_A_N5_10 = 59,
	KIWI_BOSID_DZDV_4_B_N5_11 = 60,
	KIWI_BOSID_DZDV_4_C_N5_12 = 61,
	KIWI_BOSID_DZDV_1_N5_13 = 62,
	KIWI_BOSID_DZDV_2_N5_14 = 63,
	KIWI_BOSID_DZDV_3_N5_15 = 64,
	KIWI_BOSID_DZDV_4_N5_16 = 65,
	KIWI_BOSID_DZDV_1_PUSK_N5_17 = 66,
	KIWI_BOSID_DZDV_2_PUSK_N5_18 = 67,
	KIWI_BOSID_DZDV_3_PUSK_N5_19 = 68,
	KIWI_BOSID_DZDV_4_PUSK_N5_20 = 69,
	KIWI_BOSID_DZDV_PUSK_N5_21 = 70,
	KIWI_BOSID_DZDV_1_SRAB_N5_22 = 71,
	KIWI_BOSID_DZDV_2_SRAB_N5_23 = 72,
	KIWI_BOSID_DZDV_3_SRAB_N5_24 = 73,
	KIWI_BOSID_DZDV_4_SRAB_N5_25 = 74,
	KIWI_BOSID_UDZDV_SRAB_N5_26 = 75,
	KIWI_BOSID_DZDV_NA_OTKL_N5_27 = 76,
	KIWI_BOSID_3I0_PUSK_N5_28 = 77,
	KIWI_BOSID_TO_1_A_PUSK_N7_1 = 78,
	KIWI_BOSID_TO_1_B_PUSK_N7_2 = 79,
	KIWI_BOSID_TO_1_C_PUSK_N7_3 = 80,
	KIWI_BOSID_TO_1_PUSK_N7_4 = 81,
	KIWI_BOSID_TO_1_SRAB_N7_5 = 82,
	KIWI_BOSID_TO_2_A_PUSK_N7_6 = 83,
	KIWI_BOSID_TO_2_B_PUSK_N7_7 = 84,
	KIWI_BOSID_TO_2_C_PUSK_N7_8 = 85,
	KIWI_BOSID_TO_2_PUSK_N7_9 = 86,
	KIWI_BOSID_TO_2_SRAB_N7_10 = 87,
	KIWI_BOSID_TO_PUSK_N7_11 = 88,
	KIWI_BOSID_TO_NA_OTKL_N7_12 = 89,
	KIWI_BOSID_MTZ_1_A_PUSK_N8_1 = 90,
	KIWI_BOSID_MTZ_1_B_PUSK_N8_2 = 91,
	KIWI_BOSID_MTZ_1_C_PUSK_N8_3 = 92,
	KIWI_BOSID_MTZ_1_PUSK_N8_4 = 93,
	KIWI_BOSID_MTZ_1_SRAB_N8_5 = 94,
	KIWI_BOSID_UMTZ_1_SRAB_N8_6 = 95,
	KIWI_BOSID_MTZ_1_NA_OTKL_N8_7 = 96,
	KIWI_BOSID_MTZ_2_A_PUSK_N9_1 = 97,
	KIWI_BOSID_MTZ_2_B_PUSK_N9_2 = 98,
	KIWI_BOSID_MTZ_2_C_PUSK_N9_3 = 99,
	KIWI_BOSID_MTZ_2_PUSK_N9_4 = 100,
	KIWI_BOSID_MTZ_2_SRAB_N9_5 = 101,
	KIWI_BOSID_UMTZ_2_SRAB_N9_6 = 102,
	KIWI_BOSID_MTZ_2_NA_OTKL_N9_7 = 103,
	KIWI_BOSID_PEREGRUZKA_PUSK_N10_1 = 104,
	KIWI_BOSID_PEREGRUZKA_N10_2 = 105,
	KIWI_BOSID_PEREGRUZKA_NA_OTKL_N10_3 = 106,
	KIWI_BOSID_RAZGRUZKA_1_N10_4 = 107,
	KIWI_BOSID_RAZGRUZKA_2_N10_5 = 108,
	KIWI_BOSID_LZSH_1_DATCHIK_N11_1 = 109,
	KIWI_BOSID_LZSH_2_DATCHIK_N11_2 = 110,
	KIWI_BOSID_LZSH_PUSK_N11_3 = 111,
	KIWI_BOSID_LZSH_NA_OTKL_N11_4 = 112,
	KIWI_BOSID_LZSH_1_NEISPR_N11_5 = 113,
	KIWI_BOSID_LZSH_2_NEISPR_N11_6 = 114,
	KIWI_BOSID_ZDZ_PUSK_PO_I_N12_1 = 115,
	KIWI_BOSID_ZDZ_PUSK_PO_3I0_N12_2 = 116,
	KIWI_BOSID_ZDZ_NA_OTKL_N12_3 = 117,
	KIWI_BOSID_ZDZ_NEISPR_N12_4 = 118,
	KIWI_BOSID_ZOF_PUSK_N13_1 = 119,
	KIWI_BOSID_ZOF_NA_SIGN_N13_2 = 120,
	KIWI_BOSID_ZOF_NA_OTKL_N13_3 = 121,
	KIWI_BOSID_OZZ_1_PUSK_N14_1 = 122,
	KIWI_BOSID_OZZ_1_NA_SIGN_N14_2 = 123,
	KIWI_BOSID_OZZ_1_NA_OTKL_N14_3 = 124,
	KIWI_BOSID_OZZ_2_PUSK_N14_4 = 125,
	KIWI_BOSID_OZZ_2_NA_OTKL_N14_5 = 126,
	KIWI_BOSID_ZMN_1_PUSK_N16_1 = 127,
	KIWI_BOSID_ZMN_1_SRAB_N16_2 = 128,
	KIWI_BOSID_ZMN_2_PUSK_N16_3 = 129,
	KIWI_BOSID_ZMN_2_SRAB_N16_4 = 130,
	KIWI_BOSID_ZMN_NA_OTKL_N16_5 = 131,
	KIWI_BOSID_ZPP_PUSK_N17_1 = 132,
	KIWI_BOSID_ZPP_SRAB_N17_2 = 133,
	KIWI_BOSID_ZPP_NA_OTKL_N17_3 = 134,
	KIWI_BOSID_ZPN_1_PUSK_N18_1 = 135,
	KIWI_BOSID_ZPN_1_SRAB_N18_2 = 136,
	KIWI_BOSID_ZPN_2_PUSK_N18_3 = 137,
	KIWI_BOSID_ZPN_2_SRAB_N18_4 = 138,
	KIWI_BOSID_ZPN_NA_OTKL_N18_5 = 139,
	KIWI_BOSID_ZPN_NA_BLOK_VKL_N18_6 = 140,
	KIWI_BOSID_ZPN_NA_PUSK_APV_N18_7 = 141,
	KIWI_BOSID_DTO_A_SRAB_N20_1 = 142,
	KIWI_BOSID_DTO_B_SRAB_N20_2 = 143,
	KIWI_BOSID_DTO_C_SRAB_N20_3 = 144,
	KIWI_BOSID_DTO_NA_OTKL_N20_4 = 145,
	KIWI_BOSID_DZT_A_PUSK_N20_5 = 146,
	KIWI_BOSID_DZT_B_PUSK_N20_6 = 147,
	KIWI_BOSID_DZT_C_PUSK_N20_7 = 148,
	KIWI_BOSID_DZT_PUSK_N20_8 = 149,
	KIWI_BOSID_DZT_A_SRAB_N20_9 = 150,
	KIWI_BOSID_DZT_B_SRAB_N20_10 = 151,
	KIWI_BOSID_DZT_C_SRAB_N20_11 = 152,
	KIWI_BOSID_DZT_NA_OTKL_N20_12 = 153,
	KIWI_BOSID_IPB_DZT_A_N20_13 = 154,
	KIWI_BOSID_IPB_DZT_B_N20_14 = 155,
	KIWI_BOSID_IPB_DZT_C_N20_15 = 156,
	KIWI_BOSID_ZZP_PUSK_N21_1 = 157,
	KIWI_BOSID_ZZP_NA_SIGN_N21_2 = 158,
	KIWI_BOSID_ZZP_NA_OTKL_N21_3 = 159,
	KIWI_BOSID_ZBR_PUSK_N21_4 = 160,
	KIWI_BOSID_ZBR_NA_SIGN_N21_5 = 161,
	KIWI_BOSID_ZBR_NA_OTKL_N21_6 = 162,
	KIWI_BOSID_TIAZHELYJ_PUSK_N22_1 = 163,
	KIWI_BOSID_ZAPRET_PUSKA_N22_2 = 164,
	KIWI_BOSID_TM_1_NA_SIGN_N22_3 = 165,
	KIWI_BOSID_TM_2_NA_SIGN_N22_4 = 166,
	KIWI_BOSID_TM_2_NA_OTKL_N22_5 = 167,
	KIWI_BOSID_PUSK_DVIGATELIA_N22_6 = 518,
	KIWI_BOSID_MIN_TZ_PUSK_N23_1 = 168,
	KIWI_BOSID_MIN_TZ_NA_SIGN_N23_2 = 169,
	KIWI_BOSID_MIN_TZ_NA_OTKL_N23_3 = 170,
	KIWI_BOSID_ZAR_PUSK_N24_1 = 171,
	KIWI_BOSID_ZAR_NA_SIGN_N24_2 = 172,
	KIWI_BOSID_ZAR_NA_OTKL_N24_3 = 173,
	KIWI_BOSID_VZ_SP_N25_1 = 174,
	KIWI_BOSID_VZ_VOZD_OHL_N25_2 = 175,
	KIWI_BOSID_VZ_VOD_OHL_N25_3 = 176,
	KIWI_BOSID_VZ_NA_OTKL_N25_4 = 177,
	KIWI_BOSID_VS_VOD_OHL_N25_5 = 178,
	KIWI_BOSID_VS_VODA_V_KORP_N25_6 = 179,
	KIWI_BOSID_OKP_DLIT_N26_1 = 180,
	KIWI_BOSID_OKP_MP_N26_2 = 181,
	KIWI_BOSID_OKP_GP_N26_3 = 182,
	KIWI_BOSID_OKP_HP_N26_4 = 183,
	KIWI_BOSID_OKP_ZAPRET_PUSKA_N26_5 = 184,
	KIWI_BOSID_PT_SF6_BLOK_N28_1 = 185,
	KIWI_BOSID_SF6_Q_NA_OTKL_N28_2 = 186,
	KIWI_BOSID_BLOK_OTKL_PO_SF6_N28_3 = 187,
	KIWI_BOSID_POTERIA_SF6_Q_N28_4 = 188,
	KIWI_BOSID_POTERIA_SF6_TT_N28_5 = 189,
	KIWI_BOSID_SF6_TT_NA_OTKL_N28_6 = 190,
	KIWI_BOSID_UROV_SRAB_N29_1 = 191,
	KIWI_BOSID_RT_UROV_N29_2 = 192,
	KIWI_BOSID_ACHR_RAZRESHENIE_N31_1 = 193,
	KIWI_BOSID_ACHR_GOTOVNOST_N31_2 = 195,
	KIWI_BOSID_ACHR_1_PUSK_N31_3 = 196,
	KIWI_BOSID_ACHR_1_SRAB_N31_4 = 197,
	KIWI_BOSID_ACHR_2_PUSK_N31_5 = 198,
	KIWI_BOSID_ACHR_2_SRAB_N31_6 = 199,
	KIWI_BOSID_DAR_PUSK_N31_7 = 200,
	KIWI_BOSID_DAR_SRAB_N31_8 = 201,
	KIWI_BOSID_ACHR_DV_PUSK_N31_9 = 202,
	KIWI_BOSID_ACHR_DV_SRAB_N31_10 = 203,
	KIWI_BOSID_ACHR_PUSK_N31_11 = 204,
	KIWI_BOSID_ACHR_NA_OTKL_N31_12 = 205,
	KIWI_BOSID_CHAPV_RAZRESHENIE_N32_1 = 206,
	KIWI_BOSID_CHAPV_GOTOVNOST_N32_2 = 207,
	KIWI_BOSID_K_CHAPV_NE_GOTOV_N32_3 = 208,
	KIWI_BOSID_CHAPV_F_PUSK_N32_4 = 209,
	KIWI_BOSID_CHAPV_F_SRAB_N32_5 = 210,
	KIWI_BOSID_CHAPV_DV_PUSK_N32_6 = 211,
	KIWI_BOSID_CHAPV_DV_SRAB_N32_7 = 212,
	KIWI_BOSID_CHAPV_PUSK_N32_8 = 213,
	KIWI_BOSID_CHAPV_NA_VKL_N32_9 = 214,
	KIWI_BOSID_ACHR_RAZRESHENIE_1_OCH_N33_1 = 215,
	KIWI_BOSID_ACHR_1_PUSK_1_OCH_N33_2 = 216,
	KIWI_BOSID_ACHR_1_SRAB_1_OCH_N33_3 = 217,
	KIWI_BOSID_ACHR_2_PUSK_1_OCH_N33_4 = 218,
	KIWI_BOSID_ACHR_2_SRAB_1_OCH_N33_5 = 219,
	KIWI_BOSID_DAR_PUSK_1_OCH_N33_6 = 220,
	KIWI_BOSID_DAR_SRAB_1_OCH_N33_7 = 221,
	KIWI_BOSID_ACHR_PUSK_1_OCH_N33_8 = 222,
	KIWI_BOSID_ACHR_SRAB_1_OCH_N33_9 = 223,
	KIWI_BOSID_ACHR_RAZRESHENIE_2_OCH_N33_10 = 224,
	KIWI_BOSID_ACHR_1_PUSK_2_OCH_N33_11 = 225,
	KIWI_BOSID_ACHR_1_SRAB_2_OCH_N33_12 = 226,
	KIWI_BOSID_ACHR_2_PUSK_2_OCH_N33_13 = 227,
	KIWI_BOSID_ACHR_2_SRAB_2_OCH_N33_14 = 228,
	KIWI_BOSID_DAR_PUSK_2_OCH_N33_15 = 229,
	KIWI_BOSID_DAR_SRAB_2_OCH_N33_16 = 230,
	KIWI_BOSID_ACHR_PUSK_2_OCH_N33_17 = 231,
	KIWI_BOSID_ACHR_SRAB_2_OCH_N33_18 = 232,
	KIWI_BOSID_ACHR_RAZRESHENIE_3_OCH_N33_19 = 233,
	KIWI_BOSID_ACHR_1_PUSK_3_OCH_N33_20 = 234,
	KIWI_BOSID_ACHR_1_SRAB_3_OCH_N33_21 = 235,
	KIWI_BOSID_ACHR_2_PUSK_3_OCH_N33_22 = 236,
	KIWI_BOSID_ACHR_2_SRAB_3_OCH_N33_23 = 237,
	KIWI_BOSID_DAR_PUSK_3_OCH_N33_24 = 238,
	KIWI_BOSID_DAR_SRAB_3_OCH_N33_25 = 239,
	KIWI_BOSID_ACHR_PUSK_3_OCH_N33_26 = 240,
	KIWI_BOSID_ACHR_SRAB_3_OCH_N33_27 = 241,
	KIWI_BOSID_ACHR_RAZRESHENIE_4_OCH_N33_28 = 242,
	KIWI_BOSID_ACHR_1_PUSK_4_OCH_N33_29 = 243,
	KIWI_BOSID_ACHR_1_SRAB_4_OCH_N33_30 = 244,
	KIWI_BOSID_ACHR_2_PUSK_4_OCH_N33_31 = 245,
	KIWI_BOSID_ACHR_2_SRAB_4_OCH_N33_32 = 246,
	KIWI_BOSID_DAR_PUSK_4_OCH_N33_33 = 247,
	KIWI_BOSID_DAR_SRAB_4_OCH_N33_34 = 248,
	KIWI_BOSID_ACHR_PUSK_4_OCH_N33_35 = 249,
	KIWI_BOSID_ACHR_SRAB_4_OCH_N33_36 = 250,
	KIWI_BOSID_ACHR_RAZRESHENIE_5_OCH_N33_37 = 251,
	KIWI_BOSID_ACHR_1_PUSK_5_OCH_N33_38 = 252,
	KIWI_BOSID_ACHR_1_SRAB_5_OCH_N33_39 = 253,
	KIWI_BOSID_ACHR_2_PUSK_5_OCH_N33_40 = 254,
	KIWI_BOSID_ACHR_2_SRAB_5_OCH_N33_41 = 255,
	KIWI_BOSID_DAR_PUSK_5_OCH_N33_42 = 256,
	KIWI_BOSID_DAR_SRAB_5_OCH_N33_43 = 257,
	KIWI_BOSID_ACHR_PUSK_5_OCH_N33_44 = 258,
	KIWI_BOSID_ACHR_SRAB_5_OCH_N33_45 = 259,
	KIWI_BOSID_ACHR_RAZRESHENIE_6_OCH_N33_46 = 260,
	KIWI_BOSID_ACHR_1_PUSK_6_OCH_N33_47 = 261,
	KIWI_BOSID_ACHR_1_SRAB_6_OCH_N33_48 = 262,
	KIWI_BOSID_ACHR_2_PUSK_6_OCH_N33_49 = 263,
	KIWI_BOSID_ACHR_2_SRAB_6_OCH_N33_50 = 264,
	KIWI_BOSID_DAR_PUSK_6_OCH_N33_51 = 265,
	KIWI_BOSID_DAR_SRAB_6_OCH_N33_52 = 266,
	KIWI_BOSID_ACHR_PUSK_6_OCH_N33_53 = 267,
	KIWI_BOSID_ACHR_SRAB_6_OCH_N33_54 = 268,
	KIWI_BOSID_ACHR_RAZRESHENIE_7_OCH_N33_55 = 269,
	KIWI_BOSID_ACHR_1_PUSK_7_OCH_N33_56 = 270,
	KIWI_BOSID_ACHR_1_SRAB_7_OCH_N33_57 = 271,
	KIWI_BOSID_ACHR_2_PUSK_7_OCH_N33_58 = 272,
	KIWI_BOSID_ACHR_2_SRAB_7_OCH_N33_59 = 273,
	KIWI_BOSID_DAR_PUSK_7_OCH_N33_60 = 274,
	KIWI_BOSID_DAR_SRAB_7_OCH_N33_61 = 275,
	KIWI_BOSID_ACHR_PUSK_7_OCH_N33_62 = 276,
	KIWI_BOSID_ACHR_SRAB_7_OCH_N33_63 = 277,
	KIWI_BOSID_ACHR_RAZRESHENIE_8_OCH_N33_64 = 278,
	KIWI_BOSID_ACHR_1_PUSK_8_OCH_N33_65 = 279,
	KIWI_BOSID_ACHR_1_SRAB_8_OCH_N33_66 = 280,
	KIWI_BOSID_ACHR_2_PUSK_8_OCH_N33_67 = 281,
	KIWI_BOSID_ACHR_2_SRAB_8_OCH_N33_68 = 282,
	KIWI_BOSID_DAR_PUSK_8_OCH_N33_69 = 283,
	KIWI_BOSID_DAR_SRAB_8_OCH_N33_70 = 284,
	KIWI_BOSID_ACHR_PUSK_8_OCH_N33_71 = 285,
	KIWI_BOSID_ACHR_SRAB_8_OCH_N33_72 = 286,
	KIWI_BOSID_ACHR_RAZRESHENIE_9_OCH_N33_73 = 287,
	KIWI_BOSID_ACHR_1_PUSK_9_OCH_N33_74 = 288,
	KIWI_BOSID_ACHR_1_SRAB_9_OCH_N33_75 = 289,
	KIWI_BOSID_ACHR_2_PUSK_9_OCH_N33_76 = 290,
	KIWI_BOSID_ACHR_2_SRAB_9_OCH_N33_77 = 291,
	KIWI_BOSID_DAR_PUSK_9_OCH_N33_78 = 292,
	KIWI_BOSID_DAR_SRAB_9_OCH_N33_79 = 293,
	KIWI_BOSID_ACHR_PUSK_9_OCH_N33_80 = 294,
	KIWI_BOSID_ACHR_SRAB_9_OCH_N33_81 = 295,
	KIWI_BOSID_CHAPV_SRAB_1_OCH_N34_1 = 296,
	KIWI_BOSID_CHAPV_PUSK_1_OCH_N34_2 = 297,
	KIWI_BOSID_CHAPV_RAZRESHENIE_1_OCH_N34_3 = 298,
	KIWI_BOSID_CHAPV_SRAB_2_OCH_N34_4 = 299,
	KIWI_BOSID_CHAPV_PUSK_2_OCH_N34_5 = 300,
	KIWI_BOSID_CHAPV_RAZRESHENIE_2_OCH_N34_6 = 301,
	KIWI_BOSID_CHAPV_SRAB_3_OCH_N34_7 = 302,
	KIWI_BOSID_CHAPV_PUSK_3_OCH_N34_8 = 303,
	KIWI_BOSID_CHAPV_RAZRESHENIE_3_OCH_N34_9 = 304,
	KIWI_BOSID_CHAPV_SRAB_4_OCH_N34_10 = 305,
	KIWI_BOSID_CHAPV_PUSK_4_OCH_N34_11 = 306,
	KIWI_BOSID_CHAPV_RAZRESHENIE_4_OCH_N34_12 = 307,
	KIWI_BOSID_CHAPV_SRAB_5_OCH_N34_13 = 308,
	KIWI_BOSID_CHAPV_PUSK_5_OCH_N34_14 = 309,
	KIWI_BOSID_CHAPV_RAZRESHENIE_5_OCH_N34_15 = 310,
	KIWI_BOSID_CHAPV_SRAB_6_OCH_N34_16 = 311,
	KIWI_BOSID_CHAPV_PUSK_6_OCH_N34_17 = 312,
	KIWI_BOSID_CHAPV_RAZRESHENIE_6_OCH_N34_18 = 313,
	KIWI_BOSID_CHAPV_SRAB_7_OCH_N34_19 = 314,
	KIWI_BOSID_CHAPV_PUSK_7_OCH_N34_20 = 315,
	KIWI_BOSID_CHAPV_RAZRESHENIE_7_OCH_N34_21 = 316,
	KIWI_BOSID_CHAPV_SRAB_8_OCH_N34_22 = 317,
	KIWI_BOSID_CHAPV_PUSK_8_OCH_N34_23 = 318,
	KIWI_BOSID_CHAPV_RAZRESHENIE_8_OCH_N34_24 = 319,
	KIWI_BOSID_CHAPV_SRAB_9_OCH_N34_25 = 320,
	KIWI_BOSID_CHAPV_PUSK_9_OCH_N34_26 = 321,
	KIWI_BOSID_CHAPV_RAZRESHENIE_9_OCH_N34_27 = 322,
	KIWI_BOSID_AVR_PUSK_N36_1 = 323,
	KIWI_BOSID_RABOTA_AVR_N36_2 = 324,
	KIWI_BOSID_AVR_NA_OTKL_VV_N36_3 = 325,
	KIWI_BOSID_AVR_NA_VKL_SV_N36_4 = 326,
	KIWI_BOSID_AVR_VNR_BLOK_N36_5 = 327,
	KIWI_BOSID_GOTOV_K_AVR_N36_6 = 328,
	KIWI_BOSID_VNR_GOTOVNOST_N37_1 = 329,
	KIWI_BOSID_VNR_PUSK_N37_2 = 330,
	KIWI_BOSID_RABOTA_VNR_N37_3 = 331,
	KIWI_BOSID_VNR_NA_VKL_VV_N37_4 = 332,
	KIWI_BOSID_VNR_NA_OTKL_SV_N37_5 = 333,
	KIWI_BOSID_VNR_NEUSPESHNOE_N37_6 = 334,
	KIWI_BOSID_VNR_USPESHNOE_N37_7 = 335,
	KIWI_BOSID_OPERATIVNOE_VKL_N39_1 = 336,
	KIWI_BOSID_OPERATIVNOE_OTKL_N39_2 = 337,
	KIWI_BOSID_UPR_PO_DV_N39_3 = 338,
	KIWI_BOSID_UPR_PO_ASU_N39_4 = 339,
	KIWI_BOSID_UPR_S_PU_N39_5 = 340,
	KIWI_BOSID_AUV_VYVEDENA_N39_6 = 341,
	KIWI_BOSID_VKLUCHIT_N40_1 = 342,
	KIWI_BOSID_VKL_LOG_N40_2 = 343,
	KIWI_BOSID_VKL_NEUSPESHN_N40_3 = 344,
	KIWI_BOSID_VKL_BLOKIROVANO_N40_4 = 345,
	KIWI_BOSID_VKLUCHENIE_S_KS_N40_5 = 346,
	KIWI_BOSID_VKL_S_KS_NEUSPESHN_N40_6 = 347,
	KIWI_BOSID_OTKLUCHIT_N41_1 = 348,
	KIWI_BOSID_PUSK_UROV_OT_ZASHCH_N41_2 = 349,
	KIWI_BOSID_ZAPRET_AVR_OT_ZASHCH_N41_3 = 350,
	KIWI_BOSID_OTKL_LOG_N41_4 = 351,
	KIWI_BOSID_ZASHCH_EV_EO_1_N41_5 = 352,
	KIWI_BOSID_ZASHCH_EO_2_N41_6 = 353,
	KIWI_BOSID_DT_EO_N41_7 = 354,
	KIWI_BOSID_BLOK_OPER_VKL_N41_8 = 355,
	KIWI_BOSID_AVARIJNOE_OTKL_N42_1 = 356,
	KIWI_BOSID_NS_N42_2 = 357,
	KIWI_BOSID_APVL_RAZRESHENIE_N43_1 = 358,
	KIWI_BOSID_PUSK_APVSH_N43_2 = 359,
	KIWI_BOSID_APVSH_RAZRESHENIE_N43_3 = 360,
	KIWI_BOSID_APV_GOTOVNOST_N43_4 = 361,
	KIWI_BOSID_APV_START_N44_1 = 362,
	KIWI_BOSID_APV_1_PUSK_N44_2 = 363,
	KIWI_BOSID_RABOTA_APV_1_N44_3 = 364,
	KIWI_BOSID_APV_2_PUSK_N44_4 = 365,
	KIWI_BOSID_RABOTA_APV_2_N44_5 = 366,
	KIWI_BOSID_APV_NA_VKL_N44_6 = 367,
	KIWI_BOSID_APV_1_NEUSPESHNOE_N44_7 = 368,
	KIWI_BOSID_APV_1_USPESHNOE_N44_8 = 369,
	KIWI_BOSID_APV_2_NEUSPESHNOE_N44_9 = 370,
	KIWI_BOSID_APV_2_USPESHNOE_N44_10 = 371,
	KIWI_BOSID_NEISPR_VYKL_N46_1 = 372,
	KIWI_BOSID_AVARIA_SHP_N46_2 = 373,
	KIWI_BOSID_PRUZH_NE_ZAVEDENA_N46_3 = 374,
	KIWI_BOSID_NIZKAJA_T_POLUSOV_N46_4 = 375,
	KIWI_BOSID_VYKL_NE_GOTOV_N46_5 = 376,
	KIWI_BOSID_VYKL_OTKLUCHEN_N46_6 = 377,
	KIWI_BOSID_VYKL_VKLUCHEN_N46_7 = 378,
	KIWI_BOSID_NEISPR_CU_N46_8 = 379,
	KIWI_BOSID_NEUSPESHN_VKL_N46_9 = 380,
	KIWI_BOSID_NEUSPESHN_OTKL_N46_10 = 381,
	KIWI_BOSID_KCN_SRAB_N47_1 = 382,
	KIWI_BOSID_KCN_NA_SIGN_N47_2 = 383,
	KIWI_BOSID_KCN_PUSK_N47_3 = 384,
	KIWI_BOSID_NB_A_SRAB_N48_1 = 385,
	KIWI_BOSID_NB_B_SRAB_N48_2 = 386,
	KIWI_BOSID_NB_C_SRAB_N48_3 = 387,
	KIWI_BOSID_NB_SRAB_N48_4 = 388,
	KIWI_BOSID_NB_PUSK_N48_5 = 389,
	KIWI_BOSID_KCT_A_SRAB_N48_6 = 390,
	KIWI_BOSID_KCT_B_SRAB_N48_7 = 391,
	KIWI_BOSID_KCT_C_SRAB_N48_8 = 392,
	KIWI_BOSID_KCT_SRAB_N48_9 = 393,
	KIWI_BOSID_PR_USTAVOK_2_N50_1 = 394,
	KIWI_BOSID_PR_USTAVOK_1_N50_2 = 395,
	KIWI_BOSID_PR_UST_PO_DV_N50_3 = 396,
	KIWI_BOSID_PR_UST_IZ_ASU_N50_4 = 397,
	KIWI_BOSID_PR_UST_S_PU_N50_5 = 398,
	KIWI_BOSID_PUSK_ZASHCHIT_N50_6 = 399,
	KIWI_BOSID_BLOK_SMENY_PR_UST_N50_7 = 400,
	KIWI_BOSID_AVARIJNAJA_SIGN_N51_1 = 401,
	KIWI_BOSID_AVARIJA_N51_2 = 402,
	KIWI_BOSID_DZ_1_OTKLUCHENIE_N51_3 = 403,
	KIWI_BOSID_DZ_2_OTKLUCHENIE_N51_4 = 404,
	KIWI_BOSID_DZ_3_OTKLUCHENIE_N51_5 = 405,
	KIWI_BOSID_DZ_4_OTKLUCHENIE_N51_6 = 406,
	KIWI_BOSID_UDZ_OTKLUCHENIE_N51_7 = 407,
	KIWI_BOSID_DZDV_1_OTKLUCHENIE_N51_8 = 408,
	KIWI_BOSID_DZDV_2_OTKLUCHENIE_N51_9 = 409,
	KIWI_BOSID_DZDV_3_OTKLUCHENIE_N51_10 = 410,
	KIWI_BOSID_DZDV_4_OTKLUCHENIE_N51_11 = 411,
	KIWI_BOSID_UDZDV_OTKLUCHENIE_N51_12 = 412,
	KIWI_BOSID_TO_1_OTKLUCHENIE_N51_13 = 413,
	KIWI_BOSID_TO_2_OTKLUCHENIE_N51_14 = 414,
	KIWI_BOSID_MTZ_1_OTKLUCHENIE_N51_15 = 415,
	KIWI_BOSID_UMTZ_1_OTKLUCHENIE_N51_16 = 416,
	KIWI_BOSID_MTZ_2_OTKLUCHENIE_N51_17 = 417,
	KIWI_BOSID_UMTZ_2_OTKLUCHENIE_N51_18 = 418,
	KIWI_BOSID_PEREGRUZKA_OTKL_N51_19 = 419,
	KIWI_BOSID_LZSH_OTKL_N51_20 = 420,
	KIWI_BOSID_ZDZ_OTKLUCHENIE_N51_21 = 421,
	KIWI_BOSID_ZOF_OTKLUCHENIE_N51_22 = 422,
	KIWI_BOSID_OZZ_1_OTKLUCHENIE_N51_23 = 423,
	KIWI_BOSID_OZZ_2_OTKLUCHENIE_N51_24 = 424,
	KIWI_BOSID_ZMN_OTKLUCHENIE_N51_25 = 425,
	KIWI_BOSID_ZPP_OTKLUCHENIE_N51_26 = 426,
	KIWI_BOSID_ZPN_OTKLUCHENIE_N51_27 = 427,
	KIWI_BOSID_DTO_OTKLUCHENIE_N51_28 = 428,
	KIWI_BOSID_DZT_OTKLUCHENIE_N51_29 = 429,
	KIWI_BOSID_ZZP_OTKLUCHENIE_N51_30 = 430,
	KIWI_BOSID_ZBR_OTKLUCHENIE_N51_31 = 431,
	KIWI_BOSID_TM_OTKLUCHENIE_N51_32 = 432,
	KIWI_BOSID_MIN_TZ_OTKLUCHENIE_N51_33 = 433,
	KIWI_BOSID_ZAR_OTKLUCHENIE_N51_34 = 434,
	KIWI_BOSID_VZ_SMAZKA_PODSH_N51_35 = 435,
	KIWI_BOSID_VZ_VOZDUSHN_OHLAZHD_N51_36 = 436,
	KIWI_BOSID_VZ_VODIANOE_OHLAZHD_N51_37 = 437,
	KIWI_BOSID_SF6_Q_OTKLUCHENIE_N51_38 = 438,
	KIWI_BOSID_SF6_TT_OTKLUCHENIE_N51_39 = 439,
	KIWI_BOSID_ACHR_OTKLUCHENIE_N51_40 = 440,
	KIWI_BOSID_VNESH_OTKL_OT_DZSH_N51_41 = 441,
	KIWI_BOSID_VNESH_OTKL_OT_UROV_N51_42 = 442,
	KIWI_BOSID_VNESH_ZASHCHITA_N51_43 = 443,
	KIWI_BOSID_AVAR_SIGN_DOP_N51_44 = 444,
	KIWI_BOSID_PREDUPR_SIGN_N52_1 = 445,
	KIWI_BOSID_3U0_SIGNAL_N52_2 = 446,
	KIWI_BOSID_PEREGRUZKA_SIGNAL_N52_3 = 447,
	KIWI_BOSID_LZSH_1_NEISPRAVNOST_N52_4 = 448,
	KIWI_BOSID_LZSH_2_NEISPRAVNOST_N52_5 = 449,
	KIWI_BOSID_ZDZ_NEISPRAVNOST_N52_6 = 450,
	KIWI_BOSID_ZOF_SIGNAL_N52_7 = 451,
	KIWI_BOSID_OZZ_1_SIGNAL_N52_8 = 452,
	KIWI_BOSID_ZMN_1_SIGNAL_N52_9 = 453,
	KIWI_BOSID_ZMN_2_SIGNAL_N52_10 = 454,
	KIWI_BOSID_ZPP_SIGNAL_N52_11 = 455,
	KIWI_BOSID_ZPN_1_SIGNAL_N52_12 = 456,
	KIWI_BOSID_ZPN_2_SIGNAL_N52_13 = 457,
	KIWI_BOSID_ZZP_SIGNAL_N52_14 = 458,
	KIWI_BOSID_ZBR_SIGNAL_N52_15 = 459,
	KIWI_BOSID_TM_TIAZHELYJ_PUSK_N52_16 = 460,
	KIWI_BOSID_TM_ZAPRET_PUSKA_N52_17 = 461,
	KIWI_BOSID_TM_1_SIGNAL_N52_18 = 462,
	KIWI_BOSID_TM_2_SIGNAL_N52_19 = 463,
	KIWI_BOSID_MIN_TZ_SIGNAL_N52_20 = 464,
	KIWI_BOSID_ZAR_SIGNAL_N52_21 = 465,
	KIWI_BOSID_VS_VODIANOJE_OHLAZHD_N52_22 = 466,
	KIWI_BOSID_VS_VODA_V_KORPUSE_N52_23 = 467,
	KIWI_BOSID_OKP_SIGNAL_N52_24 = 468,
	KIWI_BOSID_UROV_N52_25 = 469,
	KIWI_BOSID_ACHR_1_OCHERED_SRAB_N52_26 = 470,
	KIWI_BOSID_ACHR_2_OCHERED_SRAB_N52_27 = 471,
	KIWI_BOSID_ACHR_3_OCHERED_SRAB_N52_28 = 472,
	KIWI_BOSID_ACHR_4_OCHERED_SRAB_N52_29 = 473,
	KIWI_BOSID_ACHR_5_OCHERED_SRAB_N52_30 = 474,
	KIWI_BOSID_ACHR_6_OCHERED_SRAB_N52_31 = 475,
	KIWI_BOSID_ACHR_7_OCHERED_SRAB_N52_32 = 476,
	KIWI_BOSID_ACHR_8_OCHERED_SRAB_N52_33 = 477,
	KIWI_BOSID_ACHR_9_OCHERED_SRAB_N52_34 = 478,
	KIWI_BOSID_AVR_SRABATYVANIJE_N52_35 = 479,
	KIWI_BOSID_VNR_SRABATYVANIJE_N52_36 = 480,
	KIWI_BOSID_NEUSP_POPYTKA_VNR_N52_37 = 481,
	KIWI_BOSID_NEUSP_POPYTKA_VKL_N52_38 = 482,
	KIWI_BOSID_NEUSP_POPYTKA_VKL_S_KS_N52_39 = 483,
	KIWI_BOSID_OTKL_NA_AV_EV_EO_1_N52_40 = 484,
	KIWI_BOSID_OTKL_NA_AV_EO_2_N52_41 = 485,
	KIWI_BOSID_VYKLUCHATEL_NEISPR_N52_42 = 486,
	KIWI_BOSID_SHP_NEISPR_N52_43 = 487,
	KIWI_BOSID_PRUZHINA_NE_ZAVEDENA_N52_44 = 488,
	KIWI_BOSID_T_POLUSOV_NIZKAJA_N52_45 = 489,
	KIWI_BOSID_CEPI_UPRAVL_NEISPR_N52_46 = 490,
	KIWI_BOSID_VKL_NEUSPESHNOE_N52_47 = 491,
	KIWI_BOSID_OTKL_NEUSPESHNOE_N52_48 = 492,
	KIWI_BOSID_NEISPR_CEPEJ_NAPR_N52_49 = 493,
	KIWI_BOSID_NEBALANS_TOKOV_N52_50 = 494,
	KIWI_BOSID_NEISPR_CEPEJ_TOKA_N52_51 = 495,
	KIWI_BOSID_SF6_Q_SIGNAL_N52_52 = 496,
	KIWI_BOSID_SF6_Q_AVARIA_N52_53 = 497,
	KIWI_BOSID_SF6_TT_SIGNAL_N52_54 = 498,
	KIWI_BOSID_SF6_TT_AVARIA_N52_55 = 499,
	KIWI_BOSID_RESURS_Q_SIGN_N52_56 = 500,
	KIWI_BOSID_QSVERHTOK_N52_57 = 501,
	KIWI_BOSID_PREDUPR_SIGN_DOP_N52_58 = 502,
	KIWI_BOSID_ALTEJ_NEISPRAVEN_N52_59 = 503,
	KIWI_BOSID_SJEM_SIGNALIZACII_N53_1 = 504,

	KIWI_BOSID_PITANIE_OT_SETI_N70_1 = 600,

	KIWI_BOSID_RESURS_Q_SNIZHENIE_N100_1 = 505,
	KIWI_BOSID_Q_OTKL_SVERHTOK_N100_2 = 506,
	KIWI_BOSID_OMP_RASCH_N100_3 = 507,
	KIWI_BOSID_REZHIM_NALADKI_N100_4 = 508,
	KIWI_BOSID_REZHIM_FKIK_N100_5 = 509,
	KIWI_BOSID_NEISPRAVNOST_ALTEJ_N100_6 = 510,
	KIWI_BOSID_OTKAZ_ALTEJ_N100_7 = 511,
	KIWI_BOSID_PUSK_OSC_N100_8 = 512,
	KIWI_BOSID_F_NEDOSTOVERNA_N100_9 = 513,
	KIWI_BOSID_DF_NEDOSTOVERNA_N100_10 = 514,
	KIWI_BOSID_BLOK_PO_F_NED_N100_11 = 515,
	KIWI_BOSID_BLOK_PO_DF_NED_N100_12 = 516,
	KIWI_BOSID_OTKAZ_MVV_DOP_N100_13 = 517,

	KIWI_BOSID_FNED_N200_1 = 708,
	KIWI_BOSID_FRATENED_N200_2 = 709,
	KIWI_BOSID_START_N200_3 = 710,
	KIWI_BOSID_TRANSIENT_N200_4 = 711,

	KIWI_BOSID_INVALID_SIGNAL = KIWI_INVALID_ID
} kiwi_BinaryOutputSignalID;
/*-----------------------------------------------------------------------------------------------*/
/** @brief Тип идентификатора (двоичного) выходного сигнала пускового органа. */
typedef enum kiwi_FaultDetectorBinaryOutputSignalID_TAG
{
	KIWI_BOSID_PO_IMIN_N1_1 = 0,
	KIWI_BOSID_PO_USH_MIN_N1_2 = 1,
	KIWI_BOSID_PO_USH_MAKS_N1_3 = 2,
	KIWI_BOSID_PO_UVST_MIN_N1_4 = 3,
	KIWI_BOSID_PO_UVST_MAKS_N1_5 = 4,
	KIWI_BOSID_PO_3U0_MAKS_1_N1_6 = 5,
	KIWI_BOSID_PO_3U0_MAKS_2_N1_7 = 6,
	KIWI_BOSID_PO_KS_N1_8 = 7,
	KIWI_BOSID_PO_KS_ULAVLIVANIE_N1_9 = 8,
	KIWI_BOSID_PO_KS_BLOK_PO_U_N1_10 = 9,
	KIWI_BOSID_PO_KS_BLOK_PO_F_N1_11 = 10,
	KIWI_BOSID_PO_KS_BLOK_PO_FI_N1_12 = 11,
	KIWI_BOSID_PO_U2_MAKS_N1_13 = 12,
	KIWI_BOSID_PO_FMAKS_N1_14 = 13,
	KIWI_BOSID_PO_UVMB_N1_15 = 14,
	KIWI_BOSID_PO_U2_VMB_N1_16 = 15,
	KIWI_BOSID_PO_RNM_A_N1_17 = 16,
	KIWI_BOSID_PO_RNM_A_NEDOST_N1_18 = 17,
	KIWI_BOSID_PO_RNM_A_PRIAMOE_N1_19 = 18,
	KIWI_BOSID_PO_RNM_A_OBRATNOE_N1_20 = 19,
	KIWI_BOSID_PO_RNM_B_N1_21 = 20,
	KIWI_BOSID_PO_RNM_B_NEDOST_N1_22 = 21,
	KIWI_BOSID_PO_RNM_B_PRIAMOE_N1_23 = 22,
	KIWI_BOSID_PO_RNM_B_OBRATNOE_N1_24 = 23,
	KIWI_BOSID_PO_RNM_C_N1_25 = 24,
	KIWI_BOSID_PO_RNM_C_NEDOST_N1_26 = 25,
	KIWI_BOSID_PO_RNM_C_PRIAMOE_N1_27 = 26,
	KIWI_BOSID_PO_RNM_C_OBRATNOE_N1_28 = 27,
	KIWI_BOSID_PO_UBLOK_N1_29 = 144,
	KIWI_BOSID_PO_KS_GOTOVNOST_N1_30 = 274,
	KIWI_BOSID_PO_I1_BK_N3_1 = 28,
	KIWI_BOSID_PO_I2_BK_N3_2 = 29,
	KIWI_BOSID_PO_ZDZ_1_AB_N4_1 = 30,
	KIWI_BOSID_PO_ZDZ_1_BC_N4_2 = 31,
	KIWI_BOSID_PO_ZDZ_1_CA_N4_3 = 32,
	KIWI_BOSID_PO_ZDZ_2_AB_N4_4 = 33,
	KIWI_BOSID_PO_ZDZ_2_BC_N4_5 = 34,
	KIWI_BOSID_PO_ZDZ_2_CA_N4_6 = 35,
	KIWI_BOSID_PO_ZDZ_3_AB_N4_7 = 36,
	KIWI_BOSID_PO_ZDZ_3_BC_N4_8 = 37,
	KIWI_BOSID_PO_ZDZ_3_CA_N4_9 = 38,
	KIWI_BOSID_PO_ZDZ_4_AB_N4_10 = 39,
	KIWI_BOSID_PO_ZDZ_4_BC_N4_11 = 40,
	KIWI_BOSID_PO_ZDZ_4_CA_N4_12 = 41,
	KIWI_BOSID_PO_ZDZDV_1_A0_N5_1 = 42,
	KIWI_BOSID_PO_ZDZDV_1_B0_N5_2 = 43,
	KIWI_BOSID_PO_ZDZDV_1_C0_N5_3 = 44,
	KIWI_BOSID_PO_ZDZDV_2_A0_N5_4 = 45,
	KIWI_BOSID_PO_ZDZDV_2_B0_N5_5 = 46,
	KIWI_BOSID_PO_ZDZDV_2_C0_N5_6 = 47,
	KIWI_BOSID_PO_ZDZDV_3_A0_N5_7 = 48,
	KIWI_BOSID_PO_ZDZDV_3_B0_N5_8 = 49,
	KIWI_BOSID_PO_ZDZDV_3_C0_N5_9 = 50,
	KIWI_BOSID_PO_ZDZDV_4_A0_N5_10 = 51,
	KIWI_BOSID_PO_ZDZDV_4_B0_N5_11 = 52,
	KIWI_BOSID_PO_ZDZDV_4_C0_N5_12 = 53,
	KIWI_BOSID_PO_3I0_DZZ_N5_13 = 54,
	KIWI_BOSID_PO_KI2_DZDV_N5_14 = 275,
	KIWI_BOSID_PO_ITO_1_A_N7_1 = 55,
	KIWI_BOSID_PO_ITO_1_B_N7_2 = 56,
	KIWI_BOSID_PO_ITO_1_C_N7_3 = 57,
	KIWI_BOSID_PO_ITO_2_A_N7_4 = 58,
	KIWI_BOSID_PO_ITO_2_B_N7_5 = 59,
	KIWI_BOSID_PO_ITO_2_C_N7_6 = 60,
	KIWI_BOSID_PO_IMTZ_1_A_N8_1 = 61,
	KIWI_BOSID_PO_IMTZ_1_B_N8_2 = 62,
	KIWI_BOSID_PO_IMTZ_1_C_N8_3 = 63,
	KIWI_BOSID_PO_IMTZ_1_ZAV_PUSK_A_N8_4 = 64,
	KIWI_BOSID_PO_IMTZ_1_ZAV_PUSK_B_N8_5 = 65,
	KIWI_BOSID_PO_IMTZ_1_ZAV_PUSK_C_N8_6 = 66,
	KIWI_BOSID_PO_IMTZ_1_ZAV_N8_7 = 67,
	KIWI_BOSID_PO_IMTZ_1_GR_A_N8_8 = 70,
	KIWI_BOSID_PO_IMTZ_1_GR_B_N8_9 = 71,
	KIWI_BOSID_PO_IMTZ_1_GR_C_N8_10 = 72,
	KIWI_BOSID_PO_IMTZ_2_A_N9_1 = 79,
	KIWI_BOSID_PO_IMTZ_2_B_N9_2 = 80,
	KIWI_BOSID_PO_IMTZ_2_C_N9_3 = 81,
	KIWI_BOSID_PO_IMTZ_2_ZAV_PUSK_A_N9_4 = 82,
	KIWI_BOSID_PO_IMTZ_2_ZAV_PUSK_B_N9_5 = 83,
	KIWI_BOSID_PO_IMTZ_2_ZAV_PUSK_C_N9_6 = 84,
	KIWI_BOSID_PO_IMTZ_2_ZAV_N9_7 = 85,
	KIWI_BOSID_PO_IMTZ_2_GR_A_N9_8 = 88,
	KIWI_BOSID_PO_IMTZ_2_GR_B_N9_9 = 89,
	KIWI_BOSID_PO_IMTZ_2_GR_C_N9_10 = 90,
	KIWI_BOSID_PO_IZP_N10_1 = 97,
	KIWI_BOSID_PO_IZP_ZAV_PUSK_N10_2 = 98,
	KIWI_BOSID_PO_IZP_ZAV_N10_3 = 99,
	KIWI_BOSID_PO_IZDZ_N12_1 = 100,
	KIWI_BOSID_PO_3I0ZDZ_N12_2 = 101,
	KIWI_BOSID_PO_KI2_ZOF_N13_1 = 102,
	KIWI_BOSID_PO_I2_ZOF_N13_2 = 103,
	KIWI_BOSID_PO_RNM_OP_N13_3 = 104,
	KIWI_BOSID_PO_RNM_OP_NEDOST_N13_4 = 105,
	KIWI_BOSID_PO_RNM_OP_PRIAMOE_N13_5 = 106,
	KIWI_BOSID_PO_RNM_OP_OBRATNOE_N13_6 = 107,
	KIWI_BOSID_PO_IOZZ_1_VG_N14_1 = 108,
	KIWI_BOSID_PO_IOZZ_1_N14_2 = 109,
	KIWI_BOSID_PO_UOZZ_1_N14_3 = 110,
	KIWI_BOSID_PO_IOZZ_2_N14_4 = 111,
	KIWI_BOSID_PO_RNM_NP_N14_5 = 112,
	KIWI_BOSID_PO_RNM_NP_NEDOST_N14_6 = 113,
	KIWI_BOSID_PO_RNM_NP_PRIAMOE_N14_7 = 114,
	KIWI_BOSID_PO_RNM_NP_OBRATNOE_N14_8 = 115,
	KIWI_BOSID_PO_UZMN_1_N16_1 = 116,
	KIWI_BOSID_PO_UZMN_2_N16_2 = 117,
	KIWI_BOSID_PO_FZPP_N17_1 = 118,
	KIWI_BOSID_PO_UZPN_1_N18_1 = 119,
	KIWI_BOSID_PO_UZPN_2_N18_2 = 120,
	KIWI_BOSID_PO_IDTO_A_N20_1 = 121,
	KIWI_BOSID_PO_IDTO_B_N20_2 = 122,
	KIWI_BOSID_PO_IDTO_C_N20_3 = 123,
	KIWI_BOSID_PO_DZT_A_N20_4 = 124,
	KIWI_BOSID_PO_DZT_B_N20_5 = 125,
	KIWI_BOSID_PO_DZT_C_N20_6 = 126,
	KIWI_BOSID_PO_DZT_G_A_N20_7 = 127,
	KIWI_BOSID_PO_DZT_G_B_N20_8 = 128,
	KIWI_BOSID_PO_DZT_G_C_N20_9 = 129,
	KIWI_BOSID_PO_IPB_2G_A_N20_10 = 130,
	KIWI_BOSID_PO_IPB_2G_B_N20_11 = 131,
	KIWI_BOSID_PO_IPB_2G_C_N20_12 = 132,
	KIWI_BOSID_PO_IZZP_N21_1 = 133,
	KIWI_BOSID_PO_ITM_PUSK_N22_1 = 134,
	KIWI_BOSID_PO_ETM_PUSK_N22_2 = 135,
	KIWI_BOSID_PO_100_ETM_PUSK_N22_3 = 136,
	KIWI_BOSID_PO_ETM_SIGN_N22_4 = 137,
	KIWI_BOSID_PO_ETM_OTKL_N22_5 = 138,
	KIWI_BOSID_PO_IMIN_TZ_N23_1 = 139,
	KIWI_BOSID_PO_ZZAR_N24_1 = 140,
	KIWI_BOSID_PO_IZAR_N24_2 = 141,
	KIWI_BOSID_PO_I_SF_6_BLOK_N28_1 = 142,
	KIWI_BOSID_PO_IUROV_N29_1 = 143,
	KIWI_BOSID_PO_FACHR_1_N31_1 = 145,
	KIWI_BOSID_PO_DFACHR_1_N31_2 = 146,
	KIWI_BOSID_PO_FACHR_2_N31_3 = 147,
	KIWI_BOSID_PO_FDAR_N31_4 = 148,
	KIWI_BOSID_PO_DF_DAR_N31_5 = 149,
	KIWI_BOSID_PO_FCHAPV_N32_1 = 150,
	KIWI_BOSID_PO_UCHAPV_N32_2 = 151,
	KIWI_BOSID_PO_FACHR_1_1_N33_1 = 152,
	KIWI_BOSID_PO_DFACHR_1_1_N33_2 = 153,
	KIWI_BOSID_PO_FACHR_2_1_N33_3 = 154,
	KIWI_BOSID_PO_FDAR_1_N33_4 = 155,
	KIWI_BOSID_PO_DFDAR_1_N33_5 = 156,
	KIWI_BOSID_PO_FACHR_1_2_N33_6 = 157,
	KIWI_BOSID_PO_DFACHR_1_2_N33_7 = 158,
	KIWI_BOSID_PO_FACHR_2_2_N33_8 = 159,
	KIWI_BOSID_PO_FDAR_2_N33_9 = 160,
	KIWI_BOSID_PO_DFDAR_2_N33_10 = 161,
	KIWI_BOSID_PO_FACHR_1_3_N33_11 = 162,
	KIWI_BOSID_PO_DFACHR_1_3_N33_12 = 163,
	KIWI_BOSID_PO_FACHR_2_3_N33_13 = 164,
	KIWI_BOSID_PO_FDAR_3_N33_14 = 165,
	KIWI_BOSID_PO_DFDAR_3_N33_15 = 166,
	KIWI_BOSID_PO_FACHR_1_4_N33_16 = 167,
	KIWI_BOSID_PO_DFACHR_1_4_N33_17 = 168,
	KIWI_BOSID_PO_FACHR_2_4_N33_18 = 169,
	KIWI_BOSID_PO_FDAR_4_N33_19 = 170,
	KIWI_BOSID_PO_DFDAR_4_N33_20 = 171,
	KIWI_BOSID_PO_FACHR_1_5_N33_21 = 172,
	KIWI_BOSID_PO_DFACHR_1_5_N33_22 = 173,
	KIWI_BOSID_PO_FACHR_2_5_N33_23 = 174,
	KIWI_BOSID_PO_FDAR_5_N33_24 = 175,
	KIWI_BOSID_PO_DFDAR_5_N33_25 = 176,
	KIWI_BOSID_PO_FACHR_1_6_N33_26 = 177,
	KIWI_BOSID_PO_DFACHR_1_6_N33_27 = 178,
	KIWI_BOSID_PO_FACHR_2_6_N33_28 = 179,
	KIWI_BOSID_PO_FDAR_6_N33_29 = 180,
	KIWI_BOSID_PO_DFDAR_6_N33_30 = 181,
	KIWI_BOSID_PO_FACHR_1_7_N33_31 = 182,
	KIWI_BOSID_PO_DFACHR_1_7_N33_32 = 183,
	KIWI_BOSID_PO_FACHR_2_7_N33_33 = 184,
	KIWI_BOSID_PO_FDAR_7_N33_34 = 185,
	KIWI_BOSID_PO_DFDAR_7_N33_35 = 186,
	KIWI_BOSID_PO_FACHR_1_8_N33_36 = 187,
	KIWI_BOSID_PO_DFACHR_1_8_N33_37 = 188,
	KIWI_BOSID_PO_FACHR_2_8_N33_38 = 189,
	KIWI_BOSID_PO_FDAR_8_N33_39 = 190,
	KIWI_BOSID_PO_DFDAR_8_N33_40 = 191,
	KIWI_BOSID_PO_FACHR_1_9_N33_41 = 192,
	KIWI_BOSID_PO_DFACHR_1_9_N33_42 = 193,
	KIWI_BOSID_PO_FACHR_2_9_N33_43 = 194,
	KIWI_BOSID_PO_FDAR_9_N33_44 = 195,
	KIWI_BOSID_PO_DFDAR_9_N33_45 = 196,
	KIWI_BOSID_PO_FCHAPV_1_N34_1 = 197,
	KIWI_BOSID_PO_UCHAPV_1_N34_2 = 198,
	KIWI_BOSID_PO_FCHAPV_2_N34_3 = 199,
	KIWI_BOSID_PO_UCHAPV_2_N34_4 = 200,
	KIWI_BOSID_PO_FCHAPV_3_N34_5 = 201,
	KIWI_BOSID_PO_UCHAPV_3_N34_6 = 202,
	KIWI_BOSID_PO_FCHAPV_4_N34_7 = 203,
	KIWI_BOSID_PO_UCHAPV_4_N34_8 = 204,
	KIWI_BOSID_PO_FCHAPV_5_N34_9 = 205,
	KIWI_BOSID_PO_UCHAPV_5_N34_10 = 206,
	KIWI_BOSID_PO_FCHAPV_6_N34_11 = 207,
	KIWI_BOSID_PO_UCHAPV_6_N34_12 = 208,
	KIWI_BOSID_PO_FCHAPV_7_N34_13 = 209,
	KIWI_BOSID_PO_UCHAPV_7_N34_14 = 210,
	KIWI_BOSID_PO_FCHAPV_8_N34_15 = 211,
	KIWI_BOSID_PO_UCHAPV_8_N34_16 = 212,
	KIWI_BOSID_PO_FCHAPV_9_N34_17 = 213,
	KIWI_BOSID_PO_UCHAPV_9_N34_18 = 214,
	KIWI_BOSID_PO_UAVR_N36_1 = 215,
	KIWI_BOSID_PO_FAVR_N36_2 = 216,
	KIWI_BOSID_PO_UVNR_N37_1 = 217,
	KIWI_BOSID_PO_UKCN5_AB_N47_1 = 218,
	KIWI_BOSID_PO_UKCN55_AB_N47_2 = 219,
	KIWI_BOSID_PO_UKCN110_AB_N47_3 = 220,
	KIWI_BOSID_PO_UKCN5_BC_N47_4 = 221,
	KIWI_BOSID_PO_UKCN55_BC_N47_5 = 222,
	KIWI_BOSID_PO_UKCN110_BC_N47_6 = 223,
	KIWI_BOSID_PO_UKCN45_AB_N47_7 = 224,
	KIWI_BOSID_PO_UKCN90_AB_N47_8 = 225,
	KIWI_BOSID_PO_UKCN45_BC_N47_9 = 226,
	KIWI_BOSID_PO_UKCN90_BC_N47_10 = 227,
	KIWI_BOSID_PO_DUKCN_N47_11 = 228,
	KIWI_BOSID_PO_I2_KCN_N47_12 = 229,
	KIWI_BOSID_PO_INB_A_N48_1 = 230,
	KIWI_BOSID_PO_INB_B_N48_2 = 231,
	KIWI_BOSID_PO_INB_C_N48_3 = 232,
	KIWI_BOSID_PO_IDIF_A_N48_4 = 233,
	KIWI_BOSID_PO_IDIF_B_N48_5 = 234,
	KIWI_BOSID_PO_IDIF_C_N48_6 = 235,
	KIWI_BOSID_PO_ITORM_A_N48_7 = 236,
	KIWI_BOSID_PO_ITORM_B_N48_8 = 237,
	KIWI_BOSID_PO_ITORM_C_N48_9 = 238,
	KIWI_BOSID_PO_DITORM_A_N48_10 = 239,
	KIWI_BOSID_PO_DITORM_B_N48_11 = 240,
	KIWI_BOSID_PO_DITORM_C_N48_12 = 241,
	KIWI_BOSID_PO_I_MAKS_1_N60_1 = 242,
	KIWI_BOSID_PO_I_MAKS_2_N60_2 = 243,
	KIWI_BOSID_PO_I_MAKS_3_N60_3 = 244,
	KIWI_BOSID_PO_I_MIN_1_N60_4 = 245,
	KIWI_BOSID_PO_I_MIN_2_N60_5 = 246,
	KIWI_BOSID_PO_I2_MAKS_1_N60_6 = 247,
	KIWI_BOSID_PO_3I0_MAKS_1_N60_7 = 248,
	KIWI_BOSID_PO_IN_MAKS_1_N60_8 = 249,
	KIWI_BOSID_PO_IN_MAKS_2_N60_9 = 250,
	KIWI_BOSID_PO_IN_MIN_1_N60_10 = 251,
	KIWI_BOSID_PO_IN_MIN_2_N60_11 = 252,
	KIWI_BOSID_PO_U_MAKS_1_N60_12 = 255,
	KIWI_BOSID_PO_U_MAKS_2_N60_13 = 273,
	KIWI_BOSID_PO_U_MIN_1_N60_14 = 253,
	KIWI_BOSID_PO_U_MIN_2_N60_15 = 254,
	KIWI_BOSID_PO_U2_MAKS_1_N60_16 = 256,
	KIWI_BOSID_PO_3U0_MAKS_3_N60_17 = 257,
	KIWI_BOSID_PO_UVST_MAKS_1_N60_18 = 258,
	KIWI_BOSID_PO_IA_NED_N61_1 = 259,
	KIWI_BOSID_PO_IB_NED_N61_2 = 260,
	KIWI_BOSID_PO_IC_NED_N61_3 = 261,
	KIWI_BOSID_PO_3I0_NED_N61_4 = 262,
	KIWI_BOSID_PO_IA_N_NED_N61_5 = 263,
	KIWI_BOSID_PO_IB_N_NED_N61_6 = 264,
	KIWI_BOSID_PO_IC_N_NED_N61_7 = 265,
	KIWI_BOSID_PO_UAB_NED_N61_8 = 266,
	KIWI_BOSID_PO_UBC_NED_N61_9 = 267,
	KIWI_BOSID_PO_UA_NED_N61_10 = 268,
	KIWI_BOSID_PO_UB_NED_N61_11 = 269,
	KIWI_BOSID_PO_UC_NED_N61_12 = 270,
	KIWI_BOSID_PO_3U0_NED_N61_13 = 271,
	KIWI_BOSID_PO_UVST_NED_N61_14 = 272,

	KIWI_BOSID_PO_U_PIT_NORM_N70_1 = 300,
	KIWI_BOSID_PO_U_PIT_PONIJ_N70_2 = 301,
	KIWI_BOSID_PO_U_PIT_ISCHEZ_N70_3 = 302,

	KIWI_BOSID_PO_INVALID_SIGNAL = KIWI_INVALID_ID
} kiwi_FaultDetectorBinaryOutputSignalID;
/*-----------------------------------------------------------------------------------------------*/
/** @brief Тип идентификатора (двоичного) выходного сигнала ДФПО. */
typedef enum kiwi_AFSWBinaryOutputSignalID_TAG
{
	KIWI_AFSW_BOSID_OUTPUT_1 = 0,
	KIWI_AFSW_BOSID_OUTPUT_2 = 1,
	KIWI_AFSW_BOSID_OUTPUT_3 = 2,
	KIWI_AFSW_BOSID_OUTPUT_4 = 3,
	KIWI_AFSW_BOSID_OUTPUT_5 = 4,
	KIWI_AFSW_BOSID_OUTPUT_6 = 5,
	KIWI_AFSW_BOSID_OUTPUT_7 = 6,
	KIWI_AFSW_BOSID_OUTPUT_8 = 7,
	KIWI_AFSW_BOSID_OUTPUT_9 = 8,
	KIWI_AFSW_BOSID_OUTPUT_10 = 9,
	KIWI_AFSW_BOSID_OUTPUT_11 = 10,
	KIWI_AFSW_BOSID_OUTPUT_12 = 11,
	KIWI_AFSW_BOSID_OUTPUT_13 = 12,
	KIWI_AFSW_BOSID_OUTPUT_14 = 13,
	KIWI_AFSW_BOSID_OUTPUT_15 = 14,
	KIWI_AFSW_BOSID_OUTPUT_16 = 15,
	KIWI_AFSW_BOSID_OUTPUT_17 = 16,
	KIWI_AFSW_BOSID_OUTPUT_18 = 17,
	KIWI_AFSW_BOSID_OUTPUT_19 = 18,
	KIWI_AFSW_BOSID_OUTPUT_20 = 19,
	KIWI_AFSW_BOSID_OUTPUT_21 = 20,
	KIWI_AFSW_BOSID_OUTPUT_22 = 21,
	KIWI_AFSW_BOSID_OUTPUT_23 = 22,
	KIWI_AFSW_BOSID_OUTPUT_24 = 23,
	KIWI_AFSW_BOSID_OUTPUT_25 = 24,
	KIWI_AFSW_BOSID_OUTPUT_26 = 25,
	KIWI_AFSW_BOSID_OUTPUT_27 = 26,
	KIWI_AFSW_BOSID_OUTPUT_28 = 27,
	KIWI_AFSW_BOSID_OUTPUT_29 = 28,
	KIWI_AFSW_BOSID_OUTPUT_30 = 29,
	KIWI_AFSW_BOSID_OUTPUT_31 = 30,
	KIWI_AFSW_BOSID_OUTPUT_32 = 31,
	KIWI_AFSW_BOSID_OUTPUT_33 = 32,
	KIWI_AFSW_BOSID_OUTPUT_34 = 33,
	KIWI_AFSW_BOSID_OUTPUT_35 = 34,
	KIWI_AFSW_BOSID_OUTPUT_36 = 35,
	KIWI_AFSW_BOSID_OUTPUT_37 = 36,
	KIWI_AFSW_BOSID_OUTPUT_38 = 37,
	KIWI_AFSW_BOSID_OUTPUT_39 = 38,
	KIWI_AFSW_BOSID_OUTPUT_40 = 39,
	KIWI_AFSW_BOSID_OUTPUT_41 = 40,
	KIWI_AFSW_BOSID_OUTPUT_42 = 41,
	KIWI_AFSW_BOSID_OUTPUT_43 = 42,
	KIWI_AFSW_BOSID_OUTPUT_44 = 43,
	KIWI_AFSW_BOSID_OUTPUT_45 = 44,
	KIWI_AFSW_BOSID_OUTPUT_46 = 45,
	KIWI_AFSW_BOSID_OUTPUT_47 = 46,
	KIWI_AFSW_BOSID_OUTPUT_48 = 47,
	KIWI_AFSW_BOSID_OUTPUT_49 = 48,
	KIWI_AFSW_BOSID_OUTPUT_50 = 49,
	KIWI_AFSW_BOSID_OUTPUT_51 = 50,
	KIWI_AFSW_BOSID_OUTPUT_52 = 51,
	KIWI_AFSW_BOSID_OUTPUT_53 = 52,
	KIWI_AFSW_BOSID_OUTPUT_54 = 53,
	KIWI_AFSW_BOSID_OUTPUT_55 = 54,
	KIWI_AFSW_BOSID_OUTPUT_56 = 55,
	KIWI_AFSW_BOSID_OUTPUT_57 = 56,
	KIWI_AFSW_BOSID_OUTPUT_58 = 57,
	KIWI_AFSW_BOSID_OUTPUT_59 = 58,
	KIWI_AFSW_BOSID_OUTPUT_60 = 59,
	KIWI_AFSW_BOSID_OUTPUT_61 = 60,
	KIWI_AFSW_BOSID_OUTPUT_62 = 61,
	KIWI_AFSW_BOSID_OUTPUT_63 = 62,
	KIWI_AFSW_BOSID_OUTPUT_64 = 63,

	KIWI_AFSW_BOSID_INVALID_SIGNAL = KIWI_INVALID_ID
} kiwi_AFSWBinaryOutputSignalID;
/*-----------------------------------------------------------------------------------------------*/
/** @brief Тип идентификатора светодиода. */
typedef enum kiwi_LEDID_TAG
{
	KIWI_LED_1 = 0,
	KIWI_LED_2 = 1,
	KIWI_LED_3 = 2,
	KIWI_LED_4 = 3,
	KIWI_LED_5 = 4,
	KIWI_LED_6 = 5,
	KIWI_LED_7 = 6,
	KIWI_LED_8 = 7,
	KIWI_LED_9 = 8,
	KIWI_LED_10 = 9,
	KIWI_LED_11 = 10,
	KIWI_LED_12 = 11,
	KIWI_LED_13 = 12,
	KIWI_LED_14 = 13,

	KIWI_INVALID_LED_ID = KIWI_INVALID_ID
} kiwi_LEDID;

/*-----------------------------------------------------------------------------------------------*/
/** @brief Тип идентификатора аналогового входного сигнала. */
typedef enum kiwi_AnalogInputSignalID_TAG
{
	KIWI_AISID_IA = 0,
	KIWI_AISID_IB = 1,
	KIWI_AISID_IC = 2,
	KIWI_AISID_3I0 = 3,
	KIWI_AISID_IA_N = 4,
	KIWI_AISID_IB_N = 5,
	KIWI_AISID_IC_N = 6,
	KIWI_AISID_UAB = 7,
	KIWI_AISID_UBC = 8,
	KIWI_AISID_UA = 9,
	KIWI_AISID_UB = 10,
	KIWI_AISID_3U0 = 11,
	KIWI_AISID_UVST = 12,
	KIWI_AISID_UC = 13,
	KIWI_AISID_U_PWR = 14,
	KIWI_AISID_U_CAP = 15,

	KIWI_AISID_INVALID_SIGNAL = KIWI_INVALID_ID
} kiwi_AnalogInputSignalID;
/*-----------------------------------------------------------------------------------------------*/
/** @brief Тип идентификатора аналогового выходного сигнала. */
typedef enum kiwi_AnalogOutputSignalID_TAG
{
	KIWI_AOSID_IA = 0,
	KIWI_AOSID_IB = 1,
	KIWI_AOSID_IC = 2,
	KIWI_AOSID_3I0 = 3,
	KIWI_AOSID_IA_N = 4,
	KIWI_AOSID_IB_N = 5,
	KIWI_AOSID_IC_N = 6,
	KIWI_AOSID_UA = 7,
	KIWI_AOSID_UB = 8,
	KIWI_AOSID_UC = 9,
	KIWI_AOSID_UAB = 10,
	KIWI_AOSID_UBC = 11,
	KIWI_AOSID_UCA = 12,
	KIWI_AOSID_UVST = 13,
	KIWI_AOSID_3U0 = 14,
	KIWI_AOSID_3U0_RASCH = 15,
	KIWI_AOSID_IAB = 16,
	KIWI_AOSID_IBC = 17,
	KIWI_AOSID_ICA = 18,
	KIWI_AOSID_IA0 = 19,
	KIWI_AOSID_IB0 = 20,
	KIWI_AOSID_IC0 = 21,
	KIWI_AOSID_IA_SKZ = 22,
	KIWI_AOSID_IB_SKZ = 23,
	KIWI_AOSID_IC_SKZ = 24,
	KIWI_AOSID_I1 = 25,
	KIWI_AOSID_I2 = 26,
	KIWI_AOSID_I2_DIV_I1 = 27,
	KIWI_AOSID_I1_AVAR = 28,
	KIWI_AOSID_I2_AVAR = 29,
	KIWI_AOSID_3I0_RASCH = 30,
	KIWI_AOSID_3I0_VG = 31,
	KIWI_AOSID_U1 = 32,
	KIWI_AOSID_U2 = 33,
	KIWI_AOSID_DU = 34,
	KIWI_AOSID_UBC_IA = 35,
	KIWI_AOSID_UCA_IB = 36,
	KIWI_AOSID_UAB_IC = 37,
	KIWI_AOSID_3U0_3I0 = 38,
	KIWI_AOSID_R1 = 39,
	KIWI_AOSID_X1 = 40,
	KIWI_AOSID_Z1 = 41,
	KIWI_AOSID_RAB = 42,
	KIWI_AOSID_RBC = 43,
	KIWI_AOSID_RCA = 44,
	KIWI_AOSID_XAB = 45,
	KIWI_AOSID_XBC = 46,
	KIWI_AOSID_XCA = 47,
	KIWI_AOSID_RA0 = 48,
	KIWI_AOSID_RB0 = 49,
	KIWI_AOSID_RC0 = 50,
	KIWI_AOSID_XA0 = 51,
	KIWI_AOSID_XB0 = 52,
	KIWI_AOSID_XC0 = 53,
	KIWI_AOSID_P = 54,
	KIWI_AOSID_Q = 55,
	KIWI_AOSID_S = 56,
	KIWI_AOSID_COS_PHY = 57,
	KIWI_AOSID_IE = 58,
	KIWI_AOSID_E = 59,
	KIWI_AOSID_F = 60,
	KIWI_AOSID_DF = 61,
	KIWI_AOSID_IDIF_A = 62,
	KIWI_AOSID_IDIF_B = 63,
	KIWI_AOSID_IDIF_C = 64,
	KIWI_AOSID_ITORM_A = 65,
	KIWI_AOSID_ITORM_B = 66,
	KIWI_AOSID_ITORM_C = 67,
	KIWI_AOSID_IDIF2G_A = 68,
	KIWI_AOSID_IDIF2G_B = 69,
	KIWI_AOSID_IDIF2G_C = 70,
	KIWI_AOSID_KI2G_A = 71,
	KIWI_AOSID_KI2G_B = 72,
	KIWI_AOSID_KI2G_C = 73,
	KIWI_AOSID_DITORM_A = 74,
	KIWI_AOSID_DITORM_B = 75,
	KIWI_AOSID_DITORM_C = 76,
	KIWI_AOSID_I_MAKS = 77,
	KIWI_AOSID_I_N_MAKS = 78,
	KIWI_AOSID_I_MIN = 79,
	KIWI_AOSID_I_N_MIN = 80,
	KIWI_AOSID_I_SKZ_MAKS = 81,
	KIWI_AOSID_U_MAKS = 82,
	KIWI_AOSID_U_MIN = 83,
	KIWI_AOSID_IB_RASCH = 84,
	KIWI_AOSID_IR_MAKS = 85,
	KIWI_AOSID_U_PWR = 86,
	KIWI_AOSID_U_PWR_CAP = 87,
	KIWI_AOSID_RE_IA = 100,
	KIWI_AOSID_IM_IA = 101,
	KIWI_AOSID_RE_IB = 102,
	KIWI_AOSID_IM_IB = 103,
	KIWI_AOSID_RE_IB_RASCH = 104,
	KIWI_AOSID_IM_IB_RASCH = 105,
	KIWI_AOSID_RE_IC = 106,
	KIWI_AOSID_IM_IC = 107,
	KIWI_AOSID_RE_3I0 = 108,
	KIWI_AOSID_IM_3I0 = 109,
	KIWI_AOSID_RE_IA_N = 110,
	KIWI_AOSID_IM_IA_N = 111,
	KIWI_AOSID_RE_IB_N = 112,
	KIWI_AOSID_IM_IB_N = 113,
	KIWI_AOSID_RE_IC_N = 114,
	KIWI_AOSID_IM_IC_N = 115,
	KIWI_AOSID_RE_UA = 116,
	KIWI_AOSID_IM_UA = 117,
	KIWI_AOSID_RE_UB = 118,
	KIWI_AOSID_IM_UB = 119,
	KIWI_AOSID_RE_UC = 120,
	KIWI_AOSID_IM_UC = 121,
	KIWI_AOSID_RE_UAB = 122,
	KIWI_AOSID_IM_UAB = 123,
	KIWI_AOSID_RE_UBC = 124,
	KIWI_AOSID_IM_UBC = 125,
	KIWI_AOSID_RE_UCA = 126,
	KIWI_AOSID_IM_UCA = 127,
	KIWI_AOSID_RE_UVST = 128,
	KIWI_AOSID_IM_UVST = 129,
	KIWI_AOSID_RE_3U0 = 130,
	KIWI_AOSID_IM_3U0 = 131,
	KIWI_AOSID_RE_3U0_RASCH = 132,
	KIWI_AOSID_IM_3U0_RASCH = 133,
	KIWI_AOSID_RE_U1 = 134,
	KIWI_AOSID_IM_U1 = 135,
	KIWI_AOSID_RE_I1 = 136,
	KIWI_AOSID_IM_I1 = 137,
	KIWI_AOSID_RE_U2 = 138,
	KIWI_AOSID_IM_U2 = 139,
	KIWI_AOSID_RE_I2 = 140,
	KIWI_AOSID_IM_I2 = 141,
	KIWI_AOSID_FIND = 142,
	KIWI_AOSID_N_OKP = 143,
	KIWI_AOSID_N_OKP_GOR = 144,
	KIWI_AOSID_N_OKP_HOL = 145,
	KIWI_AOSID_E_PUSK = 146,
	KIWI_AOSID_TM_T_VKL = 147,
	KIWI_AOSID_TM_T_OTKL = 148,
	KIWI_AOSID_CNT_TEK_RES = 149,
	KIWI_AOSID_CNT_SW_XX = 150,
	KIWI_AOSID_CNT_SW_NORM = 151,
	KIWI_AOSID_CNT_SW_FAULT = 152,
	KIWI_AOSID_CNT_SW_SUM = 153,

	KIWI_AOSID_DT = 160,
	KIWI_AOSID_NS = 161,
	KIWI_AOSID_T_OLD = 162,
	KIWI_AOSID_CH = 163,
	KIWI_AOSID_CTR_START = 164,
	KIWI_AOSID_CTR_T_CYCLE = 165,
	KIWI_AOSID_CTR_FRATE = 166,
	KIWI_AOSID_DELTA_A = 167,
	KIWI_AOSID_DELTA_T = 168,
	KIWI_AOSID_DFAZA = 169,
	KIWI_AOSID_FCALC = 170,
	KIWI_AOSID_FRATE = 171,
	KIWI_AOSID_FRATECALC = 172,
	KIWI_AOSID_FAZA = 173,
	KIWI_AOSID_NT = 174,
	KIWI_AOSID_T = 175,
	KIWI_AOSID_T_CALC = 176,
	KIWI_AOSID_ELMETER_P_TOTAL = 177,
	KIWI_AOSID_ELMETER_Q_TOTAL = 178,
	KIWI_AOSID_ELMETER_S_TOTAL = 179,
	KIWI_AOSID_ELMETER_P_CURRENT_DAY = 180,
	KIWI_AOSID_ELMETER_Q_CURRENT_DAY = 181,
	KIWI_AOSID_ELMETER_P_CURRENT_MONTH = 182,
	KIWI_AOSID_ELMETER_Q_CURRENT_MONTH = 183,
	KIWI_AOSID_ELMETER_P_PREVIOUS_DAY = 184,
	KIWI_AOSID_ELMETER_Q_PREVIOUS_DAY = 185,
	KIWI_AOSID_ELMETER_P_PREVIOUS_MONTH = 186,
	KIWI_AOSID_ELMETER_Q_PREVIOUS_MONTH = 187,

	KIWI_AOSID_INVALID_SIGNAL = KIWI_INVALID_ID
} kiwi_AnalogOutputSignalID;
/*-----------------------------------------------------------------------------------------------*/
/** @brief Тип идентификатора события, используемый в базе данных KIWI. */
typedef enum kiwi_EventID_TAG
{
	KIWI_EID_PUSK_DZ_PERVOJ_STUPENI = 1,
	KIWI_EID_PUSK_DZ_VTOROJ_STUPENI = 2,
	KIWI_EID_PUSK_DZ_TRETIEJ_STUPENI = 3,
	KIWI_EID_PUSK_DZ_CHETVERTOJ_STUPENI = 4,
	KIWI_EID_SRABATYVANIE_DZ_PERVOJ_STUPENI = 5,
	KIWI_EID_SRABATYVANIE_DZ_VTOROJ_STUPENI = 6,
	KIWI_EID_SRABATYVANIE_DZ_TRETIEJ_STUPENI = 7,
	KIWI_EID_SRABATYVANIE_DZ_CHETVERTOJ_STUPENI = 8,
	KIWI_EID_SRABATYVANIE_USKORENNOJ_DZ = 9,
	KIWI_EID_PUSK_DZDV_PERVOJ_STUPENI = 10,
	KIWI_EID_PUSK_DZDV_VTOROJ_STUPENI = 11,
	KIWI_EID_PUSK_DZDV_TRETIEJ_STUPENI = 12,
	KIWI_EID_PUSK_DZDV_CHETVERTOJ_STUPENI = 13,
	KIWI_EID_SRABATYVANIE_DZDV_PERVOJ_STUPENI = 14,
	KIWI_EID_SRABATYVANIE_DZDV_VTOROJ_STUPENI = 15,
	KIWI_EID_SRABATYVANIE_DZDV_TRETIEJ_STUPENI = 16,
	KIWI_EID_SRABATYVANIE_DZDV_CHETVERTOJ_STUPENI = 17,
	KIWI_EID_SRABATYVANIE_USKORENNOJ_DZDV = 18,
	KIWI_EID_PUSK_TO_1 = 19,
	KIWI_EID_SRABATYVANIE_TO_1 = 20,
	KIWI_EID_PUSK_TO_2 = 21,
	KIWI_EID_SRABATYVANIE_TO_2 = 22,
	KIWI_EID_PUSK_MTZ_1 = 23,
	KIWI_EID_SRABATYVANIE_MTZ_1 = 24,
	KIWI_EID_SRABATYVANIE_USKORENNOJ_MTZ_1 = 25,
	KIWI_EID_PUSK_MTZ_2 = 26,
	KIWI_EID_SRABATYVANIE_MTZ_2 = 27,
	KIWI_EID_SRABATYVANIE_USKORENNOJ_MTZ_2 = 28,
	KIWI_EID_PUSK_ZASHCHITY_OT_PEREGRUZKI = 29,
	KIWI_EID_PEREGRUZKA_SIGNAL = 30,
	KIWI_EID_PEREGRUZKA_OTKLUCHENIE = 31,
	KIWI_EID_SRABATYVANIE_RAZGRUZKI_1_OCHEREDI = 32,
	KIWI_EID_SRABATYVANIE_RAZGRUZKI_2_OCHEREDI = 33,
	KIWI_EID_PUSK_LZSH = 34,
	KIWI_EID_SRABATYVANIE_LZSH = 35,
	KIWI_EID_LZSH_1_NEISPRAVNOST = 36,
	KIWI_EID_LZSH_2_NEISPRAVNOST = 37,
	KIWI_EID_SRABATYVANIE_ZDZ = 38,
	KIWI_EID_NEISPRAVNOST_ZDZ = 39,
	KIWI_EID_PUSK_ZOF = 40,
	KIWI_EID_SIGNALIZACIJA_ZOF = 41,
	KIWI_EID_OTKLUCHENIE_ZOF = 42,
	KIWI_EID_PUSK_OZZ_1 = 43,
	KIWI_EID_SIGNALIZACIJA_OZZ_1 = 44,
	KIWI_EID_OTKLUCHENIE_OZZ_1 = 45,
	KIWI_EID_PUSK_OZZ_2 = 46,
	KIWI_EID_SRABATYVANIE_OZZ_2 = 47,
	KIWI_EID_PUSK_ZMN_1 = 48,
	KIWI_EID_SRABATYVANIE_ZMN_1 = 49,
	KIWI_EID_PUSK_ZMN_2 = 50,
	KIWI_EID_SRABATYVANIE_ZMN_2 = 51,
	KIWI_EID_ZMN_OTKLUCHENIE = 52,
	KIWI_EID_PUSK_ZPP = 53,
	KIWI_EID_SRABATYVANIE_ZPP = 54,
	KIWI_EID_SRABATYVANIE_ZPP_NA_OTKLUCHENIE = 55,
	KIWI_EID_PUSK_ZPN_1 = 56,
	KIWI_EID_SRABATYVANIE_ZPN_1 = 57,
	KIWI_EID_PUSK_ZPN_2 = 58,
	KIWI_EID_SRABATYVANIE_ZPN_2 = 59,
	KIWI_EID_ZPN_OTKLUCHENIE = 60,
	KIWI_EID_SRABATYVANIE_DTO = 61,
	KIWI_EID_PUSK_DZT = 62,
	KIWI_EID_SRABATYVANIE_DZT = 63,
	KIWI_EID_PUSK_ZZP = 64,
	KIWI_EID_SIGNALIZACIJA_ZZP = 65,
	KIWI_EID_OTKLUCHENIE_ZZP = 66,
	KIWI_EID_PUSK_ZBR = 67,
	KIWI_EID_SIGNALIZACIJA_ZBR = 68,
	KIWI_EID_OTKLUCHENIE_ZBR = 69,
	KIWI_EID_TIAZHELYJ_PUSK = 70,
	KIWI_EID_SIGNALIZACIJA_PEREGREVA_1 = 71,
	KIWI_EID_SIGNALIZACIJA_PEREGREVA_2 = 72,
	KIWI_EID_OTKLUCHENIE_PO_PEREGREVU = 73,
	KIWI_EID_PUSK_MIN_TZ = 74,
	KIWI_EID_SIGNALIZACIJA_MIN_TZ = 75,
	KIWI_EID_OTKLUCHENIE_MIN_TZ = 76,
	KIWI_EID_PUSK_ZAR = 77,
	KIWI_EID_SIGNALIZACIJA_ZAR = 78,
	KIWI_EID_OTKLUCHENIE_ZAR = 79,
	KIWI_EID_OSTANOV_SMAZKI_PODSHIPNIKOV = 80,
	KIWI_EID_OSTANOV_VOZDUSHNOGO_OHLAZHDENIJA = 81,
	KIWI_EID_OSTANOV_VODIANOGO_OHLAZHDENIJA = 82,
	KIWI_EID_SNIZHENIJE_POTOKA_OHLAZHDAJUSHCHEJ_VODY = 83,
	KIWI_EID_VODA_V_KORPUSE_DVIGATELIA = 84,
	KIWI_EID_ZAPRET_POSLEDUJUSHCHIH_PUSKOV = 85,
	KIWI_EID_OTKLUCHENIE_PRI_POTERE_SF_Q = 86,
	KIWI_EID_POTERIA_SF_Q = 87,
	KIWI_EID_POTERIA_SF_TT = 88,
	KIWI_EID_OTKLUCHENIE_PRI_POTERE_SF_TT = 89,
	KIWI_EID_SRABATYVANIE_UROV = 90,
	KIWI_EID_PUSK_ACHR_1 = 91,
	KIWI_EID_SRABATYVANIE_ACHR_1 = 92,
	KIWI_EID_PUSK_ACHR_2 = 93,
	KIWI_EID_SRABATYVANIE_ACHR_2 = 94,
	KIWI_EID_PUSK_DAR = 95,
	KIWI_EID_SRABATYVANIE_DAR = 96,
	KIWI_EID_PUSK_ACHR_VNESHNIJ = 97,
	KIWI_EID_SRABATYVANIE_ACHR_VNESHNEE = 98,
	KIWI_EID_PUSK_CHAPV = 99,
	KIWI_EID_SRABATYVANIE_CHAPV = 100,
	KIWI_EID_PUSK_CHAPV_VNESHNIJ = 101,
	KIWI_EID_SRABATYVANIE_CHAPV_VNESHNEE = 102,
	KIWI_EID_PUSK_ACHR_1_PERVOJ_OCHEREDI = 103,
	KIWI_EID_SRABATYVANIE_ACHR_1_PERVOJ_OCHEREDI = 104,
	KIWI_EID_PUSK_ACHR_2_PERVOJ_OCHEREDI = 105,
	KIWI_EID_SRABATYVANIE_ACHR_2_PERVOJ_OCHEREDI = 106,
	KIWI_EID_PUSK_DAR_PERVOJ_OCHEREDI = 107,
	KIWI_EID_SRABATYVANIE_DAR_PERVOJ_OCHEREDI = 108,
	KIWI_EID_PUSK_ACHR_1_VTOROJ_OCHEREDI = 109,
	KIWI_EID_SRABATYVANIE_ACHR_1_VTOROJ_OCHEREDI = 110,
	KIWI_EID_PUSK_ACHR_2_VTOROJ_OCHEREDI = 111,
	KIWI_EID_SRABATYVANIE_ACHR_2_VTOROJ_OCHEREDI = 112,
	KIWI_EID_PUSK_DAR_VTOROJ_OCHEREDI = 113,
	KIWI_EID_SRABATYVANIE_DAR_VTOROJ_OCHEREDI = 114,
	KIWI_EID_PUSK_ACHR_1_TRETIEJ_OCHEREDI = 115,
	KIWI_EID_SRABATYVANIE_ACHR_1_TRETIEJ_OCHEREDI = 116,
	KIWI_EID_PUSK_ACHR_2_TRETIEJ_OCHEREDI = 117,
	KIWI_EID_SRABATYVANIE_ACHR_2_TRETIEJ_OCHEREDI = 118,
	KIWI_EID_PUSK_DAR_TRETIEJ_OCHEREDI = 119,
	KIWI_EID_SRABATYVANIE_DAR_TRETIEJ_OCHEREDI = 120,
	KIWI_EID_PUSK_ACHR_1_CHETVERTOJ_OCHEREDI = 121,
	KIWI_EID_SRABATYVANIE_ACHR_1_CHETVERTOJ_OCHEREDI = 122,
	KIWI_EID_PUSK_ACHR_2_CHETVERTOJ_OCHEREDI = 123,
	KIWI_EID_SRABATYVANIE_ACHR_2_CHETVERTOJ_OCHEREDI = 124,
	KIWI_EID_PUSK_DAR_CHETVERTOJ_OCHEREDI = 125,
	KIWI_EID_SRABATYVANIE_DAR_CHETVERTOJ_OCHEREDI = 126,
	KIWI_EID_PUSK_ACHR_1_PIATOJ_OCHEREDI = 127,
	KIWI_EID_SRABATYVANIE_ACHR_1_PIATOJ_OCHEREDI = 128,
	KIWI_EID_PUSK_ACHR_2_PIATOJ_OCHEREDI = 129,
	KIWI_EID_SRABATYVANIE_ACHR_2_PIATOJ_OCHEREDI = 130,
	KIWI_EID_PUSK_DAR_PIATOJ_OCHEREDI = 131,
	KIWI_EID_SRABATYVANIE_DAR_PIATOJ_OCHEREDI = 132,
	KIWI_EID_PUSK_ACHR_1_SHESTOJ_OCHEREDI = 133,
	KIWI_EID_SRABATYVANIE_ACHR_1_SHESTOJ_OCHEREDI = 134,
	KIWI_EID_PUSK_ACHR_2_SHESTOJ_OCHEREDI = 135,
	KIWI_EID_SRABATYVANIE_ACHR_2_SHESTOJ_OCHEREDI = 136,
	KIWI_EID_PUSK_DAR_SHESTOJ_OCHEREDI = 137,
	KIWI_EID_SRABATYVANIE_DAR_SHESTOJ_OCHEREDI = 138,
	KIWI_EID_PUSK_ACHR_1_SEDMOJ_OCHEREDI = 139,
	KIWI_EID_SRABATYVANIE_ACHR_1_SEDMOJ_OCHEREDI = 140,
	KIWI_EID_PUSK_ACHR_2_SEDMOJ_OCHEREDI = 141,
	KIWI_EID_SRABATYVANIE_ACHR_2_SEDMOJ_OCHEREDI = 142,
	KIWI_EID_PUSK_DAR_SEDMOJ_OCHEREDI = 143,
	KIWI_EID_SRABATYVANIE_DAR_SEDMOJ_OCHEREDI = 144,
	KIWI_EID_PUSK_ACHR_1_VOSMOJ_OCHEREDI = 145,
	KIWI_EID_SRABATYVANIE_ACHR_1_VOSMOJ_OCHEREDI = 146,
	KIWI_EID_PUSK_ACHR_2_VOSMOJ_OCHEREDI = 147,
	KIWI_EID_SRABATYVANIE_ACHR_2_VOSMOJ_OCHEREDI = 148,
	KIWI_EID_PUSK_DAR_VOSMOJ_OCHEREDI = 149,
	KIWI_EID_SRABATYVANIE_DAR_VOSMOJ_OCHEREDI = 150,
	KIWI_EID_PUSK_ACHR_1_DEVIATOJ_OCHEREDI = 151,
	KIWI_EID_SRABATYVANIE_ACHR_1_DEVIATOJ_OCHEREDI = 152,
	KIWI_EID_PUSK_ACHR_2_DEVIATOJ_OCHEREDI = 153,
	KIWI_EID_SRABATYVANIE_ACHR_2_DEVIATOJ_OCHEREDI = 154,
	KIWI_EID_PUSK_DAR_DEVIATOJ_OCHEREDI = 155,
	KIWI_EID_SRABATYVANIE_DAR_DEVIATOJ_OCHEREDI = 156,
	KIWI_EID_SRABATYVANIE_CHAPV_PERVOJ_OCHEREDI = 157,
	KIWI_EID_PUSK_CHAPV_PERVOJ_OCHEREDI = 158,
	KIWI_EID_SRABATYVANIE_CHAPV_VTOROJ_OCHEREDI = 159,
	KIWI_EID_PUSK_CHAPV_VTOROJ_OCHEREDI = 160,
	KIWI_EID_SRABATYVANIE_CHAPV_TRETIEJ_OCHEREDI = 161,
	KIWI_EID_PUSK_CHAPV_TRETIEJ_OCHEREDI = 162,
	KIWI_EID_SRABATYVANIE_CHAPV_CHETVERTOJ_OCHEREDI = 163,
	KIWI_EID_PUSK_CHAPV_CHETVERTOJ_OCHEREDI = 164,
	KIWI_EID_SRABATYVANIE_CHAPV_PIATOJ_OCHEREDI = 165,
	KIWI_EID_PUSK_CHAPV_PIATOJ_OCHEREDI = 166,
	KIWI_EID_SRABATYVANIE_CHAPV_SHESTOJ_OCHEREDI = 167,
	KIWI_EID_PUSK_CHAPV_SHESTOJ_OCHEREDI = 168,
	KIWI_EID_SRABATYVANIE_CHAPV_SEDMOJ_OCHEREDI = 169,
	KIWI_EID_PUSK_CHAPV_SEDMOJ_OCHEREDI = 170,
	KIWI_EID_SRABATYVANIE_CHAPV_VOSMOJ_OCHEREDI = 171,
	KIWI_EID_PUSK_CHAPV_VOSMOJ_OCHEREDI = 172,
	KIWI_EID_SRABATYVANIE_CHAPV_DEVIATOJ_OCHEREDI = 173,
	KIWI_EID_PUSK_CHAPV_DEVIATOJ_OCHEREDI = 174,
	KIWI_EID_PUSK_AVR = 175,
	KIWI_EID_SRABATYVANIE_AVR_NA_OTKLUCHENIE_VV = 176,
	KIWI_EID_SRABATYVANIE_AVR_NA_VKLUCHENIE_SV = 177,
	KIWI_EID_PUSK_VNR = 178,
	KIWI_EID_SRABATYVANIE_VNR_NA_VKLUCHENIE_VV = 179,
	KIWI_EID_SRABATYVANIE_VNR_NA_OTKLUCHENIE_SV = 180,
	KIWI_EID_VNR_NEUSPESHNOE = 181,
	KIWI_EID_VNR_USPESHNOE = 182,
	KIWI_EID_KOMANDA_OPERATIVNOGO_VKLUCHENIJA = 183,
	KIWI_EID_KOMANDA_OPERATIVNOGO_OTKLUCHENIJA = 184,
	KIWI_EID_VKLUCHENIE_VYKLUCHATELIA = 185,
	KIWI_EID_NEUSPESHNAJA_POPYTKA_VKLUCHENIJA = 186,
	KIWI_EID_VKLUCHENIE_VYKLUCHATELIA_S_KS = 187,
	KIWI_EID_NEUSPESHNAJA_POPYTKA_VKLUCHENIJA_S_KS = 188,
	KIWI_EID_OTKLUCHENIE_VYKLUCHATELIA = 189,
	KIWI_EID_SRABATYVANIE_ZASHCHITY_EV_EO_1 = 190,
	KIWI_EID_SRABATYVANIE_ZASHCHITY_EO_2 = 191,
	KIWI_EID_AVARIJNOE_OTKLUCHENIE = 192,
	KIWI_EID_PUSK_APV_SHIN = 193,
	KIWI_EID_PUSK_APV_1 = 194,
	KIWI_EID_PUSK_APV_2 = 195,
	KIWI_EID_SRABATYVANIE_APV = 196,
	KIWI_EID_APV_1_NEUSPESHNOE = 197,
	KIWI_EID_APV_1_USPESHNOE = 198,
	KIWI_EID_APV_2_NEUSPESHNOE = 199,
	KIWI_EID_APV_2_USPESHNOE = 200,
	KIWI_EID_NEISPRAVNOST_VYKLUCHATELIA = 201,
	KIWI_EID_AVARIA_SHINKI_PITANIA = 202,
	KIWI_EID_PRUZHINA_NE_ZAVEDENA = 203,
	KIWI_EID_NIZKAJA_T_POLUSOV = 204,
	KIWI_EID_NEISPRAVNOST_CEPEJ_UPRAVLENIA = 205,
	KIWI_EID_NEUSPESHNOE_VKLUCHENIE = 206,
	KIWI_EID_NEUSPESHNOE_OTKLUCHENIE = 207,
	KIWI_EID_NEISPRAVNOST_CEPEJ_NAPRIAZHENIJA = 208,
	KIWI_EID_NEBALANS_FAZA_A = 209,
	KIWI_EID_NEBALANS_FAZA_B = 210,
	KIWI_EID_NEBALANS_FAZA_C = 211,
	KIWI_EID_NEISPRAVNOST_CEPEJ_TOKA_FAZY_A = 212,
	KIWI_EID_NEISPRAVNOST_CEPEJ_TOKA_FAZY_B = 213,
	KIWI_EID_NEISPRAVNOST_CEPEJ_TOKA_FAZY_C = 214,
	KIWI_EID_AVARIJNAJA_SIGNALIZACIJA = 215,
	KIWI_EID_PREDUPREDITELNAJA_SIGNALIZACIJA = 216,
	KIWI_EID_OSTANOV_SP = 217,
	KIWI_EID_OSTANOV_VOZD_OHL = 218,
	KIWI_EID_OSTANOV_VOD_OHL = 219,
	KIWI_EID_SF6_Q_2_ST = 220,
	KIWI_EID_SF6_Q_1_ST = 221,
	KIWI_EID_SF6_TT_2_ST = 222,
	KIWI_EID_SF6_TT_1_ST = 223,
	KIWI_EID_PUSK_UROV_VNESH = 224,
	KIWI_EID_ACHR = 225,
	KIWI_EID_CHAPV = 226,
	KIWI_EID_PUSK_AVR_VNESH = 227,
	KIWI_EID_VNESHNIJ_VKL = 228,
	KIWI_EID_DZSH_NA_OTKL = 229,
	KIWI_EID_OTKL_OT_UROV = 230,
	KIWI_EID_OTKL_SV_PO_VNR = 231,
	KIWI_EID_VNESHNIJ_OTKL = 232,
	KIWI_EID_VNESH_ZASHCH = 233,
	KIWI_EID_PUSK_APVSH_VNESH = 234,
	KIWI_EID_PUSK_APV_VNESH = 235,
	KIWI_EID_USER_EVENT_1,
	KIWI_EID_USER_EVENT_2,
	KIWI_EID_USER_EVENT_3,
	KIWI_EID_USER_EVENT_4,
	KIWI_EID_USER_EVENT_5,
	KIWI_EID_USER_EVENT_6,
	KIWI_EID_USER_EVENT_7,
	KIWI_EID_USER_EVENT_8,
	KIWI_EID_USER_EVENT_9,
	KIWI_EID_USER_EVENT_10,
	KIWI_EID_USER_EVENT_11,
	KIWI_EID_USER_EVENT_12,
	KIWI_EID_USER_EVENT_13,
	KIWI_EID_USER_EVENT_14,
	KIWI_EID_USER_EVENT_15,
	KIWI_EID_USER_EVENT_16,
	KIWI_EID_USER_EVENT_17,
	KIWI_EID_USER_EVENT_18,
	KIWI_EID_USER_EVENT_19,
	KIWI_EID_USER_EVENT_20,
	KIWI_EID_USER_EVENT_21,
	KIWI_EID_USER_EVENT_22,
	KIWI_EID_USER_EVENT_23,
	KIWI_EID_USER_EVENT_24,
	KIWI_EID_USER_EVENT_25,
	KIWI_EID_USER_EVENT_26,
	KIWI_EID_USER_EVENT_27,
	KIWI_EID_USER_EVENT_28,
	KIWI_EID_USER_EVENT_29,
	KIWI_EID_USER_EVENT_30,
	KIWI_EID_USER_EVENT_31,
	KIWI_EID_USER_EVENT_32,
	KIWI_EID_USER_EVENT_33,
	KIWI_EID_USER_EVENT_34,
	KIWI_EID_USER_EVENT_35,
	KIWI_EID_USER_EVENT_36,
	KIWI_EID_USER_EVENT_37,
	KIWI_EID_USER_EVENT_38,
	KIWI_EID_USER_EVENT_39,
	KIWI_EID_USER_EVENT_40,
	KIWI_EID_USER_EVENT_41,
	KIWI_EID_USER_EVENT_42,
	KIWI_EID_USER_EVENT_43,
	KIWI_EID_USER_EVENT_44,
	KIWI_EID_USER_EVENT_45,
	KIWI_EID_USER_EVENT_46,
	KIWI_EID_USER_EVENT_47,
	KIWI_EID_USER_EVENT_48,
	KIWI_EID_USER_EVENT_49,
	KIWI_EID_USER_EVENT_50,
	KIWI_EID_USER_EVENT_51,
	KIWI_EID_USER_EVENT_52,
	KIWI_EID_USER_EVENT_53,
	KIWI_EID_USER_EVENT_54,
	KIWI_EID_USER_EVENT_55,
	KIWI_EID_USER_EVENT_56,
	KIWI_EID_USER_EVENT_57,
	KIWI_EID_USER_EVENT_58,
	KIWI_EID_USER_EVENT_59,
	KIWI_EID_USER_EVENT_60,
	KIWI_EID_USER_EVENT_61,
	KIWI_EID_USER_EVENT_62,
	KIWI_EID_USER_EVENT_63,
	KIWI_EID_USER_EVENT_64,
	KIWI_EID_USER_EVENT_65,
	KIWI_EID_USER_EVENT_66,
	KIWI_EID_USER_EVENT_67,
	KIWI_EID_USER_EVENT_68,
	KIWI_EID_USER_EVENT_69,
	KIWI_EID_USER_EVENT_70,
	KIWI_EID_USER_EVENT_71,
	KIWI_EID_USER_EVENT_72,
	KIWI_EID_USER_EVENT_73,
	KIWI_EID_USER_EVENT_74,
	KIWI_EID_USER_EVENT_75,
	KIWI_EID_USER_EVENT_76,
	KIWI_EID_USER_EVENT_77,
	KIWI_EID_USER_EVENT_78,
	KIWI_EID_USER_EVENT_79,
	KIWI_EID_USER_EVENT_80,
	KIWI_EID_USER_EVENT_81,
	KIWI_EID_USER_EVENT_82,
	KIWI_EID_USER_EVENT_83,
	KIWI_EID_USER_EVENT_84,
	KIWI_EID_USER_EVENT_85,
	KIWI_EID_USER_EVENT_86,
	KIWI_EID_USER_EVENT_87,
	KIWI_EID_USER_EVENT_88,
	KIWI_EID_USER_EVENT_89,
	KIWI_EID_USER_EVENT_90,
	KIWI_EID_USER_EVENT_91,
	KIWI_EID_USER_EVENT_92,
	KIWI_EID_USER_EVENT_93,
	KIWI_EID_USER_EVENT_94,
	KIWI_EID_USER_EVENT_95,
	KIWI_EID_USER_EVENT_96,
	KIWI_EID_USER_EVENT_97,
	KIWI_EID_USER_EVENT_98,
	KIWI_EID_USER_EVENT_99,
	KIWI_EID_USER_EVENT_100,

	KIWI_EID_INVALID_EVENT = KIWI_INVALID_ID
} kiwi_EventID;
/*-----------------------------------------------------------------------------------------------*/
/** @brief Тип идентификатора накопителя. */
typedef enum kiwi_AccumulatorID_TAG
{
	KIWI_CID_DZ_1_SRAB = 0,
	KIWI_CID_DZ_2_SRAB = 1,
	KIWI_CID_DZ_3_SRAB = 2,
	KIWI_CID_DZ_4_SRAB = 3,
	KIWI_CID_UDZ_SRAB = 4,
	KIWI_CID_DZDV_1_SRAB = 5,
	KIWI_CID_DZDV_2_SRAB = 6,
	KIWI_CID_DZDV_3_SRAB = 7,
	KIWI_CID_DZDV_4_SRAB = 8,
	KIWI_CID_UDZDV_SRAB = 9,
	KIWI_CID_TO_1_SRAB = 12,
	KIWI_CID_TO_2_SRAB = 13,
	KIWI_CID_MTZ_1_SRAB = 14,
	KIWI_CID_UMTZ_1_SRAB = 15,
	KIWI_CID_MTZ_2_SRAB = 16,
	KIWI_CID_UMTZ_2_SRAB = 17,
	KIWI_CID_PEREGRUZKA = 18,
	KIWI_CID_PEREGRUZKA_NA_OTKL = 19,
	KIWI_CID_RAZGRUZKA_1 = 20,
	KIWI_CID_RAZGRUZKA_2 = 21,
	KIWI_CID_LZSH_NA_OTKL = 22,
	KIWI_CID_ZDZ_NA_OTKL = 23,
	KIWI_CID_ZOF_NA_SIGN = 24,
	KIWI_CID_ZOF_NA_OTKL = 25,
	KIWI_CID_OZZ_1_NA_SIGN = 26,
	KIWI_CID_OZZ_1_NA_OTKL = 27,
	KIWI_CID_OZZ_2_NA_OTKL = 28,
	KIWI_CID_ZMN_1_SRAB = 29,
	KIWI_CID_ZMN_2_SRAB = 30,
	KIWI_CID_ZPP_SRAB = 31,
	KIWI_CID_ZPN_1_SRAB = 32,
	KIWI_CID_ZPN_2_SRAB = 33,
	KIWI_CID_DTO_A_SRAB = 34,
	KIWI_CID_DTO_B_SRAB = 35,
	KIWI_CID_DTO_C_SRAB = 36,
	KIWI_CID_DZT_A_SRAB = 37,
	KIWI_CID_DZT_B_SRAB = 38,
	KIWI_CID_DZT_C_SRAB = 39,
	KIWI_CID_ZZP_NA_SIGN = 40,
	KIWI_CID_ZZP_NA_OTKL = 41,
	KIWI_CID_ZBR_NA_SIGN = 42,
	KIWI_CID_ZBR_NA_OTKL = 43,
	KIWI_CID_TIAZHELYJ_PUSK = 44,
	KIWI_CID_TM_1_NA_SIGN = 45,
	KIWI_CID_TM_2_NA_SIGN = 46,
	KIWI_CID_TM_2_NA_OTKL = 47,
	KIWI_CID_MIN_TZ_NA_SIGN = 48,
	KIWI_CID_MIN_TZ_NA_OTKL = 49,
	KIWI_CID_ZAR_NA_SIGN = 50,
	KIWI_CID_ZAR_NA_OTKL = 51,
	KIWI_CID_VZ_SP = 80,
	KIWI_CID_VZ_VOZD_OHL = 81,
	KIWI_CID_VZ_VOD_OHL = 82,
	KIWI_CID_VS_VOD_OHL = 83,
	KIWI_CID_VS_VODA_V_KORP = 84,
	KIWI_CID_OKP_DLIT = 85,
	KIWI_CID_OKP_MP = 86,
	KIWI_CID_OKP_GP = 87,
	KIWI_CID_OKP_HP = 88,
	KIWI_CID_SF6_Q_NA_OTKL = 89,
	KIWI_CID_POTERIA_SF6_Q = 90,
	KIWI_CID_POTERIA_SF6_TT = 91,
	KIWI_CID_SF6_TT_NA_OTKL = 92,
	KIWI_CID_UROV_SRAB = 93,
	KIWI_CID_ACHR_1_SRAB = 94,
	KIWI_CID_ACHR_2_SRAB = 95,
	KIWI_CID_DAR_SRAB = 96,
	KIWI_CID_ACHR_DV_SRAB = 97,
	KIWI_CID_CHAPV_F_SRAB = 98,
	KIWI_CID_CHAPV_DV_SRAB = 99,
	KIWI_CID_ACHR_1_SRAB_1_OCH = 100,
	KIWI_CID_ACHR_2_SRAB_1_OCH = 101,
	KIWI_CID_DAR_SRAB_1_OCH = 102,
	KIWI_CID_ACHR_1_SRAB_2_OCH = 103,
	KIWI_CID_ACHR_2_SRAB_2_OCH = 104,
	KIWI_CID_DAR_SRAB_2_OCH = 105,
	KIWI_CID_ACHR_1_SRAB_3_OCH = 106,
	KIWI_CID_ACHR_2_SRAB_3_OCH = 107,
	KIWI_CID_DAR_SRAB_3_OCH = 108,
	KIWI_CID_ACHR_1_SRAB_4_OCH = 109,
	KIWI_CID_ACHR_2_SRAB_4_OCH = 110,
	KIWI_CID_DAR_SRAB_4_OCH = 111,
	KIWI_CID_ACHR_1_SRAB_5_OCH = 112,
	KIWI_CID_ACHR_2_SRAB_5_OCH = 113,
	KIWI_CID_DAR_SRAB_5_OCH = 114,
	KIWI_CID_ACHR_1_SRAB_6_OCH = 115,
	KIWI_CID_ACHR_2_SRAB_6_OCH = 116,
	KIWI_CID_DAR_SRAB_6_OCH = 117,
	KIWI_CID_ACHR_1_SRAB_7_OCH = 118,
	KIWI_CID_ACHR_2_SRAB_7_OCH = 119,
	KIWI_CID_DAR_SRAB_7_OCH = 120,
	KIWI_CID_ACHR_1_SRAB_8_OCH = 121,
	KIWI_CID_ACHR_2_SRAB_8_OCH = 122,
	KIWI_CID_DAR_SRAB_8_OCH = 123,
	KIWI_CID_ACHR_1_SRAB_9_OCH = 124,
	KIWI_CID_ACHR_2_SRAB_9_OCH = 125,
	KIWI_CID_DAR_SRAB_9_OCH = 126,
	KIWI_CID_CHAPV_SRAB_1_OCH = 127,
	KIWI_CID_CHAPV_SRAB_2_OCH = 128,
	KIWI_CID_CHAPV_SRAB_3_OCH = 129,
	KIWI_CID_CHAPV_SRAB_4_OCH = 130,
	KIWI_CID_CHAPV_SRAB_5_OCH = 131,
	KIWI_CID_CHAPV_SRAB_6_OCH = 132,
	KIWI_CID_CHAPV_SRAB_7_OCH = 133,
	KIWI_CID_CHAPV_SRAB_8_OCH = 134,
	KIWI_CID_CHAPV_SRAB_9_OCH = 135,
	KIWI_CID_RABOTA_AVR = 136,
	KIWI_CID_RABOTA_VNR = 137,
	KIWI_CID_VNR_NEUSPESHNOE = 138,
	KIWI_CID_VNR_USPESHNOE = 139,
	KIWI_CID_OPERATIVNOE_VKL = 140,
	KIWI_CID_OPERATIVNOE_OTKL = 141,
	KIWI_CID_VKLUCHIT = 142,
	KIWI_CID_OTKLUCHIT = 143,
	KIWI_CID_ZASHCH_EV_EO_1 = 144,
	KIWI_CID_ZASHCH_EO_2 = 145,
	KIWI_CID_AVARIJNOE_OTKL = 146,
	KIWI_CID_NS = 147,
	KIWI_CID_APV_NA_VKL = 148,
	KIWI_CID_APV_1_NEUSPESHNOE = 149,
	KIWI_CID_APV_1_USPESHNOE = 150,
	KIWI_CID_APV_2_NEUSPESHNOE = 151,
	KIWI_CID_APV_2_USPESHNOE = 152,
	KIWI_CID_KCN_NA_SIGN = 153,
	KIWI_CID_NB_A_SRAB = 154,
	KIWI_CID_NB_B_SRAB = 155,
	KIWI_CID_NB_C_SRAB = 156,
	KIWI_CID_KCT_A_SRAB = 157,
	KIWI_CID_KCT_B_SRAB = 158,
	KIWI_CID_KCT_C_SRAB = 159,
	KIWI_CID_AVARIJNAJA_SIGN = 160,
	KIWI_CID_PREDUPR_SIGN = 161,

	KIWI_CID_MOTOCHASY = 52,
	KIWI_CID_KOLICHESTVO_VKLUCHENIJ = 53,

	/**
	 * @brief &mdash; количество ошибок при приёме ЦП данных от ПВВ базового блока по синхронному
	 *                интерфейсу;
	 */
	KIWI_CID_CPU_FROM_BASE_IOP_SYNC = 60,

	/**
	 * @brief &mdash; количество ошибок при приёме ПВВ базового блока данных от ЦП по синхронному
	 *                интерфейсу;
	 */
	KIWI_CID_BASE_IOP_FROM_CPU_SYNC = 61,

	/**
	 * @brief &mdash; количество ошибок при приёме ЦП данных от ПВВ базового блока по асинхронному
	 *                интерфейсу;
	 */
	KIWI_CID_CPU_FROM_BASE_IOP_ASYNC = 62,

	/**
	 * @brief &mdash; количество ошибок при приёме ПВВ базового блока данных от ЦП по асинхронному
	 *                интерфейсу;
	 */
	KIWI_CID_BASE_IOP_FROM_CPU_ASYNC = 63,

	/** @brief &mdash; количество ошибок при приёме ПВВ базового блока данных от ПВВ доп. модуля; */
	KIWI_CID_BASE_IOP_FROM_AUX_IOP = 64,

	/** @brief &mdash; количество ошибок при приёме ПВВ доп. модуля данных от ПВВ базового блока; */
	KIWI_CID_AUX_IOP_FROM_BASE_IOP = 65,

	/** @brief &mdash; количество ошибок при приёме ЦП данных от КП; */
	KIWI_CID_CPU_FROM_COM_P = 66,

	/** @brief &mdash; количество ошибок при приёме КП данных от ЦП; */
	KIWI_CID_COM_P_FROM_CPU = 67,

	/** @brief &mdash; количество ошибок при приёме ЦП данных от пульта; */
	KIWI_CID_CPU_FROM_CONTROL_PANEL = 68,

	/** @brief &mdash; количество ошибок при приёме пультом данных от ЦП; */
	KIWI_CID_CONTROL_PANEL_FROM_CPU = 69,

	/**
	 * @brief &mdash; количество ошибок при приёме данных КП базового блока по 1-му каналу MODBUS;
	 */
	KIWI_CID_MODBUS_1 = 70,

	/**
	 * @brief &mdash; количество ошибок при приёме данных КП базового блока по 2-му каналу MODBUS;
	 */
	KIWI_CID_MODBUS_2 = 71,

	/** @brief &mdash; Nотп; */
	KIWI_CID_N_OTP = 72,

	/** @brief &mdash; Ресурс РПН; */
	KIWI_CID_RESURS_RPN = 73,

	/** @brief &mdash; Ресурс РПН нагр. */
	KIWI_CID_RESURS_RPN_NAGR = 74,

	KIWI_CID_INVALID_ACCUMULATOR = KIWI_INVALID_ID
} kiwi_AccumulatorID;
/*-----------------------------------------------------------------------------------------------*/

/*@}*/

#ifdef __cplusplus
}
#endif

#endif /* APPLICATION_USER_BFSOFTWARE_BZP_KIWIDATABASEIDS_H_ */
